##
# File:    PdbxSchemaDef.py  (Version 4)
# Author:  J. Westbrook
# Date:    12-Jan-2013
# Version: 0.001 Initial version
#
# Updates:
#
# 15-Jan-2013 jdw - simplify index for table NDB_STRUCT_NA_BASE_PAIR_STEP
# 16-Jan-2012 jdw - converted from revised schema with updated field width data
#  5-Jul-2017 jdw - add pdb_entry table -
#
#                   *** This file is going to be generally obsolete with V5 -
##
"""
Database schema definitions for PDBx data categories populated in model files.

"""
__docformat__ = "restructuredtext en"
__author__ = "John Westbrook"
__email__ = "jwest@rcsb.rutgers.edu"
__license__ = "Creative Commons Attribution 3.0 Unported"
__version__ = "V0.001"

import sys
from wwpdb.utils.db.SchemaDefBase import SchemaDefBase


class PdbxSchemaDef(SchemaDefBase):
    """ A data class containing schema definitions PDBx data categories populated in model files.
    """
    _databaseName = "pdbxv4"
    _schemaDefDict = {
        'ATOM_SITE': {'ATTRIBUTES': {'ADP_TYPE': 'adp_type',
                                     'ANISO_B_1_1': 'aniso_B_1_1',
                                     'ANISO_B_1_1_ESD': 'aniso_B_1_1_esd',
                                     'ANISO_B_1_2': 'aniso_B_1_2',
                                     'ANISO_B_1_2_ESD': 'aniso_B_1_2_esd',
                                     'ANISO_B_1_3': 'aniso_B_1_3',
                                     'ANISO_B_1_3_ESD': 'aniso_B_1_3_esd',
                                     'ANISO_B_2_2': 'aniso_B_2_2',
                                     'ANISO_B_2_2_ESD': 'aniso_B_2_2_esd',
                                     'ANISO_B_2_3': 'aniso_B_2_3',
                                     'ANISO_B_2_3_ESD': 'aniso_B_2_3_esd',
                                     'ANISO_B_3_3': 'aniso_B_3_3',
                                     'ANISO_B_3_3_ESD': 'aniso_B_3_3_esd',
                                     'ANISO_RATIO': 'aniso_ratio',
                                     'ANISO_U_1_1': 'aniso_U_1_1',
                                     'ANISO_U_1_1_ESD': 'aniso_U_1_1_esd',
                                     'ANISO_U_1_2': 'aniso_U_1_2',
                                     'ANISO_U_1_2_ESD': 'aniso_U_1_2_esd',
                                     'ANISO_U_1_3': 'aniso_U_1_3',
                                     'ANISO_U_1_3_ESD': 'aniso_U_1_3_esd',
                                     'ANISO_U_2_2': 'aniso_U_2_2',
                                     'ANISO_U_2_2_ESD': 'aniso_U_2_2_esd',
                                     'ANISO_U_2_3': 'aniso_U_2_3',
                                     'ANISO_U_2_3_ESD': 'aniso_U_2_3_esd',
                                     'ANISO_U_3_3': 'aniso_U_3_3',
                                     'ANISO_U_3_3_ESD': 'aniso_U_3_3_esd',
                                     'ATTACHED_HYDROGENS': 'attached_hydrogens',
                                     'AUTH_ASYM_ID': 'auth_asym_id',
                                     'AUTH_ATOM_ID': 'auth_atom_id',
                                     'AUTH_COMP_ID': 'auth_comp_id',
                                     'AUTH_SEQ_ID': 'auth_seq_id',
                                     'B_EQUIV_GEOM_MEAN': 'B_equiv_geom_mean',
                                     'B_EQUIV_GEOM_MEAN_ESD': 'B_equiv_geom_mean_esd',
                                     'B_ISO_OR_EQUIV': 'B_iso_or_equiv',
                                     'B_ISO_OR_EQUIV_ESD': 'B_iso_or_equiv_esd',
                                     'CALC_ATTACHED_ATOM': 'calc_attached_atom',
                                     'CALC_FLAG': 'calc_flag',
                                     'CARTN_X': 'Cartn_x',
                                     'CARTN_X_ESD': 'Cartn_x_esd',
                                     'CARTN_Y': 'Cartn_y',
                                     'CARTN_Y_ESD': 'Cartn_y_esd',
                                     'CARTN_Z': 'Cartn_z',
                                     'CARTN_Z_ESD': 'Cartn_z_esd',
                                     'CHEMICAL_CONN_NUMBER': 'chemical_conn_number',
                                     'CONSTRAINTS': 'constraints',
                                     'DETAILS': 'details',
                                     'DISORDER_ASSEMBLY': 'disorder_assembly',
                                     'DISORDER_GROUP': 'disorder_group',
                                     'FOOTNOTE_ID': 'footnote_id',
                                     'FRACT_X': 'fract_x',
                                     'FRACT_X_ESD': 'fract_x_esd',
                                     'FRACT_Y': 'fract_y',
                                     'FRACT_Y_ESD': 'fract_y_esd',
                                     'FRACT_Z': 'fract_z',
                                     'FRACT_Z_ESD': 'fract_z_esd',
                                     'GROUP_PDB': 'group_PDB',
                                     'ID': 'id',
                                     'LABEL_ALT_ID': 'label_alt_id',
                                     'LABEL_ASYM_ID': 'label_asym_id',
                                     'LABEL_ATOM_ID': 'label_atom_id',
                                     'LABEL_COMP_ID': 'label_comp_id',
                                     'LABEL_ENTITY_ID': 'label_entity_id',
                                     'LABEL_SEQ_ID': 'label_seq_id',
                                     'OCCUPANCY': 'occupancy',
                                     'OCCUPANCY_ESD': 'occupancy_esd',
                                     'PDBX_AUTH_ALT_ID': 'pdbx_auth_alt_id',
                                     'PDBX_AUTH_ASYM_ID': 'pdbx_auth_asym_id',
                                     'PDBX_AUTH_ATOM_NAME': 'pdbx_auth_atom_name',
                                     'PDBX_AUTH_COMP_ID': 'pdbx_auth_comp_id',
                                     'PDBX_AUTH_SEQ_ID': 'pdbx_auth_seq_id',
                                     'PDBX_FORMAL_CHARGE': 'pdbx_formal_charge',
                                     'PDBX_NCS_DOM_ID': 'pdbx_ncs_dom_id',
                                     'PDBX_PDB_ATOM_NAME': 'pdbx_PDB_atom_name',
                                     'PDBX_PDB_INS_CODE': 'pdbx_PDB_ins_code',
                                     'PDBX_PDB_MODEL_NUM': 'pdbx_PDB_model_num',
                                     'PDBX_PDB_RESIDUE_NAME': 'pdbx_PDB_residue_name',
                                     'PDBX_PDB_RESIDUE_NO': 'pdbx_PDB_residue_no',
                                     'PDBX_PDB_STRAND_ID': 'pdbx_PDB_strand_id',
                                     'PDBX_STRUCT_GROUP_ID': 'pdbx_struct_group_id',
                                     'PDBX_TLS_GROUP_ID': 'pdbx_tls_group_id',
                                     'REFINEMENT_FLAGS': 'refinement_flags',
                                     'REFINEMENT_FLAGS_ADP': 'refinement_flags_adp',
                                     'REFINEMENT_FLAGS_OCCUPANCY': 'refinement_flags_occupancy',
                                     'REFINEMENT_FLAGS_POSN': 'refinement_flags_posn',
                                     'RESTRAINTS': 'restraints',
                                     'STRUCTURE_ID': 'Structure_ID',
                                     'SYMMETRY_MULTIPLICITY': 'symmetry_multiplicity',
                                     'THERMAL_DISPLACE_TYPE': 'thermal_displace_type',
                                     'TYPE_SYMBOL': 'type_symbol',
                                     'U_EQUIV_GEOM_MEAN': 'U_equiv_geom_mean',
                                     'U_EQUIV_GEOM_MEAN_ESD': 'U_equiv_geom_mean_esd',
                                     'U_ISO_OR_EQUIV': 'U_iso_or_equiv',
                                     'U_ISO_OR_EQUIV_ESD': 'U_iso_or_equiv_esd',
                                     'WYCKOFF_SYMBOL': 'Wyckoff_symbol'},
                      'ATTRIBUTE_INFO': {'ADP_TYPE': {'NULLABLE': True,
                                                      'ORDER': 75,
                                                      'PRECISION': 0,
                                                      'PRIMARY_KEY': False,
                                                      'SQL_TYPE': 'VARCHAR',
                                                      'WIDTH': 10},
                                         'ANISO_B_1_1': {'NULLABLE': True,
                                                         'ORDER': 2,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                         'ANISO_B_1_1_ESD': {'NULLABLE': True,
                                                             'ORDER': 3,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                         'ANISO_B_1_2': {'NULLABLE': True,
                                                         'ORDER': 4,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                         'ANISO_B_1_2_ESD': {'NULLABLE': True,
                                                             'ORDER': 5,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                         'ANISO_B_1_3': {'NULLABLE': True,
                                                         'ORDER': 6,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                         'ANISO_B_1_3_ESD': {'NULLABLE': True,
                                                             'ORDER': 7,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                         'ANISO_B_2_2': {'NULLABLE': True,
                                                         'ORDER': 8,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                         'ANISO_B_2_2_ESD': {'NULLABLE': True,
                                                             'ORDER': 9,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                         'ANISO_B_2_3': {'NULLABLE': True,
                                                         'ORDER': 10,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                         'ANISO_B_2_3_ESD': {'NULLABLE': True,
                                                             'ORDER': 11,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                         'ANISO_B_3_3': {'NULLABLE': True,
                                                         'ORDER': 12,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                         'ANISO_B_3_3_ESD': {'NULLABLE': True,
                                                             'ORDER': 13,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                         'ANISO_RATIO': {'NULLABLE': True,
                                                         'ORDER': 14,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                         'ANISO_U_1_1': {'NULLABLE': True,
                                                         'ORDER': 15,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                         'ANISO_U_1_1_ESD': {'NULLABLE': True,
                                                             'ORDER': 16,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                         'ANISO_U_1_2': {'NULLABLE': True,
                                                         'ORDER': 17,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                         'ANISO_U_1_2_ESD': {'NULLABLE': True,
                                                             'ORDER': 18,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                         'ANISO_U_1_3': {'NULLABLE': True,
                                                         'ORDER': 19,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                         'ANISO_U_1_3_ESD': {'NULLABLE': True,
                                                             'ORDER': 20,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                         'ANISO_U_2_2': {'NULLABLE': True,
                                                         'ORDER': 21,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                         'ANISO_U_2_2_ESD': {'NULLABLE': True,
                                                             'ORDER': 22,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                         'ANISO_U_2_3': {'NULLABLE': True,
                                                         'ORDER': 23,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                         'ANISO_U_2_3_ESD': {'NULLABLE': True,
                                                             'ORDER': 24,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                         'ANISO_U_3_3': {'NULLABLE': True,
                                                         'ORDER': 25,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                         'ANISO_U_3_3_ESD': {'NULLABLE': True,
                                                             'ORDER': 26,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                         'ATTACHED_HYDROGENS': {'NULLABLE': True,
                                                                'ORDER': 27,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'INT',
                                                                'WIDTH': 10},
                                         'AUTH_ASYM_ID': {'NULLABLE': True,
                                                          'ORDER': 28,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 10},
                                         'AUTH_ATOM_ID': {'NULLABLE': True,
                                                          'ORDER': 29,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 6},
                                         'AUTH_COMP_ID': {'NULLABLE': True,
                                                          'ORDER': 30,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 10},
                                         'AUTH_SEQ_ID': {'NULLABLE': True,
                                                         'ORDER': 31,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 10},
                                         'B_EQUIV_GEOM_MEAN': {'NULLABLE': True,
                                                               'ORDER': 32,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                         'B_EQUIV_GEOM_MEAN_ESD': {'NULLABLE': True,
                                                                   'ORDER': 33,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                         'B_ISO_OR_EQUIV': {'NULLABLE': True,
                                                            'ORDER': 34,
                                                            'PRECISION': 6,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'FLOAT',
                                                            'WIDTH': 10},
                                         'B_ISO_OR_EQUIV_ESD': {'NULLABLE': True,
                                                                'ORDER': 35,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                         'CALC_ATTACHED_ATOM': {'NULLABLE': True,
                                                                'ORDER': 36,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                         'CALC_FLAG': {'NULLABLE': True,
                                                       'ORDER': 37,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'VARCHAR',
                                                       'WIDTH': 10},
                                         'CARTN_X': {'NULLABLE': True,
                                                     'ORDER': 38,
                                                     'PRECISION': 6,
                                                     'PRIMARY_KEY': False,
                                                     'SQL_TYPE': 'FLOAT',
                                                     'WIDTH': 10},
                                         'CARTN_X_ESD': {'NULLABLE': True,
                                                         'ORDER': 39,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                         'CARTN_Y': {'NULLABLE': True,
                                                     'ORDER': 40,
                                                     'PRECISION': 6,
                                                     'PRIMARY_KEY': False,
                                                     'SQL_TYPE': 'FLOAT',
                                                     'WIDTH': 10},
                                         'CARTN_Y_ESD': {'NULLABLE': True,
                                                         'ORDER': 41,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                         'CARTN_Z': {'NULLABLE': True,
                                                     'ORDER': 42,
                                                     'PRECISION': 6,
                                                     'PRIMARY_KEY': False,
                                                     'SQL_TYPE': 'FLOAT',
                                                     'WIDTH': 10},
                                         'CARTN_Z_ESD': {'NULLABLE': True,
                                                         'ORDER': 43,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                         'CHEMICAL_CONN_NUMBER': {'NULLABLE': True,
                                                                  'ORDER': 44,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'INT',
                                                                  'WIDTH': 10},
                                         'CONSTRAINTS': {'NULLABLE': True,
                                                         'ORDER': 45,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 80},
                                         'DETAILS': {'NULLABLE': True,
                                                     'ORDER': 46,
                                                     'PRECISION': 0,
                                                     'PRIMARY_KEY': False,
                                                     'SQL_TYPE': 'VARCHAR',
                                                     'WIDTH': 200},
                                         'DISORDER_ASSEMBLY': {'NULLABLE': True,
                                                               'ORDER': 47,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                         'DISORDER_GROUP': {'NULLABLE': True,
                                                            'ORDER': 48,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 10},
                                         'FOOTNOTE_ID': {'NULLABLE': True,
                                                         'ORDER': 49,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 10},
                                         'FRACT_X': {'NULLABLE': True,
                                                     'ORDER': 50,
                                                     'PRECISION': 6,
                                                     'PRIMARY_KEY': False,
                                                     'SQL_TYPE': 'FLOAT',
                                                     'WIDTH': 10},
                                         'FRACT_X_ESD': {'NULLABLE': True,
                                                         'ORDER': 51,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                         'FRACT_Y': {'NULLABLE': True,
                                                     'ORDER': 52,
                                                     'PRECISION': 6,
                                                     'PRIMARY_KEY': False,
                                                     'SQL_TYPE': 'FLOAT',
                                                     'WIDTH': 10},
                                         'FRACT_Y_ESD': {'NULLABLE': True,
                                                         'ORDER': 53,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                         'FRACT_Z': {'NULLABLE': True,
                                                     'ORDER': 54,
                                                     'PRECISION': 6,
                                                     'PRIMARY_KEY': False,
                                                     'SQL_TYPE': 'FLOAT',
                                                     'WIDTH': 10},
                                         'FRACT_Z_ESD': {'NULLABLE': True,
                                                         'ORDER': 55,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                         'GROUP_PDB': {'NULLABLE': True,
                                                       'ORDER': 56,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'VARCHAR',
                                                       'WIDTH': 10},
                                         'ID': {'NULLABLE': False,
                                                'ORDER': 57,
                                                'PRECISION': 0,
                                                'PRIMARY_KEY': True,
                                                'SQL_TYPE': 'VARCHAR',
                                                'WIDTH': 10},
                                         'LABEL_ALT_ID': {'NULLABLE': True,
                                                          'ORDER': 58,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 10},
                                         'LABEL_ASYM_ID': {'NULLABLE': True,
                                                           'ORDER': 59,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 10},
                                         'LABEL_ATOM_ID': {'NULLABLE': True,
                                                           'ORDER': 60,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 6},
                                         'LABEL_COMP_ID': {'NULLABLE': True,
                                                           'ORDER': 61,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 10},
                                         'LABEL_ENTITY_ID': {'NULLABLE': True,
                                                             'ORDER': 62,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 10},
                                         'LABEL_SEQ_ID': {'NULLABLE': True,
                                                          'ORDER': 63,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'INT',
                                                          'WIDTH': 10},
                                         'OCCUPANCY': {'NULLABLE': True,
                                                       'ORDER': 64,
                                                       'PRECISION': 6,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'FLOAT',
                                                       'WIDTH': 10},
                                         'OCCUPANCY_ESD': {'NULLABLE': True,
                                                           'ORDER': 65,
                                                           'PRECISION': 6,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'FLOAT',
                                                           'WIDTH': 10},
                                         'PDBX_AUTH_ALT_ID': {'NULLABLE': True,
                                                              'ORDER': 80,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10},
                                         'PDBX_AUTH_ASYM_ID': {'NULLABLE': True,
                                                               'ORDER': 90,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                         'PDBX_AUTH_ATOM_NAME': {'NULLABLE': True,
                                                                 'ORDER': 87,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 6},
                                         'PDBX_AUTH_COMP_ID': {'NULLABLE': True,
                                                               'ORDER': 89,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                         'PDBX_AUTH_SEQ_ID': {'NULLABLE': True,
                                                              'ORDER': 91,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10},
                                         'PDBX_FORMAL_CHARGE': {'NULLABLE': True,
                                                                'ORDER': 88,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'INT',
                                                                'WIDTH': 10},
                                         'PDBX_NCS_DOM_ID': {'NULLABLE': True,
                                                             'ORDER': 93,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 10},
                                         'PDBX_PDB_ATOM_NAME': {'NULLABLE': True,
                                                                'ORDER': 86,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                         'PDBX_PDB_INS_CODE': {'NULLABLE': True,
                                                               'ORDER': 81,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                         'PDBX_PDB_MODEL_NUM': {'NULLABLE': True,
                                                                'ORDER': 82,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'INT',
                                                                'WIDTH': 10},
                                         'PDBX_PDB_RESIDUE_NAME': {'NULLABLE': True,
                                                                   'ORDER': 84,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 10},
                                         'PDBX_PDB_RESIDUE_NO': {'NULLABLE': True,
                                                                 'ORDER': 83,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                         'PDBX_PDB_STRAND_ID': {'NULLABLE': True,
                                                                'ORDER': 85,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                         'PDBX_STRUCT_GROUP_ID': {'NULLABLE': True,
                                                                  'ORDER': 94,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 100},
                                         'PDBX_TLS_GROUP_ID': {'NULLABLE': True,
                                                               'ORDER': 92,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                         'REFINEMENT_FLAGS': {'NULLABLE': True,
                                                              'ORDER': 76,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10},
                                         'REFINEMENT_FLAGS_ADP': {'NULLABLE': True,
                                                                  'ORDER': 77,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10},
                                         'REFINEMENT_FLAGS_OCCUPANCY': {'NULLABLE': True,
                                                                        'ORDER': 78,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                         'REFINEMENT_FLAGS_POSN': {'NULLABLE': True,
                                                                   'ORDER': 79,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 10},
                                         'RESTRAINTS': {'NULLABLE': True,
                                                        'ORDER': 66,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 200},
                                         'STRUCTURE_ID': {'NULLABLE': False,
                                                          'ORDER': 1,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': True,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 10},
                                         'SYMMETRY_MULTIPLICITY': {'NULLABLE': True,
                                                                   'ORDER': 67,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'INT',
                                                                   'WIDTH': 10},
                                         'THERMAL_DISPLACE_TYPE': {'NULLABLE': True,
                                                                   'ORDER': 68,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 10},
                                         'TYPE_SYMBOL': {'NULLABLE': True,
                                                         'ORDER': 69,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 10},
                                         'U_EQUIV_GEOM_MEAN': {'NULLABLE': True,
                                                               'ORDER': 70,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                         'U_EQUIV_GEOM_MEAN_ESD': {'NULLABLE': True,
                                                                   'ORDER': 71,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                         'U_ISO_OR_EQUIV': {'NULLABLE': True,
                                                            'ORDER': 72,
                                                            'PRECISION': 6,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'FLOAT',
                                                            'WIDTH': 10},
                                         'U_ISO_OR_EQUIV_ESD': {'NULLABLE': True,
                                                                'ORDER': 73,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                         'WYCKOFF_SYMBOL': {'NULLABLE': True,
                                                            'ORDER': 74,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 80}},
                      'ATTRIBUTE_MAP': {'ADP_TYPE': ('atom_site', 'adp_type', None, None),
                                        'ANISO_B_1_1': ('atom_site', 'aniso_B[1][1]', None, None),
                                        'ANISO_B_1_1_ESD': ('atom_site', 'aniso_B[1][1]_esd', None, None),
                                        'ANISO_B_1_2': ('atom_site', 'aniso_B[1][2]', None, None),
                                        'ANISO_B_1_2_ESD': ('atom_site', 'aniso_B[1][2]_esd', None, None),
                                        'ANISO_B_1_3': ('atom_site', 'aniso_B[1][3]', None, None),
                                        'ANISO_B_1_3_ESD': ('atom_site', 'aniso_B[1][3]_esd', None, None),
                                        'ANISO_B_2_2': ('atom_site', 'aniso_B[2][2]', None, None),
                                        'ANISO_B_2_2_ESD': ('atom_site', 'aniso_B[2][2]_esd', None, None),
                                        'ANISO_B_2_3': ('atom_site', 'aniso_B[2][3]', None, None),
                                        'ANISO_B_2_3_ESD': ('atom_site', 'aniso_B[2][3]_esd', None, None),
                                        'ANISO_B_3_3': ('atom_site', 'aniso_B[3][3]', None, None),
                                        'ANISO_B_3_3_ESD': ('atom_site', 'aniso_B[3][3]_esd', None, None),
                                        'ANISO_RATIO': ('atom_site', 'aniso_ratio', None, None),
                                        'ANISO_U_1_1': ('atom_site', 'aniso_U[1][1]', None, None),
                                        'ANISO_U_1_1_ESD': ('atom_site', 'aniso_U[1][1]_esd', None, None),
                                        'ANISO_U_1_2': ('atom_site', 'aniso_U[1][2]', None, None),
                                        'ANISO_U_1_2_ESD': ('atom_site', 'aniso_U[1][2]_esd', None, None),
                                        'ANISO_U_1_3': ('atom_site', 'aniso_U[1][3]', None, None),
                                        'ANISO_U_1_3_ESD': ('atom_site', 'aniso_U[1][3]_esd', None, None),
                                        'ANISO_U_2_2': ('atom_site', 'aniso_U[2][2]', None, None),
                                        'ANISO_U_2_2_ESD': ('atom_site', 'aniso_U[2][2]_esd', None, None),
                                        'ANISO_U_2_3': ('atom_site', 'aniso_U[2][3]', None, None),
                                        'ANISO_U_2_3_ESD': ('atom_site', 'aniso_U[2][3]_esd', None, None),
                                        'ANISO_U_3_3': ('atom_site', 'aniso_U[3][3]', None, None),
                                        'ANISO_U_3_3_ESD': ('atom_site', 'aniso_U[3][3]_esd', None, None),
                                        'ATTACHED_HYDROGENS': ('atom_site', 'attached_hydrogens', None, None),
                                        'AUTH_ASYM_ID': ('atom_site', 'auth_asym_id', None, None),
                                        'AUTH_ATOM_ID': ('atom_site', 'auth_atom_id', None, None),
                                        'AUTH_COMP_ID': ('atom_site', 'auth_comp_id', None, None),
                                        'AUTH_SEQ_ID': ('atom_site', 'auth_seq_id', None, None),
                                        'B_EQUIV_GEOM_MEAN': ('atom_site', 'B_equiv_geom_mean', None, None),
                                        'B_EQUIV_GEOM_MEAN_ESD': ('atom_site', 'B_equiv_geom_mean_esd', None, None),
                                        'B_ISO_OR_EQUIV': ('atom_site', 'B_iso_or_equiv', None, None),
                                        'B_ISO_OR_EQUIV_ESD': ('atom_site', 'B_iso_or_equiv_esd', None, None),
                                        'CALC_ATTACHED_ATOM': ('atom_site', 'calc_attached_atom', None, None),
                                        'CALC_FLAG': ('atom_site', 'calc_flag', None, None),
                                        'CARTN_X': ('atom_site', 'Cartn_x', None, None),
                                        'CARTN_X_ESD': ('atom_site', 'Cartn_x_esd', None, None),
                                        'CARTN_Y': ('atom_site', 'Cartn_y', None, None),
                                        'CARTN_Y_ESD': ('atom_site', 'Cartn_y_esd', None, None),
                                        'CARTN_Z': ('atom_site', 'Cartn_z', None, None),
                                        'CARTN_Z_ESD': ('atom_site', 'Cartn_z_esd', None, None),
                                        'CHEMICAL_CONN_NUMBER': ('atom_site', 'chemical_conn_number', None, None),
                                        'CONSTRAINTS': ('atom_site', 'constraints', None, None),
                                        'DETAILS': ('atom_site', 'details', None, None),
                                        'DISORDER_ASSEMBLY': ('atom_site', 'disorder_assembly', None, None),
                                        'DISORDER_GROUP': ('atom_site', 'disorder_group', None, None),
                                        'FOOTNOTE_ID': ('atom_site', 'footnote_id', None, None),
                                        'FRACT_X': ('atom_site', 'fract_x', None, None),
                                        'FRACT_X_ESD': ('atom_site', 'fract_x_esd', None, None),
                                        'FRACT_Y': ('atom_site', 'fract_y', None, None),
                                        'FRACT_Y_ESD': ('atom_site', 'fract_y_esd', None, None),
                                        'FRACT_Z': ('atom_site', 'fract_z', None, None),
                                        'FRACT_Z_ESD': ('atom_site', 'fract_z_esd', None, None),
                                        'GROUP_PDB': ('atom_site', 'group_PDB', None, None),
                                        'ID': ('atom_site', 'id', None, None),
                                        'LABEL_ALT_ID': ('atom_site', 'label_alt_id', None, None),
                                        'LABEL_ASYM_ID': ('atom_site', 'label_asym_id', None, None),
                                        'LABEL_ATOM_ID': ('atom_site', 'label_atom_id', None, None),
                                        'LABEL_COMP_ID': ('atom_site', 'label_comp_id', None, None),
                                        'LABEL_ENTITY_ID': ('atom_site', 'label_entity_id', None, None),
                                        'LABEL_SEQ_ID': ('atom_site', 'label_seq_id', None, None),
                                        'OCCUPANCY': ('atom_site', 'occupancy', None, None),
                                        'OCCUPANCY_ESD': ('atom_site', 'occupancy_esd', None, None),
                                        'PDBX_AUTH_ALT_ID': ('atom_site', 'pdbx_auth_alt_id', None, None),
                                        'PDBX_AUTH_ASYM_ID': ('atom_site', 'pdbx_auth_asym_id', None, None),
                                        'PDBX_AUTH_ATOM_NAME': ('atom_site', 'pdbx_auth_atom_name', None, None),
                                        'PDBX_AUTH_COMP_ID': ('atom_site', 'pdbx_auth_comp_id', None, None),
                                        'PDBX_AUTH_SEQ_ID': ('atom_site', 'pdbx_auth_seq_id', None, None),
                                        'PDBX_FORMAL_CHARGE': ('atom_site', 'pdbx_formal_charge', None, None),
                                        'PDBX_NCS_DOM_ID': ('atom_site', 'pdbx_ncs_dom_id', None, None),
                                        'PDBX_PDB_ATOM_NAME': ('atom_site', 'pdbx_PDB_atom_name', None, None),
                                        'PDBX_PDB_INS_CODE': ('atom_site', 'pdbx_PDB_ins_code', None, None),
                                        'PDBX_PDB_MODEL_NUM': ('atom_site', 'pdbx_PDB_model_num', None, None),
                                        'PDBX_PDB_RESIDUE_NAME': ('atom_site', 'pdbx_PDB_residue_name', None, None),
                                        'PDBX_PDB_RESIDUE_NO': ('atom_site', 'pdbx_PDB_residue_no', None, None),
                                        'PDBX_PDB_STRAND_ID': ('atom_site', 'pdbx_PDB_strand_id', None, None),
                                        'PDBX_STRUCT_GROUP_ID': ('atom_site', 'pdbx_struct_group_id', None, None),
                                        'PDBX_TLS_GROUP_ID': ('atom_site', 'pdbx_tls_group_id', None, None),
                                        'REFINEMENT_FLAGS': ('atom_site', 'refinement_flags', None, None),
                                        'REFINEMENT_FLAGS_ADP': ('atom_site', 'refinement_flags_adp', None, None),
                                        'REFINEMENT_FLAGS_OCCUPANCY': ('atom_site', 'refinement_flags_occupancy', None, None),
                                        'REFINEMENT_FLAGS_POSN': ('atom_site', 'refinement_flags_posn', None, None),
                                        'RESTRAINTS': ('atom_site', 'restraints', None, None),
                                        'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                        'SYMMETRY_MULTIPLICITY': ('atom_site', 'symmetry_multiplicity', None, None),
                                        'THERMAL_DISPLACE_TYPE': ('atom_site', 'thermal_displace_type', None, None),
                                        'TYPE_SYMBOL': ('atom_site', 'type_symbol', None, None),
                                        'U_EQUIV_GEOM_MEAN': ('atom_site', 'U_equiv_geom_mean', None, None),
                                        'U_EQUIV_GEOM_MEAN_ESD': ('atom_site', 'U_equiv_geom_mean_esd', None, None),
                                        'U_ISO_OR_EQUIV': ('atom_site', 'U_iso_or_equiv', None, None),
                                        'U_ISO_OR_EQUIV_ESD': ('atom_site', 'U_iso_or_equiv_esd', None, None),
                                        'WYCKOFF_SYMBOL': ('atom_site', 'Wyckoff_symbol', None, None)},
                      'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                  's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                      'MAP_MERGE_INDICES': {'atom_site': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                      'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                      'TABLE_ID': 'ATOM_SITE',
                      'TABLE_NAME': 'atom_site',
                      'TABLE_TYPE': 'transactional'},
        'ATOM_SITES': {'ATTRIBUTES': {'CARTN_TRANSFORM_AXES': 'Cartn_transform_axes',
                                      'CARTN_TRANSF_MATRIX_1_1': 'Cartn_transf_matrix_1_1',
                                      'CARTN_TRANSF_MATRIX_1_2': 'Cartn_transf_matrix_1_2',
                                      'CARTN_TRANSF_MATRIX_1_3': 'Cartn_transf_matrix_1_3',
                                      'CARTN_TRANSF_MATRIX_2_1': 'Cartn_transf_matrix_2_1',
                                      'CARTN_TRANSF_MATRIX_2_2': 'Cartn_transf_matrix_2_2',
                                      'CARTN_TRANSF_MATRIX_2_3': 'Cartn_transf_matrix_2_3',
                                      'CARTN_TRANSF_MATRIX_3_1': 'Cartn_transf_matrix_3_1',
                                      'CARTN_TRANSF_MATRIX_3_2': 'Cartn_transf_matrix_3_2',
                                      'CARTN_TRANSF_MATRIX_3_3': 'Cartn_transf_matrix_3_3',
                                      'CARTN_TRANSF_VECTOR_1': 'Cartn_transf_vector_1',
                                      'CARTN_TRANSF_VECTOR_2': 'Cartn_transf_vector_2',
                                      'CARTN_TRANSF_VECTOR_3': 'Cartn_transf_vector_3',
                                      'ENTRY_ID': 'entry_id',
                                      'FRACT_TRANSF_MATRIX_1_1': 'fract_transf_matrix_1_1',
                                      'FRACT_TRANSF_MATRIX_1_2': 'fract_transf_matrix_1_2',
                                      'FRACT_TRANSF_MATRIX_1_3': 'fract_transf_matrix_1_3',
                                      'FRACT_TRANSF_MATRIX_2_1': 'fract_transf_matrix_2_1',
                                      'FRACT_TRANSF_MATRIX_2_2': 'fract_transf_matrix_2_2',
                                      'FRACT_TRANSF_MATRIX_2_3': 'fract_transf_matrix_2_3',
                                      'FRACT_TRANSF_MATRIX_3_1': 'fract_transf_matrix_3_1',
                                      'FRACT_TRANSF_MATRIX_3_2': 'fract_transf_matrix_3_2',
                                      'FRACT_TRANSF_MATRIX_3_3': 'fract_transf_matrix_3_3',
                                      'FRACT_TRANSF_VECTOR_1': 'fract_transf_vector_1',
                                      'FRACT_TRANSF_VECTOR_2': 'fract_transf_vector_2',
                                      'FRACT_TRANSF_VECTOR_3': 'fract_transf_vector_3',
                                      'SOLUTION_HYDROGENS': 'solution_hydrogens',
                                      'SOLUTION_PRIMARY': 'solution_primary',
                                      'SOLUTION_SECONDARY': 'solution_secondary',
                                      'SPECIAL_DETAILS': 'special_details',
                                      'STRUCTURE_ID': 'Structure_ID'},
                       'ATTRIBUTE_INFO': {'CARTN_TRANSFORM_AXES': {'NULLABLE': True,
                                                                   'ORDER': 15,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 200},
                                          'CARTN_TRANSF_MATRIX_1_1': {'NULLABLE': True,
                                                                      'ORDER': 3,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                          'CARTN_TRANSF_MATRIX_1_2': {'NULLABLE': True,
                                                                      'ORDER': 4,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                          'CARTN_TRANSF_MATRIX_1_3': {'NULLABLE': True,
                                                                      'ORDER': 5,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                          'CARTN_TRANSF_MATRIX_2_1': {'NULLABLE': True,
                                                                      'ORDER': 6,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                          'CARTN_TRANSF_MATRIX_2_2': {'NULLABLE': True,
                                                                      'ORDER': 7,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                          'CARTN_TRANSF_MATRIX_2_3': {'NULLABLE': True,
                                                                      'ORDER': 8,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                          'CARTN_TRANSF_MATRIX_3_1': {'NULLABLE': True,
                                                                      'ORDER': 9,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                          'CARTN_TRANSF_MATRIX_3_2': {'NULLABLE': True,
                                                                      'ORDER': 10,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                          'CARTN_TRANSF_MATRIX_3_3': {'NULLABLE': True,
                                                                      'ORDER': 11,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                          'CARTN_TRANSF_VECTOR_1': {'NULLABLE': True,
                                                                    'ORDER': 12,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                          'CARTN_TRANSF_VECTOR_2': {'NULLABLE': True,
                                                                    'ORDER': 13,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                          'CARTN_TRANSF_VECTOR_3': {'NULLABLE': True,
                                                                    'ORDER': 14,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                          'ENTRY_ID': {'NULLABLE': False,
                                                       'ORDER': 2,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': True,
                                                       'SQL_TYPE': 'VARCHAR',
                                                       'WIDTH': 10},
                                          'FRACT_TRANSF_MATRIX_1_1': {'NULLABLE': True,
                                                                      'ORDER': 16,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                          'FRACT_TRANSF_MATRIX_1_2': {'NULLABLE': True,
                                                                      'ORDER': 17,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                          'FRACT_TRANSF_MATRIX_1_3': {'NULLABLE': True,
                                                                      'ORDER': 18,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                          'FRACT_TRANSF_MATRIX_2_1': {'NULLABLE': True,
                                                                      'ORDER': 19,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                          'FRACT_TRANSF_MATRIX_2_2': {'NULLABLE': True,
                                                                      'ORDER': 20,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                          'FRACT_TRANSF_MATRIX_2_3': {'NULLABLE': True,
                                                                      'ORDER': 21,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                          'FRACT_TRANSF_MATRIX_3_1': {'NULLABLE': True,
                                                                      'ORDER': 22,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                          'FRACT_TRANSF_MATRIX_3_2': {'NULLABLE': True,
                                                                      'ORDER': 23,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                          'FRACT_TRANSF_MATRIX_3_3': {'NULLABLE': True,
                                                                      'ORDER': 24,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                          'FRACT_TRANSF_VECTOR_1': {'NULLABLE': True,
                                                                    'ORDER': 25,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                          'FRACT_TRANSF_VECTOR_2': {'NULLABLE': True,
                                                                    'ORDER': 26,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                          'FRACT_TRANSF_VECTOR_3': {'NULLABLE': True,
                                                                    'ORDER': 27,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                          'SOLUTION_HYDROGENS': {'NULLABLE': True,
                                                                 'ORDER': 30,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                          'SOLUTION_PRIMARY': {'NULLABLE': True,
                                                               'ORDER': 28,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                          'SOLUTION_SECONDARY': {'NULLABLE': True,
                                                                 'ORDER': 29,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                          'SPECIAL_DETAILS': {'NULLABLE': True,
                                                              'ORDER': 31,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 200},
                                          'STRUCTURE_ID': {'NULLABLE': False,
                                                           'ORDER': 1,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': True,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 10}},
                       'ATTRIBUTE_MAP': {'CARTN_TRANSFORM_AXES': ('atom_sites', 'Cartn_transform_axes', None, None),
                                         'CARTN_TRANSF_MATRIX_1_1': ('atom_sites', 'Cartn_transf_matrix[1][1]', None, None),
                                         'CARTN_TRANSF_MATRIX_1_2': ('atom_sites', 'Cartn_transf_matrix[1][2]', None, None),
                                         'CARTN_TRANSF_MATRIX_1_3': ('atom_sites', 'Cartn_transf_matrix[1][3]', None, None),
                                         'CARTN_TRANSF_MATRIX_2_1': ('atom_sites', 'Cartn_transf_matrix[2][1]', None, None),
                                         'CARTN_TRANSF_MATRIX_2_2': ('atom_sites', 'Cartn_transf_matrix[2][2]', None, None),
                                         'CARTN_TRANSF_MATRIX_2_3': ('atom_sites', 'Cartn_transf_matrix[2][3]', None, None),
                                         'CARTN_TRANSF_MATRIX_3_1': ('atom_sites', 'Cartn_transf_matrix[3][1]', None, None),
                                         'CARTN_TRANSF_MATRIX_3_2': ('atom_sites', 'Cartn_transf_matrix[3][2]', None, None),
                                         'CARTN_TRANSF_MATRIX_3_3': ('atom_sites', 'Cartn_transf_matrix[3][3]', None, None),
                                         'CARTN_TRANSF_VECTOR_1': ('atom_sites', 'Cartn_transf_vector[1]', None, None),
                                         'CARTN_TRANSF_VECTOR_2': ('atom_sites', 'Cartn_transf_vector[2]', None, None),
                                         'CARTN_TRANSF_VECTOR_3': ('atom_sites', 'Cartn_transf_vector[3]', None, None),
                                         'ENTRY_ID': ('atom_sites', 'entry_id', None, None),
                                         'FRACT_TRANSF_MATRIX_1_1': ('atom_sites', 'fract_transf_matrix[1][1]', None, None),
                                         'FRACT_TRANSF_MATRIX_1_2': ('atom_sites', 'fract_transf_matrix[1][2]', None, None),
                                         'FRACT_TRANSF_MATRIX_1_3': ('atom_sites', 'fract_transf_matrix[1][3]', None, None),
                                         'FRACT_TRANSF_MATRIX_2_1': ('atom_sites', 'fract_transf_matrix[2][1]', None, None),
                                         'FRACT_TRANSF_MATRIX_2_2': ('atom_sites', 'fract_transf_matrix[2][2]', None, None),
                                         'FRACT_TRANSF_MATRIX_2_3': ('atom_sites', 'fract_transf_matrix[2][3]', None, None),
                                         'FRACT_TRANSF_MATRIX_3_1': ('atom_sites', 'fract_transf_matrix[3][1]', None, None),
                                         'FRACT_TRANSF_MATRIX_3_2': ('atom_sites', 'fract_transf_matrix[3][2]', None, None),
                                         'FRACT_TRANSF_MATRIX_3_3': ('atom_sites', 'fract_transf_matrix[3][3]', None, None),
                                         'FRACT_TRANSF_VECTOR_1': ('atom_sites', 'fract_transf_vector[1]', None, None),
                                         'FRACT_TRANSF_VECTOR_2': ('atom_sites', 'fract_transf_vector[2]', None, None),
                                         'FRACT_TRANSF_VECTOR_3': ('atom_sites', 'fract_transf_vector[3]', None, None),
                                         'SOLUTION_HYDROGENS': ('atom_sites', 'solution_hydrogens', None, None),
                                         'SOLUTION_PRIMARY': ('atom_sites', 'solution_primary', None, None),
                                         'SOLUTION_SECONDARY': ('atom_sites', 'solution_secondary', None, None),
                                         'SPECIAL_DETAILS': ('atom_sites', 'special_details', None, None),
                                         'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                       'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID'), 'TYPE': 'UNIQUE'},
                                   's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                       'MAP_MERGE_INDICES': {'atom_sites': {'ATTRIBUTES': ('entry_id',), 'TYPE': 'EQUI-JOIN'}},
                       'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                       'TABLE_ID': 'ATOM_SITES',
                       'TABLE_NAME': 'atom_sites',
                       'TABLE_TYPE': 'transactional'},
        'ATOM_SITES_ALT': {'ATTRIBUTES': {'DETAILS': 'details', 'ID': 'id', 'STRUCTURE_ID': 'Structure_ID'},
                           'ATTRIBUTE_INFO': {'DETAILS': {'NULLABLE': True,
                                                          'ORDER': 2,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 200},
                                              'ID': {'NULLABLE': False,
                                                     'ORDER': 3,
                                                     'PRECISION': 0,
                                                     'PRIMARY_KEY': True,
                                                     'SQL_TYPE': 'VARCHAR',
                                                     'WIDTH': 10},
                                              'STRUCTURE_ID': {'NULLABLE': False,
                                                               'ORDER': 1,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10}},
                           'ATTRIBUTE_MAP': {'DETAILS': ('atom_sites_alt', 'details', None, None),
                                             'ID': ('atom_sites_alt', 'id', None, None),
                                             'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                           'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                       's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                           'MAP_MERGE_INDICES': {'atom_sites_alt': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                           'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                           'TABLE_ID': 'ATOM_SITES_ALT',
                           'TABLE_NAME': 'atom_sites_alt',
                           'TABLE_TYPE': 'transactional'},
        'ATOM_SITES_ALT_ENS': {'ATTRIBUTES': {'DETAILS': 'details', 'ID': 'id', 'STRUCTURE_ID': 'Structure_ID'},
                               'ATTRIBUTE_INFO': {'DETAILS': {'NULLABLE': True,
                                                              'ORDER': 2,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 200},
                                                  'ID': {'NULLABLE': False,
                                                         'ORDER': 3,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': True,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 10},
                                                  'STRUCTURE_ID': {'NULLABLE': False,
                                                                   'ORDER': 1,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': True,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 10}},
                               'ATTRIBUTE_MAP': {'DETAILS': ('atom_sites_alt_ens', 'details', None, None),
                                                 'ID': ('atom_sites_alt_ens', 'id', None, None),
                                                 'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                               'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                           's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                               'MAP_MERGE_INDICES': {'atom_sites_alt_ens': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                               'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                               'TABLE_ID': 'ATOM_SITES_ALT_ENS',
                               'TABLE_NAME': 'atom_sites_alt_ens',
                               'TABLE_TYPE': 'transactional'},
        'ATOM_SITES_ALT_GEN': {'ATTRIBUTES': {'ALT_ID': 'alt_id', 'ENS_ID': 'ens_id', 'STRUCTURE_ID': 'Structure_ID'},
                               'ATTRIBUTE_INFO': {'ALT_ID': {'NULLABLE': False,
                                                             'ORDER': 2,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 10},
                                                  'ENS_ID': {'NULLABLE': False,
                                                             'ORDER': 3,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 10},
                                                  'STRUCTURE_ID': {'NULLABLE': False,
                                                                   'ORDER': 1,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': True,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 10}},
                               'ATTRIBUTE_MAP': {'ALT_ID': ('atom_sites_alt_gen', 'alt_id', None, None),
                                                 'ENS_ID': ('atom_sites_alt_gen', 'ens_id', None, None),
                                                 'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                               'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ALT_ID', 'ENS_ID'), 'TYPE': 'UNIQUE'},
                                           's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                               'MAP_MERGE_INDICES': {'atom_sites_alt_gen': {'ATTRIBUTES': ('alt_id', 'ens_id'),
                                                                            'TYPE': 'EQUI-JOIN'}},
                               'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                               'TABLE_ID': 'ATOM_SITES_ALT_GEN',
                               'TABLE_NAME': 'atom_sites_alt_gen',
                               'TABLE_TYPE': 'transactional'},
        'ATOM_SITES_FOOTNOTE': {'ATTRIBUTES': {'ID': 'id', 'STRUCTURE_ID': 'Structure_ID', 'TEXT': 'text'},
                                'ATTRIBUTE_INFO': {'ID': {'NULLABLE': False,
                                                          'ORDER': 2,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': True,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 10},
                                                   'STRUCTURE_ID': {'NULLABLE': False,
                                                                    'ORDER': 1,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': True,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10},
                                                   'TEXT': {'NULLABLE': True,
                                                            'ORDER': 3,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 511}},
                                'ATTRIBUTE_MAP': {'ID': ('atom_sites_footnote', 'id', None, None),
                                                  'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                  'TEXT': ('atom_sites_footnote', 'text', None, None)},
                                'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                            's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                'MAP_MERGE_INDICES': {'atom_sites_footnote': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                                'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                'TABLE_ID': 'ATOM_SITES_FOOTNOTE',
                                'TABLE_NAME': 'atom_sites_footnote',
                                'TABLE_TYPE': 'transactional'},
        'ATOM_SITE_ANISOTROP': {'ATTRIBUTES': {'B_1_1': 'B_1_1',
                                               'B_1_1_ESD': 'B_1_1_esd',
                                               'B_1_2': 'B_1_2',
                                               'B_1_2_ESD': 'B_1_2_esd',
                                               'B_1_3': 'B_1_3',
                                               'B_1_3_ESD': 'B_1_3_esd',
                                               'B_2_2': 'B_2_2',
                                               'B_2_2_ESD': 'B_2_2_esd',
                                               'B_2_3': 'B_2_3',
                                               'B_2_3_ESD': 'B_2_3_esd',
                                               'B_3_3': 'B_3_3',
                                               'B_3_3_ESD': 'B_3_3_esd',
                                               'ID': 'id',
                                               'PDBX_AUTH_ALT_ID': 'pdbx_auth_alt_id',
                                               'PDBX_AUTH_ASYM_ID': 'pdbx_auth_asym_id',
                                               'PDBX_AUTH_ATOM_ID': 'pdbx_auth_atom_id',
                                               'PDBX_AUTH_COMP_ID': 'pdbx_auth_comp_id',
                                               'PDBX_AUTH_SEQ_ID': 'pdbx_auth_seq_id',
                                               'PDBX_LABEL_ALT_ID': 'pdbx_label_alt_id',
                                               'PDBX_LABEL_ASYM_ID': 'pdbx_label_asym_id',
                                               'PDBX_LABEL_ATOM_ID': 'pdbx_label_atom_id',
                                               'PDBX_LABEL_COMP_ID': 'pdbx_label_comp_id',
                                               'PDBX_LABEL_SEQ_ID': 'pdbx_label_seq_id',
                                               'PDBX_PDB_INS_CODE': 'pdbx_PDB_ins_code',
                                               'RATIO': 'ratio',
                                               'STRUCTURE_ID': 'Structure_ID',
                                               'TYPE_SYMBOL': 'type_symbol',
                                               'U_1_1': 'U_1_1',
                                               'U_1_1_ESD': 'U_1_1_esd',
                                               'U_1_2': 'U_1_2',
                                               'U_1_2_ESD': 'U_1_2_esd',
                                               'U_1_3': 'U_1_3',
                                               'U_1_3_ESD': 'U_1_3_esd',
                                               'U_2_2': 'U_2_2',
                                               'U_2_2_ESD': 'U_2_2_esd',
                                               'U_2_3': 'U_2_3',
                                               'U_2_3_ESD': 'U_2_3_esd',
                                               'U_3_3': 'U_3_3',
                                               'U_3_3_ESD': 'U_3_3_esd'},
                                'ATTRIBUTE_INFO': {'B_1_1': {'NULLABLE': True,
                                                             'ORDER': 3,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                                   'B_1_1_ESD': {'NULLABLE': True,
                                                                 'ORDER': 4,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                                   'B_1_2': {'NULLABLE': True,
                                                             'ORDER': 5,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                                   'B_1_2_ESD': {'NULLABLE': True,
                                                                 'ORDER': 6,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                                   'B_1_3': {'NULLABLE': True,
                                                             'ORDER': 7,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                                   'B_1_3_ESD': {'NULLABLE': True,
                                                                 'ORDER': 8,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                                   'B_2_2': {'NULLABLE': True,
                                                             'ORDER': 9,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                                   'B_2_2_ESD': {'NULLABLE': True,
                                                                 'ORDER': 10,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                                   'B_2_3': {'NULLABLE': True,
                                                             'ORDER': 11,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                                   'B_2_3_ESD': {'NULLABLE': True,
                                                                 'ORDER': 12,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                                   'B_3_3': {'NULLABLE': True,
                                                             'ORDER': 13,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                                   'B_3_3_ESD': {'NULLABLE': True,
                                                                 'ORDER': 14,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                                   'ID': {'NULLABLE': False,
                                                          'ORDER': 2,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': True,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 10},
                                                   'PDBX_AUTH_ALT_ID': {'NULLABLE': True,
                                                                        'ORDER': 30,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                                   'PDBX_AUTH_ASYM_ID': {'NULLABLE': True,
                                                                         'ORDER': 31,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                                   'PDBX_AUTH_ATOM_ID': {'NULLABLE': True,
                                                                         'ORDER': 32,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 6},
                                                   'PDBX_AUTH_COMP_ID': {'NULLABLE': True,
                                                                         'ORDER': 33,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                                   'PDBX_AUTH_SEQ_ID': {'NULLABLE': True,
                                                                        'ORDER': 29,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                                   'PDBX_LABEL_ALT_ID': {'NULLABLE': True,
                                                                         'ORDER': 35,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                                   'PDBX_LABEL_ASYM_ID': {'NULLABLE': True,
                                                                          'ORDER': 36,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                   'PDBX_LABEL_ATOM_ID': {'NULLABLE': True,
                                                                          'ORDER': 37,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 6},
                                                   'PDBX_LABEL_COMP_ID': {'NULLABLE': True,
                                                                          'ORDER': 38,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                   'PDBX_LABEL_SEQ_ID': {'NULLABLE': True,
                                                                         'ORDER': 34,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'INT',
                                                                         'WIDTH': 10},
                                                   'PDBX_PDB_INS_CODE': {'NULLABLE': True,
                                                                         'ORDER': 39,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                                   'RATIO': {'NULLABLE': True,
                                                             'ORDER': 15,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                                   'STRUCTURE_ID': {'NULLABLE': False,
                                                                    'ORDER': 1,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': True,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10},
                                                   'TYPE_SYMBOL': {'NULLABLE': True,
                                                                   'ORDER': 16,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 10},
                                                   'U_1_1': {'NULLABLE': True,
                                                             'ORDER': 17,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                                   'U_1_1_ESD': {'NULLABLE': True,
                                                                 'ORDER': 18,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                                   'U_1_2': {'NULLABLE': True,
                                                             'ORDER': 19,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                                   'U_1_2_ESD': {'NULLABLE': True,
                                                                 'ORDER': 20,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                                   'U_1_3': {'NULLABLE': True,
                                                             'ORDER': 21,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                                   'U_1_3_ESD': {'NULLABLE': True,
                                                                 'ORDER': 22,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                                   'U_2_2': {'NULLABLE': True,
                                                             'ORDER': 23,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                                   'U_2_2_ESD': {'NULLABLE': True,
                                                                 'ORDER': 24,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                                   'U_2_3': {'NULLABLE': True,
                                                             'ORDER': 25,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                                   'U_2_3_ESD': {'NULLABLE': True,
                                                                 'ORDER': 26,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                                   'U_3_3': {'NULLABLE': True,
                                                             'ORDER': 27,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                                   'U_3_3_ESD': {'NULLABLE': True,
                                                                 'ORDER': 28,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10}},
                                'ATTRIBUTE_MAP': {'B_1_1': ('atom_site_anisotrop', 'B[1][1]', None, None),
                                                  'B_1_1_ESD': ('atom_site_anisotrop', 'B[1][1]_esd', None, None),
                                                  'B_1_2': ('atom_site_anisotrop', 'B[1][2]', None, None),
                                                  'B_1_2_ESD': ('atom_site_anisotrop', 'B[1][2]_esd', None, None),
                                                  'B_1_3': ('atom_site_anisotrop', 'B[1][3]', None, None),
                                                  'B_1_3_ESD': ('atom_site_anisotrop', 'B[1][3]_esd', None, None),
                                                  'B_2_2': ('atom_site_anisotrop', 'B[2][2]', None, None),
                                                  'B_2_2_ESD': ('atom_site_anisotrop', 'B[2][2]_esd', None, None),
                                                  'B_2_3': ('atom_site_anisotrop', 'B[2][3]', None, None),
                                                  'B_2_3_ESD': ('atom_site_anisotrop', 'B[2][3]_esd', None, None),
                                                  'B_3_3': ('atom_site_anisotrop', 'B[3][3]', None, None),
                                                  'B_3_3_ESD': ('atom_site_anisotrop', 'B[3][3]_esd', None, None),
                                                  'ID': ('atom_site_anisotrop', 'id', None, None),
                                                  'PDBX_AUTH_ALT_ID': ('atom_site_anisotrop', 'pdbx_auth_alt_id', None, None),
                                                  'PDBX_AUTH_ASYM_ID': ('atom_site_anisotrop',
                                                                        'pdbx_auth_asym_id',
                                                                        None,
                                                                        None),
                                                  'PDBX_AUTH_ATOM_ID': ('atom_site_anisotrop',
                                                                        'pdbx_auth_atom_id',
                                                                        None,
                                                                        None),
                                                  'PDBX_AUTH_COMP_ID': ('atom_site_anisotrop',
                                                                        'pdbx_auth_comp_id',
                                                                        None,
                                                                        None),
                                                  'PDBX_AUTH_SEQ_ID': ('atom_site_anisotrop', 'pdbx_auth_seq_id', None, None),
                                                  'PDBX_LABEL_ALT_ID': ('atom_site_anisotrop',
                                                                        'pdbx_label_alt_id',
                                                                        None,
                                                                        None),
                                                  'PDBX_LABEL_ASYM_ID': ('atom_site_anisotrop',
                                                                         'pdbx_label_asym_id',
                                                                         None,
                                                                         None),
                                                  'PDBX_LABEL_ATOM_ID': ('atom_site_anisotrop',
                                                                         'pdbx_label_atom_id',
                                                                         None,
                                                                         None),
                                                  'PDBX_LABEL_COMP_ID': ('atom_site_anisotrop',
                                                                         'pdbx_label_comp_id',
                                                                         None,
                                                                         None),
                                                  'PDBX_LABEL_SEQ_ID': ('atom_site_anisotrop',
                                                                        'pdbx_label_seq_id',
                                                                        None,
                                                                        None),
                                                  'PDBX_PDB_INS_CODE': ('atom_site_anisotrop',
                                                                        'pdbx_PDB_ins_code',
                                                                        None,
                                                                        None),
                                                  'RATIO': ('atom_site_anisotrop', 'ratio', None, None),
                                                  'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                  'TYPE_SYMBOL': ('atom_site_anisotrop', 'type_symbol', None, None),
                                                  'U_1_1': ('atom_site_anisotrop', 'U[1][1]', None, None),
                                                  'U_1_1_ESD': ('atom_site_anisotrop', 'U[1][1]_esd', None, None),
                                                  'U_1_2': ('atom_site_anisotrop', 'U[1][2]', None, None),
                                                  'U_1_2_ESD': ('atom_site_anisotrop', 'U[1][2]_esd', None, None),
                                                  'U_1_3': ('atom_site_anisotrop', 'U[1][3]', None, None),
                                                  'U_1_3_ESD': ('atom_site_anisotrop', 'U[1][3]_esd', None, None),
                                                  'U_2_2': ('atom_site_anisotrop', 'U[2][2]', None, None),
                                                  'U_2_2_ESD': ('atom_site_anisotrop', 'U[2][2]_esd', None, None),
                                                  'U_2_3': ('atom_site_anisotrop', 'U[2][3]', None, None),
                                                  'U_2_3_ESD': ('atom_site_anisotrop', 'U[2][3]_esd', None, None),
                                                  'U_3_3': ('atom_site_anisotrop', 'U[3][3]', None, None),
                                                  'U_3_3_ESD': ('atom_site_anisotrop', 'U[3][3]_esd', None, None)},
                                'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                            's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                'MAP_MERGE_INDICES': {'atom_site_anisotrop': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                                'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                'TABLE_ID': 'ATOM_SITE_ANISOTROP',
                                'TABLE_NAME': 'atom_site_anisotrop',
                                'TABLE_TYPE': 'transactional'},
        'ATOM_TYPE': {'ATTRIBUTES': {'ANALYTICAL_MASS_PERCENT': 'analytical_mass_percent',
                                     'DESCRIPTION': 'description',
                                     'NUMBER_IN_CELL': 'number_in_cell',
                                     'OXIDATION_NUMBER': 'oxidation_number',
                                     'RADIUS_BOND': 'radius_bond',
                                     'RADIUS_CONTACT': 'radius_contact',
                                     'SCAT_CROMER_MANN_A1': 'scat_Cromer_Mann_a1',
                                     'SCAT_CROMER_MANN_A2': 'scat_Cromer_Mann_a2',
                                     'SCAT_CROMER_MANN_A3': 'scat_Cromer_Mann_a3',
                                     'SCAT_CROMER_MANN_A4': 'scat_Cromer_Mann_a4',
                                     'SCAT_CROMER_MANN_B1': 'scat_Cromer_Mann_b1',
                                     'SCAT_CROMER_MANN_B2': 'scat_Cromer_Mann_b2',
                                     'SCAT_CROMER_MANN_B3': 'scat_Cromer_Mann_b3',
                                     'SCAT_CROMER_MANN_B4': 'scat_Cromer_Mann_b4',
                                     'SCAT_CROMER_MANN_C': 'scat_Cromer_Mann_c',
                                     'SCAT_DISPERSION_IMAG': 'scat_dispersion_imag',
                                     'SCAT_DISPERSION_REAL': 'scat_dispersion_real',
                                     'SCAT_DISPERSION_SOURCE': 'scat_dispersion_source',
                                     'SCAT_LENGTH_NEUTRON': 'scat_length_neutron',
                                     'SCAT_SOURCE': 'scat_source',
                                     'SCAT_VERSUS_STOL_LIST': 'scat_versus_stol_list',
                                     'STRUCTURE_ID': 'Structure_ID',
                                     'SYMBOL': 'symbol'},
                      'ATTRIBUTE_INFO': {'ANALYTICAL_MASS_PERCENT': {'NULLABLE': True,
                                                                     'ORDER': 2,
                                                                     'PRECISION': 6,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'FLOAT',
                                                                     'WIDTH': 10},
                                         'DESCRIPTION': {'NULLABLE': True,
                                                         'ORDER': 3,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 200},
                                         'NUMBER_IN_CELL': {'NULLABLE': True,
                                                            'ORDER': 4,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'INT',
                                                            'WIDTH': 10},
                                         'OXIDATION_NUMBER': {'NULLABLE': True,
                                                              'ORDER': 5,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'INT',
                                                              'WIDTH': 10},
                                         'RADIUS_BOND': {'NULLABLE': True,
                                                         'ORDER': 6,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                         'RADIUS_CONTACT': {'NULLABLE': True,
                                                            'ORDER': 7,
                                                            'PRECISION': 6,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'FLOAT',
                                                            'WIDTH': 10},
                                         'SCAT_CROMER_MANN_A1': {'NULLABLE': True,
                                                                 'ORDER': 8,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                         'SCAT_CROMER_MANN_A2': {'NULLABLE': True,
                                                                 'ORDER': 9,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                         'SCAT_CROMER_MANN_A3': {'NULLABLE': True,
                                                                 'ORDER': 10,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                         'SCAT_CROMER_MANN_A4': {'NULLABLE': True,
                                                                 'ORDER': 11,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                         'SCAT_CROMER_MANN_B1': {'NULLABLE': True,
                                                                 'ORDER': 12,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                         'SCAT_CROMER_MANN_B2': {'NULLABLE': True,
                                                                 'ORDER': 13,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                         'SCAT_CROMER_MANN_B3': {'NULLABLE': True,
                                                                 'ORDER': 14,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                         'SCAT_CROMER_MANN_B4': {'NULLABLE': True,
                                                                 'ORDER': 15,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                         'SCAT_CROMER_MANN_C': {'NULLABLE': True,
                                                                'ORDER': 16,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                         'SCAT_DISPERSION_IMAG': {'NULLABLE': True,
                                                                  'ORDER': 17,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10},
                                         'SCAT_DISPERSION_REAL': {'NULLABLE': True,
                                                                  'ORDER': 18,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10},
                                         'SCAT_DISPERSION_SOURCE': {'NULLABLE': True,
                                                                    'ORDER': 23,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 200},
                                         'SCAT_LENGTH_NEUTRON': {'NULLABLE': True,
                                                                 'ORDER': 19,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 200},
                                         'SCAT_SOURCE': {'NULLABLE': True,
                                                         'ORDER': 20,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 200},
                                         'SCAT_VERSUS_STOL_LIST': {'NULLABLE': True,
                                                                   'ORDER': 21,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 200},
                                         'STRUCTURE_ID': {'NULLABLE': False,
                                                          'ORDER': 1,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': True,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 10},
                                         'SYMBOL': {'NULLABLE': False,
                                                    'ORDER': 22,
                                                    'PRECISION': 0,
                                                    'PRIMARY_KEY': True,
                                                    'SQL_TYPE': 'VARCHAR',
                                                    'WIDTH': 10}},
                      'ATTRIBUTE_MAP': {'ANALYTICAL_MASS_PERCENT': ('atom_type', 'analytical_mass_percent', None, None),
                                        'DESCRIPTION': ('atom_type', 'description', None, None),
                                        'NUMBER_IN_CELL': ('atom_type', 'number_in_cell', None, None),
                                        'OXIDATION_NUMBER': ('atom_type', 'oxidation_number', None, None),
                                        'RADIUS_BOND': ('atom_type', 'radius_bond', None, None),
                                        'RADIUS_CONTACT': ('atom_type', 'radius_contact', None, None),
                                        'SCAT_CROMER_MANN_A1': ('atom_type', 'scat_Cromer_Mann_a1', None, None),
                                        'SCAT_CROMER_MANN_A2': ('atom_type', 'scat_Cromer_Mann_a2', None, None),
                                        'SCAT_CROMER_MANN_A3': ('atom_type', 'scat_Cromer_Mann_a3', None, None),
                                        'SCAT_CROMER_MANN_A4': ('atom_type', 'scat_Cromer_Mann_a4', None, None),
                                        'SCAT_CROMER_MANN_B1': ('atom_type', 'scat_Cromer_Mann_b1', None, None),
                                        'SCAT_CROMER_MANN_B2': ('atom_type', 'scat_Cromer_Mann_b2', None, None),
                                        'SCAT_CROMER_MANN_B3': ('atom_type', 'scat_Cromer_Mann_b3', None, None),
                                        'SCAT_CROMER_MANN_B4': ('atom_type', 'scat_Cromer_Mann_b4', None, None),
                                        'SCAT_CROMER_MANN_C': ('atom_type', 'scat_Cromer_Mann_c', None, None),
                                        'SCAT_DISPERSION_IMAG': ('atom_type', 'scat_dispersion_imag', None, None),
                                        'SCAT_DISPERSION_REAL': ('atom_type', 'scat_dispersion_real', None, None),
                                        'SCAT_DISPERSION_SOURCE': ('atom_type', 'scat_dispersion_source', None, None),
                                        'SCAT_LENGTH_NEUTRON': ('atom_type', 'scat_length_neutron', None, None),
                                        'SCAT_SOURCE': ('atom_type', 'scat_source', None, None),
                                        'SCAT_VERSUS_STOL_LIST': ('atom_type', 'scat_versus_stol_list', None, None),
                                        'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                        'SYMBOL': ('atom_type', 'symbol', None, None)},
                      'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'SYMBOL'), 'TYPE': 'UNIQUE'},
                                  's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                      'MAP_MERGE_INDICES': {'atom_type': {'ATTRIBUTES': ('symbol',), 'TYPE': 'EQUI-JOIN'}},
                      'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                      'TABLE_ID': 'ATOM_TYPE',
                      'TABLE_NAME': 'atom_type',
                      'TABLE_TYPE': 'transactional'},
        'AUDIT': {'ATTRIBUTES': {'CREATION_DATE': 'creation_date',
                                 'CREATION_METHOD': 'creation_method',
                                 'REVISION_ID': 'revision_id',
                                 'STRUCTURE_ID': 'Structure_ID',
                                 'UPDATE_RECORD': 'update_record'},
                  'ATTRIBUTE_INFO': {'CREATION_DATE': {'NULLABLE': True,
                                                       'ORDER': 2,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'DATETIME',
                                                       'WIDTH': 15},
                                     'CREATION_METHOD': {'NULLABLE': True,
                                                         'ORDER': 3,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 200},
                                     'REVISION_ID': {'NULLABLE': False,
                                                     'ORDER': 4,
                                                     'PRECISION': 0,
                                                     'PRIMARY_KEY': True,
                                                     'SQL_TYPE': 'VARCHAR',
                                                     'WIDTH': 10},
                                     'STRUCTURE_ID': {'NULLABLE': False,
                                                      'ORDER': 1,
                                                      'PRECISION': 0,
                                                      'PRIMARY_KEY': True,
                                                      'SQL_TYPE': 'VARCHAR',
                                                      'WIDTH': 10},
                                     'UPDATE_RECORD': {'NULLABLE': True,
                                                       'ORDER': 5,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'VARCHAR',
                                                       'WIDTH': 511}},
                  'ATTRIBUTE_MAP': {'CREATION_DATE': ('audit', 'creation_date', None, None),
                                    'CREATION_METHOD': ('audit', 'creation_method', None, None),
                                    'REVISION_ID': ('audit', 'revision_id', None, None),
                                    'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                    'UPDATE_RECORD': ('audit', 'update_record', None, None)},
                  'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'REVISION_ID'), 'TYPE': 'UNIQUE'},
                              's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                  'MAP_MERGE_INDICES': {'audit': {'ATTRIBUTES': ('revision_id',), 'TYPE': 'EQUI-JOIN'}},
                  'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                  'TABLE_ID': 'AUDIT',
                  'TABLE_NAME': 'audit',
                  'TABLE_TYPE': 'transactional'},
        'AUDIT_AUTHOR': {'ATTRIBUTES': {'ADDRESS': 'address',
                                        'NAME': 'name',
                                        'PDBX_ORDINAL': 'pdbx_ordinal',
                                        'STRUCTURE_ID': 'Structure_ID'},
                         'ATTRIBUTE_INFO': {'ADDRESS': {'NULLABLE': True,
                                                        'ORDER': 2,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 200},
                                            'NAME': {'NULLABLE': True,
                                                     'ORDER': 3,
                                                     'PRECISION': 0,
                                                     'PRIMARY_KEY': False,
                                                     'SQL_TYPE': 'VARCHAR',
                                                     'WIDTH': 128},
                                            'PDBX_ORDINAL': {'NULLABLE': False,
                                                             'ORDER': 4,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'INT',
                                                             'WIDTH': 10},
                                            'STRUCTURE_ID': {'NULLABLE': False,
                                                             'ORDER': 1,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 10}},
                         'ATTRIBUTE_MAP': {'ADDRESS': ('audit_author', 'address', None, None),
                                           'NAME': ('audit_author', 'name', None, None),
                                           'PDBX_ORDINAL': ('audit_author', 'pdbx_ordinal', None, None),
                                           'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                         'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'PDBX_ORDINAL'), 'TYPE': 'UNIQUE'},
                                     's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                         'MAP_MERGE_INDICES': {'audit_author': {'ATTRIBUTES': ('pdbx_ordinal',), 'TYPE': 'EQUI-JOIN'}},
                         'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                         'TABLE_ID': 'AUDIT_AUTHOR',
                         'TABLE_NAME': 'audit_author',
                         'TABLE_TYPE': 'transactional'},
        'AUDIT_CONFORM': {'ATTRIBUTES': {'DICT_LOCATION': 'dict_location',
                                         'DICT_NAME': 'dict_name',
                                         'DICT_VERSION': 'dict_version',
                                         'STRUCTURE_ID': 'Structure_ID'},
                          'ATTRIBUTE_INFO': {'DICT_LOCATION': {'NULLABLE': True,
                                                               'ORDER': 2,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 200},
                                             'DICT_NAME': {'NULLABLE': False,
                                                           'ORDER': 3,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': True,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 200},
                                             'DICT_VERSION': {'NULLABLE': False,
                                                              'ORDER': 4,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 200},
                                             'STRUCTURE_ID': {'NULLABLE': False,
                                                              'ORDER': 1,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10}},
                          'ATTRIBUTE_MAP': {'DICT_LOCATION': ('audit_conform', 'dict_location', None, None),
                                            'DICT_NAME': ('audit_conform', 'dict_name', None, None),
                                            'DICT_VERSION': ('audit_conform', 'dict_version', None, None),
                                            'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                          'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'DICT_NAME', 'DICT_VERSION'), 'TYPE': 'UNIQUE'},
                                      's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                          'MAP_MERGE_INDICES': {'audit_conform': {'ATTRIBUTES': ('dict_name', 'dict_version'),
                                                                  'TYPE': 'EQUI-JOIN'}},
                          'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                          'TABLE_ID': 'AUDIT_CONFORM',
                          'TABLE_NAME': 'audit_conform',
                          'TABLE_TYPE': 'transactional'},
        'AUDIT_CONTACT_AUTHOR': {'ATTRIBUTES': {'ADDRESS': 'address',
                                                'EMAIL': 'email',
                                                'FAX': 'fax',
                                                'NAME': 'name',
                                                'PHONE': 'phone',
                                                'STRUCTURE_ID': 'Structure_ID'},
                                 'ATTRIBUTE_INFO': {'ADDRESS': {'NULLABLE': True,
                                                                'ORDER': 2,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 200},
                                                    'EMAIL': {'NULLABLE': True,
                                                              'ORDER': 3,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 80},
                                                    'FAX': {'NULLABLE': True,
                                                            'ORDER': 4,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 80},
                                                    'NAME': {'NULLABLE': False,
                                                             'ORDER': 5,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 80},
                                                    'PHONE': {'NULLABLE': True,
                                                              'ORDER': 6,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 80},
                                                    'STRUCTURE_ID': {'NULLABLE': False,
                                                                     'ORDER': 1,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': True,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10}},
                                 'ATTRIBUTE_MAP': {'ADDRESS': ('audit_contact_author', 'address', None, None),
                                                   'EMAIL': ('audit_contact_author', 'email', None, None),
                                                   'FAX': ('audit_contact_author', 'fax', None, None),
                                                   'NAME': ('audit_contact_author', 'name', None, None),
                                                   'PHONE': ('audit_contact_author', 'phone', None, None),
                                                   'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                 'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'NAME'), 'TYPE': 'UNIQUE'},
                                             's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                 'MAP_MERGE_INDICES': {'audit_contact_author': {'ATTRIBUTES': ('name',), 'TYPE': 'EQUI-JOIN'}},
                                 'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                 'TABLE_ID': 'AUDIT_CONTACT_AUTHOR',
                                 'TABLE_NAME': 'audit_contact_author',
                                 'TABLE_TYPE': 'transactional'},
        'AUDIT_LINK': {'ATTRIBUTES': {'BLOCK_CODE': 'block_code',
                                      'BLOCK_DESCRIPTION': 'block_description',
                                      'STRUCTURE_ID': 'Structure_ID'},
                       'ATTRIBUTE_INFO': {'BLOCK_CODE': {'NULLABLE': False,
                                                         'ORDER': 2,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': True,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 10},
                                          'BLOCK_DESCRIPTION': {'NULLABLE': False,
                                                                'ORDER': 3,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 200},
                                          'STRUCTURE_ID': {'NULLABLE': False,
                                                           'ORDER': 1,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': True,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 10}},
                       'ATTRIBUTE_MAP': {'BLOCK_CODE': ('audit_link', 'block_code', None, None),
                                         'BLOCK_DESCRIPTION': ('audit_link', 'block_description', None, None),
                                         'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                       'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'BLOCK_CODE', 'BLOCK_DESCRIPTION'), 'TYPE': 'UNIQUE'},
                                   's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                       'MAP_MERGE_INDICES': {'audit_link': {'ATTRIBUTES': ('block_code', 'block_description'),
                                                            'TYPE': 'EQUI-JOIN'}},
                       'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                       'TABLE_ID': 'AUDIT_LINK',
                       'TABLE_NAME': 'audit_link',
                       'TABLE_TYPE': 'transactional'},
        'CELL1': {'ATTRIBUTES': {'ANGLE_ALPHA': 'angle_alpha',
                                 'ANGLE_ALPHA_ESD': 'angle_alpha_esd',
                                 'ANGLE_BETA': 'angle_beta',
                                 'ANGLE_BETA_ESD': 'angle_beta_esd',
                                 'ANGLE_GAMMA': 'angle_gamma',
                                 'ANGLE_GAMMA_ESD': 'angle_gamma_esd',
                                 'DETAILS': 'details',
                                 'ENTRY_ID': 'entry_id',
                                 'FORMULA_UNITS_Z': 'formula_units_Z',
                                 'LENGTH_A': 'length_a',
                                 'LENGTH_A_ESD': 'length_a_esd',
                                 'LENGTH_B': 'length_b',
                                 'LENGTH_B_ESD': 'length_b_esd',
                                 'LENGTH_C': 'length_c',
                                 'LENGTH_C_ESD': 'length_c_esd',
                                 'PDBX_UNIQUE_AXIS': 'pdbx_unique_axis',
                                 'RECIPROCAL_ANGLE_ALPHA': 'reciprocal_angle_alpha',
                                 'RECIPROCAL_ANGLE_ALPHA_ESD': 'reciprocal_angle_alpha_esd',
                                 'RECIPROCAL_ANGLE_BETA': 'reciprocal_angle_beta',
                                 'RECIPROCAL_ANGLE_BETA_ESD': 'reciprocal_angle_beta_esd',
                                 'RECIPROCAL_ANGLE_GAMMA': 'reciprocal_angle_gamma',
                                 'RECIPROCAL_ANGLE_GAMMA_ESD': 'reciprocal_angle_gamma_esd',
                                 'RECIPROCAL_LENGTH_A': 'reciprocal_length_a',
                                 'RECIPROCAL_LENGTH_A_ESD': 'reciprocal_length_a_esd',
                                 'RECIPROCAL_LENGTH_B': 'reciprocal_length_b',
                                 'RECIPROCAL_LENGTH_B_ESD': 'reciprocal_length_b_esd',
                                 'RECIPROCAL_LENGTH_C': 'reciprocal_length_c',
                                 'RECIPROCAL_LENGTH_C_ESD': 'reciprocal_length_c_esd',
                                 'STRUCTURE_ID': 'Structure_ID',
                                 'VOLUME': 'volume',
                                 'VOLUME_ESD': 'volume_esd',
                                 'Z_PDB': 'Z_PDB'},
                  'ATTRIBUTE_INFO': {'ANGLE_ALPHA': {'NULLABLE': True,
                                                     'ORDER': 2,
                                                     'PRECISION': 6,
                                                     'PRIMARY_KEY': False,
                                                     'SQL_TYPE': 'FLOAT',
                                                     'WIDTH': 10},
                                     'ANGLE_ALPHA_ESD': {'NULLABLE': True,
                                                         'ORDER': 3,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                     'ANGLE_BETA': {'NULLABLE': True,
                                                    'ORDER': 4,
                                                    'PRECISION': 6,
                                                    'PRIMARY_KEY': False,
                                                    'SQL_TYPE': 'FLOAT',
                                                    'WIDTH': 10},
                                     'ANGLE_BETA_ESD': {'NULLABLE': True,
                                                        'ORDER': 5,
                                                        'PRECISION': 6,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'FLOAT',
                                                        'WIDTH': 10},
                                     'ANGLE_GAMMA': {'NULLABLE': True,
                                                     'ORDER': 6,
                                                     'PRECISION': 6,
                                                     'PRIMARY_KEY': False,
                                                     'SQL_TYPE': 'FLOAT',
                                                     'WIDTH': 10},
                                     'ANGLE_GAMMA_ESD': {'NULLABLE': True,
                                                         'ORDER': 7,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                     'DETAILS': {'NULLABLE': True,
                                                 'ORDER': 9,
                                                 'PRECISION': 0,
                                                 'PRIMARY_KEY': False,
                                                 'SQL_TYPE': 'VARCHAR',
                                                 'WIDTH': 200},
                                     'ENTRY_ID': {'NULLABLE': False,
                                                  'ORDER': 8,
                                                  'PRECISION': 0,
                                                  'PRIMARY_KEY': True,
                                                  'SQL_TYPE': 'VARCHAR',
                                                  'WIDTH': 10},
                                     'FORMULA_UNITS_Z': {'NULLABLE': True,
                                                         'ORDER': 10,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'INT',
                                                         'WIDTH': 10},
                                     'LENGTH_A': {'NULLABLE': True,
                                                  'ORDER': 11,
                                                  'PRECISION': 6,
                                                  'PRIMARY_KEY': False,
                                                  'SQL_TYPE': 'FLOAT',
                                                  'WIDTH': 10},
                                     'LENGTH_A_ESD': {'NULLABLE': True,
                                                      'ORDER': 12,
                                                      'PRECISION': 6,
                                                      'PRIMARY_KEY': False,
                                                      'SQL_TYPE': 'FLOAT',
                                                      'WIDTH': 10},
                                     'LENGTH_B': {'NULLABLE': True,
                                                  'ORDER': 13,
                                                  'PRECISION': 6,
                                                  'PRIMARY_KEY': False,
                                                  'SQL_TYPE': 'FLOAT',
                                                  'WIDTH': 10},
                                     'LENGTH_B_ESD': {'NULLABLE': True,
                                                      'ORDER': 14,
                                                      'PRECISION': 6,
                                                      'PRIMARY_KEY': False,
                                                      'SQL_TYPE': 'FLOAT',
                                                      'WIDTH': 10},
                                     'LENGTH_C': {'NULLABLE': True,
                                                  'ORDER': 15,
                                                  'PRECISION': 6,
                                                  'PRIMARY_KEY': False,
                                                  'SQL_TYPE': 'FLOAT',
                                                  'WIDTH': 10},
                                     'LENGTH_C_ESD': {'NULLABLE': True,
                                                      'ORDER': 16,
                                                      'PRECISION': 6,
                                                      'PRIMARY_KEY': False,
                                                      'SQL_TYPE': 'FLOAT',
                                                      'WIDTH': 10},
                                     'PDBX_UNIQUE_AXIS': {'NULLABLE': True,
                                                          'ORDER': 32,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 200},
                                     'RECIPROCAL_ANGLE_ALPHA': {'NULLABLE': True,
                                                                'ORDER': 20,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                     'RECIPROCAL_ANGLE_ALPHA_ESD': {'NULLABLE': True,
                                                                    'ORDER': 23,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                     'RECIPROCAL_ANGLE_BETA': {'NULLABLE': True,
                                                               'ORDER': 21,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                     'RECIPROCAL_ANGLE_BETA_ESD': {'NULLABLE': True,
                                                                   'ORDER': 24,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                     'RECIPROCAL_ANGLE_GAMMA': {'NULLABLE': True,
                                                                'ORDER': 22,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                     'RECIPROCAL_ANGLE_GAMMA_ESD': {'NULLABLE': True,
                                                                    'ORDER': 25,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                     'RECIPROCAL_LENGTH_A': {'NULLABLE': True,
                                                             'ORDER': 26,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                     'RECIPROCAL_LENGTH_A_ESD': {'NULLABLE': True,
                                                                 'ORDER': 29,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                     'RECIPROCAL_LENGTH_B': {'NULLABLE': True,
                                                             'ORDER': 27,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                     'RECIPROCAL_LENGTH_B_ESD': {'NULLABLE': True,
                                                                 'ORDER': 30,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                     'RECIPROCAL_LENGTH_C': {'NULLABLE': True,
                                                             'ORDER': 28,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                     'RECIPROCAL_LENGTH_C_ESD': {'NULLABLE': True,
                                                                 'ORDER': 31,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                     'STRUCTURE_ID': {'NULLABLE': False,
                                                      'ORDER': 1,
                                                      'PRECISION': 0,
                                                      'PRIMARY_KEY': True,
                                                      'SQL_TYPE': 'VARCHAR',
                                                      'WIDTH': 10},
                                     'VOLUME': {'NULLABLE': True,
                                                'ORDER': 17,
                                                'PRECISION': 6,
                                                'PRIMARY_KEY': False,
                                                'SQL_TYPE': 'FLOAT',
                                                'WIDTH': 10},
                                     'VOLUME_ESD': {'NULLABLE': True,
                                                    'ORDER': 18,
                                                    'PRECISION': 6,
                                                    'PRIMARY_KEY': False,
                                                    'SQL_TYPE': 'FLOAT',
                                                    'WIDTH': 10},
                                     'Z_PDB': {'NULLABLE': True,
                                               'ORDER': 19,
                                               'PRECISION': 0,
                                               'PRIMARY_KEY': False,
                                               'SQL_TYPE': 'INT',
                                               'WIDTH': 10}},
                  'ATTRIBUTE_MAP': {'ANGLE_ALPHA': ('cell', 'angle_alpha', None, None),
                                    'ANGLE_ALPHA_ESD': ('cell', 'angle_alpha_esd', None, None),
                                    'ANGLE_BETA': ('cell', 'angle_beta', None, None),
                                    'ANGLE_BETA_ESD': ('cell', 'angle_beta_esd', None, None),
                                    'ANGLE_GAMMA': ('cell', 'angle_gamma', None, None),
                                    'ANGLE_GAMMA_ESD': ('cell', 'angle_gamma_esd', None, None),
                                    'DETAILS': ('cell', 'details', None, None),
                                    'ENTRY_ID': ('cell', 'entry_id', None, None),
                                    'FORMULA_UNITS_Z': ('cell', 'formula_units_Z', None, None),
                                    'LENGTH_A': ('cell', 'length_a', None, None),
                                    'LENGTH_A_ESD': ('cell', 'length_a_esd', None, None),
                                    'LENGTH_B': ('cell', 'length_b', None, None),
                                    'LENGTH_B_ESD': ('cell', 'length_b_esd', None, None),
                                    'LENGTH_C': ('cell', 'length_c', None, None),
                                    'LENGTH_C_ESD': ('cell', 'length_c_esd', None, None),
                                    'PDBX_UNIQUE_AXIS': ('cell', 'pdbx_unique_axis', None, None),
                                    'RECIPROCAL_ANGLE_ALPHA': ('cell', 'reciprocal_angle_alpha', None, None),
                                    'RECIPROCAL_ANGLE_ALPHA_ESD': ('cell', 'reciprocal_angle_alpha_esd', None, None),
                                    'RECIPROCAL_ANGLE_BETA': ('cell', 'reciprocal_angle_beta', None, None),
                                    'RECIPROCAL_ANGLE_BETA_ESD': ('cell', 'reciprocal_angle_beta_esd', None, None),
                                    'RECIPROCAL_ANGLE_GAMMA': ('cell', 'reciprocal_angle_gamma', None, None),
                                    'RECIPROCAL_ANGLE_GAMMA_ESD': ('cell', 'reciprocal_angle_gamma_esd', None, None),
                                    'RECIPROCAL_LENGTH_A': ('cell', 'reciprocal_length_a', None, None),
                                    'RECIPROCAL_LENGTH_A_ESD': ('cell', 'reciprocal_length_a_esd', None, None),
                                    'RECIPROCAL_LENGTH_B': ('cell', 'reciprocal_length_b', None, None),
                                    'RECIPROCAL_LENGTH_B_ESD': ('cell', 'reciprocal_length_b_esd', None, None),
                                    'RECIPROCAL_LENGTH_C': ('cell', 'reciprocal_length_c', None, None),
                                    'RECIPROCAL_LENGTH_C_ESD': ('cell', 'reciprocal_length_c_esd', None, None),
                                    'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                    'VOLUME': ('cell', 'volume', None, None),
                                    'VOLUME_ESD': ('cell', 'volume_esd', None, None),
                                    'Z_PDB': ('cell', 'Z_PDB', None, None)},
                  'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID'), 'TYPE': 'UNIQUE'},
                              's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                  'MAP_MERGE_INDICES': {'cell': {'ATTRIBUTES': ('entry_id',), 'TYPE': 'EQUI-JOIN'}},
                  'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                  'TABLE_ID': 'CELL1',
                  'TABLE_NAME': 'cell1',
                  'TABLE_TYPE': 'transactional'},
        'CELL_MEASUREMENT': {'ATTRIBUTES': {'ENTRY_ID': 'entry_id',
                                            'PRESSURE': 'pressure',
                                            'PRESSURE_ESD': 'pressure_esd',
                                            'RADIATION': 'radiation',
                                            'REFLNS_USED': 'reflns_used',
                                            'STRUCTURE_ID': 'Structure_ID',
                                            'TEMP': 'temp',
                                            'TEMP_ESD': 'temp_esd',
                                            'THETA_MAX': 'theta_max',
                                            'THETA_MIN': 'theta_min',
                                            'WAVELENGTH': 'wavelength'},
                             'ATTRIBUTE_INFO': {'ENTRY_ID': {'NULLABLE': False,
                                                             'ORDER': 2,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 10},
                                                'PRESSURE': {'NULLABLE': True,
                                                             'ORDER': 3,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                                'PRESSURE_ESD': {'NULLABLE': True,
                                                                 'ORDER': 4,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                                'RADIATION': {'NULLABLE': True,
                                                              'ORDER': 5,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 80},
                                                'REFLNS_USED': {'NULLABLE': True,
                                                                'ORDER': 6,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'INT',
                                                                'WIDTH': 10},
                                                'STRUCTURE_ID': {'NULLABLE': False,
                                                                 'ORDER': 1,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': True,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                                'TEMP': {'NULLABLE': True,
                                                         'ORDER': 7,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                                'TEMP_ESD': {'NULLABLE': True,
                                                             'ORDER': 8,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                                'THETA_MAX': {'NULLABLE': True,
                                                              'ORDER': 9,
                                                              'PRECISION': 6,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'FLOAT',
                                                              'WIDTH': 10},
                                                'THETA_MIN': {'NULLABLE': True,
                                                              'ORDER': 10,
                                                              'PRECISION': 6,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'FLOAT',
                                                              'WIDTH': 10},
                                                'WAVELENGTH': {'NULLABLE': True,
                                                               'ORDER': 11,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10}},
                             'ATTRIBUTE_MAP': {'ENTRY_ID': ('cell_measurement', 'entry_id', None, None),
                                               'PRESSURE': ('cell_measurement', 'pressure', None, None),
                                               'PRESSURE_ESD': ('cell_measurement', 'pressure_esd', None, None),
                                               'RADIATION': ('cell_measurement', 'radiation', None, None),
                                               'REFLNS_USED': ('cell_measurement', 'reflns_used', None, None),
                                               'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                               'TEMP': ('cell_measurement', 'temp', None, None),
                                               'TEMP_ESD': ('cell_measurement', 'temp_esd', None, None),
                                               'THETA_MAX': ('cell_measurement', 'theta_max', None, None),
                                               'THETA_MIN': ('cell_measurement', 'theta_min', None, None),
                                               'WAVELENGTH': ('cell_measurement', 'wavelength', None, None)},
                             'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID'), 'TYPE': 'UNIQUE'},
                                         's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                             'MAP_MERGE_INDICES': {'cell_measurement': {'ATTRIBUTES': ('entry_id',), 'TYPE': 'EQUI-JOIN'}},
                             'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                             'TABLE_ID': 'CELL_MEASUREMENT',
                             'TABLE_NAME': 'cell_measurement',
                             'TABLE_TYPE': 'transactional'},
        'CELL_MEASUREMENT_REFLN': {'ATTRIBUTES': {'INDEX_H': 'index_h',
                                                  'INDEX_K': 'index_k',
                                                  'INDEX_L': 'index_l',
                                                  'STRUCTURE_ID': 'Structure_ID',
                                                  'THETA': 'theta'},
                                   'ATTRIBUTE_INFO': {'INDEX_H': {'NULLABLE': False,
                                                                  'ORDER': 2,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': True,
                                                                  'SQL_TYPE': 'INT',
                                                                  'WIDTH': 10},
                                                      'INDEX_K': {'NULLABLE': False,
                                                                  'ORDER': 3,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': True,
                                                                  'SQL_TYPE': 'INT',
                                                                  'WIDTH': 10},
                                                      'INDEX_L': {'NULLABLE': False,
                                                                  'ORDER': 4,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': True,
                                                                  'SQL_TYPE': 'INT',
                                                                  'WIDTH': 10},
                                                      'STRUCTURE_ID': {'NULLABLE': False,
                                                                       'ORDER': 1,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': True,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                      'THETA': {'NULLABLE': True,
                                                                'ORDER': 5,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10}},
                                   'ATTRIBUTE_MAP': {'INDEX_H': ('cell_measurement_refln', 'index_h', None, None),
                                                     'INDEX_K': ('cell_measurement_refln', 'index_k', None, None),
                                                     'INDEX_L': ('cell_measurement_refln', 'index_l', None, None),
                                                     'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                     'THETA': ('cell_measurement_refln', 'theta', None, None)},
                                   'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'INDEX_H', 'INDEX_K', 'INDEX_L'),
                                                      'TYPE': 'UNIQUE'},
                                               's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                   'MAP_MERGE_INDICES': {'cell_measurement_refln': {'ATTRIBUTES': ('index_h',
                                                                                                   'index_k',
                                                                                                   'index_l'),
                                                                                    'TYPE': 'EQUI-JOIN'}},
                                   'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                   'TABLE_ID': 'CELL_MEASUREMENT_REFLN',
                                   'TABLE_NAME': 'cell_measurement_refln',
                                   'TABLE_TYPE': 'transactional'},
        'CHEMICAL': {'ATTRIBUTES': {'ABSOLUTE_CONFIGURATION': 'absolute_configuration',
                                    'COMPOUND_SOURCE': 'compound_source',
                                    'ENTRY_ID': 'entry_id',
                                    'MELTING_POINT': 'melting_point',
                                    'MELTING_POINT_GT': 'melting_point_gt',
                                    'MELTING_POINT_LT': 'melting_point_lt',
                                    'NAME_COMMON': 'name_common',
                                    'NAME_MINERAL': 'name_mineral',
                                    'NAME_STRUCTURE_TYPE': 'name_structure_type',
                                    'NAME_SYSTEMATIC': 'name_systematic',
                                    'OPTICAL_ROTATION': 'optical_rotation',
                                    'PROPERTIES_BIOLOGICAL': 'properties_biological',
                                    'PROPERTIES_PHYSICAL': 'properties_physical',
                                    'STRUCTURE_ID': 'Structure_ID',
                                    'TEMPERATURE_DECOMPOSITION': 'temperature_decomposition',
                                    'TEMPERATURE_DECOMPOSITION_ESD': 'temperature_decomposition_esd',
                                    'TEMPERATURE_DECOMPOSITION_GT': 'temperature_decomposition_gt',
                                    'TEMPERATURE_DECOMPOSITION_LT': 'temperature_decomposition_lt',
                                    'TEMPERATURE_SUBLIMATION': 'temperature_sublimation',
                                    'TEMPERATURE_SUBLIMATION_ESD': 'temperature_sublimation_esd',
                                    'TEMPERATURE_SUBLIMATION_GT': 'temperature_sublimation_gt',
                                    'TEMPERATURE_SUBLIMATION_LT': 'temperature_sublimation_lt'},
                     'ATTRIBUTE_INFO': {'ABSOLUTE_CONFIGURATION': {'NULLABLE': True,
                                                                   'ORDER': 9,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 10},
                                        'COMPOUND_SOURCE': {'NULLABLE': True,
                                                            'ORDER': 3,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 200},
                                        'ENTRY_ID': {'NULLABLE': False,
                                                     'ORDER': 2,
                                                     'PRECISION': 0,
                                                     'PRIMARY_KEY': True,
                                                     'SQL_TYPE': 'VARCHAR',
                                                     'WIDTH': 10},
                                        'MELTING_POINT': {'NULLABLE': True,
                                                          'ORDER': 4,
                                                          'PRECISION': 6,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'FLOAT',
                                                          'WIDTH': 10},
                                        'MELTING_POINT_GT': {'NULLABLE': True,
                                                             'ORDER': 10,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                        'MELTING_POINT_LT': {'NULLABLE': True,
                                                             'ORDER': 11,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                        'NAME_COMMON': {'NULLABLE': True,
                                                        'ORDER': 5,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 200},
                                        'NAME_MINERAL': {'NULLABLE': True,
                                                         'ORDER': 6,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 200},
                                        'NAME_STRUCTURE_TYPE': {'NULLABLE': True,
                                                                'ORDER': 7,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 200},
                                        'NAME_SYSTEMATIC': {'NULLABLE': True,
                                                            'ORDER': 8,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 200},
                                        'OPTICAL_ROTATION': {'NULLABLE': True,
                                                             'ORDER': 12,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 80},
                                        'PROPERTIES_BIOLOGICAL': {'NULLABLE': True,
                                                                  'ORDER': 13,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 200},
                                        'PROPERTIES_PHYSICAL': {'NULLABLE': True,
                                                                'ORDER': 14,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 200},
                                        'STRUCTURE_ID': {'NULLABLE': False,
                                                         'ORDER': 1,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': True,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 10},
                                        'TEMPERATURE_DECOMPOSITION': {'NULLABLE': True,
                                                                      'ORDER': 15,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                        'TEMPERATURE_DECOMPOSITION_ESD': {'NULLABLE': True,
                                                                          'ORDER': 16,
                                                                          'PRECISION': 6,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'FLOAT',
                                                                          'WIDTH': 10},
                                        'TEMPERATURE_DECOMPOSITION_GT': {'NULLABLE': True,
                                                                         'ORDER': 17,
                                                                         'PRECISION': 6,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'FLOAT',
                                                                         'WIDTH': 10},
                                        'TEMPERATURE_DECOMPOSITION_LT': {'NULLABLE': True,
                                                                         'ORDER': 18,
                                                                         'PRECISION': 6,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'FLOAT',
                                                                         'WIDTH': 10},
                                        'TEMPERATURE_SUBLIMATION': {'NULLABLE': True,
                                                                    'ORDER': 19,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                        'TEMPERATURE_SUBLIMATION_ESD': {'NULLABLE': True,
                                                                        'ORDER': 20,
                                                                        'PRECISION': 6,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'FLOAT',
                                                                        'WIDTH': 10},
                                        'TEMPERATURE_SUBLIMATION_GT': {'NULLABLE': True,
                                                                       'ORDER': 21,
                                                                       'PRECISION': 6,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'FLOAT',
                                                                       'WIDTH': 10},
                                        'TEMPERATURE_SUBLIMATION_LT': {'NULLABLE': True,
                                                                       'ORDER': 22,
                                                                       'PRECISION': 6,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'FLOAT',
                                                                       'WIDTH': 10}},
                     'ATTRIBUTE_MAP': {'ABSOLUTE_CONFIGURATION': ('chemical', 'absolute_configuration', None, None),
                                       'COMPOUND_SOURCE': ('chemical', 'compound_source', None, None),
                                       'ENTRY_ID': ('chemical', 'entry_id', None, None),
                                       'MELTING_POINT': ('chemical', 'melting_point', None, None),
                                       'MELTING_POINT_GT': ('chemical', 'melting_point_gt', None, None),
                                       'MELTING_POINT_LT': ('chemical', 'melting_point_lt', None, None),
                                       'NAME_COMMON': ('chemical', 'name_common', None, None),
                                       'NAME_MINERAL': ('chemical', 'name_mineral', None, None),
                                       'NAME_STRUCTURE_TYPE': ('chemical', 'name_structure_type', None, None),
                                       'NAME_SYSTEMATIC': ('chemical', 'name_systematic', None, None),
                                       'OPTICAL_ROTATION': ('chemical', 'optical_rotation', None, None),
                                       'PROPERTIES_BIOLOGICAL': ('chemical', 'properties_biological', None, None),
                                       'PROPERTIES_PHYSICAL': ('chemical', 'properties_physical', None, None),
                                       'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                       'TEMPERATURE_DECOMPOSITION': ('chemical', 'temperature_decomposition', None, None),
                                       'TEMPERATURE_DECOMPOSITION_ESD': ('chemical',
                                                                         'temperature_decomposition_esd',
                                                                         None,
                                                                         None),
                                       'TEMPERATURE_DECOMPOSITION_GT': ('chemical',
                                                                        'temperature_decomposition_gt',
                                                                        None,
                                                                        None),
                                       'TEMPERATURE_DECOMPOSITION_LT': ('chemical',
                                                                        'temperature_decomposition_lt',
                                                                        None,
                                                                        None),
                                       'TEMPERATURE_SUBLIMATION': ('chemical', 'temperature_sublimation', None, None),
                                       'TEMPERATURE_SUBLIMATION_ESD': ('chemical', 'temperature_sublimation_esd', None, None),
                                       'TEMPERATURE_SUBLIMATION_GT': ('chemical', 'temperature_sublimation_gt', None, None),
                                       'TEMPERATURE_SUBLIMATION_LT': ('chemical', 'temperature_sublimation_lt', None, None)},
                     'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID'), 'TYPE': 'UNIQUE'},
                                 's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                     'MAP_MERGE_INDICES': {'chemical': {'ATTRIBUTES': ('entry_id',), 'TYPE': 'EQUI-JOIN'}},
                     'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                     'TABLE_ID': 'CHEMICAL',
                     'TABLE_NAME': 'chemical',
                     'TABLE_TYPE': 'transactional'},
        'CHEMICAL_CONN_ATOM': {'ATTRIBUTES': {'CHARGE': 'charge',
                                              'DISPLAY_X': 'display_x',
                                              'DISPLAY_Y': 'display_y',
                                              'NCA': 'NCA',
                                              'NH': 'NH',
                                              'NUMBER': 'number',
                                              'STRUCTURE_ID': 'Structure_ID',
                                              'TYPE_SYMBOL': 'type_symbol'},
                               'ATTRIBUTE_INFO': {'CHARGE': {'NULLABLE': True,
                                                             'ORDER': 3,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'INT',
                                                             'WIDTH': 10},
                                                  'DISPLAY_X': {'NULLABLE': True,
                                                                'ORDER': 4,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                                  'DISPLAY_Y': {'NULLABLE': True,
                                                                'ORDER': 5,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                                  'NCA': {'NULLABLE': True,
                                                          'ORDER': 6,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'INT',
                                                          'WIDTH': 10},
                                                  'NH': {'NULLABLE': True,
                                                         'ORDER': 7,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'INT',
                                                         'WIDTH': 10},
                                                  'NUMBER': {'NULLABLE': False,
                                                             'ORDER': 8,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'INT',
                                                             'WIDTH': 10},
                                                  'STRUCTURE_ID': {'NULLABLE': False,
                                                                   'ORDER': 1,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': True,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 10},
                                                  'TYPE_SYMBOL': {'NULLABLE': True,
                                                                  'ORDER': 2,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10}},
                               'ATTRIBUTE_MAP': {'CHARGE': ('chemical_conn_atom', 'charge', None, None),
                                                 'DISPLAY_X': ('chemical_conn_atom', 'display_x', None, None),
                                                 'DISPLAY_Y': ('chemical_conn_atom', 'display_y', None, None),
                                                 'NCA': ('chemical_conn_atom', 'NCA', None, None),
                                                 'NH': ('chemical_conn_atom', 'NH', None, None),
                                                 'NUMBER': ('chemical_conn_atom', 'number', None, None),
                                                 'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                 'TYPE_SYMBOL': ('chemical_conn_atom', 'type_symbol', None, None)},
                               'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'NUMBER'), 'TYPE': 'UNIQUE'},
                                           's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                               'MAP_MERGE_INDICES': {'chemical_conn_atom': {'ATTRIBUTES': ('number',), 'TYPE': 'EQUI-JOIN'}},
                               'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                               'TABLE_ID': 'CHEMICAL_CONN_ATOM',
                               'TABLE_NAME': 'chemical_conn_atom',
                               'TABLE_TYPE': 'transactional'},
        'CHEMICAL_CONN_BOND': {'ATTRIBUTES': {'ATOM_1': 'atom_1',
                                              'ATOM_2': 'atom_2',
                                              'STRUCTURE_ID': 'Structure_ID',
                                              'TYPE': 'type'},
                               'ATTRIBUTE_INFO': {'ATOM_1': {'NULLABLE': False,
                                                             'ORDER': 2,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'INT',
                                                             'WIDTH': 10},
                                                  'ATOM_2': {'NULLABLE': False,
                                                             'ORDER': 3,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'INT',
                                                             'WIDTH': 10},
                                                  'STRUCTURE_ID': {'NULLABLE': False,
                                                                   'ORDER': 1,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': True,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 10},
                                                  'TYPE': {'NULLABLE': True,
                                                           'ORDER': 4,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 10}},
                               'ATTRIBUTE_MAP': {'ATOM_1': ('chemical_conn_bond', 'atom_1', None, None),
                                                 'ATOM_2': ('chemical_conn_bond', 'atom_2', None, None),
                                                 'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                 'TYPE': ('chemical_conn_bond', 'type', None, None)},
                               'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ATOM_1', 'ATOM_2'), 'TYPE': 'UNIQUE'},
                                           's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                               'MAP_MERGE_INDICES': {'chemical_conn_bond': {'ATTRIBUTES': ('atom_1', 'atom_2'),
                                                                            'TYPE': 'EQUI-JOIN'}},
                               'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                               'TABLE_ID': 'CHEMICAL_CONN_BOND',
                               'TABLE_NAME': 'chemical_conn_bond',
                               'TABLE_TYPE': 'transactional'},
        'CHEMICAL_FORMULA': {'ATTRIBUTES': {'ANALYTICAL': 'analytical',
                                            'ENTRY_ID': 'entry_id',
                                            'IUPAC': 'iupac',
                                            'MOIETY': 'moiety',
                                            'STRUCTURAL': 'structural',
                                            'STRUCTURE_ID': 'Structure_ID',
                                            'SUM': 'sum',
                                            'WEIGHT': 'weight',
                                            'WEIGHT_MEAS': 'weight_meas'},
                             'ATTRIBUTE_INFO': {'ANALYTICAL': {'NULLABLE': True,
                                                               'ORDER': 2,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 200},
                                                'ENTRY_ID': {'NULLABLE': False,
                                                             'ORDER': 3,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 10},
                                                'IUPAC': {'NULLABLE': True,
                                                          'ORDER': 4,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 200},
                                                'MOIETY': {'NULLABLE': True,
                                                           'ORDER': 5,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 200},
                                                'STRUCTURAL': {'NULLABLE': True,
                                                               'ORDER': 6,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 200},
                                                'STRUCTURE_ID': {'NULLABLE': False,
                                                                 'ORDER': 1,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': True,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                                'SUM': {'NULLABLE': True,
                                                        'ORDER': 7,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 200},
                                                'WEIGHT': {'NULLABLE': True,
                                                           'ORDER': 8,
                                                           'PRECISION': 6,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'FLOAT',
                                                           'WIDTH': 10},
                                                'WEIGHT_MEAS': {'NULLABLE': True,
                                                                'ORDER': 9,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10}},
                             'ATTRIBUTE_MAP': {'ANALYTICAL': ('chemical_formula', 'analytical', None, None),
                                               'ENTRY_ID': ('chemical_formula', 'entry_id', None, None),
                                               'IUPAC': ('chemical_formula', 'iupac', None, None),
                                               'MOIETY': ('chemical_formula', 'moiety', None, None),
                                               'STRUCTURAL': ('chemical_formula', 'structural', None, None),
                                               'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                               'SUM': ('chemical_formula', 'sum', None, None),
                                               'WEIGHT': ('chemical_formula', 'weight', None, None),
                                               'WEIGHT_MEAS': ('chemical_formula', 'weight_meas', None, None)},
                             'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID'), 'TYPE': 'UNIQUE'},
                                         's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                             'MAP_MERGE_INDICES': {'chemical_formula': {'ATTRIBUTES': ('entry_id',), 'TYPE': 'EQUI-JOIN'}},
                             'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                             'TABLE_ID': 'CHEMICAL_FORMULA',
                             'TABLE_NAME': 'chemical_formula',
                             'TABLE_TYPE': 'transactional'},
        'CHEM_COMP': {'ATTRIBUTES': {'FORMULA': 'formula',
                                     'FORMULA_WEIGHT': 'formula_weight',
                                     'ID': 'id',
                                     'MODEL_DETAILS': 'model_details',
                                     'MODEL_ERF': 'model_erf',
                                     'MODEL_SOURCE': 'model_source',
                                     'MON_NSTD_CLASS': 'mon_nstd_class',
                                     'MON_NSTD_DETAILS': 'mon_nstd_details',
                                     'MON_NSTD_FLAG': 'mon_nstd_flag',
                                     'MON_NSTD_PARENT': 'mon_nstd_parent',
                                     'MON_NSTD_PARENT_COMP_ID': 'mon_nstd_parent_comp_id',
                                     'NAME': 'name',
                                     'NUMBER_ATOMS_ALL': 'number_atoms_all',
                                     'NUMBER_ATOMS_NH': 'number_atoms_nh',
                                     'ONE_LETTER_CODE': 'one_letter_code',
                                     'PDBX_AMBIGUOUS_FLAG': 'pdbx_ambiguous_flag',
                                     'PDBX_COMPONENT_NO': 'pdbx_component_no',
                                     'PDBX_FORMAL_CHARGE': 'pdbx_formal_charge',
                                     'PDBX_IDEAL_COORDINATES_DETAILS': 'pdbx_ideal_coordinates_details',
                                     'PDBX_IDEAL_COORDINATES_MISSING_FLAG': 'pdbx_ideal_coordinates_missing_flag',
                                     'PDBX_INITIAL_DATE': 'pdbx_initial_date',
                                     'PDBX_MODEL_COORDINATES_DB_CODE': 'pdbx_model_coordinates_db_code',
                                     'PDBX_MODEL_COORDINATES_DETAILS': 'pdbx_model_coordinates_details',
                                     'PDBX_MODEL_COORDINATES_MISSING_FLAG': 'pdbx_model_coordinates_missing_flag',
                                     'PDBX_MODIFICATION_DETAILS': 'pdbx_modification_details',
                                     'PDBX_MODIFIED_DATE': 'pdbx_modified_date',
                                     'PDBX_PROCESSING_SITE': 'pdbx_processing_site',
                                     'PDBX_RELEASE_STATUS': 'pdbx_release_status',
                                     'PDBX_REPLACED_BY': 'pdbx_replaced_by',
                                     'PDBX_REPLACES': 'pdbx_replaces',
                                     'PDBX_SUBCOMPONENT_LIST': 'pdbx_subcomponent_list',
                                     'PDBX_SYNONYMS': 'pdbx_synonyms',
                                     'PDBX_TYPE': 'pdbx_type',
                                     'STRUCTURE_ID': 'Structure_ID',
                                     'THREE_LETTER_CODE': 'three_letter_code',
                                     'TYPE': 'type'},
                      'ATTRIBUTE_INFO': {'FORMULA': {'NULLABLE': True,
                                                     'ORDER': 2,
                                                     'PRECISION': 0,
                                                     'PRIMARY_KEY': False,
                                                     'SQL_TYPE': 'VARCHAR',
                                                     'WIDTH': 200},
                                         'FORMULA_WEIGHT': {'NULLABLE': True,
                                                            'ORDER': 3,
                                                            'PRECISION': 6,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'FLOAT',
                                                            'WIDTH': 10},
                                         'ID': {'NULLABLE': False,
                                                'ORDER': 4,
                                                'PRECISION': 0,
                                                'PRIMARY_KEY': True,
                                                'SQL_TYPE': 'VARCHAR',
                                                'WIDTH': 10},
                                         'MODEL_DETAILS': {'NULLABLE': True,
                                                           'ORDER': 5,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 200},
                                         'MODEL_ERF': {'NULLABLE': True,
                                                       'ORDER': 6,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'VARCHAR',
                                                       'WIDTH': 80},
                                         'MODEL_SOURCE': {'NULLABLE': True,
                                                          'ORDER': 7,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 200},
                                         'MON_NSTD_CLASS': {'NULLABLE': True,
                                                            'ORDER': 8,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 200},
                                         'MON_NSTD_DETAILS': {'NULLABLE': True,
                                                              'ORDER': 9,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 200},
                                         'MON_NSTD_FLAG': {'NULLABLE': True,
                                                           'ORDER': 10,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 10},
                                         'MON_NSTD_PARENT': {'NULLABLE': True,
                                                             'ORDER': 11,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 10},
                                         'MON_NSTD_PARENT_COMP_ID': {'NULLABLE': True,
                                                                     'ORDER': 12,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 80},
                                         'NAME': {'NULLABLE': True,
                                                  'ORDER': 13,
                                                  'PRECISION': 0,
                                                  'PRIMARY_KEY': False,
                                                  'SQL_TYPE': 'VARCHAR',
                                                  'WIDTH': 1023},
                                         'NUMBER_ATOMS_ALL': {'NULLABLE': True,
                                                              'ORDER': 14,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'INT',
                                                              'WIDTH': 10},
                                         'NUMBER_ATOMS_NH': {'NULLABLE': True,
                                                             'ORDER': 15,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'INT',
                                                             'WIDTH': 10},
                                         'ONE_LETTER_CODE': {'NULLABLE': True,
                                                             'ORDER': 16,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 10},
                                         'PDBX_AMBIGUOUS_FLAG': {'NULLABLE': True,
                                                                 'ORDER': 23,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                         'PDBX_COMPONENT_NO': {'NULLABLE': True,
                                                               'ORDER': 21,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'INT',
                                                               'WIDTH': 10},
                                         'PDBX_FORMAL_CHARGE': {'NULLABLE': True,
                                                                'ORDER': 26,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'INT',
                                                                'WIDTH': 10},
                                         'PDBX_IDEAL_COORDINATES_DETAILS': {'NULLABLE': True,
                                                                            'ORDER': 30,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 200},
                                         'PDBX_IDEAL_COORDINATES_MISSING_FLAG': {'NULLABLE': True,
                                                                                 'ORDER': 31,
                                                                                 'PRECISION': 0,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'VARCHAR',
                                                                                 'WIDTH': 10},
                                         'PDBX_INITIAL_DATE': {'NULLABLE': True,
                                                               'ORDER': 33,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'DATETIME',
                                                               'WIDTH': 15},
                                         'PDBX_MODEL_COORDINATES_DB_CODE': {'NULLABLE': True,
                                                                            'ORDER': 29,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 80},
                                         'PDBX_MODEL_COORDINATES_DETAILS': {'NULLABLE': True,
                                                                            'ORDER': 28,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 200},
                                         'PDBX_MODEL_COORDINATES_MISSING_FLAG': {'NULLABLE': True,
                                                                                 'ORDER': 32,
                                                                                 'PRECISION': 0,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'VARCHAR',
                                                                                 'WIDTH': 10},
                                         'PDBX_MODIFICATION_DETAILS': {'NULLABLE': True,
                                                                       'ORDER': 20,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 200},
                                         'PDBX_MODIFIED_DATE': {'NULLABLE': True,
                                                                'ORDER': 34,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'DATETIME',
                                                                'WIDTH': 15},
                                         'PDBX_PROCESSING_SITE': {'NULLABLE': True,
                                                                  'ORDER': 36,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10},
                                         'PDBX_RELEASE_STATUS': {'NULLABLE': True,
                                                                 'ORDER': 35,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 80},
                                         'PDBX_REPLACED_BY': {'NULLABLE': True,
                                                              'ORDER': 24,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10},
                                         'PDBX_REPLACES': {'NULLABLE': True,
                                                           'ORDER': 25,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 80},
                                         'PDBX_SUBCOMPONENT_LIST': {'NULLABLE': True,
                                                                    'ORDER': 27,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 200},
                                         'PDBX_SYNONYMS': {'NULLABLE': True,
                                                           'ORDER': 19,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 511},
                                         'PDBX_TYPE': {'NULLABLE': True,
                                                       'ORDER': 22,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'VARCHAR',
                                                       'WIDTH': 80},
                                         'STRUCTURE_ID': {'NULLABLE': False,
                                                          'ORDER': 1,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': True,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 10},
                                         'THREE_LETTER_CODE': {'NULLABLE': True,
                                                               'ORDER': 17,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 6},
                                         'TYPE': {'NULLABLE': True,
                                                  'ORDER': 18,
                                                  'PRECISION': 0,
                                                  'PRIMARY_KEY': False,
                                                  'SQL_TYPE': 'VARCHAR',
                                                  'WIDTH': 80}},
                      'ATTRIBUTE_MAP': {'FORMULA': ('chem_comp', 'formula', None, None),
                                        'FORMULA_WEIGHT': ('chem_comp', 'formula_weight', None, None),
                                        'ID': ('chem_comp', 'id', None, None),
                                        'MODEL_DETAILS': ('chem_comp', 'model_details', None, None),
                                        'MODEL_ERF': ('chem_comp', 'model_erf', None, None),
                                        'MODEL_SOURCE': ('chem_comp', 'model_source', None, None),
                                        'MON_NSTD_CLASS': ('chem_comp', 'mon_nstd_class', None, None),
                                        'MON_NSTD_DETAILS': ('chem_comp', 'mon_nstd_details', None, None),
                                        'MON_NSTD_FLAG': ('chem_comp', 'mon_nstd_flag', None, None),
                                        'MON_NSTD_PARENT': ('chem_comp', 'mon_nstd_parent', None, None),
                                        'MON_NSTD_PARENT_COMP_ID': ('chem_comp', 'mon_nstd_parent_comp_id', None, None),
                                        'NAME': ('chem_comp', 'name', None, None),
                                        'NUMBER_ATOMS_ALL': ('chem_comp', 'number_atoms_all', None, None),
                                        'NUMBER_ATOMS_NH': ('chem_comp', 'number_atoms_nh', None, None),
                                        'ONE_LETTER_CODE': ('chem_comp', 'one_letter_code', None, None),
                                        'PDBX_AMBIGUOUS_FLAG': ('chem_comp', 'pdbx_ambiguous_flag', None, None),
                                        'PDBX_COMPONENT_NO': ('chem_comp', 'pdbx_component_no', None, None),
                                        'PDBX_FORMAL_CHARGE': ('chem_comp', 'pdbx_formal_charge', None, None),
                                        'PDBX_IDEAL_COORDINATES_DETAILS': ('chem_comp',
                                                                           'pdbx_ideal_coordinates_details',
                                                                           None,
                                                                           None),
                                        'PDBX_IDEAL_COORDINATES_MISSING_FLAG': ('chem_comp',
                                                                                'pdbx_ideal_coordinates_missing_flag',
                                                                                None,
                                                                                None),
                                        'PDBX_INITIAL_DATE': ('chem_comp', 'pdbx_initial_date', None, None),
                                        'PDBX_MODEL_COORDINATES_DB_CODE': ('chem_comp',
                                                                           'pdbx_model_coordinates_db_code',
                                                                           None,
                                                                           None),
                                        'PDBX_MODEL_COORDINATES_DETAILS': ('chem_comp',
                                                                           'pdbx_model_coordinates_details',
                                                                           None,
                                                                           None),
                                        'PDBX_MODEL_COORDINATES_MISSING_FLAG': ('chem_comp',
                                                                                'pdbx_model_coordinates_missing_flag',
                                                                                None,
                                                                                None),
                                        'PDBX_MODIFICATION_DETAILS': ('chem_comp', 'pdbx_modification_details', None, None),
                                        'PDBX_MODIFIED_DATE': ('chem_comp', 'pdbx_modified_date', None, None),
                                        'PDBX_PROCESSING_SITE': ('chem_comp', 'pdbx_processing_site', None, None),
                                        'PDBX_RELEASE_STATUS': ('chem_comp', 'pdbx_release_status', None, None),
                                        'PDBX_REPLACED_BY': ('chem_comp', 'pdbx_replaced_by', None, None),
                                        'PDBX_REPLACES': ('chem_comp', 'pdbx_replaces', None, None),
                                        'PDBX_SUBCOMPONENT_LIST': ('chem_comp', 'pdbx_subcomponent_list', None, None),
                                        'PDBX_SYNONYMS': ('chem_comp', 'pdbx_synonyms', None, None),
                                        'PDBX_TYPE': ('chem_comp', 'pdbx_type', None, None),
                                        'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                        'THREE_LETTER_CODE': ('chem_comp', 'three_letter_code', None, None),
                                        'TYPE': ('chem_comp', 'type', None, None)},
                      'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                  's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                      'MAP_MERGE_INDICES': {'chem_comp': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                      'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                      'TABLE_ID': 'CHEM_COMP',
                      'TABLE_NAME': 'chem_comp',
                      'TABLE_TYPE': 'transactional'},
        'CHEM_COMP_ANGLE': {'ATTRIBUTES': {'ATOM_ID_1': 'atom_id_1',
                                           'ATOM_ID_2': 'atom_id_2',
                                           'ATOM_ID_3': 'atom_id_3',
                                           'COMP_ID': 'comp_id',
                                           'STRUCTURE_ID': 'Structure_ID',
                                           'VALUE_ANGLE': 'value_angle',
                                           'VALUE_ANGLE_ESD': 'value_angle_esd',
                                           'VALUE_DIST': 'value_dist',
                                           'VALUE_DIST_ESD': 'value_dist_esd'},
                            'ATTRIBUTE_INFO': {'ATOM_ID_1': {'NULLABLE': False,
                                                             'ORDER': 3,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 6},
                                               'ATOM_ID_2': {'NULLABLE': False,
                                                             'ORDER': 4,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 6},
                                               'ATOM_ID_3': {'NULLABLE': False,
                                                             'ORDER': 5,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 6},
                                               'COMP_ID': {'NULLABLE': False,
                                                           'ORDER': 2,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': True,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 10},
                                               'STRUCTURE_ID': {'NULLABLE': False,
                                                                'ORDER': 1,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                               'VALUE_ANGLE': {'NULLABLE': True,
                                                               'ORDER': 6,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                               'VALUE_ANGLE_ESD': {'NULLABLE': True,
                                                                   'ORDER': 7,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                               'VALUE_DIST': {'NULLABLE': True,
                                                              'ORDER': 8,
                                                              'PRECISION': 6,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'FLOAT',
                                                              'WIDTH': 10},
                                               'VALUE_DIST_ESD': {'NULLABLE': True,
                                                                  'ORDER': 9,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10}},
                            'ATTRIBUTE_MAP': {'ATOM_ID_1': ('chem_comp_angle', 'atom_id_1', None, None),
                                              'ATOM_ID_2': ('chem_comp_angle', 'atom_id_2', None, None),
                                              'ATOM_ID_3': ('chem_comp_angle', 'atom_id_3', None, None),
                                              'COMP_ID': ('chem_comp_angle', 'comp_id', None, None),
                                              'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                              'VALUE_ANGLE': ('chem_comp_angle', 'value_angle', None, None),
                                              'VALUE_ANGLE_ESD': ('chem_comp_angle', 'value_angle_esd', None, None),
                                              'VALUE_DIST': ('chem_comp_angle', 'value_dist', None, None),
                                              'VALUE_DIST_ESD': ('chem_comp_angle', 'value_dist_esd', None, None)},
                            'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID',
                                                              'COMP_ID',
                                                              'ATOM_ID_1',
                                                              'ATOM_ID_2',
                                                              'ATOM_ID_3'),
                                               'TYPE': 'UNIQUE'},
                                        's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                            'MAP_MERGE_INDICES': {'chem_comp_angle': {'ATTRIBUTES': ('comp_id',
                                                                                     'atom_id_1',
                                                                                     'atom_id_2',
                                                                                     'atom_id_3'),
                                                                      'TYPE': 'EQUI-JOIN'}},
                            'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                            'TABLE_ID': 'CHEM_COMP_ANGLE',
                            'TABLE_NAME': 'chem_comp_angle',
                            'TABLE_TYPE': 'transactional'},
        'CHEM_COMP_ATOM': {'ATTRIBUTES': {'ALT_ATOM_ID': 'alt_atom_id',
                                          'ATOM_ID': 'atom_id',
                                          'CHARGE': 'charge',
                                          'COMP_ID': 'comp_id',
                                          'MODEL_CARTN_X': 'model_Cartn_x',
                                          'MODEL_CARTN_X_ESD': 'model_Cartn_x_esd',
                                          'MODEL_CARTN_Y': 'model_Cartn_y',
                                          'MODEL_CARTN_Y_ESD': 'model_Cartn_y_esd',
                                          'MODEL_CARTN_Z': 'model_Cartn_z',
                                          'MODEL_CARTN_Z_ESD': 'model_Cartn_z_esd',
                                          'PARTIAL_CHARGE': 'partial_charge',
                                          'PDBX_ALIGN': 'pdbx_align',
                                          'PDBX_ALT_ATOM_ID': 'pdbx_alt_atom_id',
                                          'PDBX_ALT_COMP_ID': 'pdbx_alt_comp_id',
                                          'PDBX_AROMATIC_FLAG': 'pdbx_aromatic_flag',
                                          'PDBX_COMPONENT_ATOM_ID': 'pdbx_component_atom_id',
                                          'PDBX_COMPONENT_COMP_ID': 'pdbx_component_comp_id',
                                          'PDBX_LEAVING_ATOM_FLAG': 'pdbx_leaving_atom_flag',
                                          'PDBX_MODEL_CARTN_X_IDEAL': 'pdbx_model_Cartn_x_ideal',
                                          'PDBX_MODEL_CARTN_Y_IDEAL': 'pdbx_model_Cartn_y_ideal',
                                          'PDBX_MODEL_CARTN_Z_IDEAL': 'pdbx_model_Cartn_z_ideal',
                                          'PDBX_ORDINAL': 'pdbx_ordinal',
                                          'PDBX_STEREO_CONFIG': 'pdbx_stereo_config',
                                          'STRUCTURE_ID': 'Structure_ID',
                                          'SUBSTRUCT_CODE': 'substruct_code',
                                          'TYPE_SYMBOL': 'type_symbol'},
                           'ATTRIBUTE_INFO': {'ALT_ATOM_ID': {'NULLABLE': True,
                                                              'ORDER': 3,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 80},
                                              'ATOM_ID': {'NULLABLE': False,
                                                          'ORDER': 4,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': True,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 6},
                                              'CHARGE': {'NULLABLE': True,
                                                         'ORDER': 5,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'INT',
                                                         'WIDTH': 10},
                                              'COMP_ID': {'NULLABLE': False,
                                                          'ORDER': 2,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': True,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 10},
                                              'MODEL_CARTN_X': {'NULLABLE': True,
                                                                'ORDER': 6,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                              'MODEL_CARTN_X_ESD': {'NULLABLE': True,
                                                                    'ORDER': 7,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                              'MODEL_CARTN_Y': {'NULLABLE': True,
                                                                'ORDER': 8,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                              'MODEL_CARTN_Y_ESD': {'NULLABLE': True,
                                                                    'ORDER': 9,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                              'MODEL_CARTN_Z': {'NULLABLE': True,
                                                                'ORDER': 10,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                              'MODEL_CARTN_Z_ESD': {'NULLABLE': True,
                                                                    'ORDER': 11,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                              'PARTIAL_CHARGE': {'NULLABLE': True,
                                                                 'ORDER': 12,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                              'PDBX_ALIGN': {'NULLABLE': True,
                                                             'ORDER': 15,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'INT',
                                                             'WIDTH': 10},
                                              'PDBX_ALT_ATOM_ID': {'NULLABLE': True,
                                                                   'ORDER': 19,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 6},
                                              'PDBX_ALT_COMP_ID': {'NULLABLE': True,
                                                                   'ORDER': 20,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 10},
                                              'PDBX_AROMATIC_FLAG': {'NULLABLE': True,
                                                                     'ORDER': 25,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                              'PDBX_COMPONENT_ATOM_ID': {'NULLABLE': True,
                                                                         'ORDER': 17,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 6},
                                              'PDBX_COMPONENT_COMP_ID': {'NULLABLE': True,
                                                                         'ORDER': 18,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                              'PDBX_LEAVING_ATOM_FLAG': {'NULLABLE': True,
                                                                         'ORDER': 26,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                              'PDBX_MODEL_CARTN_X_IDEAL': {'NULLABLE': True,
                                                                           'ORDER': 21,
                                                                           'PRECISION': 6,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'FLOAT',
                                                                           'WIDTH': 10},
                                              'PDBX_MODEL_CARTN_Y_IDEAL': {'NULLABLE': True,
                                                                           'ORDER': 22,
                                                                           'PRECISION': 6,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'FLOAT',
                                                                           'WIDTH': 10},
                                              'PDBX_MODEL_CARTN_Z_IDEAL': {'NULLABLE': True,
                                                                           'ORDER': 23,
                                                                           'PRECISION': 6,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'FLOAT',
                                                                           'WIDTH': 10},
                                              'PDBX_ORDINAL': {'NULLABLE': True,
                                                               'ORDER': 16,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'INT',
                                                               'WIDTH': 10},
                                              'PDBX_STEREO_CONFIG': {'NULLABLE': True,
                                                                     'ORDER': 24,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                              'STRUCTURE_ID': {'NULLABLE': False,
                                                               'ORDER': 1,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                              'SUBSTRUCT_CODE': {'NULLABLE': True,
                                                                 'ORDER': 13,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                              'TYPE_SYMBOL': {'NULLABLE': True,
                                                              'ORDER': 14,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10}},
                           'ATTRIBUTE_MAP': {'ALT_ATOM_ID': ('chem_comp_atom', 'alt_atom_id', None, None),
                                             'ATOM_ID': ('chem_comp_atom', 'atom_id', None, None),
                                             'CHARGE': ('chem_comp_atom', 'charge', None, None),
                                             'COMP_ID': ('chem_comp_atom', 'comp_id', None, None),
                                             'MODEL_CARTN_X': ('chem_comp_atom', 'model_Cartn_x', None, None),
                                             'MODEL_CARTN_X_ESD': ('chem_comp_atom', 'model_Cartn_x_esd', None, None),
                                             'MODEL_CARTN_Y': ('chem_comp_atom', 'model_Cartn_y', None, None),
                                             'MODEL_CARTN_Y_ESD': ('chem_comp_atom', 'model_Cartn_y_esd', None, None),
                                             'MODEL_CARTN_Z': ('chem_comp_atom', 'model_Cartn_z', None, None),
                                             'MODEL_CARTN_Z_ESD': ('chem_comp_atom', 'model_Cartn_z_esd', None, None),
                                             'PARTIAL_CHARGE': ('chem_comp_atom', 'partial_charge', None, None),
                                             'PDBX_ALIGN': ('chem_comp_atom', 'pdbx_align', None, None),
                                             'PDBX_ALT_ATOM_ID': ('chem_comp_atom', 'pdbx_alt_atom_id', None, None),
                                             'PDBX_ALT_COMP_ID': ('chem_comp_atom', 'pdbx_alt_comp_id', None, None),
                                             'PDBX_AROMATIC_FLAG': ('chem_comp_atom', 'pdbx_aromatic_flag', None, None),
                                             'PDBX_COMPONENT_ATOM_ID': ('chem_comp_atom',
                                                                        'pdbx_component_atom_id',
                                                                        None,
                                                                        None),
                                             'PDBX_COMPONENT_COMP_ID': ('chem_comp_atom',
                                                                        'pdbx_component_comp_id',
                                                                        None,
                                                                        None),
                                             'PDBX_LEAVING_ATOM_FLAG': ('chem_comp_atom',
                                                                        'pdbx_leaving_atom_flag',
                                                                        None,
                                                                        None),
                                             'PDBX_MODEL_CARTN_X_IDEAL': ('chem_comp_atom',
                                                                          'pdbx_model_Cartn_x_ideal',
                                                                          None,
                                                                          None),
                                             'PDBX_MODEL_CARTN_Y_IDEAL': ('chem_comp_atom',
                                                                          'pdbx_model_Cartn_y_ideal',
                                                                          None,
                                                                          None),
                                             'PDBX_MODEL_CARTN_Z_IDEAL': ('chem_comp_atom',
                                                                          'pdbx_model_Cartn_z_ideal',
                                                                          None,
                                                                          None),
                                             'PDBX_ORDINAL': ('chem_comp_atom', 'pdbx_ordinal', None, None),
                                             'PDBX_STEREO_CONFIG': ('chem_comp_atom', 'pdbx_stereo_config', None, None),
                                             'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                             'SUBSTRUCT_CODE': ('chem_comp_atom', 'substruct_code', None, None),
                                             'TYPE_SYMBOL': ('chem_comp_atom', 'type_symbol', None, None)},
                           'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'COMP_ID', 'ATOM_ID'), 'TYPE': 'UNIQUE'},
                                       's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                           'MAP_MERGE_INDICES': {'chem_comp_atom': {'ATTRIBUTES': ('comp_id', 'atom_id'),
                                                                    'TYPE': 'EQUI-JOIN'}},
                           'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                           'TABLE_ID': 'CHEM_COMP_ATOM',
                           'TABLE_NAME': 'chem_comp_atom',
                           'TABLE_TYPE': 'transactional'},
        'CHEM_COMP_BOND': {'ATTRIBUTES': {'ATOM_ID_1': 'atom_id_1',
                                          'ATOM_ID_2': 'atom_id_2',
                                          'COMP_ID': 'comp_id',
                                          'PDBX_AROMATIC_FLAG': 'pdbx_aromatic_flag',
                                          'PDBX_ORDINAL': 'pdbx_ordinal',
                                          'PDBX_STEREO_CONFIG': 'pdbx_stereo_config',
                                          'STRUCTURE_ID': 'Structure_ID',
                                          'VALUE_DIST': 'value_dist',
                                          'VALUE_DIST_ESD': 'value_dist_esd',
                                          'VALUE_ORDER': 'value_order'},
                           'ATTRIBUTE_INFO': {'ATOM_ID_1': {'NULLABLE': False,
                                                            'ORDER': 3,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': True,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 6},
                                              'ATOM_ID_2': {'NULLABLE': False,
                                                            'ORDER': 4,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': True,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 6},
                                              'COMP_ID': {'NULLABLE': False,
                                                          'ORDER': 2,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': True,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 10},
                                              'PDBX_AROMATIC_FLAG': {'NULLABLE': True,
                                                                     'ORDER': 10,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                              'PDBX_ORDINAL': {'NULLABLE': True,
                                                               'ORDER': 8,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'INT',
                                                               'WIDTH': 10},
                                              'PDBX_STEREO_CONFIG': {'NULLABLE': True,
                                                                     'ORDER': 9,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                              'STRUCTURE_ID': {'NULLABLE': False,
                                                               'ORDER': 1,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                              'VALUE_DIST': {'NULLABLE': True,
                                                             'ORDER': 6,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                              'VALUE_DIST_ESD': {'NULLABLE': True,
                                                                 'ORDER': 7,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                              'VALUE_ORDER': {'NULLABLE': True,
                                                              'ORDER': 5,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10}},
                           'ATTRIBUTE_MAP': {'ATOM_ID_1': ('chem_comp_bond', 'atom_id_1', None, None),
                                             'ATOM_ID_2': ('chem_comp_bond', 'atom_id_2', None, None),
                                             'COMP_ID': ('chem_comp_bond', 'comp_id', None, None),
                                             'PDBX_AROMATIC_FLAG': ('chem_comp_bond', 'pdbx_aromatic_flag', None, None),
                                             'PDBX_ORDINAL': ('chem_comp_bond', 'pdbx_ordinal', None, None),
                                             'PDBX_STEREO_CONFIG': ('chem_comp_bond', 'pdbx_stereo_config', None, None),
                                             'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                             'VALUE_DIST': ('chem_comp_bond', 'value_dist', None, None),
                                             'VALUE_DIST_ESD': ('chem_comp_bond', 'value_dist_esd', None, None),
                                             'VALUE_ORDER': ('chem_comp_bond', 'value_order', None, None)},
                           'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'COMP_ID', 'ATOM_ID_1', 'ATOM_ID_2'),
                                              'TYPE': 'UNIQUE'},
                                       's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                           'MAP_MERGE_INDICES': {'chem_comp_bond': {'ATTRIBUTES': ('comp_id', 'atom_id_1', 'atom_id_2'),
                                                                    'TYPE': 'EQUI-JOIN'}},
                           'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                           'TABLE_ID': 'CHEM_COMP_BOND',
                           'TABLE_NAME': 'chem_comp_bond',
                           'TABLE_TYPE': 'transactional'},
        'CHEM_COMP_CHIR': {'ATTRIBUTES': {'ATOM_CONFIG': 'atom_config',
                                          'ATOM_ID': 'atom_id',
                                          'COMP_ID': 'comp_id',
                                          'ID': 'id',
                                          'NUMBER_ATOMS_ALL': 'number_atoms_all',
                                          'NUMBER_ATOMS_NH': 'number_atoms_nh',
                                          'STRUCTURE_ID': 'Structure_ID',
                                          'VOLUME_FLAG': 'volume_flag',
                                          'VOLUME_THREE': 'volume_three',
                                          'VOLUME_THREE_ESD': 'volume_three_esd'},
                           'ATTRIBUTE_INFO': {'ATOM_CONFIG': {'NULLABLE': True,
                                                              'ORDER': 4,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10},
                                              'ATOM_ID': {'NULLABLE': True,
                                                          'ORDER': 3,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 6},
                                              'COMP_ID': {'NULLABLE': False,
                                                          'ORDER': 2,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': True,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 10},
                                              'ID': {'NULLABLE': False,
                                                     'ORDER': 5,
                                                     'PRECISION': 0,
                                                     'PRIMARY_KEY': True,
                                                     'SQL_TYPE': 'VARCHAR',
                                                     'WIDTH': 10},
                                              'NUMBER_ATOMS_ALL': {'NULLABLE': True,
                                                                   'ORDER': 6,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'INT',
                                                                   'WIDTH': 10},
                                              'NUMBER_ATOMS_NH': {'NULLABLE': True,
                                                                  'ORDER': 7,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'INT',
                                                                  'WIDTH': 10},
                                              'STRUCTURE_ID': {'NULLABLE': False,
                                                               'ORDER': 1,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                              'VOLUME_FLAG': {'NULLABLE': True,
                                                              'ORDER': 8,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10},
                                              'VOLUME_THREE': {'NULLABLE': True,
                                                               'ORDER': 9,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                              'VOLUME_THREE_ESD': {'NULLABLE': True,
                                                                   'ORDER': 10,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10}},
                           'ATTRIBUTE_MAP': {'ATOM_CONFIG': ('chem_comp_chir', 'atom_config', None, None),
                                             'ATOM_ID': ('chem_comp_chir', 'atom_id', None, None),
                                             'COMP_ID': ('chem_comp_chir', 'comp_id', None, None),
                                             'ID': ('chem_comp_chir', 'id', None, None),
                                             'NUMBER_ATOMS_ALL': ('chem_comp_chir', 'number_atoms_all', None, None),
                                             'NUMBER_ATOMS_NH': ('chem_comp_chir', 'number_atoms_nh', None, None),
                                             'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                             'VOLUME_FLAG': ('chem_comp_chir', 'volume_flag', None, None),
                                             'VOLUME_THREE': ('chem_comp_chir', 'volume_three', None, None),
                                             'VOLUME_THREE_ESD': ('chem_comp_chir', 'volume_three_esd', None, None)},
                           'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'COMP_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                       's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                           'MAP_MERGE_INDICES': {'chem_comp_chir': {'ATTRIBUTES': ('comp_id', 'id'), 'TYPE': 'EQUI-JOIN'}},
                           'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                           'TABLE_ID': 'CHEM_COMP_CHIR',
                           'TABLE_NAME': 'chem_comp_chir',
                           'TABLE_TYPE': 'transactional'},
        'CHEM_COMP_CHIR_ATOM': {'ATTRIBUTES': {'ATOM_ID': 'atom_id',
                                               'CHIR_ID': 'chir_id',
                                               'COMP_ID': 'comp_id',
                                               'DEV': 'dev',
                                               'STRUCTURE_ID': 'Structure_ID'},
                                'ATTRIBUTE_INFO': {'ATOM_ID': {'NULLABLE': False,
                                                               'ORDER': 3,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 6},
                                                   'CHIR_ID': {'NULLABLE': False,
                                                               'ORDER': 4,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                                   'COMP_ID': {'NULLABLE': False,
                                                               'ORDER': 2,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                                   'DEV': {'NULLABLE': True,
                                                           'ORDER': 5,
                                                           'PRECISION': 6,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'FLOAT',
                                                           'WIDTH': 10},
                                                   'STRUCTURE_ID': {'NULLABLE': False,
                                                                    'ORDER': 1,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': True,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10}},
                                'ATTRIBUTE_MAP': {'ATOM_ID': ('chem_comp_chir_atom', 'atom_id', None, None),
                                                  'CHIR_ID': ('chem_comp_chir_atom', 'chir_id', None, None),
                                                  'COMP_ID': ('chem_comp_chir_atom', 'comp_id', None, None),
                                                  'DEV': ('chem_comp_chir_atom', 'dev', None, None),
                                                  'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'COMP_ID', 'ATOM_ID', 'CHIR_ID'),
                                                   'TYPE': 'UNIQUE'},
                                            's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                'MAP_MERGE_INDICES': {'chem_comp_chir_atom': {'ATTRIBUTES': ('comp_id', 'atom_id', 'chir_id'),
                                                                              'TYPE': 'EQUI-JOIN'}},
                                'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                'TABLE_ID': 'CHEM_COMP_CHIR_ATOM',
                                'TABLE_NAME': 'chem_comp_chir_atom',
                                'TABLE_TYPE': 'transactional'},
        'CHEM_COMP_LINK': {'ATTRIBUTES': {'DETAILS': 'details',
                                          'LINK_ID': 'link_id',
                                          'STRUCTURE_ID': 'Structure_ID',
                                          'TYPE_COMP_1': 'type_comp_1',
                                          'TYPE_COMP_2': 'type_comp_2'},
                           'ATTRIBUTE_INFO': {'DETAILS': {'NULLABLE': True,
                                                          'ORDER': 5,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 200},
                                              'LINK_ID': {'NULLABLE': False,
                                                          'ORDER': 4,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': True,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 10},
                                              'STRUCTURE_ID': {'NULLABLE': False,
                                                               'ORDER': 1,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                              'TYPE_COMP_1': {'NULLABLE': True,
                                                              'ORDER': 2,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 80},
                                              'TYPE_COMP_2': {'NULLABLE': True,
                                                              'ORDER': 3,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 80}},
                           'ATTRIBUTE_MAP': {'DETAILS': ('chem_comp_link', 'details', None, None),
                                             'LINK_ID': ('chem_comp_link', 'link_id', None, None),
                                             'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                             'TYPE_COMP_1': ('chem_comp_link', 'type_comp_1', None, None),
                                             'TYPE_COMP_2': ('chem_comp_link', 'type_comp_2', None, None)},
                           'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'LINK_ID'), 'TYPE': 'UNIQUE'},
                                       's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                           'MAP_MERGE_INDICES': {'chem_comp_link': {'ATTRIBUTES': ('link_id',), 'TYPE': 'EQUI-JOIN'}},
                           'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                           'TABLE_ID': 'CHEM_COMP_LINK',
                           'TABLE_NAME': 'chem_comp_link',
                           'TABLE_TYPE': 'transactional'},
        'CHEM_COMP_PLANE': {'ATTRIBUTES': {'COMP_ID': 'comp_id',
                                           'ID': 'id',
                                           'NUMBER_ATOMS_ALL': 'number_atoms_all',
                                           'NUMBER_ATOMS_NH': 'number_atoms_nh',
                                           'STRUCTURE_ID': 'Structure_ID'},
                            'ATTRIBUTE_INFO': {'COMP_ID': {'NULLABLE': False,
                                                           'ORDER': 2,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': True,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 10},
                                               'ID': {'NULLABLE': False,
                                                      'ORDER': 3,
                                                      'PRECISION': 0,
                                                      'PRIMARY_KEY': True,
                                                      'SQL_TYPE': 'VARCHAR',
                                                      'WIDTH': 10},
                                               'NUMBER_ATOMS_ALL': {'NULLABLE': True,
                                                                    'ORDER': 4,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'INT',
                                                                    'WIDTH': 10},
                                               'NUMBER_ATOMS_NH': {'NULLABLE': True,
                                                                   'ORDER': 5,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'INT',
                                                                   'WIDTH': 10},
                                               'STRUCTURE_ID': {'NULLABLE': False,
                                                                'ORDER': 1,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10}},
                            'ATTRIBUTE_MAP': {'COMP_ID': ('chem_comp_plane', 'comp_id', None, None),
                                              'ID': ('chem_comp_plane', 'id', None, None),
                                              'NUMBER_ATOMS_ALL': ('chem_comp_plane', 'number_atoms_all', None, None),
                                              'NUMBER_ATOMS_NH': ('chem_comp_plane', 'number_atoms_nh', None, None),
                                              'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                            'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'COMP_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                        's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                            'MAP_MERGE_INDICES': {'chem_comp_plane': {'ATTRIBUTES': ('comp_id', 'id'), 'TYPE': 'EQUI-JOIN'}},
                            'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                            'TABLE_ID': 'CHEM_COMP_PLANE',
                            'TABLE_NAME': 'chem_comp_plane',
                            'TABLE_TYPE': 'transactional'},
        'CHEM_COMP_PLANE_ATOM': {'ATTRIBUTES': {'ATOM_ID': 'atom_id',
                                                'COMP_ID': 'comp_id',
                                                'DIST_ESD': 'dist_esd',
                                                'PLANE_ID': 'plane_id',
                                                'STRUCTURE_ID': 'Structure_ID'},
                                 'ATTRIBUTE_INFO': {'ATOM_ID': {'NULLABLE': False,
                                                                'ORDER': 3,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 6},
                                                    'COMP_ID': {'NULLABLE': False,
                                                                'ORDER': 2,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                                    'DIST_ESD': {'NULLABLE': True,
                                                                 'ORDER': 5,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                                    'PLANE_ID': {'NULLABLE': False,
                                                                 'ORDER': 4,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': True,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                                    'STRUCTURE_ID': {'NULLABLE': False,
                                                                     'ORDER': 1,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': True,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10}},
                                 'ATTRIBUTE_MAP': {'ATOM_ID': ('chem_comp_plane_atom', 'atom_id', None, None),
                                                   'COMP_ID': ('chem_comp_plane_atom', 'comp_id', None, None),
                                                   'DIST_ESD': ('chem_comp_plane_atom', 'dist_esd', None, None),
                                                   'PLANE_ID': ('chem_comp_plane_atom', 'plane_id', None, None),
                                                   'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                 'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'COMP_ID', 'ATOM_ID', 'PLANE_ID'),
                                                    'TYPE': 'UNIQUE'},
                                             's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                 'MAP_MERGE_INDICES': {'chem_comp_plane_atom': {'ATTRIBUTES': ('comp_id',
                                                                                               'atom_id',
                                                                                               'plane_id'),
                                                                                'TYPE': 'EQUI-JOIN'}},
                                 'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                 'TABLE_ID': 'CHEM_COMP_PLANE_ATOM',
                                 'TABLE_NAME': 'chem_comp_plane_atom',
                                 'TABLE_TYPE': 'transactional'},
        'CHEM_COMP_TOR': {'ATTRIBUTES': {'ATOM_ID_1': 'atom_id_1',
                                         'ATOM_ID_2': 'atom_id_2',
                                         'ATOM_ID_3': 'atom_id_3',
                                         'ATOM_ID_4': 'atom_id_4',
                                         'COMP_ID': 'comp_id',
                                         'ID': 'id',
                                         'STRUCTURE_ID': 'Structure_ID'},
                          'ATTRIBUTE_INFO': {'ATOM_ID_1': {'NULLABLE': True,
                                                           'ORDER': 3,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 6},
                                             'ATOM_ID_2': {'NULLABLE': True,
                                                           'ORDER': 4,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 6},
                                             'ATOM_ID_3': {'NULLABLE': True,
                                                           'ORDER': 5,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 6},
                                             'ATOM_ID_4': {'NULLABLE': True,
                                                           'ORDER': 6,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 6},
                                             'COMP_ID': {'NULLABLE': False,
                                                         'ORDER': 2,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': True,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 10},
                                             'ID': {'NULLABLE': False,
                                                    'ORDER': 7,
                                                    'PRECISION': 0,
                                                    'PRIMARY_KEY': True,
                                                    'SQL_TYPE': 'VARCHAR',
                                                    'WIDTH': 10},
                                             'STRUCTURE_ID': {'NULLABLE': False,
                                                              'ORDER': 1,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10}},
                          'ATTRIBUTE_MAP': {'ATOM_ID_1': ('chem_comp_tor', 'atom_id_1', None, None),
                                            'ATOM_ID_2': ('chem_comp_tor', 'atom_id_2', None, None),
                                            'ATOM_ID_3': ('chem_comp_tor', 'atom_id_3', None, None),
                                            'ATOM_ID_4': ('chem_comp_tor', 'atom_id_4', None, None),
                                            'COMP_ID': ('chem_comp_tor', 'comp_id', None, None),
                                            'ID': ('chem_comp_tor', 'id', None, None),
                                            'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                          'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'COMP_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                      's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                          'MAP_MERGE_INDICES': {'chem_comp_tor': {'ATTRIBUTES': ('comp_id', 'id'), 'TYPE': 'EQUI-JOIN'}},
                          'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                          'TABLE_ID': 'CHEM_COMP_TOR',
                          'TABLE_NAME': 'chem_comp_tor',
                          'TABLE_TYPE': 'transactional'},
        'CHEM_COMP_TOR_VALUE': {'ATTRIBUTES': {'ANGLE': 'angle',
                                               'ANGLE_ESD': 'angle_esd',
                                               'COMP_ID': 'comp_id',
                                               'DIST': 'dist',
                                               'DIST_ESD': 'dist_esd',
                                               'STRUCTURE_ID': 'Structure_ID',
                                               'TOR_ID': 'tor_id'},
                                'ATTRIBUTE_INFO': {'ANGLE': {'NULLABLE': True,
                                                             'ORDER': 4,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                                   'ANGLE_ESD': {'NULLABLE': True,
                                                                 'ORDER': 5,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                                   'COMP_ID': {'NULLABLE': False,
                                                               'ORDER': 2,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                                   'DIST': {'NULLABLE': True,
                                                            'ORDER': 6,
                                                            'PRECISION': 6,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'FLOAT',
                                                            'WIDTH': 10},
                                                   'DIST_ESD': {'NULLABLE': True,
                                                                'ORDER': 7,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                                   'STRUCTURE_ID': {'NULLABLE': False,
                                                                    'ORDER': 1,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': True,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10},
                                                   'TOR_ID': {'NULLABLE': False,
                                                              'ORDER': 3,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10}},
                                'ATTRIBUTE_MAP': {'ANGLE': ('chem_comp_tor_value', 'angle', None, None),
                                                  'ANGLE_ESD': ('chem_comp_tor_value', 'angle_esd', None, None),
                                                  'COMP_ID': ('chem_comp_tor_value', 'comp_id', None, None),
                                                  'DIST': ('chem_comp_tor_value', 'dist', None, None),
                                                  'DIST_ESD': ('chem_comp_tor_value', 'dist_esd', None, None),
                                                  'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                  'TOR_ID': ('chem_comp_tor_value', 'tor_id', None, None)},
                                'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'COMP_ID', 'TOR_ID'), 'TYPE': 'UNIQUE'},
                                            's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                'MAP_MERGE_INDICES': {'chem_comp_tor_value': {'ATTRIBUTES': ('comp_id', 'tor_id'),
                                                                              'TYPE': 'EQUI-JOIN'}},
                                'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                'TABLE_ID': 'CHEM_COMP_TOR_VALUE',
                                'TABLE_NAME': 'chem_comp_tor_value',
                                'TABLE_TYPE': 'transactional'},
        'CHEM_LINK': {'ATTRIBUTES': {'DETAILS': 'details', 'ID': 'id', 'STRUCTURE_ID': 'Structure_ID'},
                      'ATTRIBUTE_INFO': {'DETAILS': {'NULLABLE': True,
                                                     'ORDER': 3,
                                                     'PRECISION': 0,
                                                     'PRIMARY_KEY': False,
                                                     'SQL_TYPE': 'VARCHAR',
                                                     'WIDTH': 200},
                                         'ID': {'NULLABLE': False,
                                                'ORDER': 2,
                                                'PRECISION': 0,
                                                'PRIMARY_KEY': True,
                                                'SQL_TYPE': 'VARCHAR',
                                                'WIDTH': 10},
                                         'STRUCTURE_ID': {'NULLABLE': False,
                                                          'ORDER': 1,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': True,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 10}},
                      'ATTRIBUTE_MAP': {'DETAILS': ('chem_link', 'details', None, None),
                                        'ID': ('chem_link', 'id', None, None),
                                        'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                      'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                  's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                      'MAP_MERGE_INDICES': {'chem_link': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                      'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                      'TABLE_ID': 'CHEM_LINK',
                      'TABLE_NAME': 'chem_link',
                      'TABLE_TYPE': 'transactional'},
        'CHEM_LINK_ANGLE': {'ATTRIBUTES': {'ATOM_1_COMP_ID': 'atom_1_comp_id',
                                           'ATOM_2_COMP_ID': 'atom_2_comp_id',
                                           'ATOM_3_COMP_ID': 'atom_3_comp_id',
                                           'ATOM_ID_1': 'atom_id_1',
                                           'ATOM_ID_2': 'atom_id_2',
                                           'ATOM_ID_3': 'atom_id_3',
                                           'LINK_ID': 'link_id',
                                           'STRUCTURE_ID': 'Structure_ID',
                                           'VALUE_ANGLE': 'value_angle',
                                           'VALUE_ANGLE_ESD': 'value_angle_esd',
                                           'VALUE_DIST': 'value_dist',
                                           'VALUE_DIST_ESD': 'value_dist_esd'},
                            'ATTRIBUTE_INFO': {'ATOM_1_COMP_ID': {'NULLABLE': True,
                                                                  'ORDER': 3,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10},
                                               'ATOM_2_COMP_ID': {'NULLABLE': True,
                                                                  'ORDER': 4,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10},
                                               'ATOM_3_COMP_ID': {'NULLABLE': True,
                                                                  'ORDER': 5,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10},
                                               'ATOM_ID_1': {'NULLABLE': False,
                                                             'ORDER': 6,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 10},
                                               'ATOM_ID_2': {'NULLABLE': False,
                                                             'ORDER': 7,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 10},
                                               'ATOM_ID_3': {'NULLABLE': False,
                                                             'ORDER': 8,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 10},
                                               'LINK_ID': {'NULLABLE': False,
                                                           'ORDER': 2,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': True,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 10},
                                               'STRUCTURE_ID': {'NULLABLE': False,
                                                                'ORDER': 1,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                               'VALUE_ANGLE': {'NULLABLE': True,
                                                               'ORDER': 9,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                               'VALUE_ANGLE_ESD': {'NULLABLE': True,
                                                                   'ORDER': 10,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                               'VALUE_DIST': {'NULLABLE': True,
                                                              'ORDER': 11,
                                                              'PRECISION': 6,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'FLOAT',
                                                              'WIDTH': 10},
                                               'VALUE_DIST_ESD': {'NULLABLE': True,
                                                                  'ORDER': 12,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10}},
                            'ATTRIBUTE_MAP': {'ATOM_1_COMP_ID': ('chem_link_angle', 'atom_1_comp_id', None, None),
                                              'ATOM_2_COMP_ID': ('chem_link_angle', 'atom_2_comp_id', None, None),
                                              'ATOM_3_COMP_ID': ('chem_link_angle', 'atom_3_comp_id', None, None),
                                              'ATOM_ID_1': ('chem_link_angle', 'atom_id_1', None, None),
                                              'ATOM_ID_2': ('chem_link_angle', 'atom_id_2', None, None),
                                              'ATOM_ID_3': ('chem_link_angle', 'atom_id_3', None, None),
                                              'LINK_ID': ('chem_link_angle', 'link_id', None, None),
                                              'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                              'VALUE_ANGLE': ('chem_link_angle', 'value_angle', None, None),
                                              'VALUE_ANGLE_ESD': ('chem_link_angle', 'value_angle_esd', None, None),
                                              'VALUE_DIST': ('chem_link_angle', 'value_dist', None, None),
                                              'VALUE_DIST_ESD': ('chem_link_angle', 'value_dist_esd', None, None)},
                            'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID',
                                                              'LINK_ID',
                                                              'ATOM_ID_1',
                                                              'ATOM_ID_2',
                                                              'ATOM_ID_3'),
                                               'TYPE': 'UNIQUE'},
                                        's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                            'MAP_MERGE_INDICES': {'chem_link_angle': {'ATTRIBUTES': ('link_id',
                                                                                     'atom_id_1',
                                                                                     'atom_id_2',
                                                                                     'atom_id_3'),
                                                                      'TYPE': 'EQUI-JOIN'}},
                            'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                            'TABLE_ID': 'CHEM_LINK_ANGLE',
                            'TABLE_NAME': 'chem_link_angle',
                            'TABLE_TYPE': 'transactional'},
        'CHEM_LINK_BOND': {'ATTRIBUTES': {'ATOM_1_COMP_ID': 'atom_1_comp_id',
                                          'ATOM_2_COMP_ID': 'atom_2_comp_id',
                                          'ATOM_ID_1': 'atom_id_1',
                                          'ATOM_ID_2': 'atom_id_2',
                                          'LINK_ID': 'link_id',
                                          'STRUCTURE_ID': 'Structure_ID',
                                          'VALUE_DIST': 'value_dist',
                                          'VALUE_DIST_ESD': 'value_dist_esd',
                                          'VALUE_ORDER': 'value_order'},
                           'ATTRIBUTE_INFO': {'ATOM_1_COMP_ID': {'NULLABLE': True,
                                                                 'ORDER': 3,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                              'ATOM_2_COMP_ID': {'NULLABLE': True,
                                                                 'ORDER': 4,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                              'ATOM_ID_1': {'NULLABLE': False,
                                                            'ORDER': 5,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': True,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 10},
                                              'ATOM_ID_2': {'NULLABLE': False,
                                                            'ORDER': 6,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': True,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 10},
                                              'LINK_ID': {'NULLABLE': False,
                                                          'ORDER': 2,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': True,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 10},
                                              'STRUCTURE_ID': {'NULLABLE': False,
                                                               'ORDER': 1,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                              'VALUE_DIST': {'NULLABLE': True,
                                                             'ORDER': 7,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                              'VALUE_DIST_ESD': {'NULLABLE': True,
                                                                 'ORDER': 8,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                              'VALUE_ORDER': {'NULLABLE': True,
                                                              'ORDER': 9,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10}},
                           'ATTRIBUTE_MAP': {'ATOM_1_COMP_ID': ('chem_link_bond', 'atom_1_comp_id', None, None),
                                             'ATOM_2_COMP_ID': ('chem_link_bond', 'atom_2_comp_id', None, None),
                                             'ATOM_ID_1': ('chem_link_bond', 'atom_id_1', None, None),
                                             'ATOM_ID_2': ('chem_link_bond', 'atom_id_2', None, None),
                                             'LINK_ID': ('chem_link_bond', 'link_id', None, None),
                                             'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                             'VALUE_DIST': ('chem_link_bond', 'value_dist', None, None),
                                             'VALUE_DIST_ESD': ('chem_link_bond', 'value_dist_esd', None, None),
                                             'VALUE_ORDER': ('chem_link_bond', 'value_order', None, None)},
                           'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'LINK_ID', 'ATOM_ID_1', 'ATOM_ID_2'),
                                              'TYPE': 'UNIQUE'},
                                       's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                           'MAP_MERGE_INDICES': {'chem_link_bond': {'ATTRIBUTES': ('link_id', 'atom_id_1', 'atom_id_2'),
                                                                    'TYPE': 'EQUI-JOIN'}},
                           'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                           'TABLE_ID': 'CHEM_LINK_BOND',
                           'TABLE_NAME': 'chem_link_bond',
                           'TABLE_TYPE': 'transactional'},
        'CHEM_LINK_CHIR': {'ATTRIBUTES': {'ATOM_COMP_ID': 'atom_comp_id',
                                          'ATOM_CONFIG': 'atom_config',
                                          'ATOM_ID': 'atom_id',
                                          'ID': 'id',
                                          'LINK_ID': 'link_id',
                                          'NUMBER_ATOMS_ALL': 'number_atoms_all',
                                          'NUMBER_ATOMS_NH': 'number_atoms_nh',
                                          'STRUCTURE_ID': 'Structure_ID',
                                          'VOLUME_FLAG': 'volume_flag',
                                          'VOLUME_THREE': 'volume_three',
                                          'VOLUME_THREE_ESD': 'volume_three_esd'},
                           'ATTRIBUTE_INFO': {'ATOM_COMP_ID': {'NULLABLE': True,
                                                               'ORDER': 3,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                              'ATOM_CONFIG': {'NULLABLE': True,
                                                              'ORDER': 5,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10},
                                              'ATOM_ID': {'NULLABLE': True,
                                                          'ORDER': 4,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 10},
                                              'ID': {'NULLABLE': False,
                                                     'ORDER': 6,
                                                     'PRECISION': 0,
                                                     'PRIMARY_KEY': True,
                                                     'SQL_TYPE': 'VARCHAR',
                                                     'WIDTH': 10},
                                              'LINK_ID': {'NULLABLE': False,
                                                          'ORDER': 2,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': True,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 10},
                                              'NUMBER_ATOMS_ALL': {'NULLABLE': True,
                                                                   'ORDER': 7,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'INT',
                                                                   'WIDTH': 10},
                                              'NUMBER_ATOMS_NH': {'NULLABLE': True,
                                                                  'ORDER': 8,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'INT',
                                                                  'WIDTH': 10},
                                              'STRUCTURE_ID': {'NULLABLE': False,
                                                               'ORDER': 1,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                              'VOLUME_FLAG': {'NULLABLE': True,
                                                              'ORDER': 9,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10},
                                              'VOLUME_THREE': {'NULLABLE': True,
                                                               'ORDER': 10,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                              'VOLUME_THREE_ESD': {'NULLABLE': True,
                                                                   'ORDER': 11,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10}},
                           'ATTRIBUTE_MAP': {'ATOM_COMP_ID': ('chem_link_chir', 'atom_comp_id', None, None),
                                             'ATOM_CONFIG': ('chem_link_chir', 'atom_config', None, None),
                                             'ATOM_ID': ('chem_link_chir', 'atom_id', None, None),
                                             'ID': ('chem_link_chir', 'id', None, None),
                                             'LINK_ID': ('chem_link_chir', 'link_id', None, None),
                                             'NUMBER_ATOMS_ALL': ('chem_link_chir', 'number_atoms_all', None, None),
                                             'NUMBER_ATOMS_NH': ('chem_link_chir', 'number_atoms_nh', None, None),
                                             'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                             'VOLUME_FLAG': ('chem_link_chir', 'volume_flag', None, None),
                                             'VOLUME_THREE': ('chem_link_chir', 'volume_three', None, None),
                                             'VOLUME_THREE_ESD': ('chem_link_chir', 'volume_three_esd', None, None)},
                           'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'LINK_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                       's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                           'MAP_MERGE_INDICES': {'chem_link_chir': {'ATTRIBUTES': ('link_id', 'id'), 'TYPE': 'EQUI-JOIN'}},
                           'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                           'TABLE_ID': 'CHEM_LINK_CHIR',
                           'TABLE_NAME': 'chem_link_chir',
                           'TABLE_TYPE': 'transactional'},
        'CHEM_LINK_CHIR_ATOM': {'ATTRIBUTES': {'ATOM_COMP_ID': 'atom_comp_id',
                                               'ATOM_ID': 'atom_id',
                                               'CHIR_ID': 'chir_id',
                                               'DEV': 'dev',
                                               'STRUCTURE_ID': 'Structure_ID'},
                                'ATTRIBUTE_INFO': {'ATOM_COMP_ID': {'NULLABLE': True,
                                                                    'ORDER': 3,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10},
                                                   'ATOM_ID': {'NULLABLE': False,
                                                               'ORDER': 4,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                                   'CHIR_ID': {'NULLABLE': False,
                                                               'ORDER': 2,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                                   'DEV': {'NULLABLE': True,
                                                           'ORDER': 5,
                                                           'PRECISION': 6,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'FLOAT',
                                                           'WIDTH': 10},
                                                   'STRUCTURE_ID': {'NULLABLE': False,
                                                                    'ORDER': 1,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': True,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10}},
                                'ATTRIBUTE_MAP': {'ATOM_COMP_ID': ('chem_link_chir_atom', 'atom_comp_id', None, None),
                                                  'ATOM_ID': ('chem_link_chir_atom', 'atom_id', None, None),
                                                  'CHIR_ID': ('chem_link_chir_atom', 'chir_id', None, None),
                                                  'DEV': ('chem_link_chir_atom', 'dev', None, None),
                                                  'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'CHIR_ID', 'ATOM_ID'), 'TYPE': 'UNIQUE'},
                                            's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                'MAP_MERGE_INDICES': {'chem_link_chir_atom': {'ATTRIBUTES': ('chir_id', 'atom_id'),
                                                                              'TYPE': 'EQUI-JOIN'}},
                                'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                'TABLE_ID': 'CHEM_LINK_CHIR_ATOM',
                                'TABLE_NAME': 'chem_link_chir_atom',
                                'TABLE_TYPE': 'transactional'},
        'CHEM_LINK_PLANE': {'ATTRIBUTES': {'ID': 'id',
                                           'LINK_ID': 'link_id',
                                           'NUMBER_ATOMS_ALL': 'number_atoms_all',
                                           'NUMBER_ATOMS_NH': 'number_atoms_nh',
                                           'STRUCTURE_ID': 'Structure_ID'},
                            'ATTRIBUTE_INFO': {'ID': {'NULLABLE': False,
                                                      'ORDER': 3,
                                                      'PRECISION': 0,
                                                      'PRIMARY_KEY': True,
                                                      'SQL_TYPE': 'VARCHAR',
                                                      'WIDTH': 10},
                                               'LINK_ID': {'NULLABLE': False,
                                                           'ORDER': 2,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': True,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 10},
                                               'NUMBER_ATOMS_ALL': {'NULLABLE': True,
                                                                    'ORDER': 4,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'INT',
                                                                    'WIDTH': 10},
                                               'NUMBER_ATOMS_NH': {'NULLABLE': True,
                                                                   'ORDER': 5,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'INT',
                                                                   'WIDTH': 10},
                                               'STRUCTURE_ID': {'NULLABLE': False,
                                                                'ORDER': 1,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10}},
                            'ATTRIBUTE_MAP': {'ID': ('chem_link_plane', 'id', None, None),
                                              'LINK_ID': ('chem_link_plane', 'link_id', None, None),
                                              'NUMBER_ATOMS_ALL': ('chem_link_plane', 'number_atoms_all', None, None),
                                              'NUMBER_ATOMS_NH': ('chem_link_plane', 'number_atoms_nh', None, None),
                                              'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                            'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'LINK_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                        's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                            'MAP_MERGE_INDICES': {'chem_link_plane': {'ATTRIBUTES': ('link_id', 'id'), 'TYPE': 'EQUI-JOIN'}},
                            'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                            'TABLE_ID': 'CHEM_LINK_PLANE',
                            'TABLE_NAME': 'chem_link_plane',
                            'TABLE_TYPE': 'transactional'},
        'CHEM_LINK_PLANE_ATOM': {'ATTRIBUTES': {'ATOM_COMP_ID': 'atom_comp_id',
                                                'ATOM_ID': 'atom_id',
                                                'PLANE_ID': 'plane_id',
                                                'STRUCTURE_ID': 'Structure_ID'},
                                 'ATTRIBUTE_INFO': {'ATOM_COMP_ID': {'NULLABLE': True,
                                                                     'ORDER': 3,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                                    'ATOM_ID': {'NULLABLE': False,
                                                                'ORDER': 4,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                                    'PLANE_ID': {'NULLABLE': False,
                                                                 'ORDER': 2,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': True,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                                    'STRUCTURE_ID': {'NULLABLE': False,
                                                                     'ORDER': 1,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': True,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10}},
                                 'ATTRIBUTE_MAP': {'ATOM_COMP_ID': ('chem_link_plane_atom', 'atom_comp_id', None, None),
                                                   'ATOM_ID': ('chem_link_plane_atom', 'atom_id', None, None),
                                                   'PLANE_ID': ('chem_link_plane_atom', 'plane_id', None, None),
                                                   'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                 'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'PLANE_ID', 'ATOM_ID'), 'TYPE': 'UNIQUE'},
                                             's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                 'MAP_MERGE_INDICES': {'chem_link_plane_atom': {'ATTRIBUTES': ('plane_id', 'atom_id'),
                                                                                'TYPE': 'EQUI-JOIN'}},
                                 'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                 'TABLE_ID': 'CHEM_LINK_PLANE_ATOM',
                                 'TABLE_NAME': 'chem_link_plane_atom',
                                 'TABLE_TYPE': 'transactional'},
        'CHEM_LINK_TOR': {'ATTRIBUTES': {'ATOM_1_COMP_ID': 'atom_1_comp_id',
                                         'ATOM_2_COMP_ID': 'atom_2_comp_id',
                                         'ATOM_3_COMP_ID': 'atom_3_comp_id',
                                         'ATOM_4_COMP_ID': 'atom_4_comp_id',
                                         'ATOM_ID_1': 'atom_id_1',
                                         'ATOM_ID_2': 'atom_id_2',
                                         'ATOM_ID_3': 'atom_id_3',
                                         'ATOM_ID_4': 'atom_id_4',
                                         'ID': 'id',
                                         'LINK_ID': 'link_id',
                                         'STRUCTURE_ID': 'Structure_ID'},
                          'ATTRIBUTE_INFO': {'ATOM_1_COMP_ID': {'NULLABLE': True,
                                                                'ORDER': 3,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                             'ATOM_2_COMP_ID': {'NULLABLE': True,
                                                                'ORDER': 4,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                             'ATOM_3_COMP_ID': {'NULLABLE': True,
                                                                'ORDER': 5,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                             'ATOM_4_COMP_ID': {'NULLABLE': True,
                                                                'ORDER': 6,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                             'ATOM_ID_1': {'NULLABLE': True,
                                                           'ORDER': 7,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 10},
                                             'ATOM_ID_2': {'NULLABLE': True,
                                                           'ORDER': 8,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 10},
                                             'ATOM_ID_3': {'NULLABLE': True,
                                                           'ORDER': 9,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 10},
                                             'ATOM_ID_4': {'NULLABLE': True,
                                                           'ORDER': 10,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 10},
                                             'ID': {'NULLABLE': False,
                                                    'ORDER': 11,
                                                    'PRECISION': 0,
                                                    'PRIMARY_KEY': True,
                                                    'SQL_TYPE': 'VARCHAR',
                                                    'WIDTH': 10},
                                             'LINK_ID': {'NULLABLE': False,
                                                         'ORDER': 2,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': True,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 10},
                                             'STRUCTURE_ID': {'NULLABLE': False,
                                                              'ORDER': 1,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10}},
                          'ATTRIBUTE_MAP': {'ATOM_1_COMP_ID': ('chem_link_tor', 'atom_1_comp_id', None, None),
                                            'ATOM_2_COMP_ID': ('chem_link_tor', 'atom_2_comp_id', None, None),
                                            'ATOM_3_COMP_ID': ('chem_link_tor', 'atom_3_comp_id', None, None),
                                            'ATOM_4_COMP_ID': ('chem_link_tor', 'atom_4_comp_id', None, None),
                                            'ATOM_ID_1': ('chem_link_tor', 'atom_id_1', None, None),
                                            'ATOM_ID_2': ('chem_link_tor', 'atom_id_2', None, None),
                                            'ATOM_ID_3': ('chem_link_tor', 'atom_id_3', None, None),
                                            'ATOM_ID_4': ('chem_link_tor', 'atom_id_4', None, None),
                                            'ID': ('chem_link_tor', 'id', None, None),
                                            'LINK_ID': ('chem_link_tor', 'link_id', None, None),
                                            'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                          'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'LINK_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                      's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                          'MAP_MERGE_INDICES': {'chem_link_tor': {'ATTRIBUTES': ('link_id', 'id'), 'TYPE': 'EQUI-JOIN'}},
                          'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                          'TABLE_ID': 'CHEM_LINK_TOR',
                          'TABLE_NAME': 'chem_link_tor',
                          'TABLE_TYPE': 'transactional'},
        'CHEM_LINK_TOR_VALUE': {'ATTRIBUTES': {'ANGLE': 'angle',
                                               'ANGLE_ESD': 'angle_esd',
                                               'DIST': 'dist',
                                               'DIST_ESD': 'dist_esd',
                                               'STRUCTURE_ID': 'Structure_ID',
                                               'TOR_ID': 'tor_id'},
                                'ATTRIBUTE_INFO': {'ANGLE': {'NULLABLE': True,
                                                             'ORDER': 3,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                                   'ANGLE_ESD': {'NULLABLE': True,
                                                                 'ORDER': 4,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                                   'DIST': {'NULLABLE': True,
                                                            'ORDER': 5,
                                                            'PRECISION': 6,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'FLOAT',
                                                            'WIDTH': 10},
                                                   'DIST_ESD': {'NULLABLE': True,
                                                                'ORDER': 6,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                                   'STRUCTURE_ID': {'NULLABLE': False,
                                                                    'ORDER': 1,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': True,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10},
                                                   'TOR_ID': {'NULLABLE': False,
                                                              'ORDER': 2,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10}},
                                'ATTRIBUTE_MAP': {'ANGLE': ('chem_link_tor_value', 'angle', None, None),
                                                  'ANGLE_ESD': ('chem_link_tor_value', 'angle_esd', None, None),
                                                  'DIST': ('chem_link_tor_value', 'dist', None, None),
                                                  'DIST_ESD': ('chem_link_tor_value', 'dist_esd', None, None),
                                                  'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                  'TOR_ID': ('chem_link_tor_value', 'tor_id', None, None)},
                                'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'TOR_ID'), 'TYPE': 'UNIQUE'},
                                            's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                'MAP_MERGE_INDICES': {'chem_link_tor_value': {'ATTRIBUTES': ('tor_id',), 'TYPE': 'EQUI-JOIN'}},
                                'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                'TABLE_ID': 'CHEM_LINK_TOR_VALUE',
                                'TABLE_NAME': 'chem_link_tor_value',
                                'TABLE_TYPE': 'transactional'},
        'CITATION': {'ATTRIBUTES': {'ABSTRACT': 'abstract',
                                    'ABSTRACT_ID_CAS': 'abstract_id_CAS',
                                    'BOOK_ID_ISBN': 'book_id_ISBN',
                                    'BOOK_PUBLISHER': 'book_publisher',
                                    'BOOK_PUBLISHER_CITY': 'book_publisher_city',
                                    'BOOK_TITLE': 'book_title',
                                    'COORDINATE_LINKAGE': 'coordinate_linkage',
                                    'COUNTRY': 'country',
                                    'DATABASE_ID_CSD': 'database_id_CSD',
                                    'DATABASE_ID_MEDLINE': 'database_id_Medline',
                                    'DETAILS': 'details',
                                    'ID': 'id',
                                    'JOURNAL_ABBREV': 'journal_abbrev',
                                    'JOURNAL_FULL': 'journal_full',
                                    'JOURNAL_ID_ASTM': 'journal_id_ASTM',
                                    'JOURNAL_ID_CSD': 'journal_id_CSD',
                                    'JOURNAL_ID_ISSN': 'journal_id_ISSN',
                                    'JOURNAL_ISSUE': 'journal_issue',
                                    'JOURNAL_VOLUME': 'journal_volume',
                                    'LANGUAGE': 'language',
                                    'PAGE_FIRST': 'page_first',
                                    'PAGE_LAST': 'page_last',
                                    'PDBX_DATABASE_ID_DOI': 'pdbx_database_id_DOI',
                                    'PDBX_DATABASE_ID_PUBMED': 'pdbx_database_id_PubMed',
                                    'STRUCTURE_ID': 'Structure_ID',
                                    'TITLE': 'title',
                                    'UNPUBLISHED_FLAG': 'unpublished_flag',
                                    'YEAR': 'year'},
                     'ATTRIBUTE_INFO': {'ABSTRACT': {'NULLABLE': True,
                                                     'ORDER': 2,
                                                     'PRECISION': 0,
                                                     'PRIMARY_KEY': False,
                                                     'SQL_TYPE': 'VARCHAR',
                                                     'WIDTH': 200},
                                        'ABSTRACT_ID_CAS': {'NULLABLE': True,
                                                            'ORDER': 3,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 200},
                                        'BOOK_ID_ISBN': {'NULLABLE': True,
                                                         'ORDER': 4,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 80},
                                        'BOOK_PUBLISHER': {'NULLABLE': True,
                                                           'ORDER': 5,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 200},
                                        'BOOK_PUBLISHER_CITY': {'NULLABLE': True,
                                                                'ORDER': 6,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 200},
                                        'BOOK_TITLE': {'NULLABLE': True,
                                                       'ORDER': 7,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'VARCHAR',
                                                       'WIDTH': 200},
                                        'COORDINATE_LINKAGE': {'NULLABLE': True,
                                                               'ORDER': 8,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                        'COUNTRY': {'NULLABLE': True,
                                                    'ORDER': 9,
                                                    'PRECISION': 0,
                                                    'PRIMARY_KEY': False,
                                                    'SQL_TYPE': 'VARCHAR',
                                                    'WIDTH': 80},
                                        'DATABASE_ID_CSD': {'NULLABLE': True,
                                                            'ORDER': 25,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 10},
                                        'DATABASE_ID_MEDLINE': {'NULLABLE': True,
                                                                'ORDER': 10,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'INT',
                                                                'WIDTH': 10},
                                        'DETAILS': {'NULLABLE': True,
                                                    'ORDER': 11,
                                                    'PRECISION': 0,
                                                    'PRIMARY_KEY': False,
                                                    'SQL_TYPE': 'VARCHAR',
                                                    'WIDTH': 200},
                                        'ID': {'NULLABLE': False,
                                               'ORDER': 12,
                                               'PRECISION': 0,
                                               'PRIMARY_KEY': True,
                                               'SQL_TYPE': 'VARCHAR',
                                               'WIDTH': 16},
                                        'JOURNAL_ABBREV': {'NULLABLE': True,
                                                           'ORDER': 13,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 255},
                                        'JOURNAL_FULL': {'NULLABLE': True,
                                                         'ORDER': 17,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 200},
                                        'JOURNAL_ID_ASTM': {'NULLABLE': True,
                                                            'ORDER': 14,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 80},
                                        'JOURNAL_ID_CSD': {'NULLABLE': True,
                                                           'ORDER': 15,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 80},
                                        'JOURNAL_ID_ISSN': {'NULLABLE': True,
                                                            'ORDER': 16,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 80},
                                        'JOURNAL_ISSUE': {'NULLABLE': True,
                                                          'ORDER': 18,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 80},
                                        'JOURNAL_VOLUME': {'NULLABLE': True,
                                                           'ORDER': 19,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 80},
                                        'LANGUAGE': {'NULLABLE': True,
                                                     'ORDER': 20,
                                                     'PRECISION': 0,
                                                     'PRIMARY_KEY': False,
                                                     'SQL_TYPE': 'VARCHAR',
                                                     'WIDTH': 80},
                                        'PAGE_FIRST': {'NULLABLE': True,
                                                       'ORDER': 21,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'VARCHAR',
                                                       'WIDTH': 80},
                                        'PAGE_LAST': {'NULLABLE': True,
                                                      'ORDER': 22,
                                                      'PRECISION': 0,
                                                      'PRIMARY_KEY': False,
                                                      'SQL_TYPE': 'VARCHAR',
                                                      'WIDTH': 80},
                                        'PDBX_DATABASE_ID_DOI': {'NULLABLE': True,
                                                                 'ORDER': 26,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 69},
                                        'PDBX_DATABASE_ID_PUBMED': {'NULLABLE': True,
                                                                    'ORDER': 27,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'INT',
                                                                    'WIDTH': 10},
                                        'STRUCTURE_ID': {'NULLABLE': False,
                                                         'ORDER': 1,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': True,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 10},
                                        'TITLE': {'NULLABLE': True,
                                                  'ORDER': 23,
                                                  'PRECISION': 0,
                                                  'PRIMARY_KEY': False,
                                                  'SQL_TYPE': 'VARCHAR',
                                                  'WIDTH': 1023},
                                        'UNPUBLISHED_FLAG': {'NULLABLE': True,
                                                             'ORDER': 28,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 10},
                                        'YEAR': {'NULLABLE': True,
                                                 'ORDER': 24,
                                                 'PRECISION': 0,
                                                 'PRIMARY_KEY': False,
                                                 'SQL_TYPE': 'INT',
                                                 'WIDTH': 10}},
                     'ATTRIBUTE_MAP': {'ABSTRACT': ('citation', 'abstract', None, None),
                                       'ABSTRACT_ID_CAS': ('citation', 'abstract_id_CAS', None, None),
                                       'BOOK_ID_ISBN': ('citation', 'book_id_ISBN', None, None),
                                       'BOOK_PUBLISHER': ('citation', 'book_publisher', None, None),
                                       'BOOK_PUBLISHER_CITY': ('citation', 'book_publisher_city', None, None),
                                       'BOOK_TITLE': ('citation', 'book_title', None, None),
                                       'COORDINATE_LINKAGE': ('citation', 'coordinate_linkage', None, None),
                                       'COUNTRY': ('citation', 'country', None, None),
                                       'DATABASE_ID_CSD': ('citation', 'database_id_CSD', None, None),
                                       'DATABASE_ID_MEDLINE': ('citation', 'database_id_Medline', None, None),
                                       'DETAILS': ('citation', 'details', None, None),
                                       'ID': ('citation', 'id', None, None),
                                       'JOURNAL_ABBREV': ('citation', 'journal_abbrev', None, None),
                                       'JOURNAL_FULL': ('citation', 'journal_full', None, None),
                                       'JOURNAL_ID_ASTM': ('citation', 'journal_id_ASTM', None, None),
                                       'JOURNAL_ID_CSD': ('citation', 'journal_id_CSD', None, None),
                                       'JOURNAL_ID_ISSN': ('citation', 'journal_id_ISSN', None, None),
                                       'JOURNAL_ISSUE': ('citation', 'journal_issue', None, None),
                                       'JOURNAL_VOLUME': ('citation', 'journal_volume', None, None),
                                       'LANGUAGE': ('citation', 'language', None, None),
                                       'PAGE_FIRST': ('citation', 'page_first', None, None),
                                       'PAGE_LAST': ('citation', 'page_last', None, None),
                                       'PDBX_DATABASE_ID_DOI': ('citation', 'pdbx_database_id_DOI', None, None),
                                       'PDBX_DATABASE_ID_PUBMED': ('citation', 'pdbx_database_id_PubMed', None, None),
                                       'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                       'TITLE': ('citation', 'title', None, None),
                                       'UNPUBLISHED_FLAG': ('citation', 'unpublished_flag', None, None),
                                       'YEAR': ('citation', 'year', None, None)},
                     'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                 's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                     'MAP_MERGE_INDICES': {'citation': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                     'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                     'TABLE_ID': 'CITATION',
                     'TABLE_NAME': 'citation',
                     'TABLE_TYPE': 'transactional'},
        'CITATION_AUTHOR': {'ATTRIBUTES': {'CITATION_ID': 'citation_id',
                                           'NAME': 'name',
                                           'ORDINAL': 'ordinal',
                                           'STRUCTURE_ID': 'Structure_ID'},
                            'ATTRIBUTE_INFO': {'CITATION_ID': {'NULLABLE': False,
                                                               'ORDER': 2,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 16},
                                               'NAME': {'NULLABLE': False,
                                                        'ORDER': 3,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': True,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 128},
                                               'ORDINAL': {'NULLABLE': False,
                                                           'ORDER': 4,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': True,
                                                           'SQL_TYPE': 'INT',
                                                           'WIDTH': 10},
                                               'STRUCTURE_ID': {'NULLABLE': False,
                                                                'ORDER': 1,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10}},
                            'ATTRIBUTE_MAP': {'CITATION_ID': ('citation_author', 'citation_id', None, None),
                                              'NAME': ('citation_author', 'name', None, None),
                                              'ORDINAL': ('citation_author', 'ordinal', None, None),
                                              'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                            'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'CITATION_ID', 'NAME', 'ORDINAL'),
                                               'TYPE': 'UNIQUE'},
                                        's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                            'MAP_MERGE_INDICES': {'citation_author': {'ATTRIBUTES': ('citation_id', 'name', 'ordinal'),
                                                                      'TYPE': 'EQUI-JOIN'}},
                            'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                            'TABLE_ID': 'CITATION_AUTHOR',
                            'TABLE_NAME': 'citation_author',
                            'TABLE_TYPE': 'transactional'},
        'CITATION_EDITOR': {'ATTRIBUTES': {'CITATION_ID': 'citation_id',
                                           'NAME': 'name',
                                           'ORDINAL': 'ordinal',
                                           'STRUCTURE_ID': 'Structure_ID'},
                            'ATTRIBUTE_INFO': {'CITATION_ID': {'NULLABLE': False,
                                                               'ORDER': 2,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                               'NAME': {'NULLABLE': False,
                                                        'ORDER': 3,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': True,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 80},
                                               'ORDINAL': {'NULLABLE': True,
                                                           'ORDER': 4,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'INT',
                                                           'WIDTH': 10},
                                               'STRUCTURE_ID': {'NULLABLE': False,
                                                                'ORDER': 1,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10}},
                            'ATTRIBUTE_MAP': {'CITATION_ID': ('citation_editor', 'citation_id', None, None),
                                              'NAME': ('citation_editor', 'name', None, None),
                                              'ORDINAL': ('citation_editor', 'ordinal', None, None),
                                              'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                            'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'CITATION_ID', 'NAME'), 'TYPE': 'UNIQUE'},
                                        's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                            'MAP_MERGE_INDICES': {'citation_editor': {'ATTRIBUTES': ('citation_id', 'name'),
                                                                      'TYPE': 'EQUI-JOIN'}},
                            'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                            'TABLE_ID': 'CITATION_EDITOR',
                            'TABLE_NAME': 'citation_editor',
                            'TABLE_TYPE': 'transactional'},
        'COMPUTING': {'ATTRIBUTES': {'CELL_REFINEMENT': 'cell_refinement',
                                     'DATA_COLLECTION': 'data_collection',
                                     'DATA_REDUCTION': 'data_reduction',
                                     'ENTRY_ID': 'entry_id',
                                     'MOLECULAR_GRAPHICS': 'molecular_graphics',
                                     'PDBX_DATA_REDUCTION_DS': 'pdbx_data_reduction_ds',
                                     'PDBX_DATA_REDUCTION_II': 'pdbx_data_reduction_ii',
                                     'PDBX_STRUCTURE_REFINEMENT_METHOD': 'pdbx_structure_refinement_method',
                                     'PUBLICATION_MATERIAL': 'publication_material',
                                     'STRUCTURE_ID': 'Structure_ID',
                                     'STRUCTURE_REFINEMENT': 'structure_refinement',
                                     'STRUCTURE_SOLUTION': 'structure_solution'},
                      'ATTRIBUTE_INFO': {'CELL_REFINEMENT': {'NULLABLE': True,
                                                             'ORDER': 3,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 200},
                                         'DATA_COLLECTION': {'NULLABLE': True,
                                                             'ORDER': 4,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 200},
                                         'DATA_REDUCTION': {'NULLABLE': True,
                                                            'ORDER': 5,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 200},
                                         'ENTRY_ID': {'NULLABLE': False,
                                                      'ORDER': 2,
                                                      'PRECISION': 0,
                                                      'PRIMARY_KEY': True,
                                                      'SQL_TYPE': 'VARCHAR',
                                                      'WIDTH': 10},
                                         'MOLECULAR_GRAPHICS': {'NULLABLE': True,
                                                                'ORDER': 6,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 200},
                                         'PDBX_DATA_REDUCTION_DS': {'NULLABLE': True,
                                                                    'ORDER': 12,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 200},
                                         'PDBX_DATA_REDUCTION_II': {'NULLABLE': True,
                                                                    'ORDER': 11,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 200},
                                         'PDBX_STRUCTURE_REFINEMENT_METHOD': {'NULLABLE': True,
                                                                              'ORDER': 10,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 200},
                                         'PUBLICATION_MATERIAL': {'NULLABLE': True,
                                                                  'ORDER': 7,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 200},
                                         'STRUCTURE_ID': {'NULLABLE': False,
                                                          'ORDER': 1,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': True,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 10},
                                         'STRUCTURE_REFINEMENT': {'NULLABLE': True,
                                                                  'ORDER': 8,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 200},
                                         'STRUCTURE_SOLUTION': {'NULLABLE': True,
                                                                'ORDER': 9,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 200}},
                      'ATTRIBUTE_MAP': {'CELL_REFINEMENT': ('computing', 'cell_refinement', None, None),
                                        'DATA_COLLECTION': ('computing', 'data_collection', None, None),
                                        'DATA_REDUCTION': ('computing', 'data_reduction', None, None),
                                        'ENTRY_ID': ('computing', 'entry_id', None, None),
                                        'MOLECULAR_GRAPHICS': ('computing', 'molecular_graphics', None, None),
                                        'PDBX_DATA_REDUCTION_DS': ('computing', 'pdbx_data_reduction_ds', None, None),
                                        'PDBX_DATA_REDUCTION_II': ('computing', 'pdbx_data_reduction_ii', None, None),
                                        'PDBX_STRUCTURE_REFINEMENT_METHOD': ('computing',
                                                                             'pdbx_structure_refinement_method',
                                                                             None,
                                                                             None),
                                        'PUBLICATION_MATERIAL': ('computing', 'publication_material', None, None),
                                        'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                        'STRUCTURE_REFINEMENT': ('computing', 'structure_refinement', None, None),
                                        'STRUCTURE_SOLUTION': ('computing', 'structure_solution', None, None)},
                      'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID'), 'TYPE': 'UNIQUE'},
                                  's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                      'MAP_MERGE_INDICES': {'computing': {'ATTRIBUTES': ('entry_id',), 'TYPE': 'EQUI-JOIN'}},
                      'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                      'TABLE_ID': 'COMPUTING',
                      'TABLE_NAME': 'computing',
                      'TABLE_TYPE': 'transactional'},
        'DATABASE1': {'ATTRIBUTES': {'CODE_CAS': 'code_CAS',
                                     'CODE_CSD': 'code_CSD',
                                     'CODE_DEPNUM_CCDC_ARCHIVE': 'code_depnum_ccdc_archive',
                                     'CODE_DEPNUM_CCDC_FIZ': 'code_depnum_ccdc_fiz',
                                     'CODE_DEPNUM_CCDC_JOURNAL': 'code_depnum_ccdc_journal',
                                     'CODE_ICSD': 'code_ICSD',
                                     'CODE_MDF': 'code_MDF',
                                     'CODE_NBS': 'code_NBS',
                                     'CODE_PDB': 'code_PDB',
                                     'CODE_PDF': 'code_PDF',
                                     'CSD_HISTORY': 'CSD_history',
                                     'ENTRY_ID': 'entry_id',
                                     'JOURNAL_ASTM': 'journal_ASTM',
                                     'JOURNAL_CSD': 'journal_CSD',
                                     'STRUCTURE_ID': 'Structure_ID'},
                      'ATTRIBUTE_INFO': {'CODE_CAS': {'NULLABLE': True,
                                                      'ORDER': 6,
                                                      'PRECISION': 0,
                                                      'PRIMARY_KEY': False,
                                                      'SQL_TYPE': 'VARCHAR',
                                                      'WIDTH': 80},
                                         'CODE_CSD': {'NULLABLE': True,
                                                      'ORDER': 7,
                                                      'PRECISION': 0,
                                                      'PRIMARY_KEY': False,
                                                      'SQL_TYPE': 'VARCHAR',
                                                      'WIDTH': 80},
                                         'CODE_DEPNUM_CCDC_ARCHIVE': {'NULLABLE': True,
                                                                      'ORDER': 15,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 80},
                                         'CODE_DEPNUM_CCDC_FIZ': {'NULLABLE': True,
                                                                  'ORDER': 13,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 80},
                                         'CODE_DEPNUM_CCDC_JOURNAL': {'NULLABLE': True,
                                                                      'ORDER': 14,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 80},
                                         'CODE_ICSD': {'NULLABLE': True,
                                                       'ORDER': 8,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'VARCHAR',
                                                       'WIDTH': 80},
                                         'CODE_MDF': {'NULLABLE': True,
                                                      'ORDER': 9,
                                                      'PRECISION': 0,
                                                      'PRIMARY_KEY': False,
                                                      'SQL_TYPE': 'VARCHAR',
                                                      'WIDTH': 80},
                                         'CODE_NBS': {'NULLABLE': True,
                                                      'ORDER': 10,
                                                      'PRECISION': 0,
                                                      'PRIMARY_KEY': False,
                                                      'SQL_TYPE': 'VARCHAR',
                                                      'WIDTH': 80},
                                         'CODE_PDB': {'NULLABLE': True,
                                                      'ORDER': 11,
                                                      'PRECISION': 0,
                                                      'PRIMARY_KEY': False,
                                                      'SQL_TYPE': 'VARCHAR',
                                                      'WIDTH': 80},
                                         'CODE_PDF': {'NULLABLE': True,
                                                      'ORDER': 12,
                                                      'PRECISION': 0,
                                                      'PRIMARY_KEY': False,
                                                      'SQL_TYPE': 'VARCHAR',
                                                      'WIDTH': 80},
                                         'CSD_HISTORY': {'NULLABLE': True,
                                                         'ORDER': 5,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 200},
                                         'ENTRY_ID': {'NULLABLE': False,
                                                      'ORDER': 2,
                                                      'PRECISION': 0,
                                                      'PRIMARY_KEY': True,
                                                      'SQL_TYPE': 'VARCHAR',
                                                      'WIDTH': 10},
                                         'JOURNAL_ASTM': {'NULLABLE': True,
                                                          'ORDER': 3,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 80},
                                         'JOURNAL_CSD': {'NULLABLE': True,
                                                         'ORDER': 4,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 80},
                                         'STRUCTURE_ID': {'NULLABLE': False,
                                                          'ORDER': 1,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': True,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 10}},
                      'ATTRIBUTE_MAP': {'CODE_CAS': ('database', 'code_CAS', None, None),
                                        'CODE_CSD': ('database', 'code_CSD', None, None),
                                        'CODE_DEPNUM_CCDC_ARCHIVE': ('database', 'code_depnum_ccdc_archive', None, None),
                                        'CODE_DEPNUM_CCDC_FIZ': ('database', 'code_depnum_ccdc_fiz', None, None),
                                        'CODE_DEPNUM_CCDC_JOURNAL': ('database', 'code_depnum_ccdc_journal', None, None),
                                        'CODE_ICSD': ('database', 'code_ICSD', None, None),
                                        'CODE_MDF': ('database', 'code_MDF', None, None),
                                        'CODE_NBS': ('database', 'code_NBS', None, None),
                                        'CODE_PDB': ('database', 'code_PDB', None, None),
                                        'CODE_PDF': ('database', 'code_PDF', None, None),
                                        'CSD_HISTORY': ('database', 'CSD_history', None, None),
                                        'ENTRY_ID': ('database', 'entry_id', None, None),
                                        'JOURNAL_ASTM': ('database', 'journal_ASTM', None, None),
                                        'JOURNAL_CSD': ('database', 'journal_CSD', None, None),
                                        'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                      'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID'), 'TYPE': 'UNIQUE'},
                                  's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                      'MAP_MERGE_INDICES': {'database': {'ATTRIBUTES': ('entry_id',), 'TYPE': 'EQUI-JOIN'}},
                      'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                      'TABLE_ID': 'DATABASE1',
                      'TABLE_NAME': 'database1',
                      'TABLE_TYPE': 'transactional'},
        'DATABASE_2': {'ATTRIBUTES': {'DATABASE_CODE': 'database_code',
                                      'DATABASE_ID': 'database_id',
                                      'STRUCTURE_ID': 'Structure_ID'},
                       'ATTRIBUTE_INFO': {'DATABASE_CODE': {'NULLABLE': False,
                                                            'ORDER': 3,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': True,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 80},
                                          'DATABASE_ID': {'NULLABLE': False,
                                                          'ORDER': 2,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': True,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 10},
                                          'STRUCTURE_ID': {'NULLABLE': False,
                                                           'ORDER': 1,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': True,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 10}},
                       'ATTRIBUTE_MAP': {'DATABASE_CODE': ('database_2', 'database_code', None, None),
                                         'DATABASE_ID': ('database_2', 'database_id', None, None),
                                         'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                       'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'DATABASE_ID', 'DATABASE_CODE'), 'TYPE': 'UNIQUE'},
                                   's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                       'MAP_MERGE_INDICES': {'database_2': {'ATTRIBUTES': ('database_id', 'database_code'),
                                                            'TYPE': 'EQUI-JOIN'}},
                       'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                       'TABLE_ID': 'DATABASE_2',
                       'TABLE_NAME': 'database_2',
                       'TABLE_TYPE': 'transactional'},
        'DATABASE_PDB_CAVEAT': {'ATTRIBUTES': {'ID': 'id', 'STRUCTURE_ID': 'Structure_ID', 'TEXT': 'text'},
                                'ATTRIBUTE_INFO': {'ID': {'NULLABLE': False,
                                                          'ORDER': 2,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': True,
                                                          'SQL_TYPE': 'INT',
                                                          'WIDTH': 10},
                                                   'STRUCTURE_ID': {'NULLABLE': False,
                                                                    'ORDER': 1,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': True,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10},
                                                   'TEXT': {'NULLABLE': True,
                                                            'ORDER': 3,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 1023}},
                                'ATTRIBUTE_MAP': {'ID': ('database_PDB_caveat', 'id', None, None),
                                                  'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                  'TEXT': ('database_PDB_caveat', 'text', None, None)},
                                'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                            's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                'MAP_MERGE_INDICES': {'database_PDB_caveat': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                                'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                'TABLE_ID': 'DATABASE_PDB_CAVEAT',
                                'TABLE_NAME': 'database_PDB_caveat',
                                'TABLE_TYPE': 'transactional'},
        'DATABASE_PDB_MATRIX': {'ATTRIBUTES': {'ENTRY_ID': 'entry_id',
                                               'ORIGX_1_1': 'origx_1_1',
                                               'ORIGX_1_2': 'origx_1_2',
                                               'ORIGX_1_3': 'origx_1_3',
                                               'ORIGX_2_1': 'origx_2_1',
                                               'ORIGX_2_2': 'origx_2_2',
                                               'ORIGX_2_3': 'origx_2_3',
                                               'ORIGX_3_1': 'origx_3_1',
                                               'ORIGX_3_2': 'origx_3_2',
                                               'ORIGX_3_3': 'origx_3_3',
                                               'ORIGX_VECTOR_1': 'origx_vector_1',
                                               'ORIGX_VECTOR_2': 'origx_vector_2',
                                               'ORIGX_VECTOR_3': 'origx_vector_3',
                                               'SCALE_1_1': 'scale_1_1',
                                               'SCALE_1_2': 'scale_1_2',
                                               'SCALE_1_3': 'scale_1_3',
                                               'SCALE_2_1': 'scale_2_1',
                                               'SCALE_2_2': 'scale_2_2',
                                               'SCALE_2_3': 'scale_2_3',
                                               'SCALE_3_1': 'scale_3_1',
                                               'SCALE_3_2': 'scale_3_2',
                                               'SCALE_3_3': 'scale_3_3',
                                               'SCALE_VECTOR_1': 'scale_vector_1',
                                               'SCALE_VECTOR_2': 'scale_vector_2',
                                               'SCALE_VECTOR_3': 'scale_vector_3',
                                               'STRUCTURE_ID': 'Structure_ID'},
                                'ATTRIBUTE_INFO': {'ENTRY_ID': {'NULLABLE': False,
                                                                'ORDER': 2,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                                   'ORIGX_1_1': {'NULLABLE': True,
                                                                 'ORDER': 3,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                                   'ORIGX_1_2': {'NULLABLE': True,
                                                                 'ORDER': 4,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                                   'ORIGX_1_3': {'NULLABLE': True,
                                                                 'ORDER': 5,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                                   'ORIGX_2_1': {'NULLABLE': True,
                                                                 'ORDER': 6,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                                   'ORIGX_2_2': {'NULLABLE': True,
                                                                 'ORDER': 7,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                                   'ORIGX_2_3': {'NULLABLE': True,
                                                                 'ORDER': 8,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                                   'ORIGX_3_1': {'NULLABLE': True,
                                                                 'ORDER': 9,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                                   'ORIGX_3_2': {'NULLABLE': True,
                                                                 'ORDER': 10,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                                   'ORIGX_3_3': {'NULLABLE': True,
                                                                 'ORDER': 11,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                                   'ORIGX_VECTOR_1': {'NULLABLE': True,
                                                                      'ORDER': 12,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                                   'ORIGX_VECTOR_2': {'NULLABLE': True,
                                                                      'ORDER': 13,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                                   'ORIGX_VECTOR_3': {'NULLABLE': True,
                                                                      'ORDER': 14,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                                   'SCALE_1_1': {'NULLABLE': True,
                                                                 'ORDER': 15,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                                   'SCALE_1_2': {'NULLABLE': True,
                                                                 'ORDER': 16,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                                   'SCALE_1_3': {'NULLABLE': True,
                                                                 'ORDER': 17,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                                   'SCALE_2_1': {'NULLABLE': True,
                                                                 'ORDER': 18,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                                   'SCALE_2_2': {'NULLABLE': True,
                                                                 'ORDER': 19,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                                   'SCALE_2_3': {'NULLABLE': True,
                                                                 'ORDER': 20,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                                   'SCALE_3_1': {'NULLABLE': True,
                                                                 'ORDER': 21,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                                   'SCALE_3_2': {'NULLABLE': True,
                                                                 'ORDER': 22,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                                   'SCALE_3_3': {'NULLABLE': True,
                                                                 'ORDER': 23,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                                   'SCALE_VECTOR_1': {'NULLABLE': True,
                                                                      'ORDER': 24,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                                   'SCALE_VECTOR_2': {'NULLABLE': True,
                                                                      'ORDER': 25,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                                   'SCALE_VECTOR_3': {'NULLABLE': True,
                                                                      'ORDER': 26,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                                   'STRUCTURE_ID': {'NULLABLE': False,
                                                                    'ORDER': 1,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': True,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10}},
                                'ATTRIBUTE_MAP': {'ENTRY_ID': ('database_PDB_matrix', 'entry_id', None, None),
                                                  'ORIGX_1_1': ('database_PDB_matrix', 'origx[1][1]', None, None),
                                                  'ORIGX_1_2': ('database_PDB_matrix', 'origx[1][2]', None, None),
                                                  'ORIGX_1_3': ('database_PDB_matrix', 'origx[1][3]', None, None),
                                                  'ORIGX_2_1': ('database_PDB_matrix', 'origx[2][1]', None, None),
                                                  'ORIGX_2_2': ('database_PDB_matrix', 'origx[2][2]', None, None),
                                                  'ORIGX_2_3': ('database_PDB_matrix', 'origx[2][3]', None, None),
                                                  'ORIGX_3_1': ('database_PDB_matrix', 'origx[3][1]', None, None),
                                                  'ORIGX_3_2': ('database_PDB_matrix', 'origx[3][2]', None, None),
                                                  'ORIGX_3_3': ('database_PDB_matrix', 'origx[3][3]', None, None),
                                                  'ORIGX_VECTOR_1': ('database_PDB_matrix', 'origx_vector[1]', None, None),
                                                  'ORIGX_VECTOR_2': ('database_PDB_matrix', 'origx_vector[2]', None, None),
                                                  'ORIGX_VECTOR_3': ('database_PDB_matrix', 'origx_vector[3]', None, None),
                                                  'SCALE_1_1': ('database_PDB_matrix', 'scale[1][1]', None, None),
                                                  'SCALE_1_2': ('database_PDB_matrix', 'scale[1][2]', None, None),
                                                  'SCALE_1_3': ('database_PDB_matrix', 'scale[1][3]', None, None),
                                                  'SCALE_2_1': ('database_PDB_matrix', 'scale[2][1]', None, None),
                                                  'SCALE_2_2': ('database_PDB_matrix', 'scale[2][2]', None, None),
                                                  'SCALE_2_3': ('database_PDB_matrix', 'scale[2][3]', None, None),
                                                  'SCALE_3_1': ('database_PDB_matrix', 'scale[3][1]', None, None),
                                                  'SCALE_3_2': ('database_PDB_matrix', 'scale[3][2]', None, None),
                                                  'SCALE_3_3': ('database_PDB_matrix', 'scale[3][3]', None, None),
                                                  'SCALE_VECTOR_1': ('database_PDB_matrix', 'scale_vector[1]', None, None),
                                                  'SCALE_VECTOR_2': ('database_PDB_matrix', 'scale_vector[2]', None, None),
                                                  'SCALE_VECTOR_3': ('database_PDB_matrix', 'scale_vector[3]', None, None),
                                                  'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID'), 'TYPE': 'UNIQUE'},
                                            's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                'MAP_MERGE_INDICES': {'database_PDB_matrix': {'ATTRIBUTES': ('entry_id',),
                                                                              'TYPE': 'EQUI-JOIN'}},
                                'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                'TABLE_ID': 'DATABASE_PDB_MATRIX',
                                'TABLE_NAME': 'database_PDB_matrix',
                                'TABLE_TYPE': 'transactional'},
        'DATABASE_PDB_REMARK': {'ATTRIBUTES': {'ID': 'id', 'STRUCTURE_ID': 'Structure_ID', 'TEXT': 'text'},
                                'ATTRIBUTE_INFO': {'ID': {'NULLABLE': False,
                                                          'ORDER': 2,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': True,
                                                          'SQL_TYPE': 'INT',
                                                          'WIDTH': 10},
                                                   'STRUCTURE_ID': {'NULLABLE': False,
                                                                    'ORDER': 1,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': True,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10},
                                                   'TEXT': {'NULLABLE': True,
                                                            'ORDER': 3,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'TEXT',
                                                            'WIDTH': 118199}},
                                'ATTRIBUTE_MAP': {'ID': ('database_PDB_remark', 'id', None, None),
                                                  'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                  'TEXT': ('database_PDB_remark', 'text', None, None)},
                                'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                            's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                'MAP_MERGE_INDICES': {'database_PDB_remark': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                                'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                'TABLE_ID': 'DATABASE_PDB_REMARK',
                                'TABLE_NAME': 'database_PDB_remark',
                                'TABLE_TYPE': 'transactional'},
        'DATABASE_PDB_REV': {'ATTRIBUTES': {'AUTHOR_NAME': 'author_name',
                                            'DATE': 'date',
                                            'DATE_ORIGINAL': 'date_original',
                                            'MOD_TYPE': 'mod_type',
                                            'NUM': 'num',
                                            'REPLACED_BY': 'replaced_by',
                                            'REPLACES': 'replaces',
                                            'STATUS': 'status',
                                            'STRUCTURE_ID': 'Structure_ID'},
                             'ATTRIBUTE_INFO': {'AUTHOR_NAME': {'NULLABLE': True,
                                                                'ORDER': 2,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 80},
                                                'DATE': {'NULLABLE': True,
                                                         'ORDER': 3,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'DATETIME',
                                                         'WIDTH': 15},
                                                'DATE_ORIGINAL': {'NULLABLE': True,
                                                                  'ORDER': 4,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'DATETIME',
                                                                  'WIDTH': 15},
                                                'MOD_TYPE': {'NULLABLE': True,
                                                             'ORDER': 5,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'INT',
                                                             'WIDTH': 10},
                                                'NUM': {'NULLABLE': False,
                                                        'ORDER': 6,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': True,
                                                        'SQL_TYPE': 'INT',
                                                        'WIDTH': 10},
                                                'REPLACED_BY': {'NULLABLE': True,
                                                                'ORDER': 7,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 80},
                                                'REPLACES': {'NULLABLE': True,
                                                             'ORDER': 8,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 80},
                                                'STATUS': {'NULLABLE': True,
                                                           'ORDER': 9,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 80},
                                                'STRUCTURE_ID': {'NULLABLE': False,
                                                                 'ORDER': 1,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': True,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10}},
                             'ATTRIBUTE_MAP': {'AUTHOR_NAME': ('database_PDB_rev', 'author_name', None, None),
                                               'DATE': ('database_PDB_rev', 'date', None, None),
                                               'DATE_ORIGINAL': ('database_PDB_rev', 'date_original', None, None),
                                               'MOD_TYPE': ('database_PDB_rev', 'mod_type', None, None),
                                               'NUM': ('database_PDB_rev', 'num', None, None),
                                               'REPLACED_BY': ('database_PDB_rev', 'replaced_by', None, None),
                                               'REPLACES': ('database_PDB_rev', 'replaces', None, None),
                                               'STATUS': ('database_PDB_rev', 'status', None, None),
                                               'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                             'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'NUM'), 'TYPE': 'UNIQUE'},
                                         's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                             'MAP_MERGE_INDICES': {'database_PDB_rev': {'ATTRIBUTES': ('num',), 'TYPE': 'EQUI-JOIN'}},
                             'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                             'TABLE_ID': 'DATABASE_PDB_REV',
                             'TABLE_NAME': 'database_PDB_rev',
                             'TABLE_TYPE': 'transactional'},
        'DATABASE_PDB_REV_RECORD': {'ATTRIBUTES': {'DETAILS': 'details',
                                                   'REV_NUM': 'rev_num',
                                                   'STRUCTURE_ID': 'Structure_ID',
                                                   'TYPE': 'type'},
                                    'ATTRIBUTE_INFO': {'DETAILS': {'NULLABLE': True,
                                                                   'ORDER': 3,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 200},
                                                       'REV_NUM': {'NULLABLE': False,
                                                                   'ORDER': 2,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': True,
                                                                   'SQL_TYPE': 'INT',
                                                                   'WIDTH': 10},
                                                       'STRUCTURE_ID': {'NULLABLE': False,
                                                                        'ORDER': 1,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': True,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                                       'TYPE': {'NULLABLE': False,
                                                                'ORDER': 4,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 80}},
                                    'ATTRIBUTE_MAP': {'DETAILS': ('database_PDB_rev_record', 'details', None, None),
                                                      'REV_NUM': ('database_PDB_rev_record', 'rev_num', None, None),
                                                      'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                      'TYPE': ('database_PDB_rev_record', 'type', None, None)},
                                    'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'REV_NUM', 'TYPE'), 'TYPE': 'UNIQUE'},
                                                's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                    'MAP_MERGE_INDICES': {'database_PDB_rev_record': {'ATTRIBUTES': ('rev_num', 'type'),
                                                                                      'TYPE': 'EQUI-JOIN'}},
                                    'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                    'TABLE_ID': 'DATABASE_PDB_REV_RECORD',
                                    'TABLE_NAME': 'database_PDB_rev_record',
                                    'TABLE_TYPE': 'transactional'},
        'DATABASE_PDB_TVECT': {'ATTRIBUTES': {'DETAILS': 'details',
                                              'ID': 'id',
                                              'STRUCTURE_ID': 'Structure_ID',
                                              'VECTOR_1': 'vector_1',
                                              'VECTOR_2': 'vector_2',
                                              'VECTOR_3': 'vector_3'},
                               'ATTRIBUTE_INFO': {'DETAILS': {'NULLABLE': True,
                                                              'ORDER': 2,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 200},
                                                  'ID': {'NULLABLE': False,
                                                         'ORDER': 3,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': True,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 10},
                                                  'STRUCTURE_ID': {'NULLABLE': False,
                                                                   'ORDER': 1,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': True,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 10},
                                                  'VECTOR_1': {'NULLABLE': True,
                                                               'ORDER': 4,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                                  'VECTOR_2': {'NULLABLE': True,
                                                               'ORDER': 5,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                                  'VECTOR_3': {'NULLABLE': True,
                                                               'ORDER': 6,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10}},
                               'ATTRIBUTE_MAP': {'DETAILS': ('database_PDB_tvect', 'details', None, None),
                                                 'ID': ('database_PDB_tvect', 'id', None, None),
                                                 'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                 'VECTOR_1': ('database_PDB_tvect', 'vector[1]', None, None),
                                                 'VECTOR_2': ('database_PDB_tvect', 'vector[2]', None, None),
                                                 'VECTOR_3': ('database_PDB_tvect', 'vector[3]', None, None)},
                               'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                           's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                               'MAP_MERGE_INDICES': {'database_PDB_tvect': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                               'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                               'TABLE_ID': 'DATABASE_PDB_TVECT',
                               'TABLE_NAME': 'database_PDB_tvect',
                               'TABLE_TYPE': 'transactional'},
        'DIFFRN': {'ATTRIBUTES': {'AMBIENT_ENVIRONMENT': 'ambient_environment',
                                  'AMBIENT_PRESSURE': 'ambient_pressure',
                                  'AMBIENT_PRESSURE_ESD': 'ambient_pressure_esd',
                                  'AMBIENT_PRESSURE_GT': 'ambient_pressure_gt',
                                  'AMBIENT_PRESSURE_LT': 'ambient_pressure_lt',
                                  'AMBIENT_TEMP': 'ambient_temp',
                                  'AMBIENT_TEMP_DETAILS': 'ambient_temp_details',
                                  'AMBIENT_TEMP_ESD': 'ambient_temp_esd',
                                  'AMBIENT_TEMP_GT': 'ambient_temp_gt',
                                  'AMBIENT_TEMP_LT': 'ambient_temp_lt',
                                  'CRYSTAL_ID': 'crystal_id',
                                  'CRYSTAL_SUPPORT': 'crystal_support',
                                  'CRYSTAL_TREATMENT': 'crystal_treatment',
                                  'DETAILS': 'details',
                                  'ID': 'id',
                                  'STRUCTURE_ID': 'Structure_ID'},
                   'ATTRIBUTE_INFO': {'AMBIENT_ENVIRONMENT': {'NULLABLE': True,
                                                              'ORDER': 2,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 80},
                                      'AMBIENT_PRESSURE': {'NULLABLE': True,
                                                           'ORDER': 11,
                                                           'PRECISION': 6,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'FLOAT',
                                                           'WIDTH': 10},
                                      'AMBIENT_PRESSURE_ESD': {'NULLABLE': True,
                                                               'ORDER': 12,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                      'AMBIENT_PRESSURE_GT': {'NULLABLE': True,
                                                              'ORDER': 13,
                                                              'PRECISION': 6,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'FLOAT',
                                                              'WIDTH': 10},
                                      'AMBIENT_PRESSURE_LT': {'NULLABLE': True,
                                                              'ORDER': 14,
                                                              'PRECISION': 6,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'FLOAT',
                                                              'WIDTH': 10},
                                      'AMBIENT_TEMP': {'NULLABLE': True,
                                                       'ORDER': 3,
                                                       'PRECISION': 6,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'FLOAT',
                                                       'WIDTH': 10},
                                      'AMBIENT_TEMP_DETAILS': {'NULLABLE': True,
                                                               'ORDER': 4,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 200},
                                      'AMBIENT_TEMP_ESD': {'NULLABLE': True,
                                                           'ORDER': 5,
                                                           'PRECISION': 6,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'FLOAT',
                                                           'WIDTH': 10},
                                      'AMBIENT_TEMP_GT': {'NULLABLE': True,
                                                          'ORDER': 15,
                                                          'PRECISION': 6,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'FLOAT',
                                                          'WIDTH': 10},
                                      'AMBIENT_TEMP_LT': {'NULLABLE': True,
                                                          'ORDER': 16,
                                                          'PRECISION': 6,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'FLOAT',
                                                          'WIDTH': 10},
                                      'CRYSTAL_ID': {'NULLABLE': True,
                                                     'ORDER': 6,
                                                     'PRECISION': 0,
                                                     'PRIMARY_KEY': False,
                                                     'SQL_TYPE': 'VARCHAR',
                                                     'WIDTH': 10},
                                      'CRYSTAL_SUPPORT': {'NULLABLE': True,
                                                          'ORDER': 7,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 200},
                                      'CRYSTAL_TREATMENT': {'NULLABLE': True,
                                                            'ORDER': 8,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 200},
                                      'DETAILS': {'NULLABLE': True,
                                                  'ORDER': 9,
                                                  'PRECISION': 0,
                                                  'PRIMARY_KEY': False,
                                                  'SQL_TYPE': 'VARCHAR',
                                                  'WIDTH': 511},
                                      'ID': {'NULLABLE': False,
                                             'ORDER': 10,
                                             'PRECISION': 0,
                                             'PRIMARY_KEY': True,
                                             'SQL_TYPE': 'VARCHAR',
                                             'WIDTH': 10},
                                      'STRUCTURE_ID': {'NULLABLE': False,
                                                       'ORDER': 1,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': True,
                                                       'SQL_TYPE': 'VARCHAR',
                                                       'WIDTH': 10}},
                   'ATTRIBUTE_MAP': {'AMBIENT_ENVIRONMENT': ('diffrn', 'ambient_environment', None, None),
                                     'AMBIENT_PRESSURE': ('diffrn', 'ambient_pressure', None, None),
                                     'AMBIENT_PRESSURE_ESD': ('diffrn', 'ambient_pressure_esd', None, None),
                                     'AMBIENT_PRESSURE_GT': ('diffrn', 'ambient_pressure_gt', None, None),
                                     'AMBIENT_PRESSURE_LT': ('diffrn', 'ambient_pressure_lt', None, None),
                                     'AMBIENT_TEMP': ('diffrn', 'ambient_temp', None, None),
                                     'AMBIENT_TEMP_DETAILS': ('diffrn', 'ambient_temp_details', None, None),
                                     'AMBIENT_TEMP_ESD': ('diffrn', 'ambient_temp_esd', None, None),
                                     'AMBIENT_TEMP_GT': ('diffrn', 'ambient_temp_gt', None, None),
                                     'AMBIENT_TEMP_LT': ('diffrn', 'ambient_temp_lt', None, None),
                                     'CRYSTAL_ID': ('diffrn', 'crystal_id', None, None),
                                     'CRYSTAL_SUPPORT': ('diffrn', 'crystal_support', None, None),
                                     'CRYSTAL_TREATMENT': ('diffrn', 'crystal_treatment', None, None),
                                     'DETAILS': ('diffrn', 'details', None, None),
                                     'ID': ('diffrn', 'id', None, None),
                                     'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                   'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                               's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                   'MAP_MERGE_INDICES': {'diffrn': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                   'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                   'TABLE_ID': 'DIFFRN',
                   'TABLE_NAME': 'diffrn',
                   'TABLE_TYPE': 'transactional'},
        'DIFFRN_ATTENUATOR': {'ATTRIBUTES': {'CODE': 'code',
                                             'MATERIAL': 'material',
                                             'SCALE': 'scale',
                                             'STRUCTURE_ID': 'Structure_ID'},
                              'ATTRIBUTE_INFO': {'CODE': {'NULLABLE': False,
                                                          'ORDER': 2,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': True,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 10},
                                                 'MATERIAL': {'NULLABLE': True,
                                                              'ORDER': 4,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 200},
                                                 'SCALE': {'NULLABLE': True,
                                                           'ORDER': 3,
                                                           'PRECISION': 6,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'FLOAT',
                                                           'WIDTH': 10},
                                                 'STRUCTURE_ID': {'NULLABLE': False,
                                                                  'ORDER': 1,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': True,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10}},
                              'ATTRIBUTE_MAP': {'CODE': ('diffrn_attenuator', 'code', None, None),
                                                'MATERIAL': ('diffrn_attenuator', 'material', None, None),
                                                'SCALE': ('diffrn_attenuator', 'scale', None, None),
                                                'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                              'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'CODE'), 'TYPE': 'UNIQUE'},
                                          's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                              'MAP_MERGE_INDICES': {'diffrn_attenuator': {'ATTRIBUTES': ('code',), 'TYPE': 'EQUI-JOIN'}},
                              'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                              'TABLE_ID': 'DIFFRN_ATTENUATOR',
                              'TABLE_NAME': 'diffrn_attenuator',
                              'TABLE_TYPE': 'transactional'},
        'DIFFRN_DETECTOR': {'ATTRIBUTES': {'AREA_RESOL_MEAN': 'area_resol_mean',
                                           'DETAILS': 'details',
                                           'DETECTOR': 'detector',
                                           'DIFFRN_ID': 'diffrn_id',
                                           'DTIME': 'dtime',
                                           'PDBX_COLLECTION_DATE': 'pdbx_collection_date',
                                           'PDBX_COLLECTION_TIME_TOTAL': 'pdbx_collection_time_total',
                                           'PDBX_FRAMES_TOTAL': 'pdbx_frames_total',
                                           'STRUCTURE_ID': 'Structure_ID',
                                           'TYPE': 'type'},
                            'ATTRIBUTE_INFO': {'AREA_RESOL_MEAN': {'NULLABLE': True,
                                                                   'ORDER': 6,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                               'DETAILS': {'NULLABLE': True,
                                                           'ORDER': 3,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 511},
                                               'DETECTOR': {'NULLABLE': True,
                                                            'ORDER': 4,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 200},
                                               'DIFFRN_ID': {'NULLABLE': False,
                                                             'ORDER': 2,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 10},
                                               'DTIME': {'NULLABLE': True,
                                                         'ORDER': 7,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                               'PDBX_COLLECTION_DATE': {'NULLABLE': True,
                                                                        'ORDER': 10,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'DATETIME',
                                                                        'WIDTH': 20},
                                               'PDBX_COLLECTION_TIME_TOTAL': {'NULLABLE': True,
                                                                              'ORDER': 9,
                                                                              'PRECISION': 6,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'FLOAT',
                                                                              'WIDTH': 10},
                                               'PDBX_FRAMES_TOTAL': {'NULLABLE': True,
                                                                     'ORDER': 8,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'INT',
                                                                     'WIDTH': 10},
                                               'STRUCTURE_ID': {'NULLABLE': False,
                                                                'ORDER': 1,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                               'TYPE': {'NULLABLE': True,
                                                        'ORDER': 5,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 511}},
                            'ATTRIBUTE_MAP': {'AREA_RESOL_MEAN': ('diffrn_detector', 'area_resol_mean', None, None),
                                              'DETAILS': ('diffrn_detector', 'details', None, None),
                                              'DETECTOR': ('diffrn_detector', 'detector', None, None),
                                              'DIFFRN_ID': ('diffrn_detector', 'diffrn_id', None, None),
                                              'DTIME': ('diffrn_detector', 'dtime', None, None),
                                              'PDBX_COLLECTION_DATE': ('diffrn_detector', 'pdbx_collection_date', None, None),
                                              'PDBX_COLLECTION_TIME_TOTAL': ('diffrn_detector',
                                                                             'pdbx_collection_time_total',
                                                                             None,
                                                                             None),
                                              'PDBX_FRAMES_TOTAL': ('diffrn_detector', 'pdbx_frames_total', None, None),
                                              'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                              'TYPE': ('diffrn_detector', 'type', None, None)},
                            'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'DIFFRN_ID'), 'TYPE': 'UNIQUE'},
                                        's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                            'MAP_MERGE_INDICES': {'diffrn_detector': {'ATTRIBUTES': ('diffrn_id',), 'TYPE': 'EQUI-JOIN'}},
                            'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                            'TABLE_ID': 'DIFFRN_DETECTOR',
                            'TABLE_NAME': 'diffrn_detector',
                            'TABLE_TYPE': 'transactional'},
        'DIFFRN_MEASUREMENT': {'ATTRIBUTES': {'DETAILS': 'details',
                                              'DEVICE': 'device',
                                              'DEVICE_DETAILS': 'device_details',
                                              'DEVICE_TYPE': 'device_type',
                                              'DIFFRN_ID': 'diffrn_id',
                                              'METHOD': 'method',
                                              'SPECIMEN_SUPPORT': 'specimen_support',
                                              'STRUCTURE_ID': 'Structure_ID'},
                               'ATTRIBUTE_INFO': {'DETAILS': {'NULLABLE': True,
                                                              'ORDER': 3,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 200},
                                                  'DEVICE': {'NULLABLE': True,
                                                             'ORDER': 4,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 200},
                                                  'DEVICE_DETAILS': {'NULLABLE': True,
                                                                     'ORDER': 5,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 200},
                                                  'DEVICE_TYPE': {'NULLABLE': True,
                                                                  'ORDER': 6,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 200},
                                                  'DIFFRN_ID': {'NULLABLE': False,
                                                                'ORDER': 2,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                                  'METHOD': {'NULLABLE': True,
                                                             'ORDER': 7,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 200},
                                                  'SPECIMEN_SUPPORT': {'NULLABLE': True,
                                                                       'ORDER': 8,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 200},
                                                  'STRUCTURE_ID': {'NULLABLE': False,
                                                                   'ORDER': 1,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': True,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 10}},
                               'ATTRIBUTE_MAP': {'DETAILS': ('diffrn_measurement', 'details', None, None),
                                                 'DEVICE': ('diffrn_measurement', 'device', None, None),
                                                 'DEVICE_DETAILS': ('diffrn_measurement', 'device_details', None, None),
                                                 'DEVICE_TYPE': ('diffrn_measurement', 'device_type', None, None),
                                                 'DIFFRN_ID': ('diffrn_measurement', 'diffrn_id', None, None),
                                                 'METHOD': ('diffrn_measurement', 'method', None, None),
                                                 'SPECIMEN_SUPPORT': ('diffrn_measurement', 'specimen_support', None, None),
                                                 'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                               'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'DIFFRN_ID'), 'TYPE': 'UNIQUE'},
                                           's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                               'MAP_MERGE_INDICES': {'diffrn_measurement': {'ATTRIBUTES': ('diffrn_id',),
                                                                            'TYPE': 'EQUI-JOIN'}},
                               'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                               'TABLE_ID': 'DIFFRN_MEASUREMENT',
                               'TABLE_NAME': 'diffrn_measurement',
                               'TABLE_TYPE': 'transactional'},
        'DIFFRN_ORIENT_MATRIX': {'ATTRIBUTES': {'DIFFRN_ID': 'diffrn_id',
                                                'STRUCTURE_ID': 'Structure_ID',
                                                'TYPE': 'type',
                                                'UB_1_1': 'UB_1_1',
                                                'UB_1_2': 'UB_1_2',
                                                'UB_1_3': 'UB_1_3',
                                                'UB_2_1': 'UB_2_1',
                                                'UB_2_2': 'UB_2_2',
                                                'UB_2_3': 'UB_2_3',
                                                'UB_3_1': 'UB_3_1',
                                                'UB_3_2': 'UB_3_2',
                                                'UB_3_3': 'UB_3_3'},
                                 'ATTRIBUTE_INFO': {'DIFFRN_ID': {'NULLABLE': False,
                                                                  'ORDER': 2,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': True,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10},
                                                    'STRUCTURE_ID': {'NULLABLE': False,
                                                                     'ORDER': 1,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': True,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                                    'TYPE': {'NULLABLE': True,
                                                             'ORDER': 3,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 200},
                                                    'UB_1_1': {'NULLABLE': True,
                                                               'ORDER': 4,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                                    'UB_1_2': {'NULLABLE': True,
                                                               'ORDER': 5,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                                    'UB_1_3': {'NULLABLE': True,
                                                               'ORDER': 6,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                                    'UB_2_1': {'NULLABLE': True,
                                                               'ORDER': 7,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                                    'UB_2_2': {'NULLABLE': True,
                                                               'ORDER': 8,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                                    'UB_2_3': {'NULLABLE': True,
                                                               'ORDER': 9,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                                    'UB_3_1': {'NULLABLE': True,
                                                               'ORDER': 10,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                                    'UB_3_2': {'NULLABLE': True,
                                                               'ORDER': 11,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                                    'UB_3_3': {'NULLABLE': True,
                                                               'ORDER': 12,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10}},
                                 'ATTRIBUTE_MAP': {'DIFFRN_ID': ('diffrn_orient_matrix', 'diffrn_id', None, None),
                                                   'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                   'TYPE': ('diffrn_orient_matrix', 'type', None, None),
                                                   'UB_1_1': ('diffrn_orient_matrix', 'UB[1][1]', None, None),
                                                   'UB_1_2': ('diffrn_orient_matrix', 'UB[1][2]', None, None),
                                                   'UB_1_3': ('diffrn_orient_matrix', 'UB[1][3]', None, None),
                                                   'UB_2_1': ('diffrn_orient_matrix', 'UB[2][1]', None, None),
                                                   'UB_2_2': ('diffrn_orient_matrix', 'UB[2][2]', None, None),
                                                   'UB_2_3': ('diffrn_orient_matrix', 'UB[2][3]', None, None),
                                                   'UB_3_1': ('diffrn_orient_matrix', 'UB[3][1]', None, None),
                                                   'UB_3_2': ('diffrn_orient_matrix', 'UB[3][2]', None, None),
                                                   'UB_3_3': ('diffrn_orient_matrix', 'UB[3][3]', None, None)},
                                 'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'DIFFRN_ID'), 'TYPE': 'UNIQUE'},
                                             's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                 'MAP_MERGE_INDICES': {'diffrn_orient_matrix': {'ATTRIBUTES': ('diffrn_id',),
                                                                                'TYPE': 'EQUI-JOIN'}},
                                 'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                 'TABLE_ID': 'DIFFRN_ORIENT_MATRIX',
                                 'TABLE_NAME': 'diffrn_orient_matrix',
                                 'TABLE_TYPE': 'transactional'},
        'DIFFRN_ORIENT_REFLN': {'ATTRIBUTES': {'ANGLE_CHI': 'angle_chi',
                                               'ANGLE_KAPPA': 'angle_kappa',
                                               'ANGLE_OMEGA': 'angle_omega',
                                               'ANGLE_PHI': 'angle_phi',
                                               'ANGLE_PSI': 'angle_psi',
                                               'ANGLE_THETA': 'angle_theta',
                                               'DIFFRN_ID': 'diffrn_id',
                                               'INDEX_H': 'index_h',
                                               'INDEX_K': 'index_k',
                                               'INDEX_L': 'index_l',
                                               'STRUCTURE_ID': 'Structure_ID'},
                                'ATTRIBUTE_INFO': {'ANGLE_CHI': {'NULLABLE': True,
                                                                 'ORDER': 3,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                                   'ANGLE_KAPPA': {'NULLABLE': True,
                                                                   'ORDER': 4,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                                   'ANGLE_OMEGA': {'NULLABLE': True,
                                                                   'ORDER': 5,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                                   'ANGLE_PHI': {'NULLABLE': True,
                                                                 'ORDER': 6,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                                   'ANGLE_PSI': {'NULLABLE': True,
                                                                 'ORDER': 7,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                                   'ANGLE_THETA': {'NULLABLE': True,
                                                                   'ORDER': 8,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                                   'DIFFRN_ID': {'NULLABLE': False,
                                                                 'ORDER': 2,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': True,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                                   'INDEX_H': {'NULLABLE': False,
                                                               'ORDER': 9,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'INT',
                                                               'WIDTH': 10},
                                                   'INDEX_K': {'NULLABLE': False,
                                                               'ORDER': 10,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'INT',
                                                               'WIDTH': 10},
                                                   'INDEX_L': {'NULLABLE': False,
                                                               'ORDER': 11,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'INT',
                                                               'WIDTH': 10},
                                                   'STRUCTURE_ID': {'NULLABLE': False,
                                                                    'ORDER': 1,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': True,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10}},
                                'ATTRIBUTE_MAP': {'ANGLE_CHI': ('diffrn_orient_refln', 'angle_chi', None, None),
                                                  'ANGLE_KAPPA': ('diffrn_orient_refln', 'angle_kappa', None, None),
                                                  'ANGLE_OMEGA': ('diffrn_orient_refln', 'angle_omega', None, None),
                                                  'ANGLE_PHI': ('diffrn_orient_refln', 'angle_phi', None, None),
                                                  'ANGLE_PSI': ('diffrn_orient_refln', 'angle_psi', None, None),
                                                  'ANGLE_THETA': ('diffrn_orient_refln', 'angle_theta', None, None),
                                                  'DIFFRN_ID': ('diffrn_orient_refln', 'diffrn_id', None, None),
                                                  'INDEX_H': ('diffrn_orient_refln', 'index_h', None, None),
                                                  'INDEX_K': ('diffrn_orient_refln', 'index_k', None, None),
                                                  'INDEX_L': ('diffrn_orient_refln', 'index_l', None, None),
                                                  'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID',
                                                                  'DIFFRN_ID',
                                                                  'INDEX_H',
                                                                  'INDEX_K',
                                                                  'INDEX_L'),
                                                   'TYPE': 'UNIQUE'},
                                            's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                'MAP_MERGE_INDICES': {'diffrn_orient_refln': {'ATTRIBUTES': ('diffrn_id',
                                                                                             'index_h',
                                                                                             'index_k',
                                                                                             'index_l'),
                                                                              'TYPE': 'EQUI-JOIN'}},
                                'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                'TABLE_ID': 'DIFFRN_ORIENT_REFLN',
                                'TABLE_NAME': 'diffrn_orient_refln',
                                'TABLE_TYPE': 'transactional'},
        'DIFFRN_RADIATION': {'ATTRIBUTES': {'COLLIMATION': 'collimation',
                                            'DIFFRN_ID': 'diffrn_id',
                                            'FILTER_EDGE': 'filter_edge',
                                            'INHOMOGENEITY': 'inhomogeneity',
                                            'MONOCHROMATOR': 'monochromator',
                                            'PDBX_ANALYZER': 'pdbx_analyzer',
                                            'PDBX_DIFFRN_PROTOCOL': 'pdbx_diffrn_protocol',
                                            'PDBX_MONOCHROMATIC_OR_LAUE_M_L': 'pdbx_monochromatic_or_laue_m_l',
                                            'PDBX_SCATTERING_TYPE': 'pdbx_scattering_type',
                                            'PDBX_WAVELENGTH': 'pdbx_wavelength',
                                            'PDBX_WAVELENGTH_LIST': 'pdbx_wavelength_list',
                                            'POLARISN_NORM': 'polarisn_norm',
                                            'POLARISN_RATIO': 'polarisn_ratio',
                                            'PROBE': 'probe',
                                            'STRUCTURE_ID': 'Structure_ID',
                                            'TYPE': 'type',
                                            'WAVELENGTH_ID': 'wavelength_id',
                                            'XRAY_SYMBOL': 'xray_symbol'},
                             'ATTRIBUTE_INFO': {'COLLIMATION': {'NULLABLE': True,
                                                                'ORDER': 3,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 200},
                                                'DIFFRN_ID': {'NULLABLE': False,
                                                              'ORDER': 2,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10},
                                                'FILTER_EDGE': {'NULLABLE': True,
                                                                'ORDER': 4,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                                'INHOMOGENEITY': {'NULLABLE': True,
                                                                  'ORDER': 5,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10},
                                                'MONOCHROMATOR': {'NULLABLE': True,
                                                                  'ORDER': 6,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 511},
                                                'PDBX_ANALYZER': {'NULLABLE': True,
                                                                  'ORDER': 17,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 200},
                                                'PDBX_DIFFRN_PROTOCOL': {'NULLABLE': True,
                                                                         'ORDER': 16,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 128},
                                                'PDBX_MONOCHROMATIC_OR_LAUE_M_L': {'NULLABLE': True,
                                                                                   'ORDER': 13,
                                                                                   'PRECISION': 0,
                                                                                   'PRIMARY_KEY': False,
                                                                                   'SQL_TYPE': 'VARCHAR',
                                                                                   'WIDTH': 10},
                                                'PDBX_SCATTERING_TYPE': {'NULLABLE': True,
                                                                         'ORDER': 18,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 80},
                                                'PDBX_WAVELENGTH': {'NULLABLE': True,
                                                                    'ORDER': 15,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 80},
                                                'PDBX_WAVELENGTH_LIST': {'NULLABLE': True,
                                                                         'ORDER': 14,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 80},
                                                'POLARISN_NORM': {'NULLABLE': True,
                                                                  'ORDER': 7,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10},
                                                'POLARISN_RATIO': {'NULLABLE': True,
                                                                   'ORDER': 8,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                                'PROBE': {'NULLABLE': True,
                                                          'ORDER': 9,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 80},
                                                'STRUCTURE_ID': {'NULLABLE': False,
                                                                 'ORDER': 1,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': True,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                                'TYPE': {'NULLABLE': True,
                                                         'ORDER': 10,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 80},
                                                'WAVELENGTH_ID': {'NULLABLE': True,
                                                                  'ORDER': 12,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10},
                                                'XRAY_SYMBOL': {'NULLABLE': True,
                                                                'ORDER': 11,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 80}},
                             'ATTRIBUTE_MAP': {'COLLIMATION': ('diffrn_radiation', 'collimation', None, None),
                                               'DIFFRN_ID': ('diffrn_radiation', 'diffrn_id', None, None),
                                               'FILTER_EDGE': ('diffrn_radiation', 'filter_edge', None, None),
                                               'INHOMOGENEITY': ('diffrn_radiation', 'inhomogeneity', None, None),
                                               'MONOCHROMATOR': ('diffrn_radiation', 'monochromator', None, None),
                                               'PDBX_ANALYZER': ('diffrn_radiation', 'pdbx_analyzer', None, None),
                                               'PDBX_DIFFRN_PROTOCOL': ('diffrn_radiation',
                                                                        'pdbx_diffrn_protocol',
                                                                        None,
                                                                        None),
                                               'PDBX_MONOCHROMATIC_OR_LAUE_M_L': ('diffrn_radiation',
                                                                                  'pdbx_monochromatic_or_laue_m_l',
                                                                                  None,
                                                                                  None),
                                               'PDBX_SCATTERING_TYPE': ('diffrn_radiation',
                                                                        'pdbx_scattering_type',
                                                                        None,
                                                                        None),
                                               'PDBX_WAVELENGTH': ('diffrn_radiation', 'pdbx_wavelength', None, None),
                                               'PDBX_WAVELENGTH_LIST': ('diffrn_radiation',
                                                                        'pdbx_wavelength_list',
                                                                        None,
                                                                        None),
                                               'POLARISN_NORM': ('diffrn_radiation', 'polarisn_norm', None, None),
                                               'POLARISN_RATIO': ('diffrn_radiation', 'polarisn_ratio', None, None),
                                               'PROBE': ('diffrn_radiation', 'probe', None, None),
                                               'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                               'TYPE': ('diffrn_radiation', 'type', None, None),
                                               'WAVELENGTH_ID': ('diffrn_radiation', 'wavelength_id', None, None),
                                               'XRAY_SYMBOL': ('diffrn_radiation', 'xray_symbol', None, None)},
                             'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'DIFFRN_ID'), 'TYPE': 'UNIQUE'},
                                         's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                             'MAP_MERGE_INDICES': {'diffrn_radiation': {'ATTRIBUTES': ('diffrn_id',), 'TYPE': 'EQUI-JOIN'}},
                             'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                             'TABLE_ID': 'DIFFRN_RADIATION',
                             'TABLE_NAME': 'diffrn_radiation',
                             'TABLE_TYPE': 'transactional'},
        'DIFFRN_RADIATION_WAVELENGTH': {'ATTRIBUTES': {'ID': 'id',
                                                       'STRUCTURE_ID': 'Structure_ID',
                                                       'WAVELENGTH': 'wavelength',
                                                       'WT': 'wt'},
                                        'ATTRIBUTE_INFO': {'ID': {'NULLABLE': False,
                                                                  'ORDER': 2,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': True,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10},
                                                           'STRUCTURE_ID': {'NULLABLE': False,
                                                                            'ORDER': 1,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': True,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 10},
                                                           'WAVELENGTH': {'NULLABLE': True,
                                                                          'ORDER': 3,
                                                                          'PRECISION': 6,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'FLOAT',
                                                                          'WIDTH': 10},
                                                           'WT': {'NULLABLE': True,
                                                                  'ORDER': 4,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10}},
                                        'ATTRIBUTE_MAP': {'ID': ('diffrn_radiation_wavelength', 'id', None, None),
                                                          'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                          'WAVELENGTH': ('diffrn_radiation_wavelength',
                                                                         'wavelength',
                                                                         None,
                                                                         None),
                                                          'WT': ('diffrn_radiation_wavelength', 'wt', None, None)},
                                        'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                                    's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                        'MAP_MERGE_INDICES': {'diffrn_radiation_wavelength': {'ATTRIBUTES': ('id',),
                                                                                              'TYPE': 'EQUI-JOIN'}},
                                        'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                        'TABLE_ID': 'DIFFRN_RADIATION_WAVELENGTH',
                                        'TABLE_NAME': 'diffrn_radiation_wavelength',
                                        'TABLE_TYPE': 'transactional'},
        'DIFFRN_REFLN': {'ATTRIBUTES': {'ANGLE_CHI': 'angle_chi',
                                        'ANGLE_KAPPA': 'angle_kappa',
                                        'ANGLE_OMEGA': 'angle_omega',
                                        'ANGLE_PHI': 'angle_phi',
                                        'ANGLE_PSI': 'angle_psi',
                                        'ANGLE_THETA': 'angle_theta',
                                        'ATTENUATOR_CODE': 'attenuator_code',
                                        'CLASS_CODE': 'class_code',
                                        'COUNTS_BG_1': 'counts_bg_1',
                                        'COUNTS_BG_2': 'counts_bg_2',
                                        'COUNTS_NET': 'counts_net',
                                        'COUNTS_PEAK': 'counts_peak',
                                        'COUNTS_TOTAL': 'counts_total',
                                        'DETECT_SLIT_HORIZ': 'detect_slit_horiz',
                                        'DETECT_SLIT_VERT': 'detect_slit_vert',
                                        'DIFFRN_ID': 'diffrn_id',
                                        'ELAPSED_TIME': 'elapsed_time',
                                        'ID': 'id',
                                        'INDEX_H': 'index_h',
                                        'INDEX_K': 'index_k',
                                        'INDEX_L': 'index_l',
                                        'INTENSITY_NET': 'intensity_net',
                                        'INTENSITY_SIGMA': 'intensity_sigma',
                                        'INTENSITY_U': 'intensity_u',
                                        'SCALE_GROUP_CODE': 'scale_group_code',
                                        'SCAN_MODE': 'scan_mode',
                                        'SCAN_MODE_BACKGD': 'scan_mode_backgd',
                                        'SCAN_RATE': 'scan_rate',
                                        'SCAN_TIME_BACKGD': 'scan_time_backgd',
                                        'SCAN_WIDTH': 'scan_width',
                                        'SINT_OVER_LAMBDA': 'sint_over_lambda',
                                        'STANDARD_CODE': 'standard_code',
                                        'STRUCTURE_ID': 'Structure_ID',
                                        'WAVELENGTH': 'wavelength',
                                        'WAVELENGTH_ID': 'wavelength_id'},
                         'ATTRIBUTE_INFO': {'ANGLE_CHI': {'NULLABLE': True,
                                                          'ORDER': 4,
                                                          'PRECISION': 6,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'FLOAT',
                                                          'WIDTH': 10},
                                            'ANGLE_KAPPA': {'NULLABLE': True,
                                                            'ORDER': 5,
                                                            'PRECISION': 6,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'FLOAT',
                                                            'WIDTH': 10},
                                            'ANGLE_OMEGA': {'NULLABLE': True,
                                                            'ORDER': 6,
                                                            'PRECISION': 6,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'FLOAT',
                                                            'WIDTH': 10},
                                            'ANGLE_PHI': {'NULLABLE': True,
                                                          'ORDER': 7,
                                                          'PRECISION': 6,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'FLOAT',
                                                          'WIDTH': 10},
                                            'ANGLE_PSI': {'NULLABLE': True,
                                                          'ORDER': 8,
                                                          'PRECISION': 6,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'FLOAT',
                                                          'WIDTH': 10},
                                            'ANGLE_THETA': {'NULLABLE': True,
                                                            'ORDER': 9,
                                                            'PRECISION': 6,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'FLOAT',
                                                            'WIDTH': 10},
                                            'ATTENUATOR_CODE': {'NULLABLE': True,
                                                                'ORDER': 10,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                            'CLASS_CODE': {'NULLABLE': True,
                                                           'ORDER': 34,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 10},
                                            'COUNTS_BG_1': {'NULLABLE': True,
                                                            'ORDER': 11,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'INT',
                                                            'WIDTH': 10},
                                            'COUNTS_BG_2': {'NULLABLE': True,
                                                            'ORDER': 12,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'INT',
                                                            'WIDTH': 10},
                                            'COUNTS_NET': {'NULLABLE': True,
                                                           'ORDER': 13,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'INT',
                                                           'WIDTH': 10},
                                            'COUNTS_PEAK': {'NULLABLE': True,
                                                            'ORDER': 14,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'INT',
                                                            'WIDTH': 10},
                                            'COUNTS_TOTAL': {'NULLABLE': True,
                                                             'ORDER': 15,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'INT',
                                                             'WIDTH': 10},
                                            'DETECT_SLIT_HORIZ': {'NULLABLE': True,
                                                                  'ORDER': 16,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10},
                                            'DETECT_SLIT_VERT': {'NULLABLE': True,
                                                                 'ORDER': 17,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                            'DIFFRN_ID': {'NULLABLE': False,
                                                          'ORDER': 2,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': True,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 10},
                                            'ELAPSED_TIME': {'NULLABLE': True,
                                                             'ORDER': 18,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                            'ID': {'NULLABLE': False,
                                                   'ORDER': 19,
                                                   'PRECISION': 0,
                                                   'PRIMARY_KEY': True,
                                                   'SQL_TYPE': 'VARCHAR',
                                                   'WIDTH': 10},
                                            'INDEX_H': {'NULLABLE': True,
                                                        'ORDER': 20,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'INT',
                                                        'WIDTH': 10},
                                            'INDEX_K': {'NULLABLE': True,
                                                        'ORDER': 21,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'INT',
                                                        'WIDTH': 10},
                                            'INDEX_L': {'NULLABLE': True,
                                                        'ORDER': 22,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'INT',
                                                        'WIDTH': 10},
                                            'INTENSITY_NET': {'NULLABLE': True,
                                                              'ORDER': 23,
                                                              'PRECISION': 6,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'FLOAT',
                                                              'WIDTH': 10},
                                            'INTENSITY_SIGMA': {'NULLABLE': True,
                                                                'ORDER': 24,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                            'INTENSITY_U': {'NULLABLE': True,
                                                            'ORDER': 35,
                                                            'PRECISION': 6,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'FLOAT',
                                                            'WIDTH': 10},
                                            'SCALE_GROUP_CODE': {'NULLABLE': True,
                                                                 'ORDER': 25,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                            'SCAN_MODE': {'NULLABLE': True,
                                                          'ORDER': 26,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 10},
                                            'SCAN_MODE_BACKGD': {'NULLABLE': True,
                                                                 'ORDER': 27,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                            'SCAN_RATE': {'NULLABLE': True,
                                                          'ORDER': 28,
                                                          'PRECISION': 6,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'FLOAT',
                                                          'WIDTH': 10},
                                            'SCAN_TIME_BACKGD': {'NULLABLE': True,
                                                                 'ORDER': 29,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                            'SCAN_WIDTH': {'NULLABLE': True,
                                                           'ORDER': 30,
                                                           'PRECISION': 6,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'FLOAT',
                                                           'WIDTH': 10},
                                            'SINT_OVER_LAMBDA': {'NULLABLE': True,
                                                                 'ORDER': 31,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                            'STANDARD_CODE': {'NULLABLE': True,
                                                              'ORDER': 32,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10},
                                            'STRUCTURE_ID': {'NULLABLE': False,
                                                             'ORDER': 1,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 10},
                                            'WAVELENGTH': {'NULLABLE': True,
                                                           'ORDER': 33,
                                                           'PRECISION': 6,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'FLOAT',
                                                           'WIDTH': 10},
                                            'WAVELENGTH_ID': {'NULLABLE': True,
                                                              'ORDER': 3,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10}},
                         'ATTRIBUTE_MAP': {'ANGLE_CHI': ('diffrn_refln', 'angle_chi', None, None),
                                           'ANGLE_KAPPA': ('diffrn_refln', 'angle_kappa', None, None),
                                           'ANGLE_OMEGA': ('diffrn_refln', 'angle_omega', None, None),
                                           'ANGLE_PHI': ('diffrn_refln', 'angle_phi', None, None),
                                           'ANGLE_PSI': ('diffrn_refln', 'angle_psi', None, None),
                                           'ANGLE_THETA': ('diffrn_refln', 'angle_theta', None, None),
                                           'ATTENUATOR_CODE': ('diffrn_refln', 'attenuator_code', None, None),
                                           'CLASS_CODE': ('diffrn_refln', 'class_code', None, None),
                                           'COUNTS_BG_1': ('diffrn_refln', 'counts_bg_1', None, None),
                                           'COUNTS_BG_2': ('diffrn_refln', 'counts_bg_2', None, None),
                                           'COUNTS_NET': ('diffrn_refln', 'counts_net', None, None),
                                           'COUNTS_PEAK': ('diffrn_refln', 'counts_peak', None, None),
                                           'COUNTS_TOTAL': ('diffrn_refln', 'counts_total', None, None),
                                           'DETECT_SLIT_HORIZ': ('diffrn_refln', 'detect_slit_horiz', None, None),
                                           'DETECT_SLIT_VERT': ('diffrn_refln', 'detect_slit_vert', None, None),
                                           'DIFFRN_ID': ('diffrn_refln', 'diffrn_id', None, None),
                                           'ELAPSED_TIME': ('diffrn_refln', 'elapsed_time', None, None),
                                           'ID': ('diffrn_refln', 'id', None, None),
                                           'INDEX_H': ('diffrn_refln', 'index_h', None, None),
                                           'INDEX_K': ('diffrn_refln', 'index_k', None, None),
                                           'INDEX_L': ('diffrn_refln', 'index_l', None, None),
                                           'INTENSITY_NET': ('diffrn_refln', 'intensity_net', None, None),
                                           'INTENSITY_SIGMA': ('diffrn_refln', 'intensity_sigma', None, None),
                                           'INTENSITY_U': ('diffrn_refln', 'intensity_u', None, None),
                                           'SCALE_GROUP_CODE': ('diffrn_refln', 'scale_group_code', None, None),
                                           'SCAN_MODE': ('diffrn_refln', 'scan_mode', None, None),
                                           'SCAN_MODE_BACKGD': ('diffrn_refln', 'scan_mode_backgd', None, None),
                                           'SCAN_RATE': ('diffrn_refln', 'scan_rate', None, None),
                                           'SCAN_TIME_BACKGD': ('diffrn_refln', 'scan_time_backgd', None, None),
                                           'SCAN_WIDTH': ('diffrn_refln', 'scan_width', None, None),
                                           'SINT_OVER_LAMBDA': ('diffrn_refln', 'sint_over_lambda', None, None),
                                           'STANDARD_CODE': ('diffrn_refln', 'standard_code', None, None),
                                           'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                           'WAVELENGTH': ('diffrn_refln', 'wavelength', None, None),
                                           'WAVELENGTH_ID': ('diffrn_refln', 'wavelength_id', None, None)},
                         'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'DIFFRN_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                     's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                         'MAP_MERGE_INDICES': {'diffrn_refln': {'ATTRIBUTES': ('diffrn_id', 'id'), 'TYPE': 'EQUI-JOIN'}},
                         'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                         'TABLE_ID': 'DIFFRN_REFLN',
                         'TABLE_NAME': 'diffrn_refln',
                         'TABLE_TYPE': 'transactional'},
        'DIFFRN_REFLNS': {'ATTRIBUTES': {'AV_R_EQUIVALENTS': 'av_R_equivalents',
                                         'AV_SIGMAI_OVER_NETI': 'av_sigmaI_over_netI',
                                         'AV_UNETI_NETI': 'av_unetI_netI',
                                         'DIFFRN_ID': 'diffrn_id',
                                         'LIMIT_H_MAX': 'limit_h_max',
                                         'LIMIT_H_MIN': 'limit_h_min',
                                         'LIMIT_K_MAX': 'limit_k_max',
                                         'LIMIT_K_MIN': 'limit_k_min',
                                         'LIMIT_L_MAX': 'limit_l_max',
                                         'LIMIT_L_MIN': 'limit_l_min',
                                         'NUMBER': 'number',
                                         'PDBX_CHI_SQUARED': 'pdbx_chi_squared',
                                         'PDBX_D_RES_HIGH': 'pdbx_d_res_high',
                                         'PDBX_D_RES_LOW': 'pdbx_d_res_low',
                                         'PDBX_NUMBER_OBS': 'pdbx_number_obs',
                                         'PDBX_OBSERVED_CRITERION': 'pdbx_observed_criterion',
                                         'PDBX_PERCENT_POSSIBLE_OBS': 'pdbx_percent_possible_obs',
                                         'PDBX_REDUNDANCY': 'pdbx_redundancy',
                                         'PDBX_REJECTS': 'pdbx_rejects',
                                         'PDBX_RMERGE_I_OBS': 'pdbx_Rmerge_I_obs',
                                         'PDBX_RSYM_VALUE': 'pdbx_Rsym_value',
                                         'REDUCTION_PROCESS': 'reduction_process',
                                         'STRUCTURE_ID': 'Structure_ID',
                                         'THETA_MAX': 'theta_max',
                                         'THETA_MIN': 'theta_min',
                                         'TRANSF_MATRIX_1_1': 'transf_matrix_1_1',
                                         'TRANSF_MATRIX_1_2': 'transf_matrix_1_2',
                                         'TRANSF_MATRIX_1_3': 'transf_matrix_1_3',
                                         'TRANSF_MATRIX_2_1': 'transf_matrix_2_1',
                                         'TRANSF_MATRIX_2_2': 'transf_matrix_2_2',
                                         'TRANSF_MATRIX_2_3': 'transf_matrix_2_3',
                                         'TRANSF_MATRIX_3_1': 'transf_matrix_3_1',
                                         'TRANSF_MATRIX_3_2': 'transf_matrix_3_2',
                                         'TRANSF_MATRIX_3_3': 'transf_matrix_3_3'},
                          'ATTRIBUTE_INFO': {'AV_R_EQUIVALENTS': {'NULLABLE': True,
                                                                  'ORDER': 3,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10},
                                             'AV_SIGMAI_OVER_NETI': {'NULLABLE': True,
                                                                     'ORDER': 4,
                                                                     'PRECISION': 6,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'FLOAT',
                                                                     'WIDTH': 10},
                                             'AV_UNETI_NETI': {'NULLABLE': True,
                                                               'ORDER': 24,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                             'DIFFRN_ID': {'NULLABLE': False,
                                                           'ORDER': 2,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': True,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 10},
                                             'LIMIT_H_MAX': {'NULLABLE': True,
                                                             'ORDER': 5,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'INT',
                                                             'WIDTH': 10},
                                             'LIMIT_H_MIN': {'NULLABLE': True,
                                                             'ORDER': 6,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'INT',
                                                             'WIDTH': 10},
                                             'LIMIT_K_MAX': {'NULLABLE': True,
                                                             'ORDER': 7,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'INT',
                                                             'WIDTH': 10},
                                             'LIMIT_K_MIN': {'NULLABLE': True,
                                                             'ORDER': 8,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'INT',
                                                             'WIDTH': 10},
                                             'LIMIT_L_MAX': {'NULLABLE': True,
                                                             'ORDER': 9,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'INT',
                                                             'WIDTH': 10},
                                             'LIMIT_L_MIN': {'NULLABLE': True,
                                                             'ORDER': 10,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'INT',
                                                             'WIDTH': 10},
                                             'NUMBER': {'NULLABLE': True,
                                                        'ORDER': 11,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'INT',
                                                        'WIDTH': 10},
                                             'PDBX_CHI_SQUARED': {'NULLABLE': True,
                                                                  'ORDER': 30,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10},
                                             'PDBX_D_RES_HIGH': {'NULLABLE': True,
                                                                 'ORDER': 26,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                             'PDBX_D_RES_LOW': {'NULLABLE': True,
                                                                'ORDER': 25,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                             'PDBX_NUMBER_OBS': {'NULLABLE': True,
                                                                 'ORDER': 34,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'INT',
                                                                 'WIDTH': 10},
                                             'PDBX_OBSERVED_CRITERION': {'NULLABLE': True,
                                                                         'ORDER': 33,
                                                                         'PRECISION': 6,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'FLOAT',
                                                                         'WIDTH': 10},
                                             'PDBX_PERCENT_POSSIBLE_OBS': {'NULLABLE': True,
                                                                           'ORDER': 27,
                                                                           'PRECISION': 6,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'FLOAT',
                                                                           'WIDTH': 10},
                                             'PDBX_REDUNDANCY': {'NULLABLE': True,
                                                                 'ORDER': 31,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                             'PDBX_REJECTS': {'NULLABLE': True,
                                                              'ORDER': 32,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'INT',
                                                              'WIDTH': 10},
                                             'PDBX_RMERGE_I_OBS': {'NULLABLE': True,
                                                                   'ORDER': 28,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                             'PDBX_RSYM_VALUE': {'NULLABLE': True,
                                                                 'ORDER': 29,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                             'REDUCTION_PROCESS': {'NULLABLE': True,
                                                                   'ORDER': 12,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 200},
                                             'STRUCTURE_ID': {'NULLABLE': False,
                                                              'ORDER': 1,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10},
                                             'THETA_MAX': {'NULLABLE': True,
                                                           'ORDER': 13,
                                                           'PRECISION': 6,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'FLOAT',
                                                           'WIDTH': 10},
                                             'THETA_MIN': {'NULLABLE': True,
                                                           'ORDER': 14,
                                                           'PRECISION': 6,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'FLOAT',
                                                           'WIDTH': 10},
                                             'TRANSF_MATRIX_1_1': {'NULLABLE': True,
                                                                   'ORDER': 15,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                             'TRANSF_MATRIX_1_2': {'NULLABLE': True,
                                                                   'ORDER': 16,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                             'TRANSF_MATRIX_1_3': {'NULLABLE': True,
                                                                   'ORDER': 17,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                             'TRANSF_MATRIX_2_1': {'NULLABLE': True,
                                                                   'ORDER': 18,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                             'TRANSF_MATRIX_2_2': {'NULLABLE': True,
                                                                   'ORDER': 19,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                             'TRANSF_MATRIX_2_3': {'NULLABLE': True,
                                                                   'ORDER': 20,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                             'TRANSF_MATRIX_3_1': {'NULLABLE': True,
                                                                   'ORDER': 21,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                             'TRANSF_MATRIX_3_2': {'NULLABLE': True,
                                                                   'ORDER': 22,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                             'TRANSF_MATRIX_3_3': {'NULLABLE': True,
                                                                   'ORDER': 23,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10}},
                          'ATTRIBUTE_MAP': {'AV_R_EQUIVALENTS': ('diffrn_reflns', 'av_R_equivalents', None, None),
                                            'AV_SIGMAI_OVER_NETI': ('diffrn_reflns', 'av_sigmaI_over_netI', None, None),
                                            'AV_UNETI_NETI': ('diffrn_reflns', 'av_unetI/netI', None, None),
                                            'DIFFRN_ID': ('diffrn_reflns', 'diffrn_id', None, None),
                                            'LIMIT_H_MAX': ('diffrn_reflns', 'limit_h_max', None, None),
                                            'LIMIT_H_MIN': ('diffrn_reflns', 'limit_h_min', None, None),
                                            'LIMIT_K_MAX': ('diffrn_reflns', 'limit_k_max', None, None),
                                            'LIMIT_K_MIN': ('diffrn_reflns', 'limit_k_min', None, None),
                                            'LIMIT_L_MAX': ('diffrn_reflns', 'limit_l_max', None, None),
                                            'LIMIT_L_MIN': ('diffrn_reflns', 'limit_l_min', None, None),
                                            'NUMBER': ('diffrn_reflns', 'number', None, None),
                                            'PDBX_CHI_SQUARED': ('diffrn_reflns', 'pdbx_chi_squared', None, None),
                                            'PDBX_D_RES_HIGH': ('diffrn_reflns', 'pdbx_d_res_high', None, None),
                                            'PDBX_D_RES_LOW': ('diffrn_reflns', 'pdbx_d_res_low', None, None),
                                            'PDBX_NUMBER_OBS': ('diffrn_reflns', 'pdbx_number_obs', None, None),
                                            'PDBX_OBSERVED_CRITERION': ('diffrn_reflns',
                                                                        'pdbx_observed_criterion',
                                                                        None,
                                                                        None),
                                            'PDBX_PERCENT_POSSIBLE_OBS': ('diffrn_reflns',
                                                                          'pdbx_percent_possible_obs',
                                                                          None,
                                                                          None),
                                            'PDBX_REDUNDANCY': ('diffrn_reflns', 'pdbx_redundancy', None, None),
                                            'PDBX_REJECTS': ('diffrn_reflns', 'pdbx_rejects', None, None),
                                            'PDBX_RMERGE_I_OBS': ('diffrn_reflns', 'pdbx_Rmerge_I_obs', None, None),
                                            'PDBX_RSYM_VALUE': ('diffrn_reflns', 'pdbx_Rsym_value', None, None),
                                            'REDUCTION_PROCESS': ('diffrn_reflns', 'reduction_process', None, None),
                                            'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                            'THETA_MAX': ('diffrn_reflns', 'theta_max', None, None),
                                            'THETA_MIN': ('diffrn_reflns', 'theta_min', None, None),
                                            'TRANSF_MATRIX_1_1': ('diffrn_reflns', 'transf_matrix[1][1]', None, None),
                                            'TRANSF_MATRIX_1_2': ('diffrn_reflns', 'transf_matrix[1][2]', None, None),
                                            'TRANSF_MATRIX_1_3': ('diffrn_reflns', 'transf_matrix[1][3]', None, None),
                                            'TRANSF_MATRIX_2_1': ('diffrn_reflns', 'transf_matrix[2][1]', None, None),
                                            'TRANSF_MATRIX_2_2': ('diffrn_reflns', 'transf_matrix[2][2]', None, None),
                                            'TRANSF_MATRIX_2_3': ('diffrn_reflns', 'transf_matrix[2][3]', None, None),
                                            'TRANSF_MATRIX_3_1': ('diffrn_reflns', 'transf_matrix[3][1]', None, None),
                                            'TRANSF_MATRIX_3_2': ('diffrn_reflns', 'transf_matrix[3][2]', None, None),
                                            'TRANSF_MATRIX_3_3': ('diffrn_reflns', 'transf_matrix[3][3]', None, None)},
                          'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'DIFFRN_ID'), 'TYPE': 'UNIQUE'},
                                      's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                          'MAP_MERGE_INDICES': {'diffrn_reflns': {'ATTRIBUTES': ('diffrn_id',), 'TYPE': 'EQUI-JOIN'}},
                          'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                          'TABLE_ID': 'DIFFRN_REFLNS',
                          'TABLE_NAME': 'diffrn_reflns',
                          'TABLE_TYPE': 'transactional'},
        'DIFFRN_REFLNS_CLASS': {'ATTRIBUTES': {'AV_R_EQ': 'av_R_eq',
                                               'AV_SGI_I': 'av_sgI_I',
                                               'AV_UI_I': 'av_uI_I',
                                               'CODE': 'code',
                                               'DESCRIPTION': 'description',
                                               'D_RES_HIGH': 'd_res_high',
                                               'D_RES_LOW': 'd_res_low',
                                               'NUMBER': 'number',
                                               'STRUCTURE_ID': 'Structure_ID'},
                                'ATTRIBUTE_INFO': {'AV_R_EQ': {'NULLABLE': True,
                                                               'ORDER': 2,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                                   'AV_SGI_I': {'NULLABLE': True,
                                                                'ORDER': 3,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                                   'AV_UI_I': {'NULLABLE': True,
                                                               'ORDER': 4,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                                   'CODE': {'NULLABLE': False,
                                                            'ORDER': 5,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': True,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 10},
                                                   'DESCRIPTION': {'NULLABLE': True,
                                                                   'ORDER': 6,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 200},
                                                   'D_RES_HIGH': {'NULLABLE': True,
                                                                  'ORDER': 7,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10},
                                                   'D_RES_LOW': {'NULLABLE': True,
                                                                 'ORDER': 8,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                                   'NUMBER': {'NULLABLE': True,
                                                              'ORDER': 9,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'INT',
                                                              'WIDTH': 10},
                                                   'STRUCTURE_ID': {'NULLABLE': False,
                                                                    'ORDER': 1,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': True,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10}},
                                'ATTRIBUTE_MAP': {'AV_R_EQ': ('diffrn_reflns_class', 'av_R_eq', None, None),
                                                  'AV_SGI_I': ('diffrn_reflns_class', 'av_sgI/I', None, None),
                                                  'AV_UI_I': ('diffrn_reflns_class', 'av_uI/I', None, None),
                                                  'CODE': ('diffrn_reflns_class', 'code', None, None),
                                                  'DESCRIPTION': ('diffrn_reflns_class', 'description', None, None),
                                                  'D_RES_HIGH': ('diffrn_reflns_class', 'd_res_high', None, None),
                                                  'D_RES_LOW': ('diffrn_reflns_class', 'd_res_low', None, None),
                                                  'NUMBER': ('diffrn_reflns_class', 'number', None, None),
                                                  'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'CODE'), 'TYPE': 'UNIQUE'},
                                            's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                'MAP_MERGE_INDICES': {'diffrn_reflns_class': {'ATTRIBUTES': ('code',), 'TYPE': 'EQUI-JOIN'}},
                                'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                'TABLE_ID': 'DIFFRN_REFLNS_CLASS',
                                'TABLE_NAME': 'diffrn_reflns_class',
                                'TABLE_TYPE': 'transactional'},
        'DIFFRN_SCALE_GROUP': {'ATTRIBUTES': {'CODE': 'code', 'I_NET': 'I_net', 'STRUCTURE_ID': 'Structure_ID'},
                               'ATTRIBUTE_INFO': {'CODE': {'NULLABLE': False,
                                                           'ORDER': 2,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': True,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 10},
                                                  'I_NET': {'NULLABLE': True,
                                                            'ORDER': 3,
                                                            'PRECISION': 6,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'FLOAT',
                                                            'WIDTH': 10},
                                                  'STRUCTURE_ID': {'NULLABLE': False,
                                                                   'ORDER': 1,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': True,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 10}},
                               'ATTRIBUTE_MAP': {'CODE': ('diffrn_scale_group', 'code', None, None),
                                                 'I_NET': ('diffrn_scale_group', 'I_net', None, None),
                                                 'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                               'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'CODE'), 'TYPE': 'UNIQUE'},
                                           's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                               'MAP_MERGE_INDICES': {'diffrn_scale_group': {'ATTRIBUTES': ('code',), 'TYPE': 'EQUI-JOIN'}},
                               'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                               'TABLE_ID': 'DIFFRN_SCALE_GROUP',
                               'TABLE_NAME': 'diffrn_scale_group',
                               'TABLE_TYPE': 'transactional'},
        'DIFFRN_SOURCE': {'ATTRIBUTES': {'CURRENT': 'current',
                                         'DETAILS': 'details',
                                         'DIFFRN_ID': 'diffrn_id',
                                         'PDBX_SYNCHROTRON_BEAMLINE': 'pdbx_synchrotron_beamline',
                                         'PDBX_SYNCHROTRON_SITE': 'pdbx_synchrotron_site',
                                         'PDBX_WAVELENGTH': 'pdbx_wavelength',
                                         'PDBX_WAVELENGTH_LIST': 'pdbx_wavelength_list',
                                         'POWER': 'power',
                                         'SIZE': 'size',
                                         'SOURCE': 'source',
                                         'STRUCTURE_ID': 'Structure_ID',
                                         'TAKE_OFF_ANGLE': 'take_off_angle',
                                         'TARGET': 'target',
                                         'TYPE': 'type',
                                         'VOLTAGE': 'voltage'},
                          'ATTRIBUTE_INFO': {'CURRENT': {'NULLABLE': True,
                                                         'ORDER': 3,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                             'DETAILS': {'NULLABLE': True,
                                                         'ORDER': 4,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 200},
                                             'DIFFRN_ID': {'NULLABLE': False,
                                                           'ORDER': 2,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': True,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 10},
                                             'PDBX_SYNCHROTRON_BEAMLINE': {'NULLABLE': True,
                                                                           'ORDER': 14,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 80},
                                             'PDBX_SYNCHROTRON_SITE': {'NULLABLE': True,
                                                                       'ORDER': 15,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 80},
                                             'PDBX_WAVELENGTH': {'NULLABLE': True,
                                                                 'ORDER': 13,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 80},
                                             'PDBX_WAVELENGTH_LIST': {'NULLABLE': True,
                                                                      'ORDER': 12,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 80},
                                             'POWER': {'NULLABLE': True,
                                                       'ORDER': 5,
                                                       'PRECISION': 6,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'FLOAT',
                                                       'WIDTH': 10},
                                             'SIZE': {'NULLABLE': True,
                                                      'ORDER': 6,
                                                      'PRECISION': 0,
                                                      'PRIMARY_KEY': False,
                                                      'SQL_TYPE': 'VARCHAR',
                                                      'WIDTH': 200},
                                             'SOURCE': {'NULLABLE': True,
                                                        'ORDER': 7,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 200},
                                             'STRUCTURE_ID': {'NULLABLE': False,
                                                              'ORDER': 1,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10},
                                             'TAKE_OFF_ANGLE': {'NULLABLE': True,
                                                                'ORDER': 11,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                             'TARGET': {'NULLABLE': True,
                                                        'ORDER': 8,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 10},
                                             'TYPE': {'NULLABLE': True,
                                                      'ORDER': 9,
                                                      'PRECISION': 0,
                                                      'PRIMARY_KEY': False,
                                                      'SQL_TYPE': 'VARCHAR',
                                                      'WIDTH': 200},
                                             'VOLTAGE': {'NULLABLE': True,
                                                         'ORDER': 10,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10}},
                          'ATTRIBUTE_MAP': {'CURRENT': ('diffrn_source', 'current', None, None),
                                            'DETAILS': ('diffrn_source', 'details', None, None),
                                            'DIFFRN_ID': ('diffrn_source', 'diffrn_id', None, None),
                                            'PDBX_SYNCHROTRON_BEAMLINE': ('diffrn_source',
                                                                          'pdbx_synchrotron_beamline',
                                                                          None,
                                                                          None),
                                            'PDBX_SYNCHROTRON_SITE': ('diffrn_source', 'pdbx_synchrotron_site', None, None),
                                            'PDBX_WAVELENGTH': ('diffrn_source', 'pdbx_wavelength', None, None),
                                            'PDBX_WAVELENGTH_LIST': ('diffrn_source', 'pdbx_wavelength_list', None, None),
                                            'POWER': ('diffrn_source', 'power', None, None),
                                            'SIZE': ('diffrn_source', 'size', None, None),
                                            'SOURCE': ('diffrn_source', 'source', None, None),
                                            'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                            'TAKE_OFF_ANGLE': ('diffrn_source', 'take-off_angle', None, None),
                                            'TARGET': ('diffrn_source', 'target', None, None),
                                            'TYPE': ('diffrn_source', 'type', None, None),
                                            'VOLTAGE': ('diffrn_source', 'voltage', None, None)},
                          'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'DIFFRN_ID'), 'TYPE': 'UNIQUE'},
                                      's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                          'MAP_MERGE_INDICES': {'diffrn_source': {'ATTRIBUTES': ('diffrn_id',), 'TYPE': 'EQUI-JOIN'}},
                          'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                          'TABLE_ID': 'DIFFRN_SOURCE',
                          'TABLE_NAME': 'diffrn_source',
                          'TABLE_TYPE': 'transactional'},
        'DIFFRN_STANDARDS': {'ATTRIBUTES': {'DECAY__': 'decay__',
                                            'DIFFRN_ID': 'diffrn_id',
                                            'INTERVAL_COUNT': 'interval_count',
                                            'INTERVAL_TIME': 'interval_time',
                                            'NUMBER': 'number',
                                            'SCALE_SIGMA': 'scale_sigma',
                                            'SCALE_U': 'scale_u',
                                            'STRUCTURE_ID': 'Structure_ID'},
                             'ATTRIBUTE_INFO': {'DECAY__': {'NULLABLE': True,
                                                            'ORDER': 3,
                                                            'PRECISION': 6,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'FLOAT',
                                                            'WIDTH': 10},
                                                'DIFFRN_ID': {'NULLABLE': False,
                                                              'ORDER': 2,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10},
                                                'INTERVAL_COUNT': {'NULLABLE': True,
                                                                   'ORDER': 4,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'INT',
                                                                   'WIDTH': 10},
                                                'INTERVAL_TIME': {'NULLABLE': True,
                                                                  'ORDER': 5,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10},
                                                'NUMBER': {'NULLABLE': True,
                                                           'ORDER': 6,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'INT',
                                                           'WIDTH': 10},
                                                'SCALE_SIGMA': {'NULLABLE': True,
                                                                'ORDER': 7,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                                'SCALE_U': {'NULLABLE': True,
                                                            'ORDER': 8,
                                                            'PRECISION': 6,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'FLOAT',
                                                            'WIDTH': 10},
                                                'STRUCTURE_ID': {'NULLABLE': False,
                                                                 'ORDER': 1,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': True,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10}},
                             'ATTRIBUTE_MAP': {'DECAY__': ('diffrn_standards', 'decay_%', None, None),
                                               'DIFFRN_ID': ('diffrn_standards', 'diffrn_id', None, None),
                                               'INTERVAL_COUNT': ('diffrn_standards', 'interval_count', None, None),
                                               'INTERVAL_TIME': ('diffrn_standards', 'interval_time', None, None),
                                               'NUMBER': ('diffrn_standards', 'number', None, None),
                                               'SCALE_SIGMA': ('diffrn_standards', 'scale_sigma', None, None),
                                               'SCALE_U': ('diffrn_standards', 'scale_u', None, None),
                                               'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                             'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'DIFFRN_ID'), 'TYPE': 'UNIQUE'},
                                         's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                             'MAP_MERGE_INDICES': {'diffrn_standards': {'ATTRIBUTES': ('diffrn_id',), 'TYPE': 'EQUI-JOIN'}},
                             'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                             'TABLE_ID': 'DIFFRN_STANDARDS',
                             'TABLE_NAME': 'diffrn_standards',
                             'TABLE_TYPE': 'transactional'},
        'DIFFRN_STANDARD_REFLN': {'ATTRIBUTES': {'CODE': 'code',
                                                 'DIFFRN_ID': 'diffrn_id',
                                                 'INDEX_H': 'index_h',
                                                 'INDEX_K': 'index_k',
                                                 'INDEX_L': 'index_l',
                                                 'STRUCTURE_ID': 'Structure_ID'},
                                  'ATTRIBUTE_INFO': {'CODE': {'NULLABLE': False,
                                                              'ORDER': 3,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10},
                                                     'DIFFRN_ID': {'NULLABLE': False,
                                                                   'ORDER': 2,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': True,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 10},
                                                     'INDEX_H': {'NULLABLE': True,
                                                                 'ORDER': 4,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'INT',
                                                                 'WIDTH': 10},
                                                     'INDEX_K': {'NULLABLE': True,
                                                                 'ORDER': 5,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'INT',
                                                                 'WIDTH': 10},
                                                     'INDEX_L': {'NULLABLE': True,
                                                                 'ORDER': 6,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'INT',
                                                                 'WIDTH': 10},
                                                     'STRUCTURE_ID': {'NULLABLE': False,
                                                                      'ORDER': 1,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10}},
                                  'ATTRIBUTE_MAP': {'CODE': ('diffrn_standard_refln', 'code', None, None),
                                                    'DIFFRN_ID': ('diffrn_standard_refln', 'diffrn_id', None, None),
                                                    'INDEX_H': ('diffrn_standard_refln', 'index_h', None, None),
                                                    'INDEX_K': ('diffrn_standard_refln', 'index_k', None, None),
                                                    'INDEX_L': ('diffrn_standard_refln', 'index_l', None, None),
                                                    'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                  'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'DIFFRN_ID', 'CODE'), 'TYPE': 'UNIQUE'},
                                              's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                  'MAP_MERGE_INDICES': {'diffrn_standard_refln': {'ATTRIBUTES': ('diffrn_id', 'code'),
                                                                                  'TYPE': 'EQUI-JOIN'}},
                                  'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                  'TABLE_ID': 'DIFFRN_STANDARD_REFLN',
                                  'TABLE_NAME': 'diffrn_standard_refln',
                                  'TABLE_TYPE': 'transactional'},
        'EM_2D_CRYSTAL_ENTITY': {'ATTRIBUTES': {'ANGLE_ALPHA': 'angle_alpha',
                                                'ANGLE_BETA': 'angle_beta',
                                                'ANGLE_GAMMA': 'angle_gamma',
                                                'DETAILS': 'details',
                                                'ENTITY_ASSEMBLY_ID': 'entity_assembly_id',
                                                'ID': 'id',
                                                'LENGTH_A': 'length_a',
                                                'LENGTH_B': 'length_b',
                                                'LENGTH_C': 'length_c',
                                                'SPACE_GROUP_NAME_H_M': 'space_group_name_H_M',
                                                'STRUCTURE_ID': 'Structure_ID'},
                                 'ATTRIBUTE_INFO': {'ANGLE_ALPHA': {'NULLABLE': True,
                                                                    'ORDER': 8,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                                    'ANGLE_BETA': {'NULLABLE': True,
                                                                   'ORDER': 9,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                                    'ANGLE_GAMMA': {'NULLABLE': True,
                                                                    'ORDER': 6,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                                    'DETAILS': {'NULLABLE': True,
                                                                'ORDER': 7,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 200},
                                                    'ENTITY_ASSEMBLY_ID': {'NULLABLE': False,
                                                                           'ORDER': 3,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': True,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10},
                                                    'ID': {'NULLABLE': False,
                                                           'ORDER': 2,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': True,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 10},
                                                    'LENGTH_A': {'NULLABLE': True,
                                                                 'ORDER': 4,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                                    'LENGTH_B': {'NULLABLE': True,
                                                                 'ORDER': 5,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                                    'LENGTH_C': {'NULLABLE': True,
                                                                 'ORDER': 10,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                                    'SPACE_GROUP_NAME_H_M': {'NULLABLE': True,
                                                                             'ORDER': 11,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 80},
                                                    'STRUCTURE_ID': {'NULLABLE': False,
                                                                     'ORDER': 1,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': True,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10}},
                                 'ATTRIBUTE_MAP': {'ANGLE_ALPHA': ('em_2d_crystal_entity', 'angle_alpha', None, None),
                                                   'ANGLE_BETA': ('em_2d_crystal_entity', 'angle_beta', None, None),
                                                   'ANGLE_GAMMA': ('em_2d_crystal_entity', 'angle_gamma', None, None),
                                                   'DETAILS': ('em_2d_crystal_entity', 'details', None, None),
                                                   'ENTITY_ASSEMBLY_ID': ('em_2d_crystal_entity',
                                                                          'entity_assembly_id',
                                                                          None,
                                                                          None),
                                                   'ID': ('em_2d_crystal_entity', 'id', None, None),
                                                   'LENGTH_A': ('em_2d_crystal_entity', 'length_a', None, None),
                                                   'LENGTH_B': ('em_2d_crystal_entity', 'length_b', None, None),
                                                   'LENGTH_C': ('em_2d_crystal_entity', 'length_c', None, None),
                                                   'SPACE_GROUP_NAME_H_M': ('em_2d_crystal_entity',
                                                                            'space_group_name_H-M',
                                                                            None,
                                                                            None),
                                                   'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                 'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID', 'ENTITY_ASSEMBLY_ID'),
                                                    'TYPE': 'UNIQUE'},
                                             's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                 'MAP_MERGE_INDICES': {'em_2d_crystal_entity': {'ATTRIBUTES': ('id', 'entity_assembly_id'),
                                                                                'TYPE': 'EQUI-JOIN'}},
                                 'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                 'TABLE_ID': 'EM_2D_CRYSTAL_ENTITY',
                                 'TABLE_NAME': 'em_2d_crystal_entity',
                                 'TABLE_TYPE': 'transactional'},
        'EM_2D_CRYSTAL_GROW': {'ATTRIBUTES': {'APPARATUS': 'apparatus',
                                              'ATMOSPHERE': 'atmosphere',
                                              'BUFFER_ID': 'buffer_id',
                                              'CITATION_ID': 'citation_id',
                                              'DETAILS': 'details',
                                              'ID': 'id',
                                              'MEAN_2D_CRYSTAL_SIZE': 'mean_2d_crystal_size',
                                              'METHOD': 'method',
                                              'NUMBER_2D_CRYSTALS': 'number_2d_crystals',
                                              'PH': 'pH',
                                              'STRUCTURE_ID': 'Structure_ID',
                                              'TEMP': 'temp',
                                              'TIME': 'time'},
                               'ATTRIBUTE_INFO': {'APPARATUS': {'NULLABLE': True,
                                                                'ORDER': 4,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 80},
                                                  'ATMOSPHERE': {'NULLABLE': True,
                                                                 'ORDER': 5,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 80},
                                                  'BUFFER_ID': {'NULLABLE': True,
                                                                'ORDER': 9,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                                  'CITATION_ID': {'NULLABLE': True,
                                                                  'ORDER': 13,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10},
                                                  'DETAILS': {'NULLABLE': True,
                                                              'ORDER': 10,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 1023},
                                                  'ID': {'NULLABLE': False,
                                                         'ORDER': 2,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': True,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 10},
                                                  'MEAN_2D_CRYSTAL_SIZE': {'NULLABLE': True,
                                                                           'ORDER': 12,
                                                                           'PRECISION': 6,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'FLOAT',
                                                                           'WIDTH': 10},
                                                  'METHOD': {'NULLABLE': True,
                                                             'ORDER': 3,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 80},
                                                  'NUMBER_2D_CRYSTALS': {'NULLABLE': True,
                                                                         'ORDER': 11,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'INT',
                                                                         'WIDTH': 10},
                                                  'PH': {'NULLABLE': True,
                                                         'ORDER': 6,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                                  'STRUCTURE_ID': {'NULLABLE': False,
                                                                   'ORDER': 1,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': True,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 10},
                                                  'TEMP': {'NULLABLE': True,
                                                           'ORDER': 7,
                                                           'PRECISION': 6,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'FLOAT',
                                                           'WIDTH': 10},
                                                  'TIME': {'NULLABLE': True,
                                                           'ORDER': 8,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 80}},
                               'ATTRIBUTE_MAP': {'APPARATUS': ('em_2d_crystal_grow', 'apparatus', None, None),
                                                 'ATMOSPHERE': ('em_2d_crystal_grow', 'atmosphere', None, None),
                                                 'BUFFER_ID': ('em_2d_crystal_grow', 'buffer_id', None, None),
                                                 'CITATION_ID': ('em_2d_crystal_grow', 'citation_id', None, None),
                                                 'DETAILS': ('em_2d_crystal_grow', 'details', None, None),
                                                 'ID': ('em_2d_crystal_grow', 'id', None, None),
                                                 'MEAN_2D_CRYSTAL_SIZE': ('em_2d_crystal_grow',
                                                                          'mean_2d_crystal_size',
                                                                          None,
                                                                          None),
                                                 'METHOD': ('em_2d_crystal_grow', 'method', None, None),
                                                 'NUMBER_2D_CRYSTALS': ('em_2d_crystal_grow',
                                                                        'number_2d_crystals',
                                                                        None,
                                                                        None),
                                                 'PH': ('em_2d_crystal_grow', 'pH', None, None),
                                                 'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                 'TEMP': ('em_2d_crystal_grow', 'temp', None, None),
                                                 'TIME': ('em_2d_crystal_grow', 'time', None, None)},
                               'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                           's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                               'MAP_MERGE_INDICES': {'em_2d_crystal_grow': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                               'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                               'TABLE_ID': 'EM_2D_CRYSTAL_GROW',
                               'TABLE_NAME': 'em_2d_crystal_grow',
                               'TABLE_TYPE': 'transactional'},
        'EM_2D_PROJECTION_SELECTION': {'ATTRIBUTES': {'CITATION_ID': 'citation_id',
                                                      'DETAILS': 'details',
                                                      'ENTRY_ID': 'entry_id',
                                                      'METHOD': 'method',
                                                      'NUM_PARTICLES': 'num_particles',
                                                      'SOFTWARE_NAME': 'software_name',
                                                      'STRUCTURE_ID': 'Structure_ID'},
                                       'ATTRIBUTE_INFO': {'CITATION_ID': {'NULLABLE': True,
                                                                          'ORDER': 7,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                          'DETAILS': {'NULLABLE': True,
                                                                      'ORDER': 6,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 200},
                                                          'ENTRY_ID': {'NULLABLE': False,
                                                                       'ORDER': 2,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': True,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                          'METHOD': {'NULLABLE': True,
                                                                     'ORDER': 5,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 200},
                                                          'NUM_PARTICLES': {'NULLABLE': True,
                                                                            'ORDER': 3,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'INT',
                                                                            'WIDTH': 10},
                                                          'SOFTWARE_NAME': {'NULLABLE': True,
                                                                            'ORDER': 4,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 128},
                                                          'STRUCTURE_ID': {'NULLABLE': False,
                                                                           'ORDER': 1,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': True,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10}},
                                       'ATTRIBUTE_MAP': {'CITATION_ID': ('em_2d_projection_selection',
                                                                         'citation_id',
                                                                         None,
                                                                         None),
                                                         'DETAILS': ('em_2d_projection_selection', 'details', None, None),
                                                         'ENTRY_ID': ('em_2d_projection_selection', 'entry_id', None, None),
                                                         'METHOD': ('em_2d_projection_selection', 'method', None, None),
                                                         'NUM_PARTICLES': ('em_2d_projection_selection',
                                                                           'num_particles',
                                                                           None,
                                                                           None),
                                                         'SOFTWARE_NAME': ('em_2d_projection_selection',
                                                                           'software_name',
                                                                           None,
                                                                           None),
                                                         'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                       'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID'), 'TYPE': 'UNIQUE'},
                                                   's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                       'MAP_MERGE_INDICES': {'em_2d_projection_selection': {'ATTRIBUTES': ('entry_id',),
                                                                                            'TYPE': 'EQUI-JOIN'}},
                                       'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                       'TABLE_ID': 'EM_2D_PROJECTION_SELECTION',
                                       'TABLE_NAME': 'em_2d_projection_selection',
                                       'TABLE_TYPE': 'transactional'},
        'EM_3D_FITTING': {'ATTRIBUTES': {'DETAILS': 'details',
                                         'ENTRY_ID': 'entry_id',
                                         'ID': 'id',
                                         'METHOD': 'method',
                                         'OVERALL_B_VALUE': 'overall_b_value',
                                         'REF_PROTOCOL': 'ref_protocol',
                                         'REF_SPACE': 'ref_space',
                                         'SOFTWARE_NAME': 'software_name',
                                         'STRUCTURE_ID': 'Structure_ID',
                                         'TARGET_CRITERIA': 'target_criteria'},
                          'ATTRIBUTE_INFO': {'DETAILS': {'NULLABLE': True,
                                                         'ORDER': 7,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 4095},
                                             'ENTRY_ID': {'NULLABLE': False,
                                                          'ORDER': 3,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': True,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 10},
                                             'ID': {'NULLABLE': False,
                                                    'ORDER': 2,
                                                    'PRECISION': 0,
                                                    'PRIMARY_KEY': True,
                                                    'SQL_TYPE': 'VARCHAR',
                                                    'WIDTH': 10},
                                             'METHOD': {'NULLABLE': True,
                                                        'ORDER': 4,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 4095},
                                             'OVERALL_B_VALUE': {'NULLABLE': True,
                                                                 'ORDER': 8,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                             'REF_PROTOCOL': {'NULLABLE': True,
                                                              'ORDER': 10,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 1023},
                                             'REF_SPACE': {'NULLABLE': True,
                                                           'ORDER': 9,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 80},
                                             'SOFTWARE_NAME': {'NULLABLE': True,
                                                               'ORDER': 6,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 200},
                                             'STRUCTURE_ID': {'NULLABLE': False,
                                                              'ORDER': 1,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10},
                                             'TARGET_CRITERIA': {'NULLABLE': True,
                                                                 'ORDER': 5,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 1023}},
                          'ATTRIBUTE_MAP': {'DETAILS': ('em_3d_fitting', 'details', None, None),
                                            'ENTRY_ID': ('em_3d_fitting', 'entry_id', None, None),
                                            'ID': ('em_3d_fitting', 'id', None, None),
                                            'METHOD': ('em_3d_fitting', 'method', None, None),
                                            'OVERALL_B_VALUE': ('em_3d_fitting', 'overall_b_value', None, None),
                                            'REF_PROTOCOL': ('em_3d_fitting', 'ref_protocol', None, None),
                                            'REF_SPACE': ('em_3d_fitting', 'ref_space', None, None),
                                            'SOFTWARE_NAME': ('em_3d_fitting', 'software_name', None, None),
                                            'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                            'TARGET_CRITERIA': ('em_3d_fitting', 'target_criteria', None, None)},
                          'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID', 'ENTRY_ID'), 'TYPE': 'UNIQUE'},
                                      's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                          'MAP_MERGE_INDICES': {'em_3d_fitting': {'ATTRIBUTES': ('id', 'entry_id'), 'TYPE': 'EQUI-JOIN'}},
                          'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                          'TABLE_ID': 'EM_3D_FITTING',
                          'TABLE_NAME': 'em_3d_fitting',
                          'TABLE_TYPE': 'transactional'},
        'EM_3D_FITTING_LIST': {'ATTRIBUTES': {'3D_FITTING_ID': '3d_fitting_id',
                                              'ID': 'id',
                                              'PDB_CHAIN_ID': 'pdb_chain_id',
                                              'PDB_ENTRY_ID': 'pdb_entry_id',
                                              'STRUCTURE_ID': 'Structure_ID'},
                               'ATTRIBUTE_INFO': {'3D_FITTING_ID': {'NULLABLE': False,
                                                                    'ORDER': 2,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': True,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10},
                                                  'ID': {'NULLABLE': False,
                                                         'ORDER': 3,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': True,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 10},
                                                  'PDB_CHAIN_ID': {'NULLABLE': True,
                                                                   'ORDER': 5,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 10},
                                                  'PDB_ENTRY_ID': {'NULLABLE': True,
                                                                   'ORDER': 4,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 80},
                                                  'STRUCTURE_ID': {'NULLABLE': False,
                                                                   'ORDER': 1,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': True,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 10}},
                               'ATTRIBUTE_MAP': {'3D_FITTING_ID': ('em_3d_fitting_list', '3d_fitting_id', None, None),
                                                 'ID': ('em_3d_fitting_list', 'id', None, None),
                                                 'PDB_CHAIN_ID': ('em_3d_fitting_list', 'pdb_chain_id', None, None),
                                                 'PDB_ENTRY_ID': ('em_3d_fitting_list', 'pdb_entry_id', None, None),
                                                 'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                               'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', '3D_FITTING_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                           's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                               'MAP_MERGE_INDICES': {'em_3d_fitting_list': {'ATTRIBUTES': ('3d_fitting_id', 'id'),
                                                                            'TYPE': 'EQUI-JOIN'}},
                               'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                               'TABLE_ID': 'EM_3D_FITTING_LIST',
                               'TABLE_NAME': 'em_3d_fitting_list',
                               'TABLE_TYPE': 'transactional'},
        'EM_3D_RECONSTRUCTION': {'ATTRIBUTES': {'ACTUAL_PIXEL_SIZE': 'actual_pixel_size',
                                                'CITATION_ID': 'citation_id',
                                                'CTF_CORRECTION_METHOD': 'ctf_correction_method',
                                                'DETAILS': 'details',
                                                'ENTRY_ID': 'entry_id',
                                                'EULER_ANGLES_DETAILS': 'euler_angles_details',
                                                'ID': 'id',
                                                'MAGNIFICATION_CALIBRATION': 'magnification_calibration',
                                                'METHOD': 'method',
                                                'NOMINAL_PIXEL_SIZE': 'nominal_pixel_size',
                                                'NUM_CLASS_AVERAGES': 'num_class_averages',
                                                'NUM_PARTICLES': 'num_particles',
                                                'RESOLUTION': 'resolution',
                                                'RESOLUTION_METHOD': 'resolution_method',
                                                'SOFTWARE': 'software',
                                                'STRUCTURE_ID': 'Structure_ID'},
                                 'ATTRIBUTE_INFO': {'ACTUAL_PIXEL_SIZE': {'NULLABLE': True,
                                                                          'ORDER': 12,
                                                                          'PRECISION': 6,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'FLOAT',
                                                                          'WIDTH': 10},
                                                    'CITATION_ID': {'NULLABLE': True,
                                                                    'ORDER': 5,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10},
                                                    'CTF_CORRECTION_METHOD': {'NULLABLE': True,
                                                                              'ORDER': 10,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 200},
                                                    'DETAILS': {'NULLABLE': True,
                                                                'ORDER': 6,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 4095},
                                                    'ENTRY_ID': {'NULLABLE': False,
                                                                 'ORDER': 2,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': True,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                                    'EULER_ANGLES_DETAILS': {'NULLABLE': True,
                                                                             'ORDER': 14,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 200},
                                                    'ID': {'NULLABLE': False,
                                                           'ORDER': 3,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': True,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 10},
                                                    'MAGNIFICATION_CALIBRATION': {'NULLABLE': True,
                                                                                  'ORDER': 9,
                                                                                  'PRECISION': 0,
                                                                                  'PRIMARY_KEY': False,
                                                                                  'SQL_TYPE': 'VARCHAR',
                                                                                  'WIDTH': 511},
                                                    'METHOD': {'NULLABLE': True,
                                                               'ORDER': 4,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 511},
                                                    'NOMINAL_PIXEL_SIZE': {'NULLABLE': True,
                                                                           'ORDER': 11,
                                                                           'PRECISION': 6,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'FLOAT',
                                                                           'WIDTH': 10},
                                                    'NUM_CLASS_AVERAGES': {'NULLABLE': True,
                                                                           'ORDER': 15,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'INT',
                                                                           'WIDTH': 10},
                                                    'NUM_PARTICLES': {'NULLABLE': True,
                                                                      'ORDER': 13,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'INT',
                                                                      'WIDTH': 10},
                                                    'RESOLUTION': {'NULLABLE': True,
                                                                   'ORDER': 7,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                                    'RESOLUTION_METHOD': {'NULLABLE': True,
                                                                          'ORDER': 8,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 511},
                                                    'SOFTWARE': {'NULLABLE': True,
                                                                 'ORDER': 16,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 200},
                                                    'STRUCTURE_ID': {'NULLABLE': False,
                                                                     'ORDER': 1,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': True,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10}},
                                 'ATTRIBUTE_MAP': {'ACTUAL_PIXEL_SIZE': ('em_3d_reconstruction',
                                                                         'actual_pixel_size',
                                                                         None,
                                                                         None),
                                                   'CITATION_ID': ('em_3d_reconstruction', 'citation_id', None, None),
                                                   'CTF_CORRECTION_METHOD': ('em_3d_reconstruction',
                                                                             'ctf_correction_method',
                                                                             None,
                                                                             None),
                                                   'DETAILS': ('em_3d_reconstruction', 'details', None, None),
                                                   'ENTRY_ID': ('em_3d_reconstruction', 'entry_id', None, None),
                                                   'EULER_ANGLES_DETAILS': ('em_3d_reconstruction',
                                                                            'euler_angles_details',
                                                                            None,
                                                                            None),
                                                   'ID': ('em_3d_reconstruction', 'id', None, None),
                                                   'MAGNIFICATION_CALIBRATION': ('em_3d_reconstruction',
                                                                                 'magnification_calibration',
                                                                                 None,
                                                                                 None),
                                                   'METHOD': ('em_3d_reconstruction', 'method', None, None),
                                                   'NOMINAL_PIXEL_SIZE': ('em_3d_reconstruction',
                                                                          'nominal_pixel_size',
                                                                          None,
                                                                          None),
                                                   'NUM_CLASS_AVERAGES': ('em_3d_reconstruction',
                                                                          'num_class_averages',
                                                                          None,
                                                                          None),
                                                   'NUM_PARTICLES': ('em_3d_reconstruction', 'num_particles', None, None),
                                                   'RESOLUTION': ('em_3d_reconstruction', 'resolution', None, None),
                                                   'RESOLUTION_METHOD': ('em_3d_reconstruction',
                                                                         'resolution_method',
                                                                         None,
                                                                         None),
                                                   'SOFTWARE': ('em_3d_reconstruction', 'software', None, None),
                                                   'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                 'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                             's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                 'MAP_MERGE_INDICES': {'em_3d_reconstruction': {'ATTRIBUTES': ('entry_id', 'id'),
                                                                                'TYPE': 'EQUI-JOIN'}},
                                 'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                 'TABLE_ID': 'EM_3D_RECONSTRUCTION',
                                 'TABLE_NAME': 'em_3d_reconstruction',
                                 'TABLE_TYPE': 'transactional'},
        'EM_ASSEMBLY': {'ATTRIBUTES': {'AGGREGATION_STATE': 'aggregation_state',
                                       'COMPOSITION': 'composition',
                                       'DETAILS': 'details',
                                       'ENTRY_ID': 'entry_id',
                                       'ID': 'id',
                                       'MOL_WT_EXP': 'mol_wt_exp',
                                       'MOL_WT_METHOD': 'mol_wt_method',
                                       'MOL_WT_THEO': 'mol_wt_theo',
                                       'NAME': 'name',
                                       'NUM_COMPONENTS': 'num_components',
                                       'STRUCTURE_ID': 'Structure_ID'},
                        'ATTRIBUTE_INFO': {'AGGREGATION_STATE': {'NULLABLE': True,
                                                                 'ORDER': 5,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 80},
                                           'COMPOSITION': {'NULLABLE': True,
                                                           'ORDER': 6,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 200},
                                           'DETAILS': {'NULLABLE': True,
                                                       'ORDER': 11,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'VARCHAR',
                                                       'WIDTH': 1023},
                                           'ENTRY_ID': {'NULLABLE': False,
                                                        'ORDER': 3,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': True,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 10},
                                           'ID': {'NULLABLE': False,
                                                  'ORDER': 2,
                                                  'PRECISION': 0,
                                                  'PRIMARY_KEY': True,
                                                  'SQL_TYPE': 'VARCHAR',
                                                  'WIDTH': 10},
                                           'MOL_WT_EXP': {'NULLABLE': True,
                                                          'ORDER': 8,
                                                          'PRECISION': 6,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'FLOAT',
                                                          'WIDTH': 10},
                                           'MOL_WT_METHOD': {'NULLABLE': True,
                                                             'ORDER': 10,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 200},
                                           'MOL_WT_THEO': {'NULLABLE': True,
                                                           'ORDER': 9,
                                                           'PRECISION': 6,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'FLOAT',
                                                           'WIDTH': 10},
                                           'NAME': {'NULLABLE': True,
                                                    'ORDER': 4,
                                                    'PRECISION': 0,
                                                    'PRIMARY_KEY': False,
                                                    'SQL_TYPE': 'VARCHAR',
                                                    'WIDTH': 511},
                                           'NUM_COMPONENTS': {'NULLABLE': True,
                                                              'ORDER': 7,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'INT',
                                                              'WIDTH': 10},
                                           'STRUCTURE_ID': {'NULLABLE': False,
                                                            'ORDER': 1,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': True,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 10}},
                        'ATTRIBUTE_MAP': {'AGGREGATION_STATE': ('em_assembly', 'aggregation_state', None, None),
                                          'COMPOSITION': ('em_assembly', 'composition', None, None),
                                          'DETAILS': ('em_assembly', 'details', None, None),
                                          'ENTRY_ID': ('em_assembly', 'entry_id', None, None),
                                          'ID': ('em_assembly', 'id', None, None),
                                          'MOL_WT_EXP': ('em_assembly', 'mol_wt_exp', None, None),
                                          'MOL_WT_METHOD': ('em_assembly', 'mol_wt_method', None, None),
                                          'MOL_WT_THEO': ('em_assembly', 'mol_wt_theo', None, None),
                                          'NAME': ('em_assembly', 'name', None, None),
                                          'NUM_COMPONENTS': ('em_assembly', 'num_components', None, None),
                                          'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                        'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID', 'ENTRY_ID'), 'TYPE': 'UNIQUE'},
                                    's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                        'MAP_MERGE_INDICES': {'em_assembly': {'ATTRIBUTES': ('id', 'entry_id'), 'TYPE': 'EQUI-JOIN'}},
                        'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                        'TABLE_ID': 'EM_ASSEMBLY',
                        'TABLE_NAME': 'em_assembly',
                        'TABLE_TYPE': 'transactional'},
        'EM_BUFFER': {'ATTRIBUTES': {'DETAILS': 'details', 'ID': 'id', 'NAME': 'name', 'STRUCTURE_ID': 'Structure_ID'},
                      'ATTRIBUTE_INFO': {'DETAILS': {'NULLABLE': True,
                                                     'ORDER': 4,
                                                     'PRECISION': 0,
                                                     'PRIMARY_KEY': False,
                                                     'SQL_TYPE': 'VARCHAR',
                                                     'WIDTH': 200},
                                         'ID': {'NULLABLE': False,
                                                'ORDER': 2,
                                                'PRECISION': 0,
                                                'PRIMARY_KEY': True,
                                                'SQL_TYPE': 'VARCHAR',
                                                'WIDTH': 10},
                                         'NAME': {'NULLABLE': True,
                                                  'ORDER': 3,
                                                  'PRECISION': 0,
                                                  'PRIMARY_KEY': False,
                                                  'SQL_TYPE': 'VARCHAR',
                                                  'WIDTH': 255},
                                         'STRUCTURE_ID': {'NULLABLE': False,
                                                          'ORDER': 1,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': True,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 10}},
                      'ATTRIBUTE_MAP': {'DETAILS': ('em_buffer', 'details', None, None),
                                        'ID': ('em_buffer', 'id', None, None),
                                        'NAME': ('em_buffer', 'name', None, None),
                                        'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                      'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                  's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                      'MAP_MERGE_INDICES': {'em_buffer': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                      'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                      'TABLE_ID': 'EM_BUFFER',
                      'TABLE_NAME': 'em_buffer',
                      'TABLE_TYPE': 'transactional'},
        'EM_BUFFER_COMPONENTS': {'ATTRIBUTES': {'BUFFER_ID': 'buffer_id',
                                                'CONC': 'conc',
                                                'DETAILS': 'details',
                                                'ID': 'id',
                                                'NAME': 'name',
                                                'STRUCTURE_ID': 'Structure_ID',
                                                'VOLUME': 'volume'},
                                 'ATTRIBUTE_INFO': {'BUFFER_ID': {'NULLABLE': False,
                                                                  'ORDER': 3,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': True,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10},
                                                    'CONC': {'NULLABLE': True,
                                                             'ORDER': 6,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 10},
                                                    'DETAILS': {'NULLABLE': True,
                                                                'ORDER': 7,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 200},
                                                    'ID': {'NULLABLE': False,
                                                           'ORDER': 2,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': True,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 10},
                                                    'NAME': {'NULLABLE': True,
                                                             'ORDER': 4,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 80},
                                                    'STRUCTURE_ID': {'NULLABLE': False,
                                                                     'ORDER': 1,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': True,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                                    'VOLUME': {'NULLABLE': True,
                                                               'ORDER': 5,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10}},
                                 'ATTRIBUTE_MAP': {'BUFFER_ID': ('em_buffer_components', 'buffer_id', None, None),
                                                   'CONC': ('em_buffer_components', 'conc', None, None),
                                                   'DETAILS': ('em_buffer_components', 'details', None, None),
                                                   'ID': ('em_buffer_components', 'id', None, None),
                                                   'NAME': ('em_buffer_components', 'name', None, None),
                                                   'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                   'VOLUME': ('em_buffer_components', 'volume', None, None)},
                                 'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID', 'BUFFER_ID'), 'TYPE': 'UNIQUE'},
                                             's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                 'MAP_MERGE_INDICES': {'em_buffer_components': {'ATTRIBUTES': ('id', 'buffer_id'),
                                                                                'TYPE': 'EQUI-JOIN'}},
                                 'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                 'TABLE_ID': 'EM_BUFFER_COMPONENTS',
                                 'TABLE_NAME': 'em_buffer_components',
                                 'TABLE_TYPE': 'transactional'},
        'EM_DETECTOR': {'ATTRIBUTES': {'DETAILS': 'details',
                                       'DETECTIVE_QUANTUM_EFFICIENCY': 'detective_quantum_efficiency',
                                       'ENTRY_ID': 'entry_id',
                                       'ID': 'id',
                                       'STRUCTURE_ID': 'Structure_ID',
                                       'TYPE': 'type'},
                        'ATTRIBUTE_INFO': {'DETAILS': {'NULLABLE': True,
                                                       'ORDER': 4,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'VARCHAR',
                                                       'WIDTH': 200},
                                           'DETECTIVE_QUANTUM_EFFICIENCY': {'NULLABLE': True,
                                                                            'ORDER': 6,
                                                                            'PRECISION': 6,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'FLOAT',
                                                                            'WIDTH': 10},
                                           'ENTRY_ID': {'NULLABLE': False,
                                                        'ORDER': 2,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': True,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 10},
                                           'ID': {'NULLABLE': False,
                                                  'ORDER': 3,
                                                  'PRECISION': 0,
                                                  'PRIMARY_KEY': True,
                                                  'SQL_TYPE': 'VARCHAR',
                                                  'WIDTH': 10},
                                           'STRUCTURE_ID': {'NULLABLE': False,
                                                            'ORDER': 1,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': True,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 10},
                                           'TYPE': {'NULLABLE': True,
                                                    'ORDER': 5,
                                                    'PRECISION': 0,
                                                    'PRIMARY_KEY': False,
                                                    'SQL_TYPE': 'VARCHAR',
                                                    'WIDTH': 80}},
                        'ATTRIBUTE_MAP': {'DETAILS': ('em_detector', 'details', None, None),
                                          'DETECTIVE_QUANTUM_EFFICIENCY': ('em_detector',
                                                                           'detective_quantum_efficiency',
                                                                           None,
                                                                           None),
                                          'ENTRY_ID': ('em_detector', 'entry_id', None, None),
                                          'ID': ('em_detector', 'id', None, None),
                                          'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                          'TYPE': ('em_detector', 'type', None, None)},
                        'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                    's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                        'MAP_MERGE_INDICES': {'em_detector': {'ATTRIBUTES': ('entry_id', 'id'), 'TYPE': 'EQUI-JOIN'}},
                        'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                        'TABLE_ID': 'EM_DETECTOR',
                        'TABLE_NAME': 'em_detector',
                        'TABLE_TYPE': 'transactional'},
        'EM_ELECTRON_DIFFRACTION': {'ATTRIBUTES': {'DETAILS': 'details',
                                                   'ENTRY_ID': 'entry_id',
                                                   'ID': 'id',
                                                   'NUM_DIFF_PATTERNS': 'num_diff_patterns',
                                                   'NUM_STRUCTURE_FACTORS': 'num_structure_factors',
                                                   'STRUCTURE_ID': 'Structure_ID'},
                                    'ATTRIBUTE_INFO': {'DETAILS': {'NULLABLE': True,
                                                                   'ORDER': 6,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 200},
                                                       'ENTRY_ID': {'NULLABLE': False,
                                                                    'ORDER': 2,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': True,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10},
                                                       'ID': {'NULLABLE': False,
                                                              'ORDER': 3,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10},
                                                       'NUM_DIFF_PATTERNS': {'NULLABLE': True,
                                                                             'ORDER': 5,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'INT',
                                                                             'WIDTH': 10},
                                                       'NUM_STRUCTURE_FACTORS': {'NULLABLE': True,
                                                                                 'ORDER': 4,
                                                                                 'PRECISION': 0,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'INT',
                                                                                 'WIDTH': 10},
                                                       'STRUCTURE_ID': {'NULLABLE': False,
                                                                        'ORDER': 1,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': True,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10}},
                                    'ATTRIBUTE_MAP': {'DETAILS': ('em_electron_diffraction', 'details', None, None),
                                                      'ENTRY_ID': ('em_electron_diffraction', 'entry_id', None, None),
                                                      'ID': ('em_electron_diffraction', 'id', None, None),
                                                      'NUM_DIFF_PATTERNS': ('em_electron_diffraction',
                                                                            'num_diff_patterns',
                                                                            None,
                                                                            None),
                                                      'NUM_STRUCTURE_FACTORS': ('em_electron_diffraction',
                                                                                'num_structure_factors',
                                                                                None,
                                                                                None),
                                                      'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                    'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                                's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                    'MAP_MERGE_INDICES': {'em_electron_diffraction': {'ATTRIBUTES': ('entry_id', 'id'),
                                                                                      'TYPE': 'EQUI-JOIN'}},
                                    'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                    'TABLE_ID': 'EM_ELECTRON_DIFFRACTION',
                                    'TABLE_NAME': 'em_electron_diffraction',
                                    'TABLE_TYPE': 'transactional'},
        'EM_ELECTRON_DIFFRACTION_PATTERN': {'ATTRIBUTES': {'ENTRY_ID': 'entry_id',
                                                           'ID': 'id',
                                                           'NUM_IMAGES_BY_TILT_ANGLE': 'num_images_by_tilt_angle',
                                                           'NUM_PATTERNS_BY_TILT_ANGLE': 'num_patterns_by_tilt_angle',
                                                           'STRUCTURE_ID': 'Structure_ID',
                                                           'TILT_ANGLE': 'tilt_angle'},
                                            'ATTRIBUTE_INFO': {'ENTRY_ID': {'NULLABLE': False,
                                                                            'ORDER': 2,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': True,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 10},
                                                               'ID': {'NULLABLE': False,
                                                                      'ORDER': 3,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                                               'NUM_IMAGES_BY_TILT_ANGLE': {'NULLABLE': True,
                                                                                            'ORDER': 5,
                                                                                            'PRECISION': 0,
                                                                                            'PRIMARY_KEY': False,
                                                                                            'SQL_TYPE': 'INT',
                                                                                            'WIDTH': 10},
                                                               'NUM_PATTERNS_BY_TILT_ANGLE': {'NULLABLE': True,
                                                                                              'ORDER': 4,
                                                                                              'PRECISION': 0,
                                                                                              'PRIMARY_KEY': False,
                                                                                              'SQL_TYPE': 'INT',
                                                                                              'WIDTH': 10},
                                                               'STRUCTURE_ID': {'NULLABLE': False,
                                                                                'ORDER': 1,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': True,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 10},
                                                               'TILT_ANGLE': {'NULLABLE': True,
                                                                              'ORDER': 6,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'INT',
                                                                              'WIDTH': 10}},
                                            'ATTRIBUTE_MAP': {'ENTRY_ID': ('em_electron_diffraction_pattern',
                                                                           'entry_id',
                                                                           None,
                                                                           None),
                                                              'ID': ('em_electron_diffraction_pattern', 'id', None, None),
                                                              'NUM_IMAGES_BY_TILT_ANGLE': ('em_electron_diffraction_pattern',
                                                                                           'num_images_by_tilt_angle',
                                                                                           None,
                                                                                           None),
                                                              'NUM_PATTERNS_BY_TILT_ANGLE': ('em_electron_diffraction_pattern',
                                                                                             'num_patterns_by_tilt_angle',
                                                                                             None,
                                                                                             None),
                                                              'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                              'TILT_ANGLE': ('em_electron_diffraction_pattern',
                                                                             'tilt_angle',
                                                                             None,
                                                                             None)},
                                            'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID', 'ID'),
                                                               'TYPE': 'UNIQUE'},
                                                        's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                            'MAP_MERGE_INDICES': {'em_electron_diffraction_pattern': {'ATTRIBUTES': ('entry_id',
                                                                                                                     'id'),
                                                                                                      'TYPE': 'EQUI-JOIN'}},
                                            'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                            'TABLE_ID': 'EM_ELECTRON_DIFFRACTION_PATTERN',
                                            'TABLE_NAME': 'em_electron_diffraction_pattern',
                                            'TABLE_TYPE': 'transactional'},
        'EM_ELECTRON_DIFFRACTION_PHASE': {'ATTRIBUTES': {'D_RES_HIGH': 'd_res_high',
                                                         'ENTRY_ID': 'entry_id',
                                                         'HIGHEST_RESOLUTION_SHELL_ERROR': 'highest_resolution_shell_error',
                                                         'ID': 'id',
                                                         'OVERALL_ERROR': 'overall_error',
                                                         'REJECTION_CRITERIA_ERROR': 'rejection_criteria_error',
                                                         'RESIDUAL': 'residual',
                                                         'STRUCTURE_ID': 'Structure_ID'},
                                          'ATTRIBUTE_INFO': {'D_RES_HIGH': {'NULLABLE': True,
                                                                            'ORDER': 4,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'INT',
                                                                            'WIDTH': 10},
                                                             'ENTRY_ID': {'NULLABLE': False,
                                                                          'ORDER': 2,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': True,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                             'HIGHEST_RESOLUTION_SHELL_ERROR': {'NULLABLE': True,
                                                                                                'ORDER': 6,
                                                                                                'PRECISION': 0,
                                                                                                'PRIMARY_KEY': False,
                                                                                                'SQL_TYPE': 'INT',
                                                                                                'WIDTH': 10},
                                                             'ID': {'NULLABLE': False,
                                                                    'ORDER': 3,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': True,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10},
                                                             'OVERALL_ERROR': {'NULLABLE': True,
                                                                               'ORDER': 7,
                                                                               'PRECISION': 0,
                                                                               'PRIMARY_KEY': False,
                                                                               'SQL_TYPE': 'INT',
                                                                               'WIDTH': 10},
                                                             'REJECTION_CRITERIA_ERROR': {'NULLABLE': True,
                                                                                          'ORDER': 8,
                                                                                          'PRECISION': 0,
                                                                                          'PRIMARY_KEY': False,
                                                                                          'SQL_TYPE': 'INT',
                                                                                          'WIDTH': 10},
                                                             'RESIDUAL': {'NULLABLE': True,
                                                                          'ORDER': 5,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'INT',
                                                                          'WIDTH': 10},
                                                             'STRUCTURE_ID': {'NULLABLE': False,
                                                                              'ORDER': 1,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': True,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10}},
                                          'ATTRIBUTE_MAP': {'D_RES_HIGH': ('em_electron_diffraction_phase',
                                                                           'd_res_high',
                                                                           None,
                                                                           None),
                                                            'ENTRY_ID': ('em_electron_diffraction_phase',
                                                                         'entry_id',
                                                                         None,
                                                                         None),
                                                            'HIGHEST_RESOLUTION_SHELL_ERROR': ('em_electron_diffraction_phase',
                                                                                               'highest_resolution_shell_error',
                                                                                               None,
                                                                                               None),
                                                            'ID': ('em_electron_diffraction_phase', 'id', None, None),
                                                            'OVERALL_ERROR': ('em_electron_diffraction_phase',
                                                                              'overall_error',
                                                                              None,
                                                                              None),
                                                            'REJECTION_CRITERIA_ERROR': ('em_electron_diffraction_phase',
                                                                                         'rejection_criteria_error',
                                                                                         None,
                                                                                         None),
                                                            'RESIDUAL': ('em_electron_diffraction_phase',
                                                                         'residual',
                                                                         None,
                                                                         None),
                                                            'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                          'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID', 'ID'),
                                                             'TYPE': 'UNIQUE'},
                                                      's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                          'MAP_MERGE_INDICES': {'em_electron_diffraction_phase': {'ATTRIBUTES': ('entry_id',
                                                                                                                 'id'),
                                                                                                  'TYPE': 'EQUI-JOIN'}},
                                          'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                          'TABLE_ID': 'EM_ELECTRON_DIFFRACTION_PHASE',
                                          'TABLE_NAME': 'em_electron_diffraction_phase',
                                          'TABLE_TYPE': 'transactional'},
        'EM_ENTITY_ASSEMBLY': {'ATTRIBUTES': {'ASSEMBLY_ID': 'assembly_id',
                                              'DETAILS': 'details',
                                              'EBI_CELL': 'ebi_cell',
                                              'EBI_CELLULAR_LOCATION': 'ebi_cellular_location',
                                              'EBI_ENGINEERED': 'ebi_engineered',
                                              'EBI_EXPRESSION_SYSTEM': 'ebi_expression_system',
                                              'EBI_EXPRESSION_SYSTEM_PLASMID': 'ebi_expression_system_plasmid',
                                              'EBI_ORGANELLE': 'ebi_organelle',
                                              'EBI_ORGANISM_COMMON': 'ebi_organism_common',
                                              'EBI_ORGANISM_SCIENTIFIC': 'ebi_organism_scientific',
                                              'EBI_STRAIN': 'ebi_strain',
                                              'EBI_TISSUE': 'ebi_tissue',
                                              'GO_ID': 'go_id',
                                              'ID': 'id',
                                              'IPR_ID': 'ipr_id',
                                              'MUTANT_FLAG': 'mutant_flag',
                                              'NAME': 'name',
                                              'NUMBER_OF_COPIES': 'number_of_copies',
                                              'OLIGOMERIC_DETAILS': 'oligomeric_details',
                                              'STRUCTURE_ID': 'Structure_ID',
                                              'SYNONYM': 'synonym',
                                              'TYPE': 'type'},
                               'ATTRIBUTE_INFO': {'ASSEMBLY_ID': {'NULLABLE': False,
                                                                  'ORDER': 3,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': True,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10},
                                                  'DETAILS': {'NULLABLE': True,
                                                              'ORDER': 6,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 511},
                                                  'EBI_CELL': {'NULLABLE': True,
                                                               'ORDER': 11,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 200},
                                                  'EBI_CELLULAR_LOCATION': {'NULLABLE': True,
                                                                            'ORDER': 13,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 200},
                                                  'EBI_ENGINEERED': {'NULLABLE': True,
                                                                     'ORDER': 14,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 80},
                                                  'EBI_EXPRESSION_SYSTEM': {'NULLABLE': True,
                                                                            'ORDER': 15,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 200},
                                                  'EBI_EXPRESSION_SYSTEM_PLASMID': {'NULLABLE': True,
                                                                                    'ORDER': 16,
                                                                                    'PRECISION': 0,
                                                                                    'PRIMARY_KEY': False,
                                                                                    'SQL_TYPE': 'VARCHAR',
                                                                                    'WIDTH': 80},
                                                  'EBI_ORGANELLE': {'NULLABLE': True,
                                                                    'ORDER': 12,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 200},
                                                  'EBI_ORGANISM_COMMON': {'NULLABLE': True,
                                                                          'ORDER': 8,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 200},
                                                  'EBI_ORGANISM_SCIENTIFIC': {'NULLABLE': True,
                                                                              'ORDER': 7,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 200},
                                                  'EBI_STRAIN': {'NULLABLE': True,
                                                                 'ORDER': 9,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 200},
                                                  'EBI_TISSUE': {'NULLABLE': True,
                                                                 'ORDER': 10,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 200},
                                                  'GO_ID': {'NULLABLE': True,
                                                            'ORDER': 17,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 80},
                                                  'ID': {'NULLABLE': False,
                                                         'ORDER': 2,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': True,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 10},
                                                  'IPR_ID': {'NULLABLE': True,
                                                             'ORDER': 18,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 80},
                                                  'MUTANT_FLAG': {'NULLABLE': True,
                                                                  'ORDER': 20,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 80},
                                                  'NAME': {'NULLABLE': True,
                                                           'ORDER': 5,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 255},
                                                  'NUMBER_OF_COPIES': {'NULLABLE': True,
                                                                       'ORDER': 21,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'INT',
                                                                       'WIDTH': 10},
                                                  'OLIGOMERIC_DETAILS': {'NULLABLE': True,
                                                                         'ORDER': 22,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 200},
                                                  'STRUCTURE_ID': {'NULLABLE': False,
                                                                   'ORDER': 1,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': True,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 10},
                                                  'SYNONYM': {'NULLABLE': True,
                                                              'ORDER': 19,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 80},
                                                  'TYPE': {'NULLABLE': True,
                                                           'ORDER': 4,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 80}},
                               'ATTRIBUTE_MAP': {'ASSEMBLY_ID': ('em_entity_assembly', 'assembly_id', None, None),
                                                 'DETAILS': ('em_entity_assembly', 'details', None, None),
                                                 'EBI_CELL': ('em_entity_assembly', 'ebi_cell', None, None),
                                                 'EBI_CELLULAR_LOCATION': ('em_entity_assembly',
                                                                           'ebi_cellular_location',
                                                                           None,
                                                                           None),
                                                 'EBI_ENGINEERED': ('em_entity_assembly', 'ebi_engineered', None, None),
                                                 'EBI_EXPRESSION_SYSTEM': ('em_entity_assembly',
                                                                           'ebi_expression_system',
                                                                           None,
                                                                           None),
                                                 'EBI_EXPRESSION_SYSTEM_PLASMID': ('em_entity_assembly',
                                                                                   'ebi_expression_system_plasmid',
                                                                                   None,
                                                                                   None),
                                                 'EBI_ORGANELLE': ('em_entity_assembly', 'ebi_organelle', None, None),
                                                 'EBI_ORGANISM_COMMON': ('em_entity_assembly',
                                                                         'ebi_organism_common',
                                                                         None,
                                                                         None),
                                                 'EBI_ORGANISM_SCIENTIFIC': ('em_entity_assembly',
                                                                             'ebi_organism_scientific',
                                                                             None,
                                                                             None),
                                                 'EBI_STRAIN': ('em_entity_assembly', 'ebi_strain', None, None),
                                                 'EBI_TISSUE': ('em_entity_assembly', 'ebi_tissue', None, None),
                                                 'GO_ID': ('em_entity_assembly', 'go_id', None, None),
                                                 'ID': ('em_entity_assembly', 'id', None, None),
                                                 'IPR_ID': ('em_entity_assembly', 'ipr_id', None, None),
                                                 'MUTANT_FLAG': ('em_entity_assembly', 'mutant_flag', None, None),
                                                 'NAME': ('em_entity_assembly', 'name', None, None),
                                                 'NUMBER_OF_COPIES': ('em_entity_assembly', 'number_of_copies', None, None),
                                                 'OLIGOMERIC_DETAILS': ('em_entity_assembly',
                                                                        'oligomeric_details',
                                                                        None,
                                                                        None),
                                                 'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                 'SYNONYM': ('em_entity_assembly', 'synonym', None, None),
                                                 'TYPE': ('em_entity_assembly', 'type', None, None)},
                               'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID', 'ASSEMBLY_ID'), 'TYPE': 'UNIQUE'},
                                           's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                               'MAP_MERGE_INDICES': {'em_entity_assembly': {'ATTRIBUTES': ('id', 'assembly_id'),
                                                                            'TYPE': 'EQUI-JOIN'}},
                               'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                               'TABLE_ID': 'EM_ENTITY_ASSEMBLY',
                               'TABLE_NAME': 'em_entity_assembly',
                               'TABLE_TYPE': 'transactional'},
        'EM_ENTITY_ASSEMBLY_LIST': {'ATTRIBUTES': {'ENTITY_ASSEMBLY_ID': 'entity_assembly_id',
                                                   'ENTITY_ID': 'entity_id',
                                                   'ID': 'id',
                                                   'NUMBER_OF_COPIES': 'number_of_copies',
                                                   'OLIGOMERIC_DETAILS': 'oligomeric_details',
                                                   'STRUCTURE_ID': 'Structure_ID'},
                                    'ATTRIBUTE_INFO': {'ENTITY_ASSEMBLY_ID': {'NULLABLE': False,
                                                                              'ORDER': 4,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': True,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                                       'ENTITY_ID': {'NULLABLE': False,
                                                                     'ORDER': 3,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': True,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                                       'ID': {'NULLABLE': False,
                                                              'ORDER': 2,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10},
                                                       'NUMBER_OF_COPIES': {'NULLABLE': True,
                                                                            'ORDER': 6,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'INT',
                                                                            'WIDTH': 10},
                                                       'OLIGOMERIC_DETAILS': {'NULLABLE': True,
                                                                              'ORDER': 5,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 80},
                                                       'STRUCTURE_ID': {'NULLABLE': False,
                                                                        'ORDER': 1,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': True,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10}},
                                    'ATTRIBUTE_MAP': {'ENTITY_ASSEMBLY_ID': ('em_entity_assembly_list',
                                                                             'entity_assembly_id',
                                                                             None,
                                                                             None),
                                                      'ENTITY_ID': ('em_entity_assembly_list', 'entity_id', None, None),
                                                      'ID': ('em_entity_assembly_list', 'id', None, None),
                                                      'NUMBER_OF_COPIES': ('em_entity_assembly_list',
                                                                           'number_of_copies',
                                                                           None,
                                                                           None),
                                                      'OLIGOMERIC_DETAILS': ('em_entity_assembly_list',
                                                                             'oligomeric_details',
                                                                             None,
                                                                             None),
                                                      'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                    'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID', 'ENTITY_ID', 'ENTITY_ASSEMBLY_ID'),
                                                       'TYPE': 'UNIQUE'},
                                                's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                    'MAP_MERGE_INDICES': {'em_entity_assembly_list': {'ATTRIBUTES': ('id',
                                                                                                     'entity_id',
                                                                                                     'entity_assembly_id'),
                                                                                      'TYPE': 'EQUI-JOIN'}},
                                    'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                    'TABLE_ID': 'EM_ENTITY_ASSEMBLY_LIST',
                                    'TABLE_NAME': 'em_entity_assembly_list',
                                    'TABLE_TYPE': 'transactional'},
        'EM_EULER_ANGLE_DISTRIBUTION': {'ATTRIBUTES': {'ALPHA': 'alpha',
                                                       'BETA': 'beta',
                                                       'DETAILS': 'details',
                                                       'ENTRY_ID': 'entry_id',
                                                       'GAMMA': 'gamma',
                                                       'ID': 'id',
                                                       'STRUCTURE_ID': 'Structure_ID'},
                                        'ATTRIBUTE_INFO': {'ALPHA': {'NULLABLE': True,
                                                                     'ORDER': 5,
                                                                     'PRECISION': 6,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'FLOAT',
                                                                     'WIDTH': 10},
                                                           'BETA': {'NULLABLE': True,
                                                                    'ORDER': 6,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                                           'DETAILS': {'NULLABLE': True,
                                                                       'ORDER': 4,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 200},
                                                           'ENTRY_ID': {'NULLABLE': False,
                                                                        'ORDER': 3,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': True,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                                           'GAMMA': {'NULLABLE': True,
                                                                     'ORDER': 7,
                                                                     'PRECISION': 6,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'FLOAT',
                                                                     'WIDTH': 10},
                                                           'ID': {'NULLABLE': False,
                                                                  'ORDER': 2,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': True,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10},
                                                           'STRUCTURE_ID': {'NULLABLE': False,
                                                                            'ORDER': 1,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': True,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 10}},
                                        'ATTRIBUTE_MAP': {'ALPHA': ('em_euler_angle_distribution', 'alpha', None, None),
                                                          'BETA': ('em_euler_angle_distribution', 'beta', None, None),
                                                          'DETAILS': ('em_euler_angle_distribution', 'details', None, None),
                                                          'ENTRY_ID': ('em_euler_angle_distribution', 'entry_id', None, None),
                                                          'GAMMA': ('em_euler_angle_distribution', 'gamma', None, None),
                                                          'ID': ('em_euler_angle_distribution', 'id', None, None),
                                                          'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                        'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID', 'ENTRY_ID'), 'TYPE': 'UNIQUE'},
                                                    's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                        'MAP_MERGE_INDICES': {'em_euler_angle_distribution': {'ATTRIBUTES': ('id', 'entry_id'),
                                                                                              'TYPE': 'EQUI-JOIN'}},
                                        'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                        'TABLE_ID': 'EM_EULER_ANGLE_DISTRIBUTION',
                                        'TABLE_NAME': 'em_euler_angle_distribution',
                                        'TABLE_TYPE': 'transactional'},
        'EM_EXPERIMENT': {'ATTRIBUTES': {'ENTRY_ID': 'entry_id',
                                         'RECONSTRUCTION_METHOD': 'reconstruction_method',
                                         'SPECIMEN_TYPE': 'specimen_type',
                                         'STRUCTURE_ID': 'Structure_ID'},
                          'ATTRIBUTE_INFO': {'ENTRY_ID': {'NULLABLE': False,
                                                          'ORDER': 2,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': True,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 10},
                                             'RECONSTRUCTION_METHOD': {'NULLABLE': True,
                                                                       'ORDER': 3,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 80},
                                             'SPECIMEN_TYPE': {'NULLABLE': True,
                                                               'ORDER': 4,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 200},
                                             'STRUCTURE_ID': {'NULLABLE': False,
                                                              'ORDER': 1,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10}},
                          'ATTRIBUTE_MAP': {'ENTRY_ID': ('em_experiment', 'entry_id', None, None),
                                            'RECONSTRUCTION_METHOD': ('em_experiment', 'reconstruction_method', None, None),
                                            'SPECIMEN_TYPE': ('em_experiment', 'specimen_type', None, None),
                                            'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                          'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID'), 'TYPE': 'UNIQUE'},
                                      's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                          'MAP_MERGE_INDICES': {'em_experiment': {'ATTRIBUTES': ('entry_id',), 'TYPE': 'EQUI-JOIN'}},
                          'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                          'TABLE_ID': 'EM_EXPERIMENT',
                          'TABLE_NAME': 'em_experiment',
                          'TABLE_TYPE': 'transactional'},
        'EM_HELICAL_ENTITY': {'ATTRIBUTES': {'ANGULAR_ROTATION_PER_SUBUNIT': 'angular_rotation_per_subunit',
                                             'AXIAL_RISE_PER_SUBUNIT': 'axial_rise_per_subunit',
                                             'AXIAL_SYMMETRY': 'axial_symmetry',
                                             'DETAILS': 'details',
                                             'DYAD': 'dyad',
                                             'ENTITY_ASSEMBLY_ID': 'entity_assembly_id',
                                             'HAND': 'hand',
                                             'ID': 'id',
                                             'STRUCTURE_ID': 'Structure_ID'},
                              'ATTRIBUTE_INFO': {'ANGULAR_ROTATION_PER_SUBUNIT': {'NULLABLE': True,
                                                                                  'ORDER': 7,
                                                                                  'PRECISION': 6,
                                                                                  'PRIMARY_KEY': False,
                                                                                  'SQL_TYPE': 'FLOAT',
                                                                                  'WIDTH': 10},
                                                 'AXIAL_RISE_PER_SUBUNIT': {'NULLABLE': True,
                                                                            'ORDER': 8,
                                                                            'PRECISION': 6,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'FLOAT',
                                                                            'WIDTH': 10},
                                                 'AXIAL_SYMMETRY': {'NULLABLE': True,
                                                                    'ORDER': 6,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 200},
                                                 'DETAILS': {'NULLABLE': True,
                                                             'ORDER': 4,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 200},
                                                 'DYAD': {'NULLABLE': True,
                                                          'ORDER': 5,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 80},
                                                 'ENTITY_ASSEMBLY_ID': {'NULLABLE': False,
                                                                        'ORDER': 3,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': True,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                                 'HAND': {'NULLABLE': True,
                                                          'ORDER': 9,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 200},
                                                 'ID': {'NULLABLE': False,
                                                        'ORDER': 2,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': True,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 10},
                                                 'STRUCTURE_ID': {'NULLABLE': False,
                                                                  'ORDER': 1,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': True,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10}},
                              'ATTRIBUTE_MAP': {'ANGULAR_ROTATION_PER_SUBUNIT': ('em_helical_entity',
                                                                                 'angular_rotation_per_subunit',
                                                                                 None,
                                                                                 None),
                                                'AXIAL_RISE_PER_SUBUNIT': ('em_helical_entity',
                                                                           'axial_rise_per_subunit',
                                                                           None,
                                                                           None),
                                                'AXIAL_SYMMETRY': ('em_helical_entity', 'axial_symmetry', None, None),
                                                'DETAILS': ('em_helical_entity', 'details', None, None),
                                                'DYAD': ('em_helical_entity', 'dyad', None, None),
                                                'ENTITY_ASSEMBLY_ID': ('em_helical_entity', 'entity_assembly_id', None, None),
                                                'HAND': ('em_helical_entity', 'hand', None, None),
                                                'ID': ('em_helical_entity', 'id', None, None),
                                                'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                              'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID', 'ENTITY_ASSEMBLY_ID'), 'TYPE': 'UNIQUE'},
                                          's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                              'MAP_MERGE_INDICES': {'em_helical_entity': {'ATTRIBUTES': ('id', 'entity_assembly_id'),
                                                                          'TYPE': 'EQUI-JOIN'}},
                              'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                              'TABLE_ID': 'EM_HELICAL_ENTITY',
                              'TABLE_NAME': 'em_helical_entity',
                              'TABLE_TYPE': 'transactional'},
        'EM_ICOS_VIRUS_SHELLS': {'ATTRIBUTES': {'ID': 'id',
                                                'SHELL_DIAMETER': 'shell_diameter',
                                                'STRUCTURE_ID': 'Structure_ID',
                                                'TRIANGULATION_NUM': 'triangulation_num',
                                                'VIRUS_ENTITY_ID': 'virus_entity_id'},
                                 'ATTRIBUTE_INFO': {'ID': {'NULLABLE': False,
                                                           'ORDER': 3,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': True,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 10},
                                                    'SHELL_DIAMETER': {'NULLABLE': True,
                                                                       'ORDER': 4,
                                                                       'PRECISION': 6,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'FLOAT',
                                                                       'WIDTH': 10},
                                                    'STRUCTURE_ID': {'NULLABLE': False,
                                                                     'ORDER': 1,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': True,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                                    'TRIANGULATION_NUM': {'NULLABLE': True,
                                                                          'ORDER': 5,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'INT',
                                                                          'WIDTH': 10},
                                                    'VIRUS_ENTITY_ID': {'NULLABLE': False,
                                                                        'ORDER': 2,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': True,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10}},
                                 'ATTRIBUTE_MAP': {'ID': ('em_icos_virus_shells', 'id', None, None),
                                                   'SHELL_DIAMETER': ('em_icos_virus_shells', 'shell_diameter', None, None),
                                                   'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                   'TRIANGULATION_NUM': ('em_icos_virus_shells',
                                                                         'triangulation_num',
                                                                         None,
                                                                         None),
                                                   'VIRUS_ENTITY_ID': ('em_icos_virus_shells', 'virus_entity_id', None, None)},
                                 'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'VIRUS_ENTITY_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                             's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                 'MAP_MERGE_INDICES': {'em_icos_virus_shells': {'ATTRIBUTES': ('virus_entity_id', 'id'),
                                                                                'TYPE': 'EQUI-JOIN'}},
                                 'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                 'TABLE_ID': 'EM_ICOS_VIRUS_SHELLS',
                                 'TABLE_NAME': 'em_icos_virus_shells',
                                 'TABLE_TYPE': 'transactional'},
        'EM_IMAGE_SCANS': {'ATTRIBUTES': {'CITATION_ID': 'citation_id',
                                          'DETAILS': 'details',
                                          'ENTRY_ID': 'entry_id',
                                          'ID': 'id',
                                          'NUMBER_DIGITAL_IMAGES': 'number_digital_images',
                                          'OD_RANGE': 'od_range',
                                          'QUANT_BIT_SIZE': 'quant_bit_size',
                                          'SAMPLING_SIZE': 'sampling_size',
                                          'SCANNER_MODEL': 'scanner_model',
                                          'STRUCTURE_ID': 'Structure_ID'},
                           'ATTRIBUTE_INFO': {'CITATION_ID': {'NULLABLE': True,
                                                              'ORDER': 10,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10},
                                              'DETAILS': {'NULLABLE': True,
                                                          'ORDER': 5,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 200},
                                              'ENTRY_ID': {'NULLABLE': False,
                                                           'ORDER': 2,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': True,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 10},
                                              'ID': {'NULLABLE': False,
                                                     'ORDER': 3,
                                                     'PRECISION': 0,
                                                     'PRIMARY_KEY': True,
                                                     'SQL_TYPE': 'VARCHAR',
                                                     'WIDTH': 10},
                                              'NUMBER_DIGITAL_IMAGES': {'NULLABLE': True,
                                                                        'ORDER': 4,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'INT',
                                                                        'WIDTH': 10},
                                              'OD_RANGE': {'NULLABLE': True,
                                                           'ORDER': 8,
                                                           'PRECISION': 6,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'FLOAT',
                                                           'WIDTH': 10},
                                              'QUANT_BIT_SIZE': {'NULLABLE': True,
                                                                 'ORDER': 9,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'INT',
                                                                 'WIDTH': 10},
                                              'SAMPLING_SIZE': {'NULLABLE': True,
                                                                'ORDER': 7,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                              'SCANNER_MODEL': {'NULLABLE': True,
                                                                'ORDER': 6,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 80},
                                              'STRUCTURE_ID': {'NULLABLE': False,
                                                               'ORDER': 1,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10}},
                           'ATTRIBUTE_MAP': {'CITATION_ID': ('em_image_scans', 'citation_id', None, None),
                                             'DETAILS': ('em_image_scans', 'details', None, None),
                                             'ENTRY_ID': ('em_image_scans', 'entry_id', None, None),
                                             'ID': ('em_image_scans', 'id', None, None),
                                             'NUMBER_DIGITAL_IMAGES': ('em_image_scans', 'number_digital_images', None, None),
                                             'OD_RANGE': ('em_image_scans', 'od_range', None, None),
                                             'QUANT_BIT_SIZE': ('em_image_scans', 'quant_bit_size', None, None),
                                             'SAMPLING_SIZE': ('em_image_scans', 'sampling_size', None, None),
                                             'SCANNER_MODEL': ('em_image_scans', 'scanner_model', None, None),
                                             'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                           'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                       's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                           'MAP_MERGE_INDICES': {'em_image_scans': {'ATTRIBUTES': ('entry_id', 'id'), 'TYPE': 'EQUI-JOIN'}},
                           'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                           'TABLE_ID': 'EM_IMAGE_SCANS',
                           'TABLE_NAME': 'em_image_scans',
                           'TABLE_TYPE': 'transactional'},
        'EM_IMAGING': {'ATTRIBUTES': {'ACCELERATING_VOLTAGE': 'accelerating_voltage',
                                      'ASTIGMATISM': 'astigmatism',
                                      'CALIBRATED_MAGNIFICATION': 'calibrated_magnification',
                                      'CITATION_ID': 'citation_id',
                                      'DATE': 'date',
                                      'DETAILS': 'details',
                                      'DETECTOR_DISTANCE': 'detector_distance',
                                      'DETECTOR_ID': 'detector_id',
                                      'ELECTRON_BEAM_TILT_PARAMS': 'electron_beam_tilt_params',
                                      'ELECTRON_DOSE': 'electron_dose',
                                      'ELECTRON_SOURCE': 'electron_source',
                                      'ENERGY_FILTER': 'energy_filter',
                                      'ENERGY_WINDOW': 'energy_window',
                                      'ENTRY_ID': 'entry_id',
                                      'ID': 'id',
                                      'ILLUMINATION_MODE': 'illumination_mode',
                                      'MICROSCOPE_ID': 'microscope_id',
                                      'MICROSCOPE_MODEL': 'microscope_model',
                                      'MODE': 'mode',
                                      'NOMINAL_CS': 'nominal_cs',
                                      'NOMINAL_DEFOCUS_MAX': 'nominal_defocus_max',
                                      'NOMINAL_DEFOCUS_MIN': 'nominal_defocus_min',
                                      'NOMINAL_MAGNIFICATION': 'nominal_magnification',
                                      'RECORDING_TEMPERATURE_MAXIMUM': 'recording_temperature_maximum',
                                      'RECORDING_TEMPERATURE_MINIMUM': 'recording_temperature_minimum',
                                      'SAMPLE_SUPPORT_ID': 'sample_support_id',
                                      'SCANS_ID': 'scans_id',
                                      'SPECIMEN_HOLDER_MODEL': 'specimen_holder_model',
                                      'SPECIMEN_HOLDER_TYPE': 'specimen_holder_type',
                                      'STRUCTURE_ID': 'Structure_ID',
                                      'TEMPERATURE': 'temperature',
                                      'TILT_ANGLE_MAX': 'tilt_angle_max',
                                      'TILT_ANGLE_MIN': 'tilt_angle_min'},
                       'ATTRIBUTE_INFO': {'ACCELERATING_VOLTAGE': {'NULLABLE': True,
                                                                   'ORDER': 15,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'INT',
                                                                   'WIDTH': 10},
                                          'ASTIGMATISM': {'NULLABLE': True,
                                                          'ORDER': 4,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 200},
                                          'CALIBRATED_MAGNIFICATION': {'NULLABLE': True,
                                                                       'ORDER': 24,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'INT',
                                                                       'WIDTH': 10},
                                          'CITATION_ID': {'NULLABLE': True,
                                                          'ORDER': 29,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 10},
                                          'DATE': {'NULLABLE': True,
                                                   'ORDER': 14,
                                                   'PRECISION': 0,
                                                   'PRIMARY_KEY': False,
                                                   'SQL_TYPE': 'VARCHAR',
                                                   'WIDTH': 80},
                                          'DETAILS': {'NULLABLE': True,
                                                      'ORDER': 13,
                                                      'PRECISION': 0,
                                                      'PRIMARY_KEY': False,
                                                      'SQL_TYPE': 'VARCHAR',
                                                      'WIDTH': 1023},
                                          'DETECTOR_DISTANCE': {'NULLABLE': True,
                                                                'ORDER': 31,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                          'DETECTOR_ID': {'NULLABLE': True,
                                                          'ORDER': 7,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 10},
                                          'ELECTRON_BEAM_TILT_PARAMS': {'NULLABLE': True,
                                                                        'ORDER': 5,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 200},
                                          'ELECTRON_DOSE': {'NULLABLE': True,
                                                            'ORDER': 26,
                                                            'PRECISION': 6,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'FLOAT',
                                                            'WIDTH': 10},
                                          'ELECTRON_SOURCE': {'NULLABLE': True,
                                                              'ORDER': 25,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 80},
                                          'ENERGY_FILTER': {'NULLABLE': True,
                                                            'ORDER': 27,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 80},
                                          'ENERGY_WINDOW': {'NULLABLE': True,
                                                            'ORDER': 28,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 80},
                                          'ENTRY_ID': {'NULLABLE': False,
                                                       'ORDER': 2,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': True,
                                                       'SQL_TYPE': 'VARCHAR',
                                                       'WIDTH': 10},
                                          'ID': {'NULLABLE': False,
                                                 'ORDER': 3,
                                                 'PRECISION': 0,
                                                 'PRIMARY_KEY': True,
                                                 'SQL_TYPE': 'VARCHAR',
                                                 'WIDTH': 10},
                                          'ILLUMINATION_MODE': {'NULLABLE': True,
                                                                'ORDER': 16,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 80},
                                          'MICROSCOPE_ID': {'NULLABLE': True,
                                                            'ORDER': 9,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 10},
                                          'MICROSCOPE_MODEL': {'NULLABLE': True,
                                                               'ORDER': 10,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 80},
                                          'MODE': {'NULLABLE': True,
                                                   'ORDER': 17,
                                                   'PRECISION': 0,
                                                   'PRIMARY_KEY': False,
                                                   'SQL_TYPE': 'VARCHAR',
                                                   'WIDTH': 80},
                                          'NOMINAL_CS': {'NULLABLE': True,
                                                         'ORDER': 18,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                          'NOMINAL_DEFOCUS_MAX': {'NULLABLE': True,
                                                                  'ORDER': 20,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10},
                                          'NOMINAL_DEFOCUS_MIN': {'NULLABLE': True,
                                                                  'ORDER': 19,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10},
                                          'NOMINAL_MAGNIFICATION': {'NULLABLE': True,
                                                                    'ORDER': 23,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'INT',
                                                                    'WIDTH': 10},
                                          'RECORDING_TEMPERATURE_MAXIMUM': {'NULLABLE': True,
                                                                            'ORDER': 33,
                                                                            'PRECISION': 6,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'FLOAT',
                                                                            'WIDTH': 10},
                                          'RECORDING_TEMPERATURE_MINIMUM': {'NULLABLE': True,
                                                                            'ORDER': 32,
                                                                            'PRECISION': 6,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'FLOAT',
                                                                            'WIDTH': 10},
                                          'SAMPLE_SUPPORT_ID': {'NULLABLE': True,
                                                                'ORDER': 6,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                          'SCANS_ID': {'NULLABLE': True,
                                                       'ORDER': 8,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'VARCHAR',
                                                       'WIDTH': 10},
                                          'SPECIMEN_HOLDER_MODEL': {'NULLABLE': True,
                                                                    'ORDER': 12,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 80},
                                          'SPECIMEN_HOLDER_TYPE': {'NULLABLE': True,
                                                                   'ORDER': 11,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 200},
                                          'STRUCTURE_ID': {'NULLABLE': False,
                                                           'ORDER': 1,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': True,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 10},
                                          'TEMPERATURE': {'NULLABLE': True,
                                                          'ORDER': 30,
                                                          'PRECISION': 6,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'FLOAT',
                                                          'WIDTH': 10},
                                          'TILT_ANGLE_MAX': {'NULLABLE': True,
                                                             'ORDER': 22,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                          'TILT_ANGLE_MIN': {'NULLABLE': True,
                                                             'ORDER': 21,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10}},
                       'ATTRIBUTE_MAP': {'ACCELERATING_VOLTAGE': ('em_imaging', 'accelerating_voltage', None, None),
                                         'ASTIGMATISM': ('em_imaging', 'astigmatism', None, None),
                                         'CALIBRATED_MAGNIFICATION': ('em_imaging', 'calibrated_magnification', None, None),
                                         'CITATION_ID': ('em_imaging', 'citation_id', None, None),
                                         'DATE': ('em_imaging', 'date', None, None),
                                         'DETAILS': ('em_imaging', 'details', None, None),
                                         'DETECTOR_DISTANCE': ('em_imaging', 'detector_distance', None, None),
                                         'DETECTOR_ID': ('em_imaging', 'detector_id', None, None),
                                         'ELECTRON_BEAM_TILT_PARAMS': ('em_imaging', 'electron_beam_tilt_params', None, None),
                                         'ELECTRON_DOSE': ('em_imaging', 'electron_dose', None, None),
                                         'ELECTRON_SOURCE': ('em_imaging', 'electron_source', None, None),
                                         'ENERGY_FILTER': ('em_imaging', 'energy_filter', None, None),
                                         'ENERGY_WINDOW': ('em_imaging', 'energy_window', None, None),
                                         'ENTRY_ID': ('em_imaging', 'entry_id', None, None),
                                         'ID': ('em_imaging', 'id', None, None),
                                         'ILLUMINATION_MODE': ('em_imaging', 'illumination_mode', None, None),
                                         'MICROSCOPE_ID': ('em_imaging', 'microscope_id', None, None),
                                         'MICROSCOPE_MODEL': ('em_imaging', 'microscope_model', None, None),
                                         'MODE': ('em_imaging', 'mode', None, None),
                                         'NOMINAL_CS': ('em_imaging', 'nominal_cs', None, None),
                                         'NOMINAL_DEFOCUS_MAX': ('em_imaging', 'nominal_defocus_max', None, None),
                                         'NOMINAL_DEFOCUS_MIN': ('em_imaging', 'nominal_defocus_min', None, None),
                                         'NOMINAL_MAGNIFICATION': ('em_imaging', 'nominal_magnification', None, None),
                                         'RECORDING_TEMPERATURE_MAXIMUM': ('em_imaging',
                                                                           'recording_temperature_maximum',
                                                                           None,
                                                                           None),
                                         'RECORDING_TEMPERATURE_MINIMUM': ('em_imaging',
                                                                           'recording_temperature_minimum',
                                                                           None,
                                                                           None),
                                         'SAMPLE_SUPPORT_ID': ('em_imaging', 'sample_support_id', None, None),
                                         'SCANS_ID': ('em_imaging', 'scans_id', None, None),
                                         'SPECIMEN_HOLDER_MODEL': ('em_imaging', 'specimen_holder_model', None, None),
                                         'SPECIMEN_HOLDER_TYPE': ('em_imaging', 'specimen_holder_type', None, None),
                                         'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                         'TEMPERATURE': ('em_imaging', 'temperature', None, None),
                                         'TILT_ANGLE_MAX': ('em_imaging', 'tilt_angle_max', None, None),
                                         'TILT_ANGLE_MIN': ('em_imaging', 'tilt_angle_min', None, None)},
                       'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                   's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                       'MAP_MERGE_INDICES': {'em_imaging': {'ATTRIBUTES': ('entry_id', 'id'), 'TYPE': 'EQUI-JOIN'}},
                       'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                       'TABLE_ID': 'EM_IMAGING',
                       'TABLE_NAME': 'em_imaging',
                       'TABLE_TYPE': 'transactional'},
        'EM_SAMPLE_PREPARATION': {'ATTRIBUTES': {'2D_CRYSTAL_GROW_ID': '2d_crystal_grow_id',
                                                 'BUFFER_ID': 'buffer_id',
                                                 'DETAILS': 'details',
                                                 'ENTITY_ASSEMBLY_ID': 'entity_assembly_id',
                                                 'ENTRY_ID': 'entry_id',
                                                 'ID': 'id',
                                                 'PH': 'ph',
                                                 'SAMPLE_CONCENTRATION': 'sample_concentration',
                                                 'STRUCTURE_ID': 'Structure_ID',
                                                 'SUPPORT_ID': 'support_id'},
                                  'ATTRIBUTE_INFO': {'2D_CRYSTAL_GROW_ID': {'NULLABLE': True,
                                                                            'ORDER': 7,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 10},
                                                     'BUFFER_ID': {'NULLABLE': True,
                                                                   'ORDER': 5,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 10},
                                                     'DETAILS': {'NULLABLE': True,
                                                                 'ORDER': 10,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 200},
                                                     'ENTITY_ASSEMBLY_ID': {'NULLABLE': True,
                                                                            'ORDER': 9,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 10},
                                                     'ENTRY_ID': {'NULLABLE': False,
                                                                  'ORDER': 2,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': True,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10},
                                                     'ID': {'NULLABLE': False,
                                                            'ORDER': 3,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': True,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 10},
                                                     'PH': {'NULLABLE': True,
                                                            'ORDER': 4,
                                                            'PRECISION': 6,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'FLOAT',
                                                            'WIDTH': 10},
                                                     'SAMPLE_CONCENTRATION': {'NULLABLE': True,
                                                                              'ORDER': 6,
                                                                              'PRECISION': 6,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'FLOAT',
                                                                              'WIDTH': 10},
                                                     'STRUCTURE_ID': {'NULLABLE': False,
                                                                      'ORDER': 1,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                                     'SUPPORT_ID': {'NULLABLE': True,
                                                                    'ORDER': 8,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10}},
                                  'ATTRIBUTE_MAP': {'2D_CRYSTAL_GROW_ID': ('em_sample_preparation',
                                                                           '2d_crystal_grow_id',
                                                                           None,
                                                                           None),
                                                    'BUFFER_ID': ('em_sample_preparation', 'buffer_id', None, None),
                                                    'DETAILS': ('em_sample_preparation', 'details', None, None),
                                                    'ENTITY_ASSEMBLY_ID': ('em_sample_preparation',
                                                                           'entity_assembly_id',
                                                                           None,
                                                                           None),
                                                    'ENTRY_ID': ('em_sample_preparation', 'entry_id', None, None),
                                                    'ID': ('em_sample_preparation', 'id', None, None),
                                                    'PH': ('em_sample_preparation', 'ph', None, None),
                                                    'SAMPLE_CONCENTRATION': ('em_sample_preparation',
                                                                             'sample_concentration',
                                                                             None,
                                                                             None),
                                                    'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                    'SUPPORT_ID': ('em_sample_preparation', 'support_id', None, None)},
                                  'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                              's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                  'MAP_MERGE_INDICES': {'em_sample_preparation': {'ATTRIBUTES': ('entry_id', 'id'),
                                                                                  'TYPE': 'EQUI-JOIN'}},
                                  'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                  'TABLE_ID': 'EM_SAMPLE_PREPARATION',
                                  'TABLE_NAME': 'em_sample_preparation',
                                  'TABLE_TYPE': 'transactional'},
        'EM_SAMPLE_SUPPORT': {'ATTRIBUTES': {'CITATION_ID': 'citation_id',
                                             'DETAILS': 'details',
                                             'FILM_MATERIAL': 'film_material',
                                             'GRID_MATERIAL': 'grid_material',
                                             'GRID_MESH_SIZE': 'grid_mesh_size',
                                             'GRID_TYPE': 'grid_type',
                                             'ID': 'id',
                                             'METHOD': 'method',
                                             'PRETREATMENT': 'pretreatment',
                                             'STRUCTURE_ID': 'Structure_ID'},
                              'ATTRIBUTE_INFO': {'CITATION_ID': {'NULLABLE': True,
                                                                 'ORDER': 10,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                                 'DETAILS': {'NULLABLE': True,
                                                             'ORDER': 9,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 200},
                                                 'FILM_MATERIAL': {'NULLABLE': True,
                                                                   'ORDER': 3,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 80},
                                                 'GRID_MATERIAL': {'NULLABLE': True,
                                                                   'ORDER': 5,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 80},
                                                 'GRID_MESH_SIZE': {'NULLABLE': True,
                                                                    'ORDER': 6,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'INT',
                                                                    'WIDTH': 10},
                                                 'GRID_TYPE': {'NULLABLE': True,
                                                               'ORDER': 7,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 80},
                                                 'ID': {'NULLABLE': False,
                                                        'ORDER': 2,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': True,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 10},
                                                 'METHOD': {'NULLABLE': True,
                                                            'ORDER': 4,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 200},
                                                 'PRETREATMENT': {'NULLABLE': True,
                                                                  'ORDER': 8,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 200},
                                                 'STRUCTURE_ID': {'NULLABLE': False,
                                                                  'ORDER': 1,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': True,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10}},
                              'ATTRIBUTE_MAP': {'CITATION_ID': ('em_sample_support', 'citation_id', None, None),
                                                'DETAILS': ('em_sample_support', 'details', None, None),
                                                'FILM_MATERIAL': ('em_sample_support', 'film_material', None, None),
                                                'GRID_MATERIAL': ('em_sample_support', 'grid_material', None, None),
                                                'GRID_MESH_SIZE': ('em_sample_support', 'grid_mesh_size', None, None),
                                                'GRID_TYPE': ('em_sample_support', 'grid_type', None, None),
                                                'ID': ('em_sample_support', 'id', None, None),
                                                'METHOD': ('em_sample_support', 'method', None, None),
                                                'PRETREATMENT': ('em_sample_support', 'pretreatment', None, None),
                                                'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                              'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                          's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                              'MAP_MERGE_INDICES': {'em_sample_support': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                              'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                              'TABLE_ID': 'EM_SAMPLE_SUPPORT',
                              'TABLE_NAME': 'em_sample_support',
                              'TABLE_TYPE': 'transactional'},
        'EM_SINGLE_PARTICLE_ENTITY': {'ATTRIBUTES': {'ENTRY_ID': 'entry_id',
                                                     'STRUCTURE_ID': 'Structure_ID',
                                                     'SYMMETRY_TYPE': 'symmetry_type'},
                                      'ATTRIBUTE_INFO': {'ENTRY_ID': {'NULLABLE': False,
                                                                      'ORDER': 2,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                                         'STRUCTURE_ID': {'NULLABLE': False,
                                                                          'ORDER': 1,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': True,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                         'SYMMETRY_TYPE': {'NULLABLE': True,
                                                                           'ORDER': 3,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 80}},
                                      'ATTRIBUTE_MAP': {'ENTRY_ID': ('em_single_particle_entity', 'entry_id', None, None),
                                                        'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                        'SYMMETRY_TYPE': ('em_single_particle_entity',
                                                                          'symmetry_type',
                                                                          None,
                                                                          None)},
                                      'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID'), 'TYPE': 'UNIQUE'},
                                                  's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                      'MAP_MERGE_INDICES': {'em_single_particle_entity': {'ATTRIBUTES': ('entry_id',),
                                                                                          'TYPE': 'EQUI-JOIN'}},
                                      'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                      'TABLE_ID': 'EM_SINGLE_PARTICLE_ENTITY',
                                      'TABLE_NAME': 'em_single_particle_entity',
                                      'TABLE_TYPE': 'transactional'},
        'EM_VIRUS_ENTITY': {'ATTRIBUTES': {'DETAILS': 'details',
                                           'EMPTY': 'empty',
                                           'ENTITY_ASSEMBLY_ID': 'entity_assembly_id',
                                           'ENVELOPED': 'enveloped',
                                           'ICTVDB_ID': 'ictvdb_id',
                                           'ID': 'id',
                                           'STRUCTURE_ID': 'Structure_ID',
                                           'VIRUS_HOST_CATEGORY': 'virus_host_category',
                                           'VIRUS_HOST_GROWTH_CELL': 'virus_host_growth_cell',
                                           'VIRUS_HOST_SPECIES': 'virus_host_species',
                                           'VIRUS_ISOLATE': 'virus_isolate',
                                           'VIRUS_TYPE': 'virus_type'},
                            'ATTRIBUTE_INFO': {'DETAILS': {'NULLABLE': True,
                                                           'ORDER': 12,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 200},
                                               'EMPTY': {'NULLABLE': True,
                                                         'ORDER': 11,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 80},
                                               'ENTITY_ASSEMBLY_ID': {'NULLABLE': False,
                                                                      'ORDER': 9,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                               'ENVELOPED': {'NULLABLE': True,
                                                             'ORDER': 10,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 80},
                                               'ICTVDB_ID': {'NULLABLE': True,
                                                             'ORDER': 8,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 80},
                                               'ID': {'NULLABLE': False,
                                                      'ORDER': 2,
                                                      'PRECISION': 0,
                                                      'PRIMARY_KEY': True,
                                                      'SQL_TYPE': 'VARCHAR',
                                                      'WIDTH': 10},
                                               'STRUCTURE_ID': {'NULLABLE': False,
                                                                'ORDER': 1,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                               'VIRUS_HOST_CATEGORY': {'NULLABLE': True,
                                                                       'ORDER': 3,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 80},
                                               'VIRUS_HOST_GROWTH_CELL': {'NULLABLE': True,
                                                                          'ORDER': 5,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 80},
                                               'VIRUS_HOST_SPECIES': {'NULLABLE': True,
                                                                      'ORDER': 4,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 80},
                                               'VIRUS_ISOLATE': {'NULLABLE': True,
                                                                 'ORDER': 7,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 80},
                                               'VIRUS_TYPE': {'NULLABLE': True,
                                                              'ORDER': 6,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 80}},
                            'ATTRIBUTE_MAP': {'DETAILS': ('em_virus_entity', 'details', None, None),
                                              'EMPTY': ('em_virus_entity', 'empty', None, None),
                                              'ENTITY_ASSEMBLY_ID': ('em_virus_entity', 'entity_assembly_id', None, None),
                                              'ENVELOPED': ('em_virus_entity', 'enveloped', None, None),
                                              'ICTVDB_ID': ('em_virus_entity', 'ictvdb_id', None, None),
                                              'ID': ('em_virus_entity', 'id', None, None),
                                              'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                              'VIRUS_HOST_CATEGORY': ('em_virus_entity', 'virus_host_category', None, None),
                                              'VIRUS_HOST_GROWTH_CELL': ('em_virus_entity',
                                                                         'virus_host_growth_cell',
                                                                         None,
                                                                         None),
                                              'VIRUS_HOST_SPECIES': ('em_virus_entity', 'virus_host_species', None, None),
                                              'VIRUS_ISOLATE': ('em_virus_entity', 'virus_isolate', None, None),
                                              'VIRUS_TYPE': ('em_virus_entity', 'virus_type', None, None)},
                            'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID', 'ENTITY_ASSEMBLY_ID'), 'TYPE': 'UNIQUE'},
                                        's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                            'MAP_MERGE_INDICES': {'em_virus_entity': {'ATTRIBUTES': ('id', 'entity_assembly_id'),
                                                                      'TYPE': 'EQUI-JOIN'}},
                            'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                            'TABLE_ID': 'EM_VIRUS_ENTITY',
                            'TABLE_NAME': 'em_virus_entity',
                            'TABLE_TYPE': 'transactional'},
        'EM_VITRIFICATION': {'ATTRIBUTES': {'CITATION_ID': 'citation_id',
                                            'CRYOGEN_NAME': 'cryogen_name',
                                            'DETAILS': 'details',
                                            'ENTRY_ID': 'entry_id',
                                            'HUMIDITY': 'humidity',
                                            'ID': 'id',
                                            'INSTRUMENT': 'instrument',
                                            'METHOD': 'method',
                                            'SAMPLE_PREPARATION_ID': 'sample_preparation_id',
                                            'STRUCTURE_ID': 'Structure_ID',
                                            'TEMP': 'temp',
                                            'TIME_RESOLVED_STATE': 'time_resolved_state'},
                             'ATTRIBUTE_INFO': {'CITATION_ID': {'NULLABLE': True,
                                                                'ORDER': 11,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                                'CRYOGEN_NAME': {'NULLABLE': True,
                                                                 'ORDER': 5,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 80},
                                                'DETAILS': {'NULLABLE': True,
                                                            'ORDER': 12,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 511},
                                                'ENTRY_ID': {'NULLABLE': False,
                                                             'ORDER': 2,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 10},
                                                'HUMIDITY': {'NULLABLE': True,
                                                             'ORDER': 6,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 80},
                                                'ID': {'NULLABLE': False,
                                                       'ORDER': 3,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': True,
                                                       'SQL_TYPE': 'VARCHAR',
                                                       'WIDTH': 10},
                                                'INSTRUMENT': {'NULLABLE': True,
                                                               'ORDER': 8,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 200},
                                                'METHOD': {'NULLABLE': True,
                                                           'ORDER': 9,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 1023},
                                                'SAMPLE_PREPARATION_ID': {'NULLABLE': True,
                                                                          'ORDER': 4,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                'STRUCTURE_ID': {'NULLABLE': False,
                                                                 'ORDER': 1,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': True,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                                'TEMP': {'NULLABLE': True,
                                                         'ORDER': 7,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                                'TIME_RESOLVED_STATE': {'NULLABLE': True,
                                                                        'ORDER': 10,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 200}},
                             'ATTRIBUTE_MAP': {'CITATION_ID': ('em_vitrification', 'citation_id', None, None),
                                               'CRYOGEN_NAME': ('em_vitrification', 'cryogen_name', None, None),
                                               'DETAILS': ('em_vitrification', 'details', None, None),
                                               'ENTRY_ID': ('em_vitrification', 'entry_id', None, None),
                                               'HUMIDITY': ('em_vitrification', 'humidity', None, None),
                                               'ID': ('em_vitrification', 'id', None, None),
                                               'INSTRUMENT': ('em_vitrification', 'instrument', None, None),
                                               'METHOD': ('em_vitrification', 'method', None, None),
                                               'SAMPLE_PREPARATION_ID': ('em_vitrification',
                                                                         'sample_preparation_id',
                                                                         None,
                                                                         None),
                                               'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                               'TEMP': ('em_vitrification', 'temp', None, None),
                                               'TIME_RESOLVED_STATE': ('em_vitrification', 'time_resolved_state', None, None)},
                             'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                         's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                             'MAP_MERGE_INDICES': {'em_vitrification': {'ATTRIBUTES': ('entry_id', 'id'),
                                                                        'TYPE': 'EQUI-JOIN'}},
                             'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                             'TABLE_ID': 'EM_VITRIFICATION',
                             'TABLE_NAME': 'em_vitrification',
                             'TABLE_TYPE': 'transactional'},
        'ENTITY': {'ATTRIBUTES': {'DETAILS': 'details',
                                  'FORMULA_WEIGHT': 'formula_weight',
                                  'ID': 'id',
                                  'PDBX_DESCRIPTION': 'pdbx_description',
                                  'PDBX_EC': 'pdbx_ec',
                                  'PDBX_FORMULA_WEIGHT_EXPTL': 'pdbx_formula_weight_exptl',
                                  'PDBX_FORMULA_WEIGHT_EXPTL_METHOD': 'pdbx_formula_weight_exptl_method',
                                  'PDBX_FRAGMENT': 'pdbx_fragment',
                                  'PDBX_MODIFICATION': 'pdbx_modification',
                                  'PDBX_MUTATION': 'pdbx_mutation',
                                  'PDBX_NUMBER_OF_MOLECULES': 'pdbx_number_of_molecules',
                                  'PDBX_PARENT_ENTITY_ID': 'pdbx_parent_entity_id',
                                  'PDBX_TARGET_ID': 'pdbx_target_id',
                                  'SRC_METHOD': 'src_method',
                                  'STRUCTURE_ID': 'Structure_ID',
                                  'TYPE': 'type'},
                   'ATTRIBUTE_INFO': {'DETAILS': {'NULLABLE': True,
                                                  'ORDER': 2,
                                                  'PRECISION': 0,
                                                  'PRIMARY_KEY': False,
                                                  'SQL_TYPE': 'VARCHAR',
                                                  'WIDTH': 1023},
                                      'FORMULA_WEIGHT': {'NULLABLE': True,
                                                         'ORDER': 3,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                      'ID': {'NULLABLE': False,
                                             'ORDER': 4,
                                             'PRECISION': 0,
                                             'PRIMARY_KEY': True,
                                             'SQL_TYPE': 'VARCHAR',
                                             'WIDTH': 10},
                                      'PDBX_DESCRIPTION': {'NULLABLE': True,
                                                           'ORDER': 7,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 1023},
                                      'PDBX_EC': {'NULLABLE': True,
                                                  'ORDER': 12,
                                                  'PRECISION': 0,
                                                  'PRIMARY_KEY': False,
                                                  'SQL_TYPE': 'VARCHAR',
                                                  'WIDTH': 80},
                                      'PDBX_FORMULA_WEIGHT_EXPTL': {'NULLABLE': True,
                                                                    'ORDER': 14,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                      'PDBX_FORMULA_WEIGHT_EXPTL_METHOD': {'NULLABLE': True,
                                                                           'ORDER': 15,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 80},
                                      'PDBX_FRAGMENT': {'NULLABLE': True,
                                                        'ORDER': 11,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 255},
                                      'PDBX_MODIFICATION': {'NULLABLE': True,
                                                            'ORDER': 13,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 80},
                                      'PDBX_MUTATION': {'NULLABLE': True,
                                                        'ORDER': 10,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 255},
                                      'PDBX_NUMBER_OF_MOLECULES': {'NULLABLE': True,
                                                                   'ORDER': 8,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                      'PDBX_PARENT_ENTITY_ID': {'NULLABLE': True,
                                                                'ORDER': 9,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                      'PDBX_TARGET_ID': {'NULLABLE': True,
                                                         'ORDER': 16,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 10},
                                      'SRC_METHOD': {'NULLABLE': True,
                                                     'ORDER': 5,
                                                     'PRECISION': 0,
                                                     'PRIMARY_KEY': False,
                                                     'SQL_TYPE': 'VARCHAR',
                                                     'WIDTH': 10},
                                      'STRUCTURE_ID': {'NULLABLE': False,
                                                       'ORDER': 1,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': True,
                                                       'SQL_TYPE': 'VARCHAR',
                                                       'WIDTH': 10},
                                      'TYPE': {'NULLABLE': True,
                                               'ORDER': 6,
                                               'PRECISION': 0,
                                               'PRIMARY_KEY': False,
                                               'SQL_TYPE': 'VARCHAR',
                                               'WIDTH': 12}},
                   'ATTRIBUTE_MAP': {'DETAILS': ('entity', 'details', None, None),
                                     'FORMULA_WEIGHT': ('entity', 'formula_weight', None, None),
                                     'ID': ('entity', 'id', None, None),
                                     'PDBX_DESCRIPTION': ('entity', 'pdbx_description', None, None),
                                     'PDBX_EC': ('entity', 'pdbx_ec', None, None),
                                     'PDBX_FORMULA_WEIGHT_EXPTL': ('entity', 'pdbx_formula_weight_exptl', None, None),
                                     'PDBX_FORMULA_WEIGHT_EXPTL_METHOD': ('entity',
                                                                          'pdbx_formula_weight_exptl_method',
                                                                          None,
                                                                          None),
                                     'PDBX_FRAGMENT': ('entity', 'pdbx_fragment', None, None),
                                     'PDBX_MODIFICATION': ('entity', 'pdbx_modification', None, None),
                                     'PDBX_MUTATION': ('entity', 'pdbx_mutation', None, None),
                                     'PDBX_NUMBER_OF_MOLECULES': ('entity', 'pdbx_number_of_molecules', None, None),
                                     'PDBX_PARENT_ENTITY_ID': ('entity', 'pdbx_parent_entity_id', None, None),
                                     'PDBX_TARGET_ID': ('entity', 'pdbx_target_id', None, None),
                                     'SRC_METHOD': ('entity', 'src_method', None, None),
                                     'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                     'TYPE': ('entity', 'type', None, None)},
                   'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                               's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                   'MAP_MERGE_INDICES': {'entity': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                   'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                   'TABLE_ID': 'ENTITY',
                   'TABLE_NAME': 'entity',
                   'TABLE_TYPE': 'transactional'},
        'ENTITY_KEYWORDS': {'ATTRIBUTES': {'ENTITY_ID': 'entity_id',
                                           'PDBX_EC': 'pdbx_ec',
                                           'PDBX_FRAGMENT': 'pdbx_fragment',
                                           'PDBX_MUTATION': 'pdbx_mutation',
                                           'STRUCTURE_ID': 'Structure_ID',
                                           'TEXT': 'text'},
                            'ATTRIBUTE_INFO': {'ENTITY_ID': {'NULLABLE': False,
                                                             'ORDER': 2,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 10},
                                               'PDBX_EC': {'NULLABLE': True,
                                                           'ORDER': 6,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 80},
                                               'PDBX_FRAGMENT': {'NULLABLE': True,
                                                                 'ORDER': 5,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 80},
                                               'PDBX_MUTATION': {'NULLABLE': True,
                                                                 'ORDER': 4,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 80},
                                               'STRUCTURE_ID': {'NULLABLE': False,
                                                                'ORDER': 1,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                               'TEXT': {'NULLABLE': True,
                                                        'ORDER': 3,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 200}},
                            'ATTRIBUTE_MAP': {'ENTITY_ID': ('entity_keywords', 'entity_id', None, None),
                                              'PDBX_EC': ('entity_keywords', 'pdbx_ec', None, None),
                                              'PDBX_FRAGMENT': ('entity_keywords', 'pdbx_fragment', None, None),
                                              'PDBX_MUTATION': ('entity_keywords', 'pdbx_mutation', None, None),
                                              'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                              'TEXT': ('entity_keywords', 'text', None, None)},
                            'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTITY_ID'), 'TYPE': 'UNIQUE'},
                                        's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                            'MAP_MERGE_INDICES': {'entity_keywords': {'ATTRIBUTES': ('entity_id',), 'TYPE': 'EQUI-JOIN'}},
                            'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                            'TABLE_ID': 'ENTITY_KEYWORDS',
                            'TABLE_NAME': 'entity_keywords',
                            'TABLE_TYPE': 'transactional'},
        'ENTITY_LINK': {'ATTRIBUTES': {'DETAILS': 'details',
                                       'ENTITY_ID_1': 'entity_id_1',
                                       'ENTITY_ID_2': 'entity_id_2',
                                       'ENTITY_SEQ_NUM_1': 'entity_seq_num_1',
                                       'ENTITY_SEQ_NUM_2': 'entity_seq_num_2',
                                       'LINK_ID': 'link_id',
                                       'STRUCTURE_ID': 'Structure_ID'},
                        'ATTRIBUTE_INFO': {'DETAILS': {'NULLABLE': True,
                                                       'ORDER': 5,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'VARCHAR',
                                                       'WIDTH': 200},
                                           'ENTITY_ID_1': {'NULLABLE': True,
                                                           'ORDER': 3,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 10},
                                           'ENTITY_ID_2': {'NULLABLE': True,
                                                           'ORDER': 4,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 10},
                                           'ENTITY_SEQ_NUM_1': {'NULLABLE': True,
                                                                'ORDER': 6,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'INT',
                                                                'WIDTH': 10},
                                           'ENTITY_SEQ_NUM_2': {'NULLABLE': True,
                                                                'ORDER': 7,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'INT',
                                                                'WIDTH': 10},
                                           'LINK_ID': {'NULLABLE': False,
                                                       'ORDER': 2,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': True,
                                                       'SQL_TYPE': 'VARCHAR',
                                                       'WIDTH': 10},
                                           'STRUCTURE_ID': {'NULLABLE': False,
                                                            'ORDER': 1,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': True,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 10}},
                        'ATTRIBUTE_MAP': {'DETAILS': ('entity_link', 'details', None, None),
                                          'ENTITY_ID_1': ('entity_link', 'entity_id_1', None, None),
                                          'ENTITY_ID_2': ('entity_link', 'entity_id_2', None, None),
                                          'ENTITY_SEQ_NUM_1': ('entity_link', 'entity_seq_num_1', None, None),
                                          'ENTITY_SEQ_NUM_2': ('entity_link', 'entity_seq_num_2', None, None),
                                          'LINK_ID': ('entity_link', 'link_id', None, None),
                                          'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                        'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'LINK_ID'), 'TYPE': 'UNIQUE'},
                                    's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                        'MAP_MERGE_INDICES': {'entity_link': {'ATTRIBUTES': ('link_id',), 'TYPE': 'EQUI-JOIN'}},
                        'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                        'TABLE_ID': 'ENTITY_LINK',
                        'TABLE_NAME': 'entity_link',
                        'TABLE_TYPE': 'transactional'},
        'ENTITY_NAME_COM': {'ATTRIBUTES': {'ENTITY_ID': 'entity_id', 'NAME': 'name', 'STRUCTURE_ID': 'Structure_ID'},
                            'ATTRIBUTE_INFO': {'ENTITY_ID': {'NULLABLE': False,
                                                             'ORDER': 2,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 10},
                                               'NAME': {'NULLABLE': True,
                                                        'ORDER': 3,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 1023},
                                               'STRUCTURE_ID': {'NULLABLE': False,
                                                                'ORDER': 1,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10}},
                            'ATTRIBUTE_MAP': {'ENTITY_ID': ('entity_name_com', 'entity_id', None, None),
                                              'NAME': ('entity_name_com', 'name', None, None),
                                              'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                            'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTITY_ID'), 'TYPE': 'UNIQUE'},
                                        's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                            'MAP_MERGE_INDICES': {'entity_name_com': {'ATTRIBUTES': ('entity_id',), 'TYPE': 'EQUI-JOIN'}},
                            'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                            'TABLE_ID': 'ENTITY_NAME_COM',
                            'TABLE_NAME': 'entity_name_com',
                            'TABLE_TYPE': 'transactional'},
        'ENTITY_NAME_SYS': {'ATTRIBUTES': {'ENTITY_ID': 'entity_id',
                                           'NAME': 'name',
                                           'STRUCTURE_ID': 'Structure_ID',
                                           'SYSTEM': 'system'},
                            'ATTRIBUTE_INFO': {'ENTITY_ID': {'NULLABLE': False,
                                                             'ORDER': 2,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 10},
                                               'NAME': {'NULLABLE': True,
                                                        'ORDER': 3,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 200},
                                               'STRUCTURE_ID': {'NULLABLE': False,
                                                                'ORDER': 1,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                               'SYSTEM': {'NULLABLE': True,
                                                          'ORDER': 4,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 200}},
                            'ATTRIBUTE_MAP': {'ENTITY_ID': ('entity_name_sys', 'entity_id', None, None),
                                              'NAME': ('entity_name_sys', 'name', None, None),
                                              'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                              'SYSTEM': ('entity_name_sys', 'system', None, None)},
                            'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTITY_ID'), 'TYPE': 'UNIQUE'},
                                        's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                            'MAP_MERGE_INDICES': {'entity_name_sys': {'ATTRIBUTES': ('entity_id',), 'TYPE': 'EQUI-JOIN'}},
                            'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                            'TABLE_ID': 'ENTITY_NAME_SYS',
                            'TABLE_NAME': 'entity_name_sys',
                            'TABLE_TYPE': 'transactional'},
        'ENTITY_POLY': {'ATTRIBUTES': {'ENTITY_ID': 'entity_id',
                                       'NSTD_CHIRALITY': 'nstd_chirality',
                                       'NSTD_LINKAGE': 'nstd_linkage',
                                       'NSTD_MONOMER': 'nstd_monomer',
                                       'NUMBER_OF_MONOMERS': 'number_of_monomers',
                                       'PDBX_SEQ_ONE_LETTER_CODE': 'pdbx_seq_one_letter_code',
                                       'PDBX_SEQ_ONE_LETTER_CODE_CAN': 'pdbx_seq_one_letter_code_can',
                                       'PDBX_STRAND_ID': 'pdbx_strand_id',
                                       'PDBX_TARGET_IDENTIFIER': 'pdbx_target_identifier',
                                       'STRUCTURE_ID': 'Structure_ID',
                                       'TYPE': 'type',
                                       'TYPE_DETAILS': 'type_details'},
                        'ATTRIBUTE_INFO': {'ENTITY_ID': {'NULLABLE': False,
                                                         'ORDER': 2,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': True,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 10},
                                           'NSTD_CHIRALITY': {'NULLABLE': True,
                                                              'ORDER': 3,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10},
                                           'NSTD_LINKAGE': {'NULLABLE': True,
                                                            'ORDER': 4,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 10},
                                           'NSTD_MONOMER': {'NULLABLE': True,
                                                            'ORDER': 5,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 10},
                                           'NUMBER_OF_MONOMERS': {'NULLABLE': True,
                                                                  'ORDER': 6,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'INT',
                                                                  'WIDTH': 10},
                                           'PDBX_SEQ_ONE_LETTER_CODE': {'NULLABLE': True,
                                                                        'ORDER': 10,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 32000},
                                           'PDBX_SEQ_ONE_LETTER_CODE_CAN': {'NULLABLE': True,
                                                                            'ORDER': 11,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 16383},
                                           'PDBX_STRAND_ID': {'NULLABLE': True,
                                                              'ORDER': 9,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 128},
                                           'PDBX_TARGET_IDENTIFIER': {'NULLABLE': True,
                                                                      'ORDER': 12,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 128},
                                           'STRUCTURE_ID': {'NULLABLE': False,
                                                            'ORDER': 1,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': True,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 10},
                                           'TYPE': {'NULLABLE': True,
                                                    'ORDER': 7,
                                                    'PRECISION': 0,
                                                    'PRIMARY_KEY': False,
                                                    'SQL_TYPE': 'VARCHAR',
                                                    'WIDTH': 80},
                                           'TYPE_DETAILS': {'NULLABLE': True,
                                                            'ORDER': 8,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 200}},
                        'ATTRIBUTE_MAP': {'ENTITY_ID': ('entity_poly', 'entity_id', None, None),
                                          'NSTD_CHIRALITY': ('entity_poly', 'nstd_chirality', None, None),
                                          'NSTD_LINKAGE': ('entity_poly', 'nstd_linkage', None, None),
                                          'NSTD_MONOMER': ('entity_poly', 'nstd_monomer', None, None),
                                          'NUMBER_OF_MONOMERS': ('entity_poly', 'number_of_monomers', None, None),
                                          'PDBX_SEQ_ONE_LETTER_CODE': ('entity_poly', 'pdbx_seq_one_letter_code', None, None),
                                          'PDBX_SEQ_ONE_LETTER_CODE_CAN': ('entity_poly',
                                                                           'pdbx_seq_one_letter_code_can',
                                                                           None,
                                                                           None),
                                          'PDBX_STRAND_ID': ('entity_poly', 'pdbx_strand_id', None, None),
                                          'PDBX_TARGET_IDENTIFIER': ('entity_poly', 'pdbx_target_identifier', None, None),
                                          'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                          'TYPE': ('entity_poly', 'type', None, None),
                                          'TYPE_DETAILS': ('entity_poly', 'type_details', None, None)},
                        'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTITY_ID'), 'TYPE': 'UNIQUE'},
                                    's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                        'MAP_MERGE_INDICES': {'entity_poly': {'ATTRIBUTES': ('entity_id',), 'TYPE': 'EQUI-JOIN'}},
                        'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                        'TABLE_ID': 'ENTITY_POLY',
                        'TABLE_NAME': 'entity_poly',
                        'TABLE_TYPE': 'transactional'},
        'ENTITY_POLY_SEQ': {'ATTRIBUTES': {'ENTITY_ID': 'entity_id',
                                           'HETERO': 'hetero',
                                           'MON_ID': 'mon_id',
                                           'NUM': 'num',
                                           'STRUCTURE_ID': 'Structure_ID'},
                            'ATTRIBUTE_INFO': {'ENTITY_ID': {'NULLABLE': False,
                                                             'ORDER': 3,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 10},
                                               'HETERO': {'NULLABLE': True,
                                                          'ORDER': 4,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 10},
                                               'MON_ID': {'NULLABLE': False,
                                                          'ORDER': 2,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': True,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 10},
                                               'NUM': {'NULLABLE': False,
                                                       'ORDER': 5,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': True,
                                                       'SQL_TYPE': 'INT',
                                                       'WIDTH': 10},
                                               'STRUCTURE_ID': {'NULLABLE': False,
                                                                'ORDER': 1,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10}},
                            'ATTRIBUTE_MAP': {'ENTITY_ID': ('entity_poly_seq', 'entity_id', None, None),
                                              'HETERO': ('entity_poly_seq', 'hetero', None, None),
                                              'MON_ID': ('entity_poly_seq', 'mon_id', None, None),
                                              'NUM': ('entity_poly_seq', 'num', None, None),
                                              'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                            'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'MON_ID', 'ENTITY_ID', 'NUM'), 'TYPE': 'UNIQUE'},
                                        's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                            'MAP_MERGE_INDICES': {'entity_poly_seq': {'ATTRIBUTES': ('mon_id', 'entity_id', 'num'),
                                                                      'TYPE': 'EQUI-JOIN'}},
                            'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                            'TABLE_ID': 'ENTITY_POLY_SEQ',
                            'TABLE_NAME': 'entity_poly_seq',
                            'TABLE_TYPE': 'transactional'},
        'ENTITY_SRC_GEN': {'ATTRIBUTES': {'ENTITY_ID': 'entity_id',
                                          'EXPRESSION_SYSTEM_ID': 'expression_system_id',
                                          'GENE_SRC_COMMON_NAME': 'gene_src_common_name',
                                          'GENE_SRC_DETAILS': 'gene_src_details',
                                          'GENE_SRC_DEV_STAGE': 'gene_src_dev_stage',
                                          'GENE_SRC_GENUS': 'gene_src_genus',
                                          'GENE_SRC_SPECIES': 'gene_src_species',
                                          'GENE_SRC_STRAIN': 'gene_src_strain',
                                          'GENE_SRC_TISSUE': 'gene_src_tissue',
                                          'GENE_SRC_TISSUE_FRACTION': 'gene_src_tissue_fraction',
                                          'HOST_ORG_COMMON_NAME': 'host_org_common_name',
                                          'HOST_ORG_DETAILS': 'host_org_details',
                                          'HOST_ORG_GENUS': 'host_org_genus',
                                          'HOST_ORG_SPECIES': 'host_org_species',
                                          'HOST_ORG_STRAIN': 'host_org_strain',
                                          'PDBX_DESCRIPTION': 'pdbx_description',
                                          'PDBX_GENE_SRC_ATCC': 'pdbx_gene_src_atcc',
                                          'PDBX_GENE_SRC_CELL': 'pdbx_gene_src_cell',
                                          'PDBX_GENE_SRC_CELLULAR_LOCATION': 'pdbx_gene_src_cellular_location',
                                          'PDBX_GENE_SRC_CELL_LINE': 'pdbx_gene_src_cell_line',
                                          'PDBX_GENE_SRC_FRAGMENT': 'pdbx_gene_src_fragment',
                                          'PDBX_GENE_SRC_GENE': 'pdbx_gene_src_gene',
                                          'PDBX_GENE_SRC_NCBI_TAXONOMY_ID': 'pdbx_gene_src_ncbi_taxonomy_id',
                                          'PDBX_GENE_SRC_ORGAN': 'pdbx_gene_src_organ',
                                          'PDBX_GENE_SRC_ORGANELLE': 'pdbx_gene_src_organelle',
                                          'PDBX_GENE_SRC_PLASMID': 'pdbx_gene_src_plasmid',
                                          'PDBX_GENE_SRC_PLASMID_NAME': 'pdbx_gene_src_plasmid_name',
                                          'PDBX_GENE_SRC_SCIENTIFIC_NAME': 'pdbx_gene_src_scientific_name',
                                          'PDBX_GENE_SRC_VARIANT': 'pdbx_gene_src_variant',
                                          'PDBX_HOST_ORG_ATCC': 'pdbx_host_org_atcc',
                                          'PDBX_HOST_ORG_CELL': 'pdbx_host_org_cell',
                                          'PDBX_HOST_ORG_CELLULAR_LOCATION': 'pdbx_host_org_cellular_location',
                                          'PDBX_HOST_ORG_CELL_LINE': 'pdbx_host_org_cell_line',
                                          'PDBX_HOST_ORG_CULTURE_COLLECTION': 'pdbx_host_org_culture_collection',
                                          'PDBX_HOST_ORG_GENE': 'pdbx_host_org_gene',
                                          'PDBX_HOST_ORG_NCBI_TAXONOMY_ID': 'pdbx_host_org_ncbi_taxonomy_id',
                                          'PDBX_HOST_ORG_ORGAN': 'pdbx_host_org_organ',
                                          'PDBX_HOST_ORG_ORGANELLE': 'pdbx_host_org_organelle',
                                          'PDBX_HOST_ORG_SCIENTIFIC_NAME': 'pdbx_host_org_scientific_name',
                                          'PDBX_HOST_ORG_STRAIN': 'pdbx_host_org_strain',
                                          'PDBX_HOST_ORG_TISSUE': 'pdbx_host_org_tissue',
                                          'PDBX_HOST_ORG_TISSUE_FRACTION': 'pdbx_host_org_tissue_fraction',
                                          'PDBX_HOST_ORG_VARIANT': 'pdbx_host_org_variant',
                                          'PDBX_HOST_ORG_VECTOR': 'pdbx_host_org_vector',
                                          'PDBX_HOST_ORG_VECTOR_TYPE': 'pdbx_host_org_vector_type',
                                          'PLASMID_DETAILS': 'plasmid_details',
                                          'PLASMID_NAME': 'plasmid_name',
                                          'START_CONSTRUCT_ID': 'start_construct_id',
                                          'STRUCTURE_ID': 'Structure_ID'},
                           'ATTRIBUTE_INFO': {'ENTITY_ID': {'NULLABLE': False,
                                                            'ORDER': 2,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': True,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 10},
                                              'EXPRESSION_SYSTEM_ID': {'NULLABLE': True,
                                                                       'ORDER': 45,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 80},
                                              'GENE_SRC_COMMON_NAME': {'NULLABLE': True,
                                                                       'ORDER': 3,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 200},
                                              'GENE_SRC_DETAILS': {'NULLABLE': True,
                                                                   'ORDER': 4,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 511},
                                              'GENE_SRC_DEV_STAGE': {'NULLABLE': True,
                                                                     'ORDER': 46,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 200},
                                              'GENE_SRC_GENUS': {'NULLABLE': True,
                                                                 'ORDER': 5,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 200},
                                              'GENE_SRC_SPECIES': {'NULLABLE': True,
                                                                   'ORDER': 6,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 200},
                                              'GENE_SRC_STRAIN': {'NULLABLE': True,
                                                                  'ORDER': 7,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 511},
                                              'GENE_SRC_TISSUE': {'NULLABLE': True,
                                                                  'ORDER': 8,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 200},
                                              'GENE_SRC_TISSUE_FRACTION': {'NULLABLE': True,
                                                                           'ORDER': 9,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 200},
                                              'HOST_ORG_COMMON_NAME': {'NULLABLE': True,
                                                                       'ORDER': 31,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 200},
                                              'HOST_ORG_DETAILS': {'NULLABLE': True,
                                                                   'ORDER': 32,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 200},
                                              'HOST_ORG_GENUS': {'NULLABLE': True,
                                                                 'ORDER': 10,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 200},
                                              'HOST_ORG_SPECIES': {'NULLABLE': True,
                                                                   'ORDER': 11,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 200},
                                              'HOST_ORG_STRAIN': {'NULLABLE': True,
                                                                  'ORDER': 33,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 200},
                                              'PDBX_DESCRIPTION': {'NULLABLE': True,
                                                                   'ORDER': 30,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 4095},
                                              'PDBX_GENE_SRC_ATCC': {'NULLABLE': True,
                                                                     'ORDER': 17,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 200},
                                              'PDBX_GENE_SRC_CELL': {'NULLABLE': True,
                                                                     'ORDER': 22,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 200},
                                              'PDBX_GENE_SRC_CELLULAR_LOCATION': {'NULLABLE': True,
                                                                                  'ORDER': 23,
                                                                                  'PRECISION': 0,
                                                                                  'PRIMARY_KEY': False,
                                                                                  'SQL_TYPE': 'VARCHAR',
                                                                                  'WIDTH': 200},
                                              'PDBX_GENE_SRC_CELL_LINE': {'NULLABLE': True,
                                                                          'ORDER': 16,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 200},
                                              'PDBX_GENE_SRC_FRAGMENT': {'NULLABLE': True,
                                                                         'ORDER': 12,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 200},
                                              'PDBX_GENE_SRC_GENE': {'NULLABLE': True,
                                                                     'ORDER': 13,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 511},
                                              'PDBX_GENE_SRC_NCBI_TAXONOMY_ID': {'NULLABLE': True,
                                                                                 'ORDER': 48,
                                                                                 'PRECISION': 0,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'VARCHAR',
                                                                                 'WIDTH': 80},
                                              'PDBX_GENE_SRC_ORGAN': {'NULLABLE': True,
                                                                      'ORDER': 18,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 200},
                                              'PDBX_GENE_SRC_ORGANELLE': {'NULLABLE': True,
                                                                          'ORDER': 19,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 200},
                                              'PDBX_GENE_SRC_PLASMID': {'NULLABLE': True,
                                                                        'ORDER': 20,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 200},
                                              'PDBX_GENE_SRC_PLASMID_NAME': {'NULLABLE': True,
                                                                             'ORDER': 21,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 200},
                                              'PDBX_GENE_SRC_SCIENTIFIC_NAME': {'NULLABLE': True,
                                                                                'ORDER': 14,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 200},
                                              'PDBX_GENE_SRC_VARIANT': {'NULLABLE': True,
                                                                        'ORDER': 15,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 200},
                                              'PDBX_HOST_ORG_ATCC': {'NULLABLE': True,
                                                                     'ORDER': 38,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 200},
                                              'PDBX_HOST_ORG_CELL': {'NULLABLE': True,
                                                                     'ORDER': 40,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 200},
                                              'PDBX_HOST_ORG_CELLULAR_LOCATION': {'NULLABLE': True,
                                                                                  'ORDER': 27,
                                                                                  'PRECISION': 0,
                                                                                  'PRIMARY_KEY': False,
                                                                                  'SQL_TYPE': 'VARCHAR',
                                                                                  'WIDTH': 200},
                                              'PDBX_HOST_ORG_CELL_LINE': {'NULLABLE': True,
                                                                          'ORDER': 37,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 200},
                                              'PDBX_HOST_ORG_CULTURE_COLLECTION': {'NULLABLE': True,
                                                                                   'ORDER': 39,
                                                                                   'PRECISION': 0,
                                                                                   'PRIMARY_KEY': False,
                                                                                   'SQL_TYPE': 'VARCHAR',
                                                                                   'WIDTH': 200},
                                              'PDBX_HOST_ORG_GENE': {'NULLABLE': True,
                                                                     'ORDER': 24,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 200},
                                              'PDBX_HOST_ORG_NCBI_TAXONOMY_ID': {'NULLABLE': True,
                                                                                 'ORDER': 49,
                                                                                 'PRECISION': 0,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'VARCHAR',
                                                                                 'WIDTH': 80},
                                              'PDBX_HOST_ORG_ORGAN': {'NULLABLE': True,
                                                                      'ORDER': 25,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 200},
                                              'PDBX_HOST_ORG_ORGANELLE': {'NULLABLE': True,
                                                                          'ORDER': 26,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 200},
                                              'PDBX_HOST_ORG_SCIENTIFIC_NAME': {'NULLABLE': True,
                                                                                'ORDER': 41,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 200},
                                              'PDBX_HOST_ORG_STRAIN': {'NULLABLE': True,
                                                                       'ORDER': 28,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 200},
                                              'PDBX_HOST_ORG_TISSUE': {'NULLABLE': True,
                                                                       'ORDER': 42,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 200},
                                              'PDBX_HOST_ORG_TISSUE_FRACTION': {'NULLABLE': True,
                                                                                'ORDER': 29,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 200},
                                              'PDBX_HOST_ORG_VARIANT': {'NULLABLE': True,
                                                                        'ORDER': 36,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 200},
                                              'PDBX_HOST_ORG_VECTOR': {'NULLABLE': True,
                                                                       'ORDER': 43,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 200},
                                              'PDBX_HOST_ORG_VECTOR_TYPE': {'NULLABLE': True,
                                                                            'ORDER': 44,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 200},
                                              'PLASMID_DETAILS': {'NULLABLE': True,
                                                                  'ORDER': 34,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 511},
                                              'PLASMID_NAME': {'NULLABLE': True,
                                                               'ORDER': 35,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 200},
                                              'START_CONSTRUCT_ID': {'NULLABLE': True,
                                                                     'ORDER': 47,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                              'STRUCTURE_ID': {'NULLABLE': False,
                                                               'ORDER': 1,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10}},
                           'ATTRIBUTE_MAP': {'ENTITY_ID': ('entity_src_gen', 'entity_id', None, None),
                                             'EXPRESSION_SYSTEM_ID': ('entity_src_gen', 'expression_system_id', None, None),
                                             'GENE_SRC_COMMON_NAME': ('entity_src_gen', 'gene_src_common_name', None, None),
                                             'GENE_SRC_DETAILS': ('entity_src_gen', 'gene_src_details', None, None),
                                             'GENE_SRC_DEV_STAGE': ('entity_src_gen', 'gene_src_dev_stage', None, None),
                                             'GENE_SRC_GENUS': ('entity_src_gen', 'gene_src_genus', None, None),
                                             'GENE_SRC_SPECIES': ('entity_src_gen', 'gene_src_species', None, None),
                                             'GENE_SRC_STRAIN': ('entity_src_gen', 'gene_src_strain', None, None),
                                             'GENE_SRC_TISSUE': ('entity_src_gen', 'gene_src_tissue', None, None),
                                             'GENE_SRC_TISSUE_FRACTION': ('entity_src_gen',
                                                                          'gene_src_tissue_fraction',
                                                                          None,
                                                                          None),
                                             'HOST_ORG_COMMON_NAME': ('entity_src_gen', 'host_org_common_name', None, None),
                                             'HOST_ORG_DETAILS': ('entity_src_gen', 'host_org_details', None, None),
                                             'HOST_ORG_GENUS': ('entity_src_gen', 'host_org_genus', None, None),
                                             'HOST_ORG_SPECIES': ('entity_src_gen', 'host_org_species', None, None),
                                             'HOST_ORG_STRAIN': ('entity_src_gen', 'host_org_strain', None, None),
                                             'PDBX_DESCRIPTION': ('entity_src_gen', 'pdbx_description', None, None),
                                             'PDBX_GENE_SRC_ATCC': ('entity_src_gen', 'pdbx_gene_src_atcc', None, None),
                                             'PDBX_GENE_SRC_CELL': ('entity_src_gen', 'pdbx_gene_src_cell', None, None),
                                             'PDBX_GENE_SRC_CELLULAR_LOCATION': ('entity_src_gen',
                                                                                 'pdbx_gene_src_cellular_location',
                                                                                 None,
                                                                                 None),
                                             'PDBX_GENE_SRC_CELL_LINE': ('entity_src_gen',
                                                                         'pdbx_gene_src_cell_line',
                                                                         None,
                                                                         None),
                                             'PDBX_GENE_SRC_FRAGMENT': ('entity_src_gen',
                                                                        'pdbx_gene_src_fragment',
                                                                        None,
                                                                        None),
                                             'PDBX_GENE_SRC_GENE': ('entity_src_gen', 'pdbx_gene_src_gene', None, None),
                                             'PDBX_GENE_SRC_NCBI_TAXONOMY_ID': ('entity_src_gen',
                                                                                'pdbx_gene_src_ncbi_taxonomy_id',
                                                                                None,
                                                                                None),
                                             'PDBX_GENE_SRC_ORGAN': ('entity_src_gen', 'pdbx_gene_src_organ', None, None),
                                             'PDBX_GENE_SRC_ORGANELLE': ('entity_src_gen',
                                                                         'pdbx_gene_src_organelle',
                                                                         None,
                                                                         None),
                                             'PDBX_GENE_SRC_PLASMID': ('entity_src_gen', 'pdbx_gene_src_plasmid', None, None),
                                             'PDBX_GENE_SRC_PLASMID_NAME': ('entity_src_gen',
                                                                            'pdbx_gene_src_plasmid_name',
                                                                            None,
                                                                            None),
                                             'PDBX_GENE_SRC_SCIENTIFIC_NAME': ('entity_src_gen',
                                                                               'pdbx_gene_src_scientific_name',
                                                                               None,
                                                                               None),
                                             'PDBX_GENE_SRC_VARIANT': ('entity_src_gen', 'pdbx_gene_src_variant', None, None),
                                             'PDBX_HOST_ORG_ATCC': ('entity_src_gen', 'pdbx_host_org_atcc', None, None),
                                             'PDBX_HOST_ORG_CELL': ('entity_src_gen', 'pdbx_host_org_cell', None, None),
                                             'PDBX_HOST_ORG_CELLULAR_LOCATION': ('entity_src_gen',
                                                                                 'pdbx_host_org_cellular_location',
                                                                                 None,
                                                                                 None),
                                             'PDBX_HOST_ORG_CELL_LINE': ('entity_src_gen',
                                                                         'pdbx_host_org_cell_line',
                                                                         None,
                                                                         None),
                                             'PDBX_HOST_ORG_CULTURE_COLLECTION': ('entity_src_gen',
                                                                                  'pdbx_host_org_culture_collection',
                                                                                  None,
                                                                                  None),
                                             'PDBX_HOST_ORG_GENE': ('entity_src_gen', 'pdbx_host_org_gene', None, None),
                                             'PDBX_HOST_ORG_NCBI_TAXONOMY_ID': ('entity_src_gen',
                                                                                'pdbx_host_org_ncbi_taxonomy_id',
                                                                                None,
                                                                                None),
                                             'PDBX_HOST_ORG_ORGAN': ('entity_src_gen', 'pdbx_host_org_organ', None, None),
                                             'PDBX_HOST_ORG_ORGANELLE': ('entity_src_gen',
                                                                         'pdbx_host_org_organelle',
                                                                         None,
                                                                         None),
                                             'PDBX_HOST_ORG_SCIENTIFIC_NAME': ('entity_src_gen',
                                                                               'pdbx_host_org_scientific_name',
                                                                               None,
                                                                               None),
                                             'PDBX_HOST_ORG_STRAIN': ('entity_src_gen', 'pdbx_host_org_strain', None, None),
                                             'PDBX_HOST_ORG_TISSUE': ('entity_src_gen', 'pdbx_host_org_tissue', None, None),
                                             'PDBX_HOST_ORG_TISSUE_FRACTION': ('entity_src_gen',
                                                                               'pdbx_host_org_tissue_fraction',
                                                                               None,
                                                                               None),
                                             'PDBX_HOST_ORG_VARIANT': ('entity_src_gen', 'pdbx_host_org_variant', None, None),
                                             'PDBX_HOST_ORG_VECTOR': ('entity_src_gen', 'pdbx_host_org_vector', None, None),
                                             'PDBX_HOST_ORG_VECTOR_TYPE': ('entity_src_gen',
                                                                           'pdbx_host_org_vector_type',
                                                                           None,
                                                                           None),
                                             'PLASMID_DETAILS': ('entity_src_gen', 'plasmid_details', None, None),
                                             'PLASMID_NAME': ('entity_src_gen', 'plasmid_name', None, None),
                                             'START_CONSTRUCT_ID': ('entity_src_gen', 'start_construct_id', None, None),
                                             'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                           'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTITY_ID'), 'TYPE': 'UNIQUE'},
                                       's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                           'MAP_MERGE_INDICES': {'entity_src_gen': {'ATTRIBUTES': ('entity_id',), 'TYPE': 'EQUI-JOIN'}},
                           'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                           'TABLE_ID': 'ENTITY_SRC_GEN',
                           'TABLE_NAME': 'entity_src_gen',
                           'TABLE_TYPE': 'transactional'},
        'ENTITY_SRC_NAT': {'ATTRIBUTES': {'COMMON_NAME': 'common_name',
                                          'DETAILS': 'details',
                                          'ENTITY_ID': 'entity_id',
                                          'GENUS': 'genus',
                                          'PDBX_ATCC': 'pdbx_atcc',
                                          'PDBX_CELL': 'pdbx_cell',
                                          'PDBX_CELLULAR_LOCATION': 'pdbx_cellular_location',
                                          'PDBX_CELL_LINE': 'pdbx_cell_line',
                                          'PDBX_FRAGMENT': 'pdbx_fragment',
                                          'PDBX_NCBI_TAXONOMY_ID': 'pdbx_ncbi_taxonomy_id',
                                          'PDBX_ORGAN': 'pdbx_organ',
                                          'PDBX_ORGANELLE': 'pdbx_organelle',
                                          'PDBX_ORGANISM_SCIENTIFIC': 'pdbx_organism_scientific',
                                          'PDBX_PLASMID_DETAILS': 'pdbx_plasmid_details',
                                          'PDBX_PLASMID_NAME': 'pdbx_plasmid_name',
                                          'PDBX_SECRETION': 'pdbx_secretion',
                                          'PDBX_VARIANT': 'pdbx_variant',
                                          'SPECIES': 'species',
                                          'STRAIN': 'strain',
                                          'STRUCTURE_ID': 'Structure_ID',
                                          'TISSUE': 'tissue',
                                          'TISSUE_FRACTION': 'tissue_fraction'},
                           'ATTRIBUTE_INFO': {'COMMON_NAME': {'NULLABLE': True,
                                                              'ORDER': 3,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 200},
                                              'DETAILS': {'NULLABLE': True,
                                                          'ORDER': 4,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 4095},
                                              'ENTITY_ID': {'NULLABLE': False,
                                                            'ORDER': 2,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': True,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 10},
                                              'GENUS': {'NULLABLE': True,
                                                        'ORDER': 5,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 200},
                                              'PDBX_ATCC': {'NULLABLE': True,
                                                            'ORDER': 15,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 200},
                                              'PDBX_CELL': {'NULLABLE': True,
                                                            'ORDER': 19,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 200},
                                              'PDBX_CELLULAR_LOCATION': {'NULLABLE': True,
                                                                         'ORDER': 16,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 200},
                                              'PDBX_CELL_LINE': {'NULLABLE': True,
                                                                 'ORDER': 14,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 200},
                                              'PDBX_FRAGMENT': {'NULLABLE': True,
                                                                'ORDER': 12,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 200},
                                              'PDBX_NCBI_TAXONOMY_ID': {'NULLABLE': True,
                                                                        'ORDER': 22,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 80},
                                              'PDBX_ORGAN': {'NULLABLE': True,
                                                             'ORDER': 17,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 200},
                                              'PDBX_ORGANELLE': {'NULLABLE': True,
                                                                 'ORDER': 18,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 200},
                                              'PDBX_ORGANISM_SCIENTIFIC': {'NULLABLE': True,
                                                                           'ORDER': 10,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 200},
                                              'PDBX_PLASMID_DETAILS': {'NULLABLE': True,
                                                                       'ORDER': 21,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 200},
                                              'PDBX_PLASMID_NAME': {'NULLABLE': True,
                                                                    'ORDER': 20,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 200},
                                              'PDBX_SECRETION': {'NULLABLE': True,
                                                                 'ORDER': 11,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 200},
                                              'PDBX_VARIANT': {'NULLABLE': True,
                                                               'ORDER': 13,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 200},
                                              'SPECIES': {'NULLABLE': True,
                                                          'ORDER': 6,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 200},
                                              'STRAIN': {'NULLABLE': True,
                                                         'ORDER': 7,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 1023},
                                              'STRUCTURE_ID': {'NULLABLE': False,
                                                               'ORDER': 1,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                              'TISSUE': {'NULLABLE': True,
                                                         'ORDER': 8,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 200},
                                              'TISSUE_FRACTION': {'NULLABLE': True,
                                                                  'ORDER': 9,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 200}},
                           'ATTRIBUTE_MAP': {'COMMON_NAME': ('entity_src_nat', 'common_name', None, None),
                                             'DETAILS': ('entity_src_nat', 'details', None, None),
                                             'ENTITY_ID': ('entity_src_nat', 'entity_id', None, None),
                                             'GENUS': ('entity_src_nat', 'genus', None, None),
                                             'PDBX_ATCC': ('entity_src_nat', 'pdbx_atcc', None, None),
                                             'PDBX_CELL': ('entity_src_nat', 'pdbx_cell', None, None),
                                             'PDBX_CELLULAR_LOCATION': ('entity_src_nat',
                                                                        'pdbx_cellular_location',
                                                                        None,
                                                                        None),
                                             'PDBX_CELL_LINE': ('entity_src_nat', 'pdbx_cell_line', None, None),
                                             'PDBX_FRAGMENT': ('entity_src_nat', 'pdbx_fragment', None, None),
                                             'PDBX_NCBI_TAXONOMY_ID': ('entity_src_nat', 'pdbx_ncbi_taxonomy_id', None, None),
                                             'PDBX_ORGAN': ('entity_src_nat', 'pdbx_organ', None, None),
                                             'PDBX_ORGANELLE': ('entity_src_nat', 'pdbx_organelle', None, None),
                                             'PDBX_ORGANISM_SCIENTIFIC': ('entity_src_nat',
                                                                          'pdbx_organism_scientific',
                                                                          None,
                                                                          None),
                                             'PDBX_PLASMID_DETAILS': ('entity_src_nat', 'pdbx_plasmid_details', None, None),
                                             'PDBX_PLASMID_NAME': ('entity_src_nat', 'pdbx_plasmid_name', None, None),
                                             'PDBX_SECRETION': ('entity_src_nat', 'pdbx_secretion', None, None),
                                             'PDBX_VARIANT': ('entity_src_nat', 'pdbx_variant', None, None),
                                             'SPECIES': ('entity_src_nat', 'species', None, None),
                                             'STRAIN': ('entity_src_nat', 'strain', None, None),
                                             'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                             'TISSUE': ('entity_src_nat', 'tissue', None, None),
                                             'TISSUE_FRACTION': ('entity_src_nat', 'tissue_fraction', None, None)},
                           'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTITY_ID'), 'TYPE': 'UNIQUE'},
                                       's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                           'MAP_MERGE_INDICES': {'entity_src_nat': {'ATTRIBUTES': ('entity_id',), 'TYPE': 'EQUI-JOIN'}},
                           'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                           'TABLE_ID': 'ENTITY_SRC_NAT',
                           'TABLE_NAME': 'entity_src_nat',
                           'TABLE_TYPE': 'transactional'},
        'ENTRY': {'ATTRIBUTES': {'ID': 'id', 'PDBX_DOI': 'pdbx_DOI', 'PDBX_PC': 'pdbx_pc', 'STRUCTURE_ID': 'Structure_ID'},
                  'ATTRIBUTE_INFO': {'ID': {'NULLABLE': False,
                                            'ORDER': 2,
                                            'PRECISION': 0,
                                            'PRIMARY_KEY': True,
                                            'SQL_TYPE': 'VARCHAR',
                                            'WIDTH': 10},
                                     'PDBX_DOI': {'NULLABLE': True,
                                                  'ORDER': 3,
                                                  'PRECISION': 0,
                                                  'PRIMARY_KEY': False,
                                                  'SQL_TYPE': 'VARCHAR',
                                                  'WIDTH': 10},
                                     'PDBX_PC': {'NULLABLE': True,
                                                 'ORDER': 4,
                                                 'PRECISION': 0,
                                                 'PRIMARY_KEY': False,
                                                 'SQL_TYPE': 'VARCHAR',
                                                 'WIDTH': 10},
                                     'STRUCTURE_ID': {'NULLABLE': False,
                                                      'ORDER': 1,
                                                      'PRECISION': 0,
                                                      'PRIMARY_KEY': True,
                                                      'SQL_TYPE': 'VARCHAR',
                                                      'WIDTH': 10}},
                  'ATTRIBUTE_MAP': {'ID': ('entry', 'id', None, None),
                                    'PDBX_DOI': ('entry', 'pdbx_DOI', None, None),
                                    'PDBX_PC': ('entry', 'pdbx_pc', None, None),
                                    'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                  'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                              's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                  'MAP_MERGE_INDICES': {'entry': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                  'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                  'TABLE_ID': 'ENTRY',
                  'TABLE_NAME': 'entry',
                  'TABLE_TYPE': 'transactional'},
        'ENTRY_LINK': {'ATTRIBUTES': {'DETAILS': 'details',
                                      'ENTRY_ID': 'entry_id',
                                      'ID': 'id',
                                      'STRUCTURE_ID': 'Structure_ID'},
                       'ATTRIBUTE_INFO': {'DETAILS': {'NULLABLE': True,
                                                      'ORDER': 4,
                                                      'PRECISION': 0,
                                                      'PRIMARY_KEY': False,
                                                      'SQL_TYPE': 'VARCHAR',
                                                      'WIDTH': 200},
                                          'ENTRY_ID': {'NULLABLE': False,
                                                       'ORDER': 2,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': True,
                                                       'SQL_TYPE': 'VARCHAR',
                                                       'WIDTH': 10},
                                          'ID': {'NULLABLE': False,
                                                 'ORDER': 3,
                                                 'PRECISION': 0,
                                                 'PRIMARY_KEY': True,
                                                 'SQL_TYPE': 'VARCHAR',
                                                 'WIDTH': 10},
                                          'STRUCTURE_ID': {'NULLABLE': False,
                                                           'ORDER': 1,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': True,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 10}},
                       'ATTRIBUTE_MAP': {'DETAILS': ('entry_link', 'details', None, None),
                                         'ENTRY_ID': ('entry_link', 'entry_id', None, None),
                                         'ID': ('entry_link', 'id', None, None),
                                         'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                       'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                   's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                       'MAP_MERGE_INDICES': {'entry_link': {'ATTRIBUTES': ('entry_id', 'id'), 'TYPE': 'EQUI-JOIN'}},
                       'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                       'TABLE_ID': 'ENTRY_LINK',
                       'TABLE_NAME': 'entry_link',
                       'TABLE_TYPE': 'transactional'},
        'EXPTL': {'ATTRIBUTES': {'ABSORPT_COEFFICIENT_MU': 'absorpt_coefficient_mu',
                                 'ABSORPT_CORRECTION_TYPE': 'absorpt_correction_type',
                                 'ABSORPT_CORRECTION_T_MAX': 'absorpt_correction_T_max',
                                 'ABSORPT_CORRECTION_T_MIN': 'absorpt_correction_T_min',
                                 'ABSORPT_PROCESS_DETAILS': 'absorpt_process_details',
                                 'CRYSTALS_NUMBER': 'crystals_number',
                                 'DETAILS': 'details',
                                 'ENTRY_ID': 'entry_id',
                                 'METHOD': 'method',
                                 'METHOD_DETAILS': 'method_details',
                                 'STRUCTURE_ID': 'Structure_ID'},
                  'ATTRIBUTE_INFO': {'ABSORPT_COEFFICIENT_MU': {'NULLABLE': True,
                                                                'ORDER': 3,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                     'ABSORPT_CORRECTION_TYPE': {'NULLABLE': True,
                                                                 'ORDER': 6,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                     'ABSORPT_CORRECTION_T_MAX': {'NULLABLE': True,
                                                                  'ORDER': 4,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10},
                                     'ABSORPT_CORRECTION_T_MIN': {'NULLABLE': True,
                                                                  'ORDER': 5,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10},
                                     'ABSORPT_PROCESS_DETAILS': {'NULLABLE': True,
                                                                 'ORDER': 7,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 200},
                                     'CRYSTALS_NUMBER': {'NULLABLE': True,
                                                         'ORDER': 8,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'INT',
                                                         'WIDTH': 10},
                                     'DETAILS': {'NULLABLE': True,
                                                 'ORDER': 9,
                                                 'PRECISION': 0,
                                                 'PRIMARY_KEY': False,
                                                 'SQL_TYPE': 'VARCHAR',
                                                 'WIDTH': 1023},
                                     'ENTRY_ID': {'NULLABLE': False,
                                                  'ORDER': 2,
                                                  'PRECISION': 0,
                                                  'PRIMARY_KEY': True,
                                                  'SQL_TYPE': 'VARCHAR',
                                                  'WIDTH': 10},
                                     'METHOD': {'NULLABLE': False,
                                                'ORDER': 10,
                                                'PRECISION': 0,
                                                'PRIMARY_KEY': True,
                                                'SQL_TYPE': 'VARCHAR',
                                                'WIDTH': 80},
                                     'METHOD_DETAILS': {'NULLABLE': True,
                                                        'ORDER': 11,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 200},
                                     'STRUCTURE_ID': {'NULLABLE': False,
                                                      'ORDER': 1,
                                                      'PRECISION': 0,
                                                      'PRIMARY_KEY': True,
                                                      'SQL_TYPE': 'VARCHAR',
                                                      'WIDTH': 10}},
                  'ATTRIBUTE_MAP': {'ABSORPT_COEFFICIENT_MU': ('exptl', 'absorpt_coefficient_mu', None, None),
                                    'ABSORPT_CORRECTION_TYPE': ('exptl', 'absorpt_correction_type', None, None),
                                    'ABSORPT_CORRECTION_T_MAX': ('exptl', 'absorpt_correction_T_max', None, None),
                                    'ABSORPT_CORRECTION_T_MIN': ('exptl', 'absorpt_correction_T_min', None, None),
                                    'ABSORPT_PROCESS_DETAILS': ('exptl', 'absorpt_process_details', None, None),
                                    'CRYSTALS_NUMBER': ('exptl', 'crystals_number', None, None),
                                    'DETAILS': ('exptl', 'details', None, None),
                                    'ENTRY_ID': ('exptl', 'entry_id', None, None),
                                    'METHOD': ('exptl', 'method', None, None),
                                    'METHOD_DETAILS': ('exptl', 'method_details', None, None),
                                    'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                  'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID', 'METHOD'), 'TYPE': 'UNIQUE'},
                              's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                  'MAP_MERGE_INDICES': {'exptl': {'ATTRIBUTES': ('entry_id', 'method'), 'TYPE': 'EQUI-JOIN'}},
                  'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                  'TABLE_ID': 'EXPTL',
                  'TABLE_NAME': 'exptl',
                  'TABLE_TYPE': 'transactional'},
        'EXPTL_CRYSTAL': {'ATTRIBUTES': {'COLOUR': 'colour',
                                         'COLOUR_LUSTRE': 'colour_lustre',
                                         'COLOUR_MODIFIER': 'colour_modifier',
                                         'COLOUR_PRIMARY': 'colour_primary',
                                         'DENSITY_DIFFRN': 'density_diffrn',
                                         'DENSITY_MATTHEWS': 'density_Matthews',
                                         'DENSITY_MEAS': 'density_meas',
                                         'DENSITY_MEAS_ESD': 'density_meas_esd',
                                         'DENSITY_MEAS_GT': 'density_meas_gt',
                                         'DENSITY_MEAS_LT': 'density_meas_lt',
                                         'DENSITY_MEAS_TEMP': 'density_meas_temp',
                                         'DENSITY_MEAS_TEMP_ESD': 'density_meas_temp_esd',
                                         'DENSITY_MEAS_TEMP_GT': 'density_meas_temp_gt',
                                         'DENSITY_MEAS_TEMP_LT': 'density_meas_temp_lt',
                                         'DENSITY_METHOD': 'density_method',
                                         'DENSITY_PERCENT_SOL': 'density_percent_sol',
                                         'DESCRIPTION': 'description',
                                         'F_000': 'F_000',
                                         'ID': 'id',
                                         'PDBX_CRYSTAL_IMAGE_FORMAT': 'pdbx_crystal_image_format',
                                         'PDBX_CRYSTAL_IMAGE_URL': 'pdbx_crystal_image_url',
                                         'PDBX_MOSAICITY': 'pdbx_mosaicity',
                                         'PDBX_MOSAICITY_ESD': 'pdbx_mosaicity_esd',
                                         'PREPARATION': 'preparation',
                                         'SIZE_MAX': 'size_max',
                                         'SIZE_MID': 'size_mid',
                                         'SIZE_MIN': 'size_min',
                                         'SIZE_RAD': 'size_rad',
                                         'STRUCTURE_ID': 'Structure_ID'},
                          'ATTRIBUTE_INFO': {'COLOUR': {'NULLABLE': True,
                                                        'ORDER': 2,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 80},
                                             'COLOUR_LUSTRE': {'NULLABLE': True,
                                                               'ORDER': 15,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 80},
                                             'COLOUR_MODIFIER': {'NULLABLE': True,
                                                                 'ORDER': 16,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 80},
                                             'COLOUR_PRIMARY': {'NULLABLE': True,
                                                                'ORDER': 17,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 80},
                                             'DENSITY_DIFFRN': {'NULLABLE': True,
                                                                'ORDER': 3,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                             'DENSITY_MATTHEWS': {'NULLABLE': True,
                                                                  'ORDER': 4,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10},
                                             'DENSITY_MEAS': {'NULLABLE': True,
                                                              'ORDER': 18,
                                                              'PRECISION': 6,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'FLOAT',
                                                              'WIDTH': 10},
                                             'DENSITY_MEAS_ESD': {'NULLABLE': True,
                                                                  'ORDER': 19,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10},
                                             'DENSITY_MEAS_GT': {'NULLABLE': True,
                                                                 'ORDER': 20,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                             'DENSITY_MEAS_LT': {'NULLABLE': True,
                                                                 'ORDER': 21,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                             'DENSITY_MEAS_TEMP': {'NULLABLE': True,
                                                                   'ORDER': 22,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                             'DENSITY_MEAS_TEMP_ESD': {'NULLABLE': True,
                                                                       'ORDER': 23,
                                                                       'PRECISION': 6,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'FLOAT',
                                                                       'WIDTH': 10},
                                             'DENSITY_MEAS_TEMP_GT': {'NULLABLE': True,
                                                                      'ORDER': 24,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                             'DENSITY_MEAS_TEMP_LT': {'NULLABLE': True,
                                                                      'ORDER': 25,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                             'DENSITY_METHOD': {'NULLABLE': True,
                                                                'ORDER': 5,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 200},
                                             'DENSITY_PERCENT_SOL': {'NULLABLE': True,
                                                                     'ORDER': 6,
                                                                     'PRECISION': 6,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'FLOAT',
                                                                     'WIDTH': 10},
                                             'DESCRIPTION': {'NULLABLE': True,
                                                             'ORDER': 7,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 4095},
                                             'F_000': {'NULLABLE': True,
                                                       'ORDER': 8,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'INT',
                                                       'WIDTH': 10},
                                             'ID': {'NULLABLE': False,
                                                    'ORDER': 9,
                                                    'PRECISION': 0,
                                                    'PRIMARY_KEY': True,
                                                    'SQL_TYPE': 'VARCHAR',
                                                    'WIDTH': 10},
                                             'PDBX_CRYSTAL_IMAGE_FORMAT': {'NULLABLE': True,
                                                                           'ORDER': 27,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 80},
                                             'PDBX_CRYSTAL_IMAGE_URL': {'NULLABLE': True,
                                                                        'ORDER': 26,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 80},
                                             'PDBX_MOSAICITY': {'NULLABLE': True,
                                                                'ORDER': 28,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                             'PDBX_MOSAICITY_ESD': {'NULLABLE': True,
                                                                    'ORDER': 29,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                             'PREPARATION': {'NULLABLE': True,
                                                             'ORDER': 10,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 200},
                                             'SIZE_MAX': {'NULLABLE': True,
                                                          'ORDER': 11,
                                                          'PRECISION': 6,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'FLOAT',
                                                          'WIDTH': 10},
                                             'SIZE_MID': {'NULLABLE': True,
                                                          'ORDER': 12,
                                                          'PRECISION': 6,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'FLOAT',
                                                          'WIDTH': 10},
                                             'SIZE_MIN': {'NULLABLE': True,
                                                          'ORDER': 13,
                                                          'PRECISION': 6,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'FLOAT',
                                                          'WIDTH': 10},
                                             'SIZE_RAD': {'NULLABLE': True,
                                                          'ORDER': 14,
                                                          'PRECISION': 6,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'FLOAT',
                                                          'WIDTH': 10},
                                             'STRUCTURE_ID': {'NULLABLE': False,
                                                              'ORDER': 1,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10}},
                          'ATTRIBUTE_MAP': {'COLOUR': ('exptl_crystal', 'colour', None, None),
                                            'COLOUR_LUSTRE': ('exptl_crystal', 'colour_lustre', None, None),
                                            'COLOUR_MODIFIER': ('exptl_crystal', 'colour_modifier', None, None),
                                            'COLOUR_PRIMARY': ('exptl_crystal', 'colour_primary', None, None),
                                            'DENSITY_DIFFRN': ('exptl_crystal', 'density_diffrn', None, None),
                                            'DENSITY_MATTHEWS': ('exptl_crystal', 'density_Matthews', None, None),
                                            'DENSITY_MEAS': ('exptl_crystal', 'density_meas', None, None),
                                            'DENSITY_MEAS_ESD': ('exptl_crystal', 'density_meas_esd', None, None),
                                            'DENSITY_MEAS_GT': ('exptl_crystal', 'density_meas_gt', None, None),
                                            'DENSITY_MEAS_LT': ('exptl_crystal', 'density_meas_lt', None, None),
                                            'DENSITY_MEAS_TEMP': ('exptl_crystal', 'density_meas_temp', None, None),
                                            'DENSITY_MEAS_TEMP_ESD': ('exptl_crystal', 'density_meas_temp_esd', None, None),
                                            'DENSITY_MEAS_TEMP_GT': ('exptl_crystal', 'density_meas_temp_gt', None, None),
                                            'DENSITY_MEAS_TEMP_LT': ('exptl_crystal', 'density_meas_temp_lt', None, None),
                                            'DENSITY_METHOD': ('exptl_crystal', 'density_method', None, None),
                                            'DENSITY_PERCENT_SOL': ('exptl_crystal', 'density_percent_sol', None, None),
                                            'DESCRIPTION': ('exptl_crystal', 'description', None, None),
                                            'F_000': ('exptl_crystal', 'F_000', None, None),
                                            'ID': ('exptl_crystal', 'id', None, None),
                                            'PDBX_CRYSTAL_IMAGE_FORMAT': ('exptl_crystal',
                                                                          'pdbx_crystal_image_format',
                                                                          None,
                                                                          None),
                                            'PDBX_CRYSTAL_IMAGE_URL': ('exptl_crystal', 'pdbx_crystal_image_url', None, None),
                                            'PDBX_MOSAICITY': ('exptl_crystal', 'pdbx_mosaicity', None, None),
                                            'PDBX_MOSAICITY_ESD': ('exptl_crystal', 'pdbx_mosaicity_esd', None, None),
                                            'PREPARATION': ('exptl_crystal', 'preparation', None, None),
                                            'SIZE_MAX': ('exptl_crystal', 'size_max', None, None),
                                            'SIZE_MID': ('exptl_crystal', 'size_mid', None, None),
                                            'SIZE_MIN': ('exptl_crystal', 'size_min', None, None),
                                            'SIZE_RAD': ('exptl_crystal', 'size_rad', None, None),
                                            'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                          'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                      's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                          'MAP_MERGE_INDICES': {'exptl_crystal': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                          'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                          'TABLE_ID': 'EXPTL_CRYSTAL',
                          'TABLE_NAME': 'exptl_crystal',
                          'TABLE_TYPE': 'transactional'},
        'EXPTL_CRYSTAL_FACE': {'ATTRIBUTES': {'CRYSTAL_ID': 'crystal_id',
                                              'DIFFR_CHI': 'diffr_chi',
                                              'DIFFR_KAPPA': 'diffr_kappa',
                                              'DIFFR_PHI': 'diffr_phi',
                                              'DIFFR_PSI': 'diffr_psi',
                                              'INDEX_H': 'index_h',
                                              'INDEX_K': 'index_k',
                                              'INDEX_L': 'index_l',
                                              'PERP_DIST': 'perp_dist',
                                              'STRUCTURE_ID': 'Structure_ID'},
                               'ATTRIBUTE_INFO': {'CRYSTAL_ID': {'NULLABLE': False,
                                                                 'ORDER': 2,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': True,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                                  'DIFFR_CHI': {'NULLABLE': True,
                                                                'ORDER': 3,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                                  'DIFFR_KAPPA': {'NULLABLE': True,
                                                                  'ORDER': 4,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10},
                                                  'DIFFR_PHI': {'NULLABLE': True,
                                                                'ORDER': 5,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                                  'DIFFR_PSI': {'NULLABLE': True,
                                                                'ORDER': 6,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                                  'INDEX_H': {'NULLABLE': False,
                                                              'ORDER': 7,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'INT',
                                                              'WIDTH': 10},
                                                  'INDEX_K': {'NULLABLE': False,
                                                              'ORDER': 8,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'INT',
                                                              'WIDTH': 10},
                                                  'INDEX_L': {'NULLABLE': False,
                                                              'ORDER': 9,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'INT',
                                                              'WIDTH': 10},
                                                  'PERP_DIST': {'NULLABLE': True,
                                                                'ORDER': 10,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                                  'STRUCTURE_ID': {'NULLABLE': False,
                                                                   'ORDER': 1,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': True,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 10}},
                               'ATTRIBUTE_MAP': {'CRYSTAL_ID': ('exptl_crystal_face', 'crystal_id', None, None),
                                                 'DIFFR_CHI': ('exptl_crystal_face', 'diffr_chi', None, None),
                                                 'DIFFR_KAPPA': ('exptl_crystal_face', 'diffr_kappa', None, None),
                                                 'DIFFR_PHI': ('exptl_crystal_face', 'diffr_phi', None, None),
                                                 'DIFFR_PSI': ('exptl_crystal_face', 'diffr_psi', None, None),
                                                 'INDEX_H': ('exptl_crystal_face', 'index_h', None, None),
                                                 'INDEX_K': ('exptl_crystal_face', 'index_k', None, None),
                                                 'INDEX_L': ('exptl_crystal_face', 'index_l', None, None),
                                                 'PERP_DIST': ('exptl_crystal_face', 'perp_dist', None, None),
                                                 'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                               'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID',
                                                                 'CRYSTAL_ID',
                                                                 'INDEX_H',
                                                                 'INDEX_K',
                                                                 'INDEX_L'),
                                                  'TYPE': 'UNIQUE'},
                                           's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                               'MAP_MERGE_INDICES': {'exptl_crystal_face': {'ATTRIBUTES': ('crystal_id',
                                                                                           'index_h',
                                                                                           'index_k',
                                                                                           'index_l'),
                                                                            'TYPE': 'EQUI-JOIN'}},
                               'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                               'TABLE_ID': 'EXPTL_CRYSTAL_FACE',
                               'TABLE_NAME': 'exptl_crystal_face',
                               'TABLE_TYPE': 'transactional'},
        'EXPTL_CRYSTAL_GROW': {'ATTRIBUTES': {'APPARATUS': 'apparatus',
                                              'ATMOSPHERE': 'atmosphere',
                                              'CRYSTAL_ID': 'crystal_id',
                                              'DETAILS': 'details',
                                              'METHOD': 'method',
                                              'METHOD_REF': 'method_ref',
                                              'PDBX_DETAILS': 'pdbx_details',
                                              'PDBX_PH_RANGE': 'pdbx_pH_range',
                                              'PH': 'pH',
                                              'PRESSURE': 'pressure',
                                              'PRESSURE_ESD': 'pressure_esd',
                                              'SEEDING': 'seeding',
                                              'SEEDING_REF': 'seeding_ref',
                                              'STRUCTURE_ID': 'Structure_ID',
                                              'TEMP': 'temp',
                                              'TEMP_DETAILS': 'temp_details',
                                              'TEMP_ESD': 'temp_esd',
                                              'TIME': 'time'},
                               'ATTRIBUTE_INFO': {'APPARATUS': {'NULLABLE': True,
                                                                'ORDER': 3,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 200},
                                                  'ATMOSPHERE': {'NULLABLE': True,
                                                                 'ORDER': 4,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 200},
                                                  'CRYSTAL_ID': {'NULLABLE': False,
                                                                 'ORDER': 2,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': True,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                                  'DETAILS': {'NULLABLE': True,
                                                              'ORDER': 5,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 200},
                                                  'METHOD': {'NULLABLE': True,
                                                             'ORDER': 6,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 200},
                                                  'METHOD_REF': {'NULLABLE': True,
                                                                 'ORDER': 7,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 200},
                                                  'PDBX_DETAILS': {'NULLABLE': True,
                                                                   'ORDER': 17,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 4095},
                                                  'PDBX_PH_RANGE': {'NULLABLE': True,
                                                                    'ORDER': 18,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 80},
                                                  'PH': {'NULLABLE': True,
                                                         'ORDER': 8,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                                  'PRESSURE': {'NULLABLE': True,
                                                               'ORDER': 9,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                                  'PRESSURE_ESD': {'NULLABLE': True,
                                                                   'ORDER': 10,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                                  'SEEDING': {'NULLABLE': True,
                                                              'ORDER': 11,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 200},
                                                  'SEEDING_REF': {'NULLABLE': True,
                                                                  'ORDER': 12,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 200},
                                                  'STRUCTURE_ID': {'NULLABLE': False,
                                                                   'ORDER': 1,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': True,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 10},
                                                  'TEMP': {'NULLABLE': True,
                                                           'ORDER': 13,
                                                           'PRECISION': 6,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'FLOAT',
                                                           'WIDTH': 10},
                                                  'TEMP_DETAILS': {'NULLABLE': True,
                                                                   'ORDER': 14,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 200},
                                                  'TEMP_ESD': {'NULLABLE': True,
                                                               'ORDER': 15,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                                  'TIME': {'NULLABLE': True,
                                                           'ORDER': 16,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 200}},
                               'ATTRIBUTE_MAP': {'APPARATUS': ('exptl_crystal_grow', 'apparatus', None, None),
                                                 'ATMOSPHERE': ('exptl_crystal_grow', 'atmosphere', None, None),
                                                 'CRYSTAL_ID': ('exptl_crystal_grow', 'crystal_id', None, None),
                                                 'DETAILS': ('exptl_crystal_grow', 'details', None, None),
                                                 'METHOD': ('exptl_crystal_grow', 'method', None, None),
                                                 'METHOD_REF': ('exptl_crystal_grow', 'method_ref', None, None),
                                                 'PDBX_DETAILS': ('exptl_crystal_grow', 'pdbx_details', None, None),
                                                 'PDBX_PH_RANGE': ('exptl_crystal_grow', 'pdbx_pH_range', None, None),
                                                 'PH': ('exptl_crystal_grow', 'pH', None, None),
                                                 'PRESSURE': ('exptl_crystal_grow', 'pressure', None, None),
                                                 'PRESSURE_ESD': ('exptl_crystal_grow', 'pressure_esd', None, None),
                                                 'SEEDING': ('exptl_crystal_grow', 'seeding', None, None),
                                                 'SEEDING_REF': ('exptl_crystal_grow', 'seeding_ref', None, None),
                                                 'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                 'TEMP': ('exptl_crystal_grow', 'temp', None, None),
                                                 'TEMP_DETAILS': ('exptl_crystal_grow', 'temp_details', None, None),
                                                 'TEMP_ESD': ('exptl_crystal_grow', 'temp_esd', None, None),
                                                 'TIME': ('exptl_crystal_grow', 'time', None, None)},
                               'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'CRYSTAL_ID'), 'TYPE': 'UNIQUE'},
                                           's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                               'MAP_MERGE_INDICES': {'exptl_crystal_grow': {'ATTRIBUTES': ('crystal_id',),
                                                                            'TYPE': 'EQUI-JOIN'}},
                               'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                               'TABLE_ID': 'EXPTL_CRYSTAL_GROW',
                               'TABLE_NAME': 'exptl_crystal_grow',
                               'TABLE_TYPE': 'transactional'},
        'EXPTL_CRYSTAL_GROW_COMP': {'ATTRIBUTES': {'CONC': 'conc',
                                                   'CRYSTAL_ID': 'crystal_id',
                                                   'DETAILS': 'details',
                                                   'ID': 'id',
                                                   'NAME': 'name',
                                                   'SOL_ID': 'sol_id',
                                                   'STRUCTURE_ID': 'Structure_ID',
                                                   'VOLUME': 'volume'},
                                    'ATTRIBUTE_INFO': {'CONC': {'NULLABLE': True,
                                                                'ORDER': 3,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 80},
                                                       'CRYSTAL_ID': {'NULLABLE': False,
                                                                      'ORDER': 2,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                                       'DETAILS': {'NULLABLE': True,
                                                                   'ORDER': 4,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 200},
                                                       'ID': {'NULLABLE': False,
                                                              'ORDER': 5,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 80},
                                                       'NAME': {'NULLABLE': True,
                                                                'ORDER': 6,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 128},
                                                       'SOL_ID': {'NULLABLE': True,
                                                                  'ORDER': 7,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 80},
                                                       'STRUCTURE_ID': {'NULLABLE': False,
                                                                        'ORDER': 1,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': True,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                                       'VOLUME': {'NULLABLE': True,
                                                                  'ORDER': 8,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 80}},
                                    'ATTRIBUTE_MAP': {'CONC': ('exptl_crystal_grow_comp', 'conc', None, None),
                                                      'CRYSTAL_ID': ('exptl_crystal_grow_comp', 'crystal_id', None, None),
                                                      'DETAILS': ('exptl_crystal_grow_comp', 'details', None, None),
                                                      'ID': ('exptl_crystal_grow_comp', 'id', None, None),
                                                      'NAME': ('exptl_crystal_grow_comp', 'name', None, None),
                                                      'SOL_ID': ('exptl_crystal_grow_comp', 'sol_id', None, None),
                                                      'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                      'VOLUME': ('exptl_crystal_grow_comp', 'volume', None, None)},
                                    'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'CRYSTAL_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                                's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                    'MAP_MERGE_INDICES': {'exptl_crystal_grow_comp': {'ATTRIBUTES': ('crystal_id', 'id'),
                                                                                      'TYPE': 'EQUI-JOIN'}},
                                    'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                    'TABLE_ID': 'EXPTL_CRYSTAL_GROW_COMP',
                                    'TABLE_NAME': 'exptl_crystal_grow_comp',
                                    'TABLE_TYPE': 'transactional'},
        'GEOM': {'ATTRIBUTES': {'DETAILS': 'details', 'ENTRY_ID': 'entry_id', 'STRUCTURE_ID': 'Structure_ID'},
                 'ATTRIBUTE_INFO': {'DETAILS': {'NULLABLE': True,
                                                'ORDER': 3,
                                                'PRECISION': 0,
                                                'PRIMARY_KEY': False,
                                                'SQL_TYPE': 'VARCHAR',
                                                'WIDTH': 200},
                                    'ENTRY_ID': {'NULLABLE': False,
                                                 'ORDER': 2,
                                                 'PRECISION': 0,
                                                 'PRIMARY_KEY': True,
                                                 'SQL_TYPE': 'VARCHAR',
                                                 'WIDTH': 10},
                                    'STRUCTURE_ID': {'NULLABLE': False,
                                                     'ORDER': 1,
                                                     'PRECISION': 0,
                                                     'PRIMARY_KEY': True,
                                                     'SQL_TYPE': 'VARCHAR',
                                                     'WIDTH': 10}},
                 'ATTRIBUTE_MAP': {'DETAILS': ('geom', 'details', None, None),
                                   'ENTRY_ID': ('geom', 'entry_id', None, None),
                                   'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                 'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID'), 'TYPE': 'UNIQUE'},
                             's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                 'MAP_MERGE_INDICES': {'geom': {'ATTRIBUTES': ('entry_id',), 'TYPE': 'EQUI-JOIN'}},
                 'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                 'TABLE_ID': 'GEOM',
                 'TABLE_NAME': 'geom',
                 'TABLE_TYPE': 'transactional'},
        'GEOM_ANGLE': {'ATTRIBUTES': {'ATOM_SITE_AUTH_ASYM_ID_1': 'atom_site_auth_asym_id_1',
                                      'ATOM_SITE_AUTH_ASYM_ID_2': 'atom_site_auth_asym_id_2',
                                      'ATOM_SITE_AUTH_ASYM_ID_3': 'atom_site_auth_asym_id_3',
                                      'ATOM_SITE_AUTH_ATOM_ID_1': 'atom_site_auth_atom_id_1',
                                      'ATOM_SITE_AUTH_ATOM_ID_2': 'atom_site_auth_atom_id_2',
                                      'ATOM_SITE_AUTH_ATOM_ID_3': 'atom_site_auth_atom_id_3',
                                      'ATOM_SITE_AUTH_COMP_ID_1': 'atom_site_auth_comp_id_1',
                                      'ATOM_SITE_AUTH_COMP_ID_2': 'atom_site_auth_comp_id_2',
                                      'ATOM_SITE_AUTH_COMP_ID_3': 'atom_site_auth_comp_id_3',
                                      'ATOM_SITE_AUTH_SEQ_ID_1': 'atom_site_auth_seq_id_1',
                                      'ATOM_SITE_AUTH_SEQ_ID_2': 'atom_site_auth_seq_id_2',
                                      'ATOM_SITE_AUTH_SEQ_ID_3': 'atom_site_auth_seq_id_3',
                                      'ATOM_SITE_ID_1': 'atom_site_id_1',
                                      'ATOM_SITE_ID_2': 'atom_site_id_2',
                                      'ATOM_SITE_ID_3': 'atom_site_id_3',
                                      'ATOM_SITE_LABEL_ALT_ID_1': 'atom_site_label_alt_id_1',
                                      'ATOM_SITE_LABEL_ALT_ID_2': 'atom_site_label_alt_id_2',
                                      'ATOM_SITE_LABEL_ALT_ID_3': 'atom_site_label_alt_id_3',
                                      'ATOM_SITE_LABEL_ASYM_ID_1': 'atom_site_label_asym_id_1',
                                      'ATOM_SITE_LABEL_ASYM_ID_2': 'atom_site_label_asym_id_2',
                                      'ATOM_SITE_LABEL_ASYM_ID_3': 'atom_site_label_asym_id_3',
                                      'ATOM_SITE_LABEL_ATOM_ID_1': 'atom_site_label_atom_id_1',
                                      'ATOM_SITE_LABEL_ATOM_ID_2': 'atom_site_label_atom_id_2',
                                      'ATOM_SITE_LABEL_ATOM_ID_3': 'atom_site_label_atom_id_3',
                                      'ATOM_SITE_LABEL_COMP_ID_1': 'atom_site_label_comp_id_1',
                                      'ATOM_SITE_LABEL_COMP_ID_2': 'atom_site_label_comp_id_2',
                                      'ATOM_SITE_LABEL_COMP_ID_3': 'atom_site_label_comp_id_3',
                                      'ATOM_SITE_LABEL_SEQ_ID_1': 'atom_site_label_seq_id_1',
                                      'ATOM_SITE_LABEL_SEQ_ID_2': 'atom_site_label_seq_id_2',
                                      'ATOM_SITE_LABEL_SEQ_ID_3': 'atom_site_label_seq_id_3',
                                      'PDBX_ATOM_SITE_PDB_INS_CODE_1': 'pdbx_atom_site_PDB_ins_code_1',
                                      'PDBX_ATOM_SITE_PDB_INS_CODE_2': 'pdbx_atom_site_PDB_ins_code_2',
                                      'PDBX_ATOM_SITE_PDB_INS_CODE_3': 'pdbx_atom_site_PDB_ins_code_3',
                                      'PDBX_PDB_MODEL_NUM': 'pdbx_PDB_model_num',
                                      'PUBL_FLAG': 'publ_flag',
                                      'SITE_SYMMETRY_1': 'site_symmetry_1',
                                      'SITE_SYMMETRY_2': 'site_symmetry_2',
                                      'SITE_SYMMETRY_3': 'site_symmetry_3',
                                      'STRUCTURE_ID': 'Structure_ID',
                                      'VALUE': 'value',
                                      'VALUE_ESD': 'value_esd'},
                       'ATTRIBUTE_INFO': {'ATOM_SITE_AUTH_ASYM_ID_1': {'NULLABLE': True,
                                                                       'ORDER': 2,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                          'ATOM_SITE_AUTH_ASYM_ID_2': {'NULLABLE': True,
                                                                       'ORDER': 3,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                          'ATOM_SITE_AUTH_ASYM_ID_3': {'NULLABLE': True,
                                                                       'ORDER': 4,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                          'ATOM_SITE_AUTH_ATOM_ID_1': {'NULLABLE': True,
                                                                       'ORDER': 5,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 6},
                                          'ATOM_SITE_AUTH_ATOM_ID_2': {'NULLABLE': True,
                                                                       'ORDER': 6,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 6},
                                          'ATOM_SITE_AUTH_ATOM_ID_3': {'NULLABLE': True,
                                                                       'ORDER': 7,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 6},
                                          'ATOM_SITE_AUTH_COMP_ID_1': {'NULLABLE': True,
                                                                       'ORDER': 8,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                          'ATOM_SITE_AUTH_COMP_ID_2': {'NULLABLE': True,
                                                                       'ORDER': 9,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                          'ATOM_SITE_AUTH_COMP_ID_3': {'NULLABLE': True,
                                                                       'ORDER': 10,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                          'ATOM_SITE_AUTH_SEQ_ID_1': {'NULLABLE': True,
                                                                      'ORDER': 11,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                          'ATOM_SITE_AUTH_SEQ_ID_2': {'NULLABLE': True,
                                                                      'ORDER': 12,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                          'ATOM_SITE_AUTH_SEQ_ID_3': {'NULLABLE': True,
                                                                      'ORDER': 13,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                          'ATOM_SITE_ID_1': {'NULLABLE': False,
                                                             'ORDER': 14,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 10},
                                          'ATOM_SITE_ID_2': {'NULLABLE': False,
                                                             'ORDER': 15,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 10},
                                          'ATOM_SITE_ID_3': {'NULLABLE': False,
                                                             'ORDER': 16,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 10},
                                          'ATOM_SITE_LABEL_ALT_ID_1': {'NULLABLE': True,
                                                                       'ORDER': 17,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                          'ATOM_SITE_LABEL_ALT_ID_2': {'NULLABLE': True,
                                                                       'ORDER': 18,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                          'ATOM_SITE_LABEL_ALT_ID_3': {'NULLABLE': True,
                                                                       'ORDER': 19,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                          'ATOM_SITE_LABEL_ASYM_ID_1': {'NULLABLE': True,
                                                                        'ORDER': 29,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                          'ATOM_SITE_LABEL_ASYM_ID_2': {'NULLABLE': True,
                                                                        'ORDER': 30,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                          'ATOM_SITE_LABEL_ASYM_ID_3': {'NULLABLE': True,
                                                                        'ORDER': 31,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                          'ATOM_SITE_LABEL_ATOM_ID_1': {'NULLABLE': True,
                                                                        'ORDER': 23,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 6},
                                          'ATOM_SITE_LABEL_ATOM_ID_2': {'NULLABLE': True,
                                                                        'ORDER': 24,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 6},
                                          'ATOM_SITE_LABEL_ATOM_ID_3': {'NULLABLE': True,
                                                                        'ORDER': 25,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 6},
                                          'ATOM_SITE_LABEL_COMP_ID_1': {'NULLABLE': True,
                                                                        'ORDER': 20,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                          'ATOM_SITE_LABEL_COMP_ID_2': {'NULLABLE': True,
                                                                        'ORDER': 21,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                          'ATOM_SITE_LABEL_COMP_ID_3': {'NULLABLE': True,
                                                                        'ORDER': 22,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                          'ATOM_SITE_LABEL_SEQ_ID_1': {'NULLABLE': True,
                                                                       'ORDER': 26,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'INT',
                                                                       'WIDTH': 10},
                                          'ATOM_SITE_LABEL_SEQ_ID_2': {'NULLABLE': True,
                                                                       'ORDER': 27,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'INT',
                                                                       'WIDTH': 10},
                                          'ATOM_SITE_LABEL_SEQ_ID_3': {'NULLABLE': True,
                                                                       'ORDER': 28,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'INT',
                                                                       'WIDTH': 10},
                                          'PDBX_ATOM_SITE_PDB_INS_CODE_1': {'NULLABLE': True,
                                                                            'ORDER': 38,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 10},
                                          'PDBX_ATOM_SITE_PDB_INS_CODE_2': {'NULLABLE': True,
                                                                            'ORDER': 39,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 10},
                                          'PDBX_ATOM_SITE_PDB_INS_CODE_3': {'NULLABLE': True,
                                                                            'ORDER': 40,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 10},
                                          'PDBX_PDB_MODEL_NUM': {'NULLABLE': True,
                                                                 'ORDER': 41,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'INT',
                                                                 'WIDTH': 10},
                                          'PUBL_FLAG': {'NULLABLE': True,
                                                        'ORDER': 32,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 10},
                                          'SITE_SYMMETRY_1': {'NULLABLE': False,
                                                              'ORDER': 33,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10},
                                          'SITE_SYMMETRY_2': {'NULLABLE': False,
                                                              'ORDER': 34,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10},
                                          'SITE_SYMMETRY_3': {'NULLABLE': False,
                                                              'ORDER': 35,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10},
                                          'STRUCTURE_ID': {'NULLABLE': False,
                                                           'ORDER': 1,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': True,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 10},
                                          'VALUE': {'NULLABLE': True,
                                                    'ORDER': 36,
                                                    'PRECISION': 6,
                                                    'PRIMARY_KEY': False,
                                                    'SQL_TYPE': 'FLOAT',
                                                    'WIDTH': 10},
                                          'VALUE_ESD': {'NULLABLE': True,
                                                        'ORDER': 37,
                                                        'PRECISION': 6,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'FLOAT',
                                                        'WIDTH': 10}},
                       'ATTRIBUTE_MAP': {'ATOM_SITE_AUTH_ASYM_ID_1': ('geom_angle', 'atom_site_auth_asym_id_1', None, None),
                                         'ATOM_SITE_AUTH_ASYM_ID_2': ('geom_angle', 'atom_site_auth_asym_id_2', None, None),
                                         'ATOM_SITE_AUTH_ASYM_ID_3': ('geom_angle', 'atom_site_auth_asym_id_3', None, None),
                                         'ATOM_SITE_AUTH_ATOM_ID_1': ('geom_angle', 'atom_site_auth_atom_id_1', None, None),
                                         'ATOM_SITE_AUTH_ATOM_ID_2': ('geom_angle', 'atom_site_auth_atom_id_2', None, None),
                                         'ATOM_SITE_AUTH_ATOM_ID_3': ('geom_angle', 'atom_site_auth_atom_id_3', None, None),
                                         'ATOM_SITE_AUTH_COMP_ID_1': ('geom_angle', 'atom_site_auth_comp_id_1', None, None),
                                         'ATOM_SITE_AUTH_COMP_ID_2': ('geom_angle', 'atom_site_auth_comp_id_2', None, None),
                                         'ATOM_SITE_AUTH_COMP_ID_3': ('geom_angle', 'atom_site_auth_comp_id_3', None, None),
                                         'ATOM_SITE_AUTH_SEQ_ID_1': ('geom_angle', 'atom_site_auth_seq_id_1', None, None),
                                         'ATOM_SITE_AUTH_SEQ_ID_2': ('geom_angle', 'atom_site_auth_seq_id_2', None, None),
                                         'ATOM_SITE_AUTH_SEQ_ID_3': ('geom_angle', 'atom_site_auth_seq_id_3', None, None),
                                         'ATOM_SITE_ID_1': ('geom_angle', 'atom_site_id_1', None, None),
                                         'ATOM_SITE_ID_2': ('geom_angle', 'atom_site_id_2', None, None),
                                         'ATOM_SITE_ID_3': ('geom_angle', 'atom_site_id_3', None, None),
                                         'ATOM_SITE_LABEL_ALT_ID_1': ('geom_angle', 'atom_site_label_alt_id_1', None, None),
                                         'ATOM_SITE_LABEL_ALT_ID_2': ('geom_angle', 'atom_site_label_alt_id_2', None, None),
                                         'ATOM_SITE_LABEL_ALT_ID_3': ('geom_angle', 'atom_site_label_alt_id_3', None, None),
                                         'ATOM_SITE_LABEL_ASYM_ID_1': ('geom_angle', 'atom_site_label_asym_id_1', None, None),
                                         'ATOM_SITE_LABEL_ASYM_ID_2': ('geom_angle', 'atom_site_label_asym_id_2', None, None),
                                         'ATOM_SITE_LABEL_ASYM_ID_3': ('geom_angle', 'atom_site_label_asym_id_3', None, None),
                                         'ATOM_SITE_LABEL_ATOM_ID_1': ('geom_angle', 'atom_site_label_atom_id_1', None, None),
                                         'ATOM_SITE_LABEL_ATOM_ID_2': ('geom_angle', 'atom_site_label_atom_id_2', None, None),
                                         'ATOM_SITE_LABEL_ATOM_ID_3': ('geom_angle', 'atom_site_label_atom_id_3', None, None),
                                         'ATOM_SITE_LABEL_COMP_ID_1': ('geom_angle', 'atom_site_label_comp_id_1', None, None),
                                         'ATOM_SITE_LABEL_COMP_ID_2': ('geom_angle', 'atom_site_label_comp_id_2', None, None),
                                         'ATOM_SITE_LABEL_COMP_ID_3': ('geom_angle', 'atom_site_label_comp_id_3', None, None),
                                         'ATOM_SITE_LABEL_SEQ_ID_1': ('geom_angle', 'atom_site_label_seq_id_1', None, None),
                                         'ATOM_SITE_LABEL_SEQ_ID_2': ('geom_angle', 'atom_site_label_seq_id_2', None, None),
                                         'ATOM_SITE_LABEL_SEQ_ID_3': ('geom_angle', 'atom_site_label_seq_id_3', None, None),
                                         'PDBX_ATOM_SITE_PDB_INS_CODE_1': ('geom_angle',
                                                                           'pdbx_atom_site_PDB_ins_code_1',
                                                                           None,
                                                                           None),
                                         'PDBX_ATOM_SITE_PDB_INS_CODE_2': ('geom_angle',
                                                                           'pdbx_atom_site_PDB_ins_code_2',
                                                                           None,
                                                                           None),
                                         'PDBX_ATOM_SITE_PDB_INS_CODE_3': ('geom_angle',
                                                                           'pdbx_atom_site_PDB_ins_code_3',
                                                                           None,
                                                                           None),
                                         'PDBX_PDB_MODEL_NUM': ('geom_angle', 'pdbx_PDB_model_num', None, None),
                                         'PUBL_FLAG': ('geom_angle', 'publ_flag', None, None),
                                         'SITE_SYMMETRY_1': ('geom_angle', 'site_symmetry_1', None, None),
                                         'SITE_SYMMETRY_2': ('geom_angle', 'site_symmetry_2', None, None),
                                         'SITE_SYMMETRY_3': ('geom_angle', 'site_symmetry_3', None, None),
                                         'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                         'VALUE': ('geom_angle', 'value', None, None),
                                         'VALUE_ESD': ('geom_angle', 'value_esd', None, None)},
                       'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID',
                                                         'ATOM_SITE_ID_1',
                                                         'ATOM_SITE_ID_2',
                                                         'ATOM_SITE_ID_3',
                                                         'SITE_SYMMETRY_1',
                                                         'SITE_SYMMETRY_2',
                                                         'SITE_SYMMETRY_3'),
                                          'TYPE': 'UNIQUE'},
                                   's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                       'MAP_MERGE_INDICES': {'geom_angle': {'ATTRIBUTES': ('atom_site_id_1',
                                                                           'atom_site_id_2',
                                                                           'atom_site_id_3',
                                                                           'site_symmetry_1',
                                                                           'site_symmetry_2',
                                                                           'site_symmetry_3'),
                                                            'TYPE': 'EQUI-JOIN'}},
                       'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                       'TABLE_ID': 'GEOM_ANGLE',
                       'TABLE_NAME': 'geom_angle',
                       'TABLE_TYPE': 'transactional'},
        'GEOM_BOND': {'ATTRIBUTES': {'ATOM_SITE_AUTH_ASYM_ID_1': 'atom_site_auth_asym_id_1',
                                     'ATOM_SITE_AUTH_ASYM_ID_2': 'atom_site_auth_asym_id_2',
                                     'ATOM_SITE_AUTH_ATOM_ID_1': 'atom_site_auth_atom_id_1',
                                     'ATOM_SITE_AUTH_ATOM_ID_2': 'atom_site_auth_atom_id_2',
                                     'ATOM_SITE_AUTH_COMP_ID_1': 'atom_site_auth_comp_id_1',
                                     'ATOM_SITE_AUTH_COMP_ID_2': 'atom_site_auth_comp_id_2',
                                     'ATOM_SITE_AUTH_SEQ_ID_1': 'atom_site_auth_seq_id_1',
                                     'ATOM_SITE_AUTH_SEQ_ID_2': 'atom_site_auth_seq_id_2',
                                     'ATOM_SITE_ID_1': 'atom_site_id_1',
                                     'ATOM_SITE_ID_2': 'atom_site_id_2',
                                     'ATOM_SITE_LABEL_ALT_ID_1': 'atom_site_label_alt_id_1',
                                     'ATOM_SITE_LABEL_ALT_ID_2': 'atom_site_label_alt_id_2',
                                     'ATOM_SITE_LABEL_ASYM_ID_1': 'atom_site_label_asym_id_1',
                                     'ATOM_SITE_LABEL_ASYM_ID_2': 'atom_site_label_asym_id_2',
                                     'ATOM_SITE_LABEL_ATOM_ID_1': 'atom_site_label_atom_id_1',
                                     'ATOM_SITE_LABEL_ATOM_ID_2': 'atom_site_label_atom_id_2',
                                     'ATOM_SITE_LABEL_COMP_ID_1': 'atom_site_label_comp_id_1',
                                     'ATOM_SITE_LABEL_COMP_ID_2': 'atom_site_label_comp_id_2',
                                     'ATOM_SITE_LABEL_SEQ_ID_1': 'atom_site_label_seq_id_1',
                                     'ATOM_SITE_LABEL_SEQ_ID_2': 'atom_site_label_seq_id_2',
                                     'DIST': 'dist',
                                     'DIST_ESD': 'dist_esd',
                                     'PDBX_ATOM_SITE_PDB_INS_CODE_1': 'pdbx_atom_site_PDB_ins_code_1',
                                     'PDBX_ATOM_SITE_PDB_INS_CODE_2': 'pdbx_atom_site_PDB_ins_code_2',
                                     'PDBX_PDB_MODEL_NUM': 'pdbx_PDB_model_num',
                                     'PUBL_FLAG': 'publ_flag',
                                     'SITE_SYMMETRY_1': 'site_symmetry_1',
                                     'SITE_SYMMETRY_2': 'site_symmetry_2',
                                     'STRUCTURE_ID': 'Structure_ID',
                                     'VALENCE': 'valence'},
                      'ATTRIBUTE_INFO': {'ATOM_SITE_AUTH_ASYM_ID_1': {'NULLABLE': True,
                                                                      'ORDER': 2,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                         'ATOM_SITE_AUTH_ASYM_ID_2': {'NULLABLE': True,
                                                                      'ORDER': 3,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                         'ATOM_SITE_AUTH_ATOM_ID_1': {'NULLABLE': True,
                                                                      'ORDER': 4,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 6},
                                         'ATOM_SITE_AUTH_ATOM_ID_2': {'NULLABLE': True,
                                                                      'ORDER': 5,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 6},
                                         'ATOM_SITE_AUTH_COMP_ID_1': {'NULLABLE': True,
                                                                      'ORDER': 6,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                         'ATOM_SITE_AUTH_COMP_ID_2': {'NULLABLE': True,
                                                                      'ORDER': 7,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                         'ATOM_SITE_AUTH_SEQ_ID_1': {'NULLABLE': True,
                                                                     'ORDER': 8,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                         'ATOM_SITE_AUTH_SEQ_ID_2': {'NULLABLE': True,
                                                                     'ORDER': 9,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                         'ATOM_SITE_ID_1': {'NULLABLE': False,
                                                            'ORDER': 10,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': True,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 10},
                                         'ATOM_SITE_ID_2': {'NULLABLE': False,
                                                            'ORDER': 11,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': True,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 10},
                                         'ATOM_SITE_LABEL_ALT_ID_1': {'NULLABLE': True,
                                                                      'ORDER': 12,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                         'ATOM_SITE_LABEL_ALT_ID_2': {'NULLABLE': True,
                                                                      'ORDER': 13,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                         'ATOM_SITE_LABEL_ASYM_ID_1': {'NULLABLE': True,
                                                                       'ORDER': 20,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                         'ATOM_SITE_LABEL_ASYM_ID_2': {'NULLABLE': True,
                                                                       'ORDER': 21,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                         'ATOM_SITE_LABEL_ATOM_ID_1': {'NULLABLE': True,
                                                                       'ORDER': 16,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 6},
                                         'ATOM_SITE_LABEL_ATOM_ID_2': {'NULLABLE': True,
                                                                       'ORDER': 17,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 6},
                                         'ATOM_SITE_LABEL_COMP_ID_1': {'NULLABLE': True,
                                                                       'ORDER': 14,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                         'ATOM_SITE_LABEL_COMP_ID_2': {'NULLABLE': True,
                                                                       'ORDER': 15,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                         'ATOM_SITE_LABEL_SEQ_ID_1': {'NULLABLE': True,
                                                                      'ORDER': 18,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'INT',
                                                                      'WIDTH': 10},
                                         'ATOM_SITE_LABEL_SEQ_ID_2': {'NULLABLE': True,
                                                                      'ORDER': 19,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'INT',
                                                                      'WIDTH': 10},
                                         'DIST': {'NULLABLE': True,
                                                  'ORDER': 22,
                                                  'PRECISION': 6,
                                                  'PRIMARY_KEY': False,
                                                  'SQL_TYPE': 'FLOAT',
                                                  'WIDTH': 10},
                                         'DIST_ESD': {'NULLABLE': True,
                                                      'ORDER': 23,
                                                      'PRECISION': 6,
                                                      'PRIMARY_KEY': False,
                                                      'SQL_TYPE': 'FLOAT',
                                                      'WIDTH': 10},
                                         'PDBX_ATOM_SITE_PDB_INS_CODE_1': {'NULLABLE': True,
                                                                           'ORDER': 28,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10},
                                         'PDBX_ATOM_SITE_PDB_INS_CODE_2': {'NULLABLE': True,
                                                                           'ORDER': 29,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10},
                                         'PDBX_PDB_MODEL_NUM': {'NULLABLE': True,
                                                                'ORDER': 30,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'INT',
                                                                'WIDTH': 10},
                                         'PUBL_FLAG': {'NULLABLE': True,
                                                       'ORDER': 24,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'VARCHAR',
                                                       'WIDTH': 10},
                                         'SITE_SYMMETRY_1': {'NULLABLE': False,
                                                             'ORDER': 25,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 10},
                                         'SITE_SYMMETRY_2': {'NULLABLE': False,
                                                             'ORDER': 26,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 10},
                                         'STRUCTURE_ID': {'NULLABLE': False,
                                                          'ORDER': 1,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': True,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 10},
                                         'VALENCE': {'NULLABLE': True,
                                                     'ORDER': 27,
                                                     'PRECISION': 0,
                                                     'PRIMARY_KEY': False,
                                                     'SQL_TYPE': 'INT',
                                                     'WIDTH': 10}},
                      'ATTRIBUTE_MAP': {'ATOM_SITE_AUTH_ASYM_ID_1': ('geom_bond', 'atom_site_auth_asym_id_1', None, None),
                                        'ATOM_SITE_AUTH_ASYM_ID_2': ('geom_bond', 'atom_site_auth_asym_id_2', None, None),
                                        'ATOM_SITE_AUTH_ATOM_ID_1': ('geom_bond', 'atom_site_auth_atom_id_1', None, None),
                                        'ATOM_SITE_AUTH_ATOM_ID_2': ('geom_bond', 'atom_site_auth_atom_id_2', None, None),
                                        'ATOM_SITE_AUTH_COMP_ID_1': ('geom_bond', 'atom_site_auth_comp_id_1', None, None),
                                        'ATOM_SITE_AUTH_COMP_ID_2': ('geom_bond', 'atom_site_auth_comp_id_2', None, None),
                                        'ATOM_SITE_AUTH_SEQ_ID_1': ('geom_bond', 'atom_site_auth_seq_id_1', None, None),
                                        'ATOM_SITE_AUTH_SEQ_ID_2': ('geom_bond', 'atom_site_auth_seq_id_2', None, None),
                                        'ATOM_SITE_ID_1': ('geom_bond', 'atom_site_id_1', None, None),
                                        'ATOM_SITE_ID_2': ('geom_bond', 'atom_site_id_2', None, None),
                                        'ATOM_SITE_LABEL_ALT_ID_1': ('geom_bond', 'atom_site_label_alt_id_1', None, None),
                                        'ATOM_SITE_LABEL_ALT_ID_2': ('geom_bond', 'atom_site_label_alt_id_2', None, None),
                                        'ATOM_SITE_LABEL_ASYM_ID_1': ('geom_bond', 'atom_site_label_asym_id_1', None, None),
                                        'ATOM_SITE_LABEL_ASYM_ID_2': ('geom_bond', 'atom_site_label_asym_id_2', None, None),
                                        'ATOM_SITE_LABEL_ATOM_ID_1': ('geom_bond', 'atom_site_label_atom_id_1', None, None),
                                        'ATOM_SITE_LABEL_ATOM_ID_2': ('geom_bond', 'atom_site_label_atom_id_2', None, None),
                                        'ATOM_SITE_LABEL_COMP_ID_1': ('geom_bond', 'atom_site_label_comp_id_1', None, None),
                                        'ATOM_SITE_LABEL_COMP_ID_2': ('geom_bond', 'atom_site_label_comp_id_2', None, None),
                                        'ATOM_SITE_LABEL_SEQ_ID_1': ('geom_bond', 'atom_site_label_seq_id_1', None, None),
                                        'ATOM_SITE_LABEL_SEQ_ID_2': ('geom_bond', 'atom_site_label_seq_id_2', None, None),
                                        'DIST': ('geom_bond', 'dist', None, None),
                                        'DIST_ESD': ('geom_bond', 'dist_esd', None, None),
                                        'PDBX_ATOM_SITE_PDB_INS_CODE_1': ('geom_bond',
                                                                          'pdbx_atom_site_PDB_ins_code_1',
                                                                          None,
                                                                          None),
                                        'PDBX_ATOM_SITE_PDB_INS_CODE_2': ('geom_bond',
                                                                          'pdbx_atom_site_PDB_ins_code_2',
                                                                          None,
                                                                          None),
                                        'PDBX_PDB_MODEL_NUM': ('geom_bond', 'pdbx_PDB_model_num', None, None),
                                        'PUBL_FLAG': ('geom_bond', 'publ_flag', None, None),
                                        'SITE_SYMMETRY_1': ('geom_bond', 'site_symmetry_1', None, None),
                                        'SITE_SYMMETRY_2': ('geom_bond', 'site_symmetry_2', None, None),
                                        'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                        'VALENCE': ('geom_bond', 'valence', None, None)},
                      'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID',
                                                        'ATOM_SITE_ID_1',
                                                        'ATOM_SITE_ID_2',
                                                        'SITE_SYMMETRY_1',
                                                        'SITE_SYMMETRY_2'),
                                         'TYPE': 'UNIQUE'},
                                  's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                      'MAP_MERGE_INDICES': {'geom_bond': {'ATTRIBUTES': ('atom_site_id_1',
                                                                         'atom_site_id_2',
                                                                         'site_symmetry_1',
                                                                         'site_symmetry_2'),
                                                          'TYPE': 'EQUI-JOIN'}},
                      'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                      'TABLE_ID': 'GEOM_BOND',
                      'TABLE_NAME': 'geom_bond',
                      'TABLE_TYPE': 'transactional'},
        'GEOM_CONTACT': {'ATTRIBUTES': {'ATOM_SITE_AUTH_ASYM_ID_1': 'atom_site_auth_asym_id_1',
                                        'ATOM_SITE_AUTH_ASYM_ID_2': 'atom_site_auth_asym_id_2',
                                        'ATOM_SITE_AUTH_ATOM_ID_1': 'atom_site_auth_atom_id_1',
                                        'ATOM_SITE_AUTH_ATOM_ID_2': 'atom_site_auth_atom_id_2',
                                        'ATOM_SITE_AUTH_COMP_ID_1': 'atom_site_auth_comp_id_1',
                                        'ATOM_SITE_AUTH_COMP_ID_2': 'atom_site_auth_comp_id_2',
                                        'ATOM_SITE_AUTH_SEQ_ID_1': 'atom_site_auth_seq_id_1',
                                        'ATOM_SITE_AUTH_SEQ_ID_2': 'atom_site_auth_seq_id_2',
                                        'ATOM_SITE_ID_1': 'atom_site_id_1',
                                        'ATOM_SITE_ID_2': 'atom_site_id_2',
                                        'ATOM_SITE_LABEL_ALT_ID_1': 'atom_site_label_alt_id_1',
                                        'ATOM_SITE_LABEL_ALT_ID_2': 'atom_site_label_alt_id_2',
                                        'ATOM_SITE_LABEL_ASYM_ID_1': 'atom_site_label_asym_id_1',
                                        'ATOM_SITE_LABEL_ASYM_ID_2': 'atom_site_label_asym_id_2',
                                        'ATOM_SITE_LABEL_ATOM_ID_1': 'atom_site_label_atom_id_1',
                                        'ATOM_SITE_LABEL_ATOM_ID_2': 'atom_site_label_atom_id_2',
                                        'ATOM_SITE_LABEL_COMP_ID_1': 'atom_site_label_comp_id_1',
                                        'ATOM_SITE_LABEL_COMP_ID_2': 'atom_site_label_comp_id_2',
                                        'ATOM_SITE_LABEL_SEQ_ID_1': 'atom_site_label_seq_id_1',
                                        'ATOM_SITE_LABEL_SEQ_ID_2': 'atom_site_label_seq_id_2',
                                        'DIST': 'dist',
                                        'DIST_ESD': 'dist_esd',
                                        'PDBX_ATOM_SITE_PDB_INS_CODE_1': 'pdbx_atom_site_PDB_ins_code_1',
                                        'PDBX_ATOM_SITE_PDB_INS_CODE_2': 'pdbx_atom_site_PDB_ins_code_2',
                                        'PDBX_PDB_MODEL_NUM': 'pdbx_PDB_model_num',
                                        'PUBL_FLAG': 'publ_flag',
                                        'SITE_SYMMETRY_1': 'site_symmetry_1',
                                        'SITE_SYMMETRY_2': 'site_symmetry_2',
                                        'STRUCTURE_ID': 'Structure_ID'},
                         'ATTRIBUTE_INFO': {'ATOM_SITE_AUTH_ASYM_ID_1': {'NULLABLE': True,
                                                                         'ORDER': 2,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                            'ATOM_SITE_AUTH_ASYM_ID_2': {'NULLABLE': True,
                                                                         'ORDER': 3,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                            'ATOM_SITE_AUTH_ATOM_ID_1': {'NULLABLE': True,
                                                                         'ORDER': 4,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 6},
                                            'ATOM_SITE_AUTH_ATOM_ID_2': {'NULLABLE': True,
                                                                         'ORDER': 5,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 6},
                                            'ATOM_SITE_AUTH_COMP_ID_1': {'NULLABLE': True,
                                                                         'ORDER': 6,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                            'ATOM_SITE_AUTH_COMP_ID_2': {'NULLABLE': True,
                                                                         'ORDER': 7,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                            'ATOM_SITE_AUTH_SEQ_ID_1': {'NULLABLE': True,
                                                                        'ORDER': 8,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                            'ATOM_SITE_AUTH_SEQ_ID_2': {'NULLABLE': True,
                                                                        'ORDER': 9,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                            'ATOM_SITE_ID_1': {'NULLABLE': False,
                                                               'ORDER': 10,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                            'ATOM_SITE_ID_2': {'NULLABLE': False,
                                                               'ORDER': 11,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                            'ATOM_SITE_LABEL_ALT_ID_1': {'NULLABLE': True,
                                                                         'ORDER': 12,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                            'ATOM_SITE_LABEL_ALT_ID_2': {'NULLABLE': True,
                                                                         'ORDER': 13,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                            'ATOM_SITE_LABEL_ASYM_ID_1': {'NULLABLE': True,
                                                                          'ORDER': 20,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                            'ATOM_SITE_LABEL_ASYM_ID_2': {'NULLABLE': True,
                                                                          'ORDER': 21,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                            'ATOM_SITE_LABEL_ATOM_ID_1': {'NULLABLE': True,
                                                                          'ORDER': 16,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 6},
                                            'ATOM_SITE_LABEL_ATOM_ID_2': {'NULLABLE': True,
                                                                          'ORDER': 17,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 6},
                                            'ATOM_SITE_LABEL_COMP_ID_1': {'NULLABLE': True,
                                                                          'ORDER': 14,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                            'ATOM_SITE_LABEL_COMP_ID_2': {'NULLABLE': True,
                                                                          'ORDER': 15,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                            'ATOM_SITE_LABEL_SEQ_ID_1': {'NULLABLE': True,
                                                                         'ORDER': 18,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'INT',
                                                                         'WIDTH': 10},
                                            'ATOM_SITE_LABEL_SEQ_ID_2': {'NULLABLE': True,
                                                                         'ORDER': 19,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'INT',
                                                                         'WIDTH': 10},
                                            'DIST': {'NULLABLE': True,
                                                     'ORDER': 22,
                                                     'PRECISION': 6,
                                                     'PRIMARY_KEY': False,
                                                     'SQL_TYPE': 'FLOAT',
                                                     'WIDTH': 10},
                                            'DIST_ESD': {'NULLABLE': True,
                                                         'ORDER': 23,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                            'PDBX_ATOM_SITE_PDB_INS_CODE_1': {'NULLABLE': True,
                                                                              'ORDER': 27,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                            'PDBX_ATOM_SITE_PDB_INS_CODE_2': {'NULLABLE': True,
                                                                              'ORDER': 28,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                            'PDBX_PDB_MODEL_NUM': {'NULLABLE': True,
                                                                   'ORDER': 29,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'INT',
                                                                   'WIDTH': 10},
                                            'PUBL_FLAG': {'NULLABLE': True,
                                                          'ORDER': 24,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 10},
                                            'SITE_SYMMETRY_1': {'NULLABLE': False,
                                                                'ORDER': 25,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                            'SITE_SYMMETRY_2': {'NULLABLE': False,
                                                                'ORDER': 26,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                            'STRUCTURE_ID': {'NULLABLE': False,
                                                             'ORDER': 1,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 10}},
                         'ATTRIBUTE_MAP': {'ATOM_SITE_AUTH_ASYM_ID_1': ('geom_contact',
                                                                        'atom_site_auth_asym_id_1',
                                                                        None,
                                                                        None),
                                           'ATOM_SITE_AUTH_ASYM_ID_2': ('geom_contact',
                                                                        'atom_site_auth_asym_id_2',
                                                                        None,
                                                                        None),
                                           'ATOM_SITE_AUTH_ATOM_ID_1': ('geom_contact',
                                                                        'atom_site_auth_atom_id_1',
                                                                        None,
                                                                        None),
                                           'ATOM_SITE_AUTH_ATOM_ID_2': ('geom_contact',
                                                                        'atom_site_auth_atom_id_2',
                                                                        None,
                                                                        None),
                                           'ATOM_SITE_AUTH_COMP_ID_1': ('geom_contact',
                                                                        'atom_site_auth_comp_id_1',
                                                                        None,
                                                                        None),
                                           'ATOM_SITE_AUTH_COMP_ID_2': ('geom_contact',
                                                                        'atom_site_auth_comp_id_2',
                                                                        None,
                                                                        None),
                                           'ATOM_SITE_AUTH_SEQ_ID_1': ('geom_contact', 'atom_site_auth_seq_id_1', None, None),
                                           'ATOM_SITE_AUTH_SEQ_ID_2': ('geom_contact', 'atom_site_auth_seq_id_2', None, None),
                                           'ATOM_SITE_ID_1': ('geom_contact', 'atom_site_id_1', None, None),
                                           'ATOM_SITE_ID_2': ('geom_contact', 'atom_site_id_2', None, None),
                                           'ATOM_SITE_LABEL_ALT_ID_1': ('geom_contact',
                                                                        'atom_site_label_alt_id_1',
                                                                        None,
                                                                        None),
                                           'ATOM_SITE_LABEL_ALT_ID_2': ('geom_contact',
                                                                        'atom_site_label_alt_id_2',
                                                                        None,
                                                                        None),
                                           'ATOM_SITE_LABEL_ASYM_ID_1': ('geom_contact',
                                                                         'atom_site_label_asym_id_1',
                                                                         None,
                                                                         None),
                                           'ATOM_SITE_LABEL_ASYM_ID_2': ('geom_contact',
                                                                         'atom_site_label_asym_id_2',
                                                                         None,
                                                                         None),
                                           'ATOM_SITE_LABEL_ATOM_ID_1': ('geom_contact',
                                                                         'atom_site_label_atom_id_1',
                                                                         None,
                                                                         None),
                                           'ATOM_SITE_LABEL_ATOM_ID_2': ('geom_contact',
                                                                         'atom_site_label_atom_id_2',
                                                                         None,
                                                                         None),
                                           'ATOM_SITE_LABEL_COMP_ID_1': ('geom_contact',
                                                                         'atom_site_label_comp_id_1',
                                                                         None,
                                                                         None),
                                           'ATOM_SITE_LABEL_COMP_ID_2': ('geom_contact',
                                                                         'atom_site_label_comp_id_2',
                                                                         None,
                                                                         None),
                                           'ATOM_SITE_LABEL_SEQ_ID_1': ('geom_contact',
                                                                        'atom_site_label_seq_id_1',
                                                                        None,
                                                                        None),
                                           'ATOM_SITE_LABEL_SEQ_ID_2': ('geom_contact',
                                                                        'atom_site_label_seq_id_2',
                                                                        None,
                                                                        None),
                                           'DIST': ('geom_contact', 'dist', None, None),
                                           'DIST_ESD': ('geom_contact', 'dist_esd', None, None),
                                           'PDBX_ATOM_SITE_PDB_INS_CODE_1': ('geom_contact',
                                                                             'pdbx_atom_site_PDB_ins_code_1',
                                                                             None,
                                                                             None),
                                           'PDBX_ATOM_SITE_PDB_INS_CODE_2': ('geom_contact',
                                                                             'pdbx_atom_site_PDB_ins_code_2',
                                                                             None,
                                                                             None),
                                           'PDBX_PDB_MODEL_NUM': ('geom_contact', 'pdbx_PDB_model_num', None, None),
                                           'PUBL_FLAG': ('geom_contact', 'publ_flag', None, None),
                                           'SITE_SYMMETRY_1': ('geom_contact', 'site_symmetry_1', None, None),
                                           'SITE_SYMMETRY_2': ('geom_contact', 'site_symmetry_2', None, None),
                                           'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                         'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID',
                                                           'ATOM_SITE_ID_1',
                                                           'ATOM_SITE_ID_2',
                                                           'SITE_SYMMETRY_1',
                                                           'SITE_SYMMETRY_2'),
                                            'TYPE': 'UNIQUE'},
                                     's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                         'MAP_MERGE_INDICES': {'geom_contact': {'ATTRIBUTES': ('atom_site_id_1',
                                                                               'atom_site_id_2',
                                                                               'site_symmetry_1',
                                                                               'site_symmetry_2'),
                                                                'TYPE': 'EQUI-JOIN'}},
                         'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                         'TABLE_ID': 'GEOM_CONTACT',
                         'TABLE_NAME': 'geom_contact',
                         'TABLE_TYPE': 'transactional'},
        'GEOM_HBOND': {'ATTRIBUTES': {'ANGLE_DHA': 'angle_DHA',
                                      'ANGLE_DHA_ESD': 'angle_DHA_esd',
                                      'ATOM_SITE_AUTH_ASYM_ID_A': 'atom_site_auth_asym_id_A',
                                      'ATOM_SITE_AUTH_ASYM_ID_D': 'atom_site_auth_asym_id_D',
                                      'ATOM_SITE_AUTH_ASYM_ID_H': 'atom_site_auth_asym_id_H',
                                      'ATOM_SITE_AUTH_ATOM_ID_A': 'atom_site_auth_atom_id_A',
                                      'ATOM_SITE_AUTH_ATOM_ID_D': 'atom_site_auth_atom_id_D',
                                      'ATOM_SITE_AUTH_ATOM_ID_H': 'atom_site_auth_atom_id_H',
                                      'ATOM_SITE_AUTH_COMP_ID_A': 'atom_site_auth_comp_id_A',
                                      'ATOM_SITE_AUTH_COMP_ID_D': 'atom_site_auth_comp_id_D',
                                      'ATOM_SITE_AUTH_COMP_ID_H': 'atom_site_auth_comp_id_H',
                                      'ATOM_SITE_AUTH_SEQ_ID_A': 'atom_site_auth_seq_id_A',
                                      'ATOM_SITE_AUTH_SEQ_ID_D': 'atom_site_auth_seq_id_D',
                                      'ATOM_SITE_AUTH_SEQ_ID_H': 'atom_site_auth_seq_id_H',
                                      'ATOM_SITE_ID_A': 'atom_site_id_A',
                                      'ATOM_SITE_ID_D': 'atom_site_id_D',
                                      'ATOM_SITE_ID_H': 'atom_site_id_H',
                                      'ATOM_SITE_LABEL_ALT_ID_A': 'atom_site_label_alt_id_A',
                                      'ATOM_SITE_LABEL_ALT_ID_D': 'atom_site_label_alt_id_D',
                                      'ATOM_SITE_LABEL_ALT_ID_H': 'atom_site_label_alt_id_H',
                                      'ATOM_SITE_LABEL_ASYM_ID_A': 'atom_site_label_asym_id_A',
                                      'ATOM_SITE_LABEL_ASYM_ID_D': 'atom_site_label_asym_id_D',
                                      'ATOM_SITE_LABEL_ASYM_ID_H': 'atom_site_label_asym_id_H',
                                      'ATOM_SITE_LABEL_ATOM_ID_A': 'atom_site_label_atom_id_A',
                                      'ATOM_SITE_LABEL_ATOM_ID_D': 'atom_site_label_atom_id_D',
                                      'ATOM_SITE_LABEL_ATOM_ID_H': 'atom_site_label_atom_id_H',
                                      'ATOM_SITE_LABEL_COMP_ID_A': 'atom_site_label_comp_id_A',
                                      'ATOM_SITE_LABEL_COMP_ID_D': 'atom_site_label_comp_id_D',
                                      'ATOM_SITE_LABEL_COMP_ID_H': 'atom_site_label_comp_id_H',
                                      'ATOM_SITE_LABEL_SEQ_ID_A': 'atom_site_label_seq_id_A',
                                      'ATOM_SITE_LABEL_SEQ_ID_D': 'atom_site_label_seq_id_D',
                                      'ATOM_SITE_LABEL_SEQ_ID_H': 'atom_site_label_seq_id_H',
                                      'DIST_DA': 'dist_DA',
                                      'DIST_DA_ESD': 'dist_DA_esd',
                                      'DIST_DH': 'dist_DH',
                                      'DIST_DH_ESD': 'dist_DH_esd',
                                      'DIST_HA': 'dist_HA',
                                      'DIST_HA_ESD': 'dist_HA_esd',
                                      'PUBL_FLAG': 'publ_flag',
                                      'SITE_SYMMETRY_A': 'site_symmetry_A',
                                      'SITE_SYMMETRY_D': 'site_symmetry_D',
                                      'SITE_SYMMETRY_H': 'site_symmetry_H',
                                      'STRUCTURE_ID': 'Structure_ID'},
                       'ATTRIBUTE_INFO': {'ANGLE_DHA': {'NULLABLE': True,
                                                        'ORDER': 29,
                                                        'PRECISION': 6,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'FLOAT',
                                                        'WIDTH': 10},
                                          'ANGLE_DHA_ESD': {'NULLABLE': True,
                                                            'ORDER': 30,
                                                            'PRECISION': 6,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'FLOAT',
                                                            'WIDTH': 10},
                                          'ATOM_SITE_AUTH_ASYM_ID_A': {'NULLABLE': True,
                                                                       'ORDER': 2,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                          'ATOM_SITE_AUTH_ASYM_ID_D': {'NULLABLE': True,
                                                                       'ORDER': 3,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                          'ATOM_SITE_AUTH_ASYM_ID_H': {'NULLABLE': True,
                                                                       'ORDER': 4,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                          'ATOM_SITE_AUTH_ATOM_ID_A': {'NULLABLE': True,
                                                                       'ORDER': 5,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 6},
                                          'ATOM_SITE_AUTH_ATOM_ID_D': {'NULLABLE': True,
                                                                       'ORDER': 6,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 6},
                                          'ATOM_SITE_AUTH_ATOM_ID_H': {'NULLABLE': True,
                                                                       'ORDER': 7,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 6},
                                          'ATOM_SITE_AUTH_COMP_ID_A': {'NULLABLE': True,
                                                                       'ORDER': 8,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                          'ATOM_SITE_AUTH_COMP_ID_D': {'NULLABLE': True,
                                                                       'ORDER': 9,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                          'ATOM_SITE_AUTH_COMP_ID_H': {'NULLABLE': True,
                                                                       'ORDER': 10,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                          'ATOM_SITE_AUTH_SEQ_ID_A': {'NULLABLE': True,
                                                                      'ORDER': 11,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                          'ATOM_SITE_AUTH_SEQ_ID_D': {'NULLABLE': True,
                                                                      'ORDER': 12,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                          'ATOM_SITE_AUTH_SEQ_ID_H': {'NULLABLE': True,
                                                                      'ORDER': 13,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                          'ATOM_SITE_ID_A': {'NULLABLE': False,
                                                             'ORDER': 14,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 10},
                                          'ATOM_SITE_ID_D': {'NULLABLE': False,
                                                             'ORDER': 15,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 10},
                                          'ATOM_SITE_ID_H': {'NULLABLE': False,
                                                             'ORDER': 16,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 10},
                                          'ATOM_SITE_LABEL_ALT_ID_A': {'NULLABLE': True,
                                                                       'ORDER': 17,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                          'ATOM_SITE_LABEL_ALT_ID_D': {'NULLABLE': True,
                                                                       'ORDER': 18,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                          'ATOM_SITE_LABEL_ALT_ID_H': {'NULLABLE': True,
                                                                       'ORDER': 19,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                          'ATOM_SITE_LABEL_ASYM_ID_A': {'NULLABLE': True,
                                                                        'ORDER': 31,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                          'ATOM_SITE_LABEL_ASYM_ID_D': {'NULLABLE': True,
                                                                        'ORDER': 32,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                          'ATOM_SITE_LABEL_ASYM_ID_H': {'NULLABLE': True,
                                                                        'ORDER': 33,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                          'ATOM_SITE_LABEL_ATOM_ID_A': {'NULLABLE': True,
                                                                        'ORDER': 23,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 6},
                                          'ATOM_SITE_LABEL_ATOM_ID_D': {'NULLABLE': True,
                                                                        'ORDER': 24,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 6},
                                          'ATOM_SITE_LABEL_ATOM_ID_H': {'NULLABLE': True,
                                                                        'ORDER': 25,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 6},
                                          'ATOM_SITE_LABEL_COMP_ID_A': {'NULLABLE': True,
                                                                        'ORDER': 20,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                          'ATOM_SITE_LABEL_COMP_ID_D': {'NULLABLE': True,
                                                                        'ORDER': 21,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                          'ATOM_SITE_LABEL_COMP_ID_H': {'NULLABLE': True,
                                                                        'ORDER': 22,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                          'ATOM_SITE_LABEL_SEQ_ID_A': {'NULLABLE': True,
                                                                       'ORDER': 26,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'INT',
                                                                       'WIDTH': 10},
                                          'ATOM_SITE_LABEL_SEQ_ID_D': {'NULLABLE': True,
                                                                       'ORDER': 27,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'INT',
                                                                       'WIDTH': 10},
                                          'ATOM_SITE_LABEL_SEQ_ID_H': {'NULLABLE': True,
                                                                       'ORDER': 28,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'INT',
                                                                       'WIDTH': 10},
                                          'DIST_DA': {'NULLABLE': True,
                                                      'ORDER': 34,
                                                      'PRECISION': 6,
                                                      'PRIMARY_KEY': False,
                                                      'SQL_TYPE': 'FLOAT',
                                                      'WIDTH': 10},
                                          'DIST_DA_ESD': {'NULLABLE': True,
                                                          'ORDER': 35,
                                                          'PRECISION': 6,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'FLOAT',
                                                          'WIDTH': 10},
                                          'DIST_DH': {'NULLABLE': True,
                                                      'ORDER': 36,
                                                      'PRECISION': 6,
                                                      'PRIMARY_KEY': False,
                                                      'SQL_TYPE': 'FLOAT',
                                                      'WIDTH': 10},
                                          'DIST_DH_ESD': {'NULLABLE': True,
                                                          'ORDER': 37,
                                                          'PRECISION': 6,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'FLOAT',
                                                          'WIDTH': 10},
                                          'DIST_HA': {'NULLABLE': True,
                                                      'ORDER': 38,
                                                      'PRECISION': 6,
                                                      'PRIMARY_KEY': False,
                                                      'SQL_TYPE': 'FLOAT',
                                                      'WIDTH': 10},
                                          'DIST_HA_ESD': {'NULLABLE': True,
                                                          'ORDER': 39,
                                                          'PRECISION': 6,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'FLOAT',
                                                          'WIDTH': 10},
                                          'PUBL_FLAG': {'NULLABLE': True,
                                                        'ORDER': 40,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 10},
                                          'SITE_SYMMETRY_A': {'NULLABLE': False,
                                                              'ORDER': 41,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10},
                                          'SITE_SYMMETRY_D': {'NULLABLE': False,
                                                              'ORDER': 42,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10},
                                          'SITE_SYMMETRY_H': {'NULLABLE': False,
                                                              'ORDER': 43,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10},
                                          'STRUCTURE_ID': {'NULLABLE': False,
                                                           'ORDER': 1,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': True,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 10}},
                       'ATTRIBUTE_MAP': {'ANGLE_DHA': ('geom_hbond', 'angle_DHA', None, None),
                                         'ANGLE_DHA_ESD': ('geom_hbond', 'angle_DHA_esd', None, None),
                                         'ATOM_SITE_AUTH_ASYM_ID_A': ('geom_hbond', 'atom_site_auth_asym_id_A', None, None),
                                         'ATOM_SITE_AUTH_ASYM_ID_D': ('geom_hbond', 'atom_site_auth_asym_id_D', None, None),
                                         'ATOM_SITE_AUTH_ASYM_ID_H': ('geom_hbond', 'atom_site_auth_asym_id_H', None, None),
                                         'ATOM_SITE_AUTH_ATOM_ID_A': ('geom_hbond', 'atom_site_auth_atom_id_A', None, None),
                                         'ATOM_SITE_AUTH_ATOM_ID_D': ('geom_hbond', 'atom_site_auth_atom_id_D', None, None),
                                         'ATOM_SITE_AUTH_ATOM_ID_H': ('geom_hbond', 'atom_site_auth_atom_id_H', None, None),
                                         'ATOM_SITE_AUTH_COMP_ID_A': ('geom_hbond', 'atom_site_auth_comp_id_A', None, None),
                                         'ATOM_SITE_AUTH_COMP_ID_D': ('geom_hbond', 'atom_site_auth_comp_id_D', None, None),
                                         'ATOM_SITE_AUTH_COMP_ID_H': ('geom_hbond', 'atom_site_auth_comp_id_H', None, None),
                                         'ATOM_SITE_AUTH_SEQ_ID_A': ('geom_hbond', 'atom_site_auth_seq_id_A', None, None),
                                         'ATOM_SITE_AUTH_SEQ_ID_D': ('geom_hbond', 'atom_site_auth_seq_id_D', None, None),
                                         'ATOM_SITE_AUTH_SEQ_ID_H': ('geom_hbond', 'atom_site_auth_seq_id_H', None, None),
                                         'ATOM_SITE_ID_A': ('geom_hbond', 'atom_site_id_A', None, None),
                                         'ATOM_SITE_ID_D': ('geom_hbond', 'atom_site_id_D', None, None),
                                         'ATOM_SITE_ID_H': ('geom_hbond', 'atom_site_id_H', None, None),
                                         'ATOM_SITE_LABEL_ALT_ID_A': ('geom_hbond', 'atom_site_label_alt_id_A', None, None),
                                         'ATOM_SITE_LABEL_ALT_ID_D': ('geom_hbond', 'atom_site_label_alt_id_D', None, None),
                                         'ATOM_SITE_LABEL_ALT_ID_H': ('geom_hbond', 'atom_site_label_alt_id_H', None, None),
                                         'ATOM_SITE_LABEL_ASYM_ID_A': ('geom_hbond', 'atom_site_label_asym_id_A', None, None),
                                         'ATOM_SITE_LABEL_ASYM_ID_D': ('geom_hbond', 'atom_site_label_asym_id_D', None, None),
                                         'ATOM_SITE_LABEL_ASYM_ID_H': ('geom_hbond', 'atom_site_label_asym_id_H', None, None),
                                         'ATOM_SITE_LABEL_ATOM_ID_A': ('geom_hbond', 'atom_site_label_atom_id_A', None, None),
                                         'ATOM_SITE_LABEL_ATOM_ID_D': ('geom_hbond', 'atom_site_label_atom_id_D', None, None),
                                         'ATOM_SITE_LABEL_ATOM_ID_H': ('geom_hbond', 'atom_site_label_atom_id_H', None, None),
                                         'ATOM_SITE_LABEL_COMP_ID_A': ('geom_hbond', 'atom_site_label_comp_id_A', None, None),
                                         'ATOM_SITE_LABEL_COMP_ID_D': ('geom_hbond', 'atom_site_label_comp_id_D', None, None),
                                         'ATOM_SITE_LABEL_COMP_ID_H': ('geom_hbond', 'atom_site_label_comp_id_H', None, None),
                                         'ATOM_SITE_LABEL_SEQ_ID_A': ('geom_hbond', 'atom_site_label_seq_id_A', None, None),
                                         'ATOM_SITE_LABEL_SEQ_ID_D': ('geom_hbond', 'atom_site_label_seq_id_D', None, None),
                                         'ATOM_SITE_LABEL_SEQ_ID_H': ('geom_hbond', 'atom_site_label_seq_id_H', None, None),
                                         'DIST_DA': ('geom_hbond', 'dist_DA', None, None),
                                         'DIST_DA_ESD': ('geom_hbond', 'dist_DA_esd', None, None),
                                         'DIST_DH': ('geom_hbond', 'dist_DH', None, None),
                                         'DIST_DH_ESD': ('geom_hbond', 'dist_DH_esd', None, None),
                                         'DIST_HA': ('geom_hbond', 'dist_HA', None, None),
                                         'DIST_HA_ESD': ('geom_hbond', 'dist_HA_esd', None, None),
                                         'PUBL_FLAG': ('geom_hbond', 'publ_flag', None, None),
                                         'SITE_SYMMETRY_A': ('geom_hbond', 'site_symmetry_A', None, None),
                                         'SITE_SYMMETRY_D': ('geom_hbond', 'site_symmetry_D', None, None),
                                         'SITE_SYMMETRY_H': ('geom_hbond', 'site_symmetry_H', None, None),
                                         'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                       'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID',
                                                         'ATOM_SITE_ID_A',
                                                         'ATOM_SITE_ID_D',
                                                         'ATOM_SITE_ID_H',
                                                         'SITE_SYMMETRY_A',
                                                         'SITE_SYMMETRY_D',
                                                         'SITE_SYMMETRY_H'),
                                          'TYPE': 'UNIQUE'},
                                   's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                       'MAP_MERGE_INDICES': {'geom_hbond': {'ATTRIBUTES': ('atom_site_id_A',
                                                                           'atom_site_id_D',
                                                                           'atom_site_id_H',
                                                                           'site_symmetry_A',
                                                                           'site_symmetry_D',
                                                                           'site_symmetry_H'),
                                                            'TYPE': 'EQUI-JOIN'}},
                       'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                       'TABLE_ID': 'GEOM_HBOND',
                       'TABLE_NAME': 'geom_hbond',
                       'TABLE_TYPE': 'transactional'},
        'GEOM_TORSION': {'ATTRIBUTES': {'ATOM_SITE_AUTH_ASYM_ID_1': 'atom_site_auth_asym_id_1',
                                        'ATOM_SITE_AUTH_ASYM_ID_2': 'atom_site_auth_asym_id_2',
                                        'ATOM_SITE_AUTH_ASYM_ID_3': 'atom_site_auth_asym_id_3',
                                        'ATOM_SITE_AUTH_ASYM_ID_4': 'atom_site_auth_asym_id_4',
                                        'ATOM_SITE_AUTH_ATOM_ID_1': 'atom_site_auth_atom_id_1',
                                        'ATOM_SITE_AUTH_ATOM_ID_2': 'atom_site_auth_atom_id_2',
                                        'ATOM_SITE_AUTH_ATOM_ID_3': 'atom_site_auth_atom_id_3',
                                        'ATOM_SITE_AUTH_ATOM_ID_4': 'atom_site_auth_atom_id_4',
                                        'ATOM_SITE_AUTH_COMP_ID_1': 'atom_site_auth_comp_id_1',
                                        'ATOM_SITE_AUTH_COMP_ID_2': 'atom_site_auth_comp_id_2',
                                        'ATOM_SITE_AUTH_COMP_ID_3': 'atom_site_auth_comp_id_3',
                                        'ATOM_SITE_AUTH_COMP_ID_4': 'atom_site_auth_comp_id_4',
                                        'ATOM_SITE_AUTH_SEQ_ID_1': 'atom_site_auth_seq_id_1',
                                        'ATOM_SITE_AUTH_SEQ_ID_2': 'atom_site_auth_seq_id_2',
                                        'ATOM_SITE_AUTH_SEQ_ID_3': 'atom_site_auth_seq_id_3',
                                        'ATOM_SITE_AUTH_SEQ_ID_4': 'atom_site_auth_seq_id_4',
                                        'ATOM_SITE_ID_1': 'atom_site_id_1',
                                        'ATOM_SITE_ID_2': 'atom_site_id_2',
                                        'ATOM_SITE_ID_3': 'atom_site_id_3',
                                        'ATOM_SITE_ID_4': 'atom_site_id_4',
                                        'ATOM_SITE_LABEL_ALT_ID_1': 'atom_site_label_alt_id_1',
                                        'ATOM_SITE_LABEL_ALT_ID_2': 'atom_site_label_alt_id_2',
                                        'ATOM_SITE_LABEL_ALT_ID_3': 'atom_site_label_alt_id_3',
                                        'ATOM_SITE_LABEL_ALT_ID_4': 'atom_site_label_alt_id_4',
                                        'ATOM_SITE_LABEL_ASYM_ID_1': 'atom_site_label_asym_id_1',
                                        'ATOM_SITE_LABEL_ASYM_ID_2': 'atom_site_label_asym_id_2',
                                        'ATOM_SITE_LABEL_ASYM_ID_3': 'atom_site_label_asym_id_3',
                                        'ATOM_SITE_LABEL_ASYM_ID_4': 'atom_site_label_asym_id_4',
                                        'ATOM_SITE_LABEL_ATOM_ID_1': 'atom_site_label_atom_id_1',
                                        'ATOM_SITE_LABEL_ATOM_ID_2': 'atom_site_label_atom_id_2',
                                        'ATOM_SITE_LABEL_ATOM_ID_3': 'atom_site_label_atom_id_3',
                                        'ATOM_SITE_LABEL_ATOM_ID_4': 'atom_site_label_atom_id_4',
                                        'ATOM_SITE_LABEL_COMP_ID_1': 'atom_site_label_comp_id_1',
                                        'ATOM_SITE_LABEL_COMP_ID_2': 'atom_site_label_comp_id_2',
                                        'ATOM_SITE_LABEL_COMP_ID_3': 'atom_site_label_comp_id_3',
                                        'ATOM_SITE_LABEL_COMP_ID_4': 'atom_site_label_comp_id_4',
                                        'ATOM_SITE_LABEL_SEQ_ID_1': 'atom_site_label_seq_id_1',
                                        'ATOM_SITE_LABEL_SEQ_ID_2': 'atom_site_label_seq_id_2',
                                        'ATOM_SITE_LABEL_SEQ_ID_3': 'atom_site_label_seq_id_3',
                                        'ATOM_SITE_LABEL_SEQ_ID_4': 'atom_site_label_seq_id_4',
                                        'PDBX_ATOM_SITE_PDB_INS_CODE_1': 'pdbx_atom_site_PDB_ins_code_1',
                                        'PDBX_ATOM_SITE_PDB_INS_CODE_2': 'pdbx_atom_site_PDB_ins_code_2',
                                        'PDBX_ATOM_SITE_PDB_INS_CODE_3': 'pdbx_atom_site_PDB_ins_code_3',
                                        'PDBX_ATOM_SITE_PDB_INS_CODE_4': 'pdbx_atom_site_PDB_ins_code_4',
                                        'PDBX_PDB_MODEL_NUM': 'pdbx_PDB_model_num',
                                        'PUBL_FLAG': 'publ_flag',
                                        'SITE_SYMMETRY_1': 'site_symmetry_1',
                                        'SITE_SYMMETRY_2': 'site_symmetry_2',
                                        'SITE_SYMMETRY_3': 'site_symmetry_3',
                                        'SITE_SYMMETRY_4': 'site_symmetry_4',
                                        'STRUCTURE_ID': 'Structure_ID',
                                        'VALUE': 'value',
                                        'VALUE_ESD': 'value_esd'},
                         'ATTRIBUTE_INFO': {'ATOM_SITE_AUTH_ASYM_ID_1': {'NULLABLE': True,
                                                                         'ORDER': 2,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                            'ATOM_SITE_AUTH_ASYM_ID_2': {'NULLABLE': True,
                                                                         'ORDER': 3,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                            'ATOM_SITE_AUTH_ASYM_ID_3': {'NULLABLE': True,
                                                                         'ORDER': 4,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                            'ATOM_SITE_AUTH_ASYM_ID_4': {'NULLABLE': True,
                                                                         'ORDER': 5,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                            'ATOM_SITE_AUTH_ATOM_ID_1': {'NULLABLE': True,
                                                                         'ORDER': 6,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 6},
                                            'ATOM_SITE_AUTH_ATOM_ID_2': {'NULLABLE': True,
                                                                         'ORDER': 7,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 6},
                                            'ATOM_SITE_AUTH_ATOM_ID_3': {'NULLABLE': True,
                                                                         'ORDER': 8,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 6},
                                            'ATOM_SITE_AUTH_ATOM_ID_4': {'NULLABLE': True,
                                                                         'ORDER': 9,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 6},
                                            'ATOM_SITE_AUTH_COMP_ID_1': {'NULLABLE': True,
                                                                         'ORDER': 10,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                            'ATOM_SITE_AUTH_COMP_ID_2': {'NULLABLE': True,
                                                                         'ORDER': 11,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                            'ATOM_SITE_AUTH_COMP_ID_3': {'NULLABLE': True,
                                                                         'ORDER': 12,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                            'ATOM_SITE_AUTH_COMP_ID_4': {'NULLABLE': True,
                                                                         'ORDER': 13,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                            'ATOM_SITE_AUTH_SEQ_ID_1': {'NULLABLE': True,
                                                                        'ORDER': 14,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                            'ATOM_SITE_AUTH_SEQ_ID_2': {'NULLABLE': True,
                                                                        'ORDER': 15,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                            'ATOM_SITE_AUTH_SEQ_ID_3': {'NULLABLE': True,
                                                                        'ORDER': 16,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                            'ATOM_SITE_AUTH_SEQ_ID_4': {'NULLABLE': True,
                                                                        'ORDER': 17,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                            'ATOM_SITE_ID_1': {'NULLABLE': False,
                                                               'ORDER': 18,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                            'ATOM_SITE_ID_2': {'NULLABLE': False,
                                                               'ORDER': 19,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                            'ATOM_SITE_ID_3': {'NULLABLE': False,
                                                               'ORDER': 20,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                            'ATOM_SITE_ID_4': {'NULLABLE': False,
                                                               'ORDER': 21,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                            'ATOM_SITE_LABEL_ALT_ID_1': {'NULLABLE': True,
                                                                         'ORDER': 22,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                            'ATOM_SITE_LABEL_ALT_ID_2': {'NULLABLE': True,
                                                                         'ORDER': 23,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                            'ATOM_SITE_LABEL_ALT_ID_3': {'NULLABLE': True,
                                                                         'ORDER': 24,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                            'ATOM_SITE_LABEL_ALT_ID_4': {'NULLABLE': True,
                                                                         'ORDER': 25,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                            'ATOM_SITE_LABEL_ASYM_ID_1': {'NULLABLE': True,
                                                                          'ORDER': 38,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                            'ATOM_SITE_LABEL_ASYM_ID_2': {'NULLABLE': True,
                                                                          'ORDER': 39,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                            'ATOM_SITE_LABEL_ASYM_ID_3': {'NULLABLE': True,
                                                                          'ORDER': 40,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                            'ATOM_SITE_LABEL_ASYM_ID_4': {'NULLABLE': True,
                                                                          'ORDER': 41,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                            'ATOM_SITE_LABEL_ATOM_ID_1': {'NULLABLE': True,
                                                                          'ORDER': 30,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 6},
                                            'ATOM_SITE_LABEL_ATOM_ID_2': {'NULLABLE': True,
                                                                          'ORDER': 31,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 6},
                                            'ATOM_SITE_LABEL_ATOM_ID_3': {'NULLABLE': True,
                                                                          'ORDER': 32,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 6},
                                            'ATOM_SITE_LABEL_ATOM_ID_4': {'NULLABLE': True,
                                                                          'ORDER': 33,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 6},
                                            'ATOM_SITE_LABEL_COMP_ID_1': {'NULLABLE': True,
                                                                          'ORDER': 26,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                            'ATOM_SITE_LABEL_COMP_ID_2': {'NULLABLE': True,
                                                                          'ORDER': 27,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                            'ATOM_SITE_LABEL_COMP_ID_3': {'NULLABLE': True,
                                                                          'ORDER': 28,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                            'ATOM_SITE_LABEL_COMP_ID_4': {'NULLABLE': True,
                                                                          'ORDER': 29,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                            'ATOM_SITE_LABEL_SEQ_ID_1': {'NULLABLE': True,
                                                                         'ORDER': 34,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'INT',
                                                                         'WIDTH': 10},
                                            'ATOM_SITE_LABEL_SEQ_ID_2': {'NULLABLE': True,
                                                                         'ORDER': 35,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'INT',
                                                                         'WIDTH': 10},
                                            'ATOM_SITE_LABEL_SEQ_ID_3': {'NULLABLE': True,
                                                                         'ORDER': 36,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'INT',
                                                                         'WIDTH': 10},
                                            'ATOM_SITE_LABEL_SEQ_ID_4': {'NULLABLE': True,
                                                                         'ORDER': 37,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'INT',
                                                                         'WIDTH': 10},
                                            'PDBX_ATOM_SITE_PDB_INS_CODE_1': {'NULLABLE': True,
                                                                              'ORDER': 49,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                            'PDBX_ATOM_SITE_PDB_INS_CODE_2': {'NULLABLE': True,
                                                                              'ORDER': 50,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                            'PDBX_ATOM_SITE_PDB_INS_CODE_3': {'NULLABLE': True,
                                                                              'ORDER': 51,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                            'PDBX_ATOM_SITE_PDB_INS_CODE_4': {'NULLABLE': True,
                                                                              'ORDER': 52,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                            'PDBX_PDB_MODEL_NUM': {'NULLABLE': True,
                                                                   'ORDER': 53,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'INT',
                                                                   'WIDTH': 10},
                                            'PUBL_FLAG': {'NULLABLE': True,
                                                          'ORDER': 42,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 10},
                                            'SITE_SYMMETRY_1': {'NULLABLE': False,
                                                                'ORDER': 43,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                            'SITE_SYMMETRY_2': {'NULLABLE': False,
                                                                'ORDER': 44,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                            'SITE_SYMMETRY_3': {'NULLABLE': False,
                                                                'ORDER': 45,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                            'SITE_SYMMETRY_4': {'NULLABLE': False,
                                                                'ORDER': 46,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                            'STRUCTURE_ID': {'NULLABLE': False,
                                                             'ORDER': 1,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 10},
                                            'VALUE': {'NULLABLE': True,
                                                      'ORDER': 47,
                                                      'PRECISION': 6,
                                                      'PRIMARY_KEY': False,
                                                      'SQL_TYPE': 'FLOAT',
                                                      'WIDTH': 10},
                                            'VALUE_ESD': {'NULLABLE': True,
                                                          'ORDER': 48,
                                                          'PRECISION': 6,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'FLOAT',
                                                          'WIDTH': 10}},
                         'ATTRIBUTE_MAP': {'ATOM_SITE_AUTH_ASYM_ID_1': ('geom_torsion',
                                                                        'atom_site_auth_asym_id_1',
                                                                        None,
                                                                        None),
                                           'ATOM_SITE_AUTH_ASYM_ID_2': ('geom_torsion',
                                                                        'atom_site_auth_asym_id_2',
                                                                        None,
                                                                        None),
                                           'ATOM_SITE_AUTH_ASYM_ID_3': ('geom_torsion',
                                                                        'atom_site_auth_asym_id_3',
                                                                        None,
                                                                        None),
                                           'ATOM_SITE_AUTH_ASYM_ID_4': ('geom_torsion',
                                                                        'atom_site_auth_asym_id_4',
                                                                        None,
                                                                        None),
                                           'ATOM_SITE_AUTH_ATOM_ID_1': ('geom_torsion',
                                                                        'atom_site_auth_atom_id_1',
                                                                        None,
                                                                        None),
                                           'ATOM_SITE_AUTH_ATOM_ID_2': ('geom_torsion',
                                                                        'atom_site_auth_atom_id_2',
                                                                        None,
                                                                        None),
                                           'ATOM_SITE_AUTH_ATOM_ID_3': ('geom_torsion',
                                                                        'atom_site_auth_atom_id_3',
                                                                        None,
                                                                        None),
                                           'ATOM_SITE_AUTH_ATOM_ID_4': ('geom_torsion',
                                                                        'atom_site_auth_atom_id_4',
                                                                        None,
                                                                        None),
                                           'ATOM_SITE_AUTH_COMP_ID_1': ('geom_torsion',
                                                                        'atom_site_auth_comp_id_1',
                                                                        None,
                                                                        None),
                                           'ATOM_SITE_AUTH_COMP_ID_2': ('geom_torsion',
                                                                        'atom_site_auth_comp_id_2',
                                                                        None,
                                                                        None),
                                           'ATOM_SITE_AUTH_COMP_ID_3': ('geom_torsion',
                                                                        'atom_site_auth_comp_id_3',
                                                                        None,
                                                                        None),
                                           'ATOM_SITE_AUTH_COMP_ID_4': ('geom_torsion',
                                                                        'atom_site_auth_comp_id_4',
                                                                        None,
                                                                        None),
                                           'ATOM_SITE_AUTH_SEQ_ID_1': ('geom_torsion', 'atom_site_auth_seq_id_1', None, None),
                                           'ATOM_SITE_AUTH_SEQ_ID_2': ('geom_torsion', 'atom_site_auth_seq_id_2', None, None),
                                           'ATOM_SITE_AUTH_SEQ_ID_3': ('geom_torsion', 'atom_site_auth_seq_id_3', None, None),
                                           'ATOM_SITE_AUTH_SEQ_ID_4': ('geom_torsion', 'atom_site_auth_seq_id_4', None, None),
                                           'ATOM_SITE_ID_1': ('geom_torsion', 'atom_site_id_1', None, None),
                                           'ATOM_SITE_ID_2': ('geom_torsion', 'atom_site_id_2', None, None),
                                           'ATOM_SITE_ID_3': ('geom_torsion', 'atom_site_id_3', None, None),
                                           'ATOM_SITE_ID_4': ('geom_torsion', 'atom_site_id_4', None, None),
                                           'ATOM_SITE_LABEL_ALT_ID_1': ('geom_torsion',
                                                                        'atom_site_label_alt_id_1',
                                                                        None,
                                                                        None),
                                           'ATOM_SITE_LABEL_ALT_ID_2': ('geom_torsion',
                                                                        'atom_site_label_alt_id_2',
                                                                        None,
                                                                        None),
                                           'ATOM_SITE_LABEL_ALT_ID_3': ('geom_torsion',
                                                                        'atom_site_label_alt_id_3',
                                                                        None,
                                                                        None),
                                           'ATOM_SITE_LABEL_ALT_ID_4': ('geom_torsion',
                                                                        'atom_site_label_alt_id_4',
                                                                        None,
                                                                        None),
                                           'ATOM_SITE_LABEL_ASYM_ID_1': ('geom_torsion',
                                                                         'atom_site_label_asym_id_1',
                                                                         None,
                                                                         None),
                                           'ATOM_SITE_LABEL_ASYM_ID_2': ('geom_torsion',
                                                                         'atom_site_label_asym_id_2',
                                                                         None,
                                                                         None),
                                           'ATOM_SITE_LABEL_ASYM_ID_3': ('geom_torsion',
                                                                         'atom_site_label_asym_id_3',
                                                                         None,
                                                                         None),
                                           'ATOM_SITE_LABEL_ASYM_ID_4': ('geom_torsion',
                                                                         'atom_site_label_asym_id_4',
                                                                         None,
                                                                         None),
                                           'ATOM_SITE_LABEL_ATOM_ID_1': ('geom_torsion',
                                                                         'atom_site_label_atom_id_1',
                                                                         None,
                                                                         None),
                                           'ATOM_SITE_LABEL_ATOM_ID_2': ('geom_torsion',
                                                                         'atom_site_label_atom_id_2',
                                                                         None,
                                                                         None),
                                           'ATOM_SITE_LABEL_ATOM_ID_3': ('geom_torsion',
                                                                         'atom_site_label_atom_id_3',
                                                                         None,
                                                                         None),
                                           'ATOM_SITE_LABEL_ATOM_ID_4': ('geom_torsion',
                                                                         'atom_site_label_atom_id_4',
                                                                         None,
                                                                         None),
                                           'ATOM_SITE_LABEL_COMP_ID_1': ('geom_torsion',
                                                                         'atom_site_label_comp_id_1',
                                                                         None,
                                                                         None),
                                           'ATOM_SITE_LABEL_COMP_ID_2': ('geom_torsion',
                                                                         'atom_site_label_comp_id_2',
                                                                         None,
                                                                         None),
                                           'ATOM_SITE_LABEL_COMP_ID_3': ('geom_torsion',
                                                                         'atom_site_label_comp_id_3',
                                                                         None,
                                                                         None),
                                           'ATOM_SITE_LABEL_COMP_ID_4': ('geom_torsion',
                                                                         'atom_site_label_comp_id_4',
                                                                         None,
                                                                         None),
                                           'ATOM_SITE_LABEL_SEQ_ID_1': ('geom_torsion',
                                                                        'atom_site_label_seq_id_1',
                                                                        None,
                                                                        None),
                                           'ATOM_SITE_LABEL_SEQ_ID_2': ('geom_torsion',
                                                                        'atom_site_label_seq_id_2',
                                                                        None,
                                                                        None),
                                           'ATOM_SITE_LABEL_SEQ_ID_3': ('geom_torsion',
                                                                        'atom_site_label_seq_id_3',
                                                                        None,
                                                                        None),
                                           'ATOM_SITE_LABEL_SEQ_ID_4': ('geom_torsion',
                                                                        'atom_site_label_seq_id_4',
                                                                        None,
                                                                        None),
                                           'PDBX_ATOM_SITE_PDB_INS_CODE_1': ('geom_torsion',
                                                                             'pdbx_atom_site_PDB_ins_code_1',
                                                                             None,
                                                                             None),
                                           'PDBX_ATOM_SITE_PDB_INS_CODE_2': ('geom_torsion',
                                                                             'pdbx_atom_site_PDB_ins_code_2',
                                                                             None,
                                                                             None),
                                           'PDBX_ATOM_SITE_PDB_INS_CODE_3': ('geom_torsion',
                                                                             'pdbx_atom_site_PDB_ins_code_3',
                                                                             None,
                                                                             None),
                                           'PDBX_ATOM_SITE_PDB_INS_CODE_4': ('geom_torsion',
                                                                             'pdbx_atom_site_PDB_ins_code_4',
                                                                             None,
                                                                             None),
                                           'PDBX_PDB_MODEL_NUM': ('geom_torsion', 'pdbx_PDB_model_num', None, None),
                                           'PUBL_FLAG': ('geom_torsion', 'publ_flag', None, None),
                                           'SITE_SYMMETRY_1': ('geom_torsion', 'site_symmetry_1', None, None),
                                           'SITE_SYMMETRY_2': ('geom_torsion', 'site_symmetry_2', None, None),
                                           'SITE_SYMMETRY_3': ('geom_torsion', 'site_symmetry_3', None, None),
                                           'SITE_SYMMETRY_4': ('geom_torsion', 'site_symmetry_4', None, None),
                                           'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                           'VALUE': ('geom_torsion', 'value', None, None),
                                           'VALUE_ESD': ('geom_torsion', 'value_esd', None, None)},
                         'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID',
                                                           'ATOM_SITE_ID_1',
                                                           'ATOM_SITE_ID_2',
                                                           'ATOM_SITE_ID_3',
                                                           'ATOM_SITE_ID_4',
                                                           'SITE_SYMMETRY_1',
                                                           'SITE_SYMMETRY_2',
                                                           'SITE_SYMMETRY_3',
                                                           'SITE_SYMMETRY_4'),
                                            'TYPE': 'UNIQUE'},
                                     's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                         'MAP_MERGE_INDICES': {'geom_torsion': {'ATTRIBUTES': ('atom_site_id_1',
                                                                               'atom_site_id_2',
                                                                               'atom_site_id_3',
                                                                               'atom_site_id_4',
                                                                               'site_symmetry_1',
                                                                               'site_symmetry_2',
                                                                               'site_symmetry_3',
                                                                               'site_symmetry_4'),
                                                                'TYPE': 'EQUI-JOIN'}},
                         'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                         'TABLE_ID': 'GEOM_TORSION',
                         'TABLE_NAME': 'geom_torsion',
                         'TABLE_TYPE': 'transactional'},
        'JOURNAL': {'ATTRIBUTES': {'CODEN_ASTM': 'coden_ASTM',
                                   'CODEN_CAMBRIDGE': 'coden_Cambridge',
                                   'COEDITOR_ADDRESS': 'coeditor_address',
                                   'COEDITOR_CODE': 'coeditor_code',
                                   'COEDITOR_EMAIL': 'coeditor_email',
                                   'COEDITOR_FAX': 'coeditor_fax',
                                   'COEDITOR_NAME': 'coeditor_name',
                                   'COEDITOR_NOTES': 'coeditor_notes',
                                   'COEDITOR_PHONE': 'coeditor_phone',
                                   'DATA_VALIDATION_NUMBER': 'data_validation_number',
                                   'DATE_ACCEPTED': 'date_accepted',
                                   'DATE_FROM_COEDITOR': 'date_from_coeditor',
                                   'DATE_PRINTERS_FINAL': 'date_printers_final',
                                   'DATE_PRINTERS_FIRST': 'date_printers_first',
                                   'DATE_PROOFS_IN': 'date_proofs_in',
                                   'DATE_PROOFS_OUT': 'date_proofs_out',
                                   'DATE_RECD_COPYRIGHT': 'date_recd_copyright',
                                   'DATE_RECD_ELECTRONIC': 'date_recd_electronic',
                                   'DATE_RECD_HARD_COPY': 'date_recd_hard_copy',
                                   'DATE_TO_COEDITOR': 'date_to_coeditor',
                                   'ENTRY_ID': 'entry_id',
                                   'ISSUE': 'issue',
                                   'LANGUAGE': 'language',
                                   'NAME_FULL': 'name_full',
                                   'PAGE_FIRST': 'page_first',
                                   'PAGE_LAST': 'page_last',
                                   'PAPER_CATEGORY': 'paper_category',
                                   'STRUCTURE_ID': 'Structure_ID',
                                   'SUPPL_PUBL_NUMBER': 'suppl_publ_number',
                                   'SUPPL_PUBL_PAGES': 'suppl_publ_pages',
                                   'TECHEDITOR_ADDRESS': 'techeditor_address',
                                   'TECHEDITOR_CODE': 'techeditor_code',
                                   'TECHEDITOR_EMAIL': 'techeditor_email',
                                   'TECHEDITOR_FAX': 'techeditor_fax',
                                   'TECHEDITOR_NAME': 'techeditor_name',
                                   'TECHEDITOR_NOTES': 'techeditor_notes',
                                   'TECHEDITOR_PHONE': 'techeditor_phone',
                                   'VOLUME': 'volume',
                                   'YEAR': 'year'},
                    'ATTRIBUTE_INFO': {'CODEN_ASTM': {'NULLABLE': True,
                                                      'ORDER': 3,
                                                      'PRECISION': 0,
                                                      'PRIMARY_KEY': False,
                                                      'SQL_TYPE': 'VARCHAR',
                                                      'WIDTH': 80},
                                       'CODEN_CAMBRIDGE': {'NULLABLE': True,
                                                           'ORDER': 4,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 80},
                                       'COEDITOR_ADDRESS': {'NULLABLE': True,
                                                            'ORDER': 5,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 200},
                                       'COEDITOR_CODE': {'NULLABLE': True,
                                                         'ORDER': 6,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 80},
                                       'COEDITOR_EMAIL': {'NULLABLE': True,
                                                          'ORDER': 7,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 80},
                                       'COEDITOR_FAX': {'NULLABLE': True,
                                                        'ORDER': 8,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 80},
                                       'COEDITOR_NAME': {'NULLABLE': True,
                                                         'ORDER': 9,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 80},
                                       'COEDITOR_NOTES': {'NULLABLE': True,
                                                          'ORDER': 10,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 200},
                                       'COEDITOR_PHONE': {'NULLABLE': True,
                                                          'ORDER': 11,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 80},
                                       'DATA_VALIDATION_NUMBER': {'NULLABLE': True,
                                                                  'ORDER': 12,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10},
                                       'DATE_ACCEPTED': {'NULLABLE': True,
                                                         'ORDER': 13,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'DATETIME',
                                                         'WIDTH': 15},
                                       'DATE_FROM_COEDITOR': {'NULLABLE': True,
                                                              'ORDER': 14,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'DATETIME',
                                                              'WIDTH': 15},
                                       'DATE_PRINTERS_FINAL': {'NULLABLE': True,
                                                               'ORDER': 16,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'DATETIME',
                                                               'WIDTH': 15},
                                       'DATE_PRINTERS_FIRST': {'NULLABLE': True,
                                                               'ORDER': 17,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'DATETIME',
                                                               'WIDTH': 15},
                                       'DATE_PROOFS_IN': {'NULLABLE': True,
                                                          'ORDER': 18,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'DATETIME',
                                                          'WIDTH': 15},
                                       'DATE_PROOFS_OUT': {'NULLABLE': True,
                                                           'ORDER': 19,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'DATETIME',
                                                           'WIDTH': 15},
                                       'DATE_RECD_COPYRIGHT': {'NULLABLE': True,
                                                               'ORDER': 20,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'DATETIME',
                                                               'WIDTH': 15},
                                       'DATE_RECD_ELECTRONIC': {'NULLABLE': True,
                                                                'ORDER': 21,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'DATETIME',
                                                                'WIDTH': 15},
                                       'DATE_RECD_HARD_COPY': {'NULLABLE': True,
                                                               'ORDER': 22,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'DATETIME',
                                                               'WIDTH': 15},
                                       'DATE_TO_COEDITOR': {'NULLABLE': True,
                                                            'ORDER': 15,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'DATETIME',
                                                            'WIDTH': 15},
                                       'ENTRY_ID': {'NULLABLE': False,
                                                    'ORDER': 2,
                                                    'PRECISION': 0,
                                                    'PRIMARY_KEY': True,
                                                    'SQL_TYPE': 'VARCHAR',
                                                    'WIDTH': 10},
                                       'ISSUE': {'NULLABLE': True,
                                                 'ORDER': 23,
                                                 'PRECISION': 0,
                                                 'PRIMARY_KEY': False,
                                                 'SQL_TYPE': 'VARCHAR',
                                                 'WIDTH': 80},
                                       'LANGUAGE': {'NULLABLE': True,
                                                    'ORDER': 24,
                                                    'PRECISION': 0,
                                                    'PRIMARY_KEY': False,
                                                    'SQL_TYPE': 'VARCHAR',
                                                    'WIDTH': 80},
                                       'NAME_FULL': {'NULLABLE': True,
                                                     'ORDER': 25,
                                                     'PRECISION': 0,
                                                     'PRIMARY_KEY': False,
                                                     'SQL_TYPE': 'VARCHAR',
                                                     'WIDTH': 80},
                                       'PAGE_FIRST': {'NULLABLE': True,
                                                      'ORDER': 26,
                                                      'PRECISION': 0,
                                                      'PRIMARY_KEY': False,
                                                      'SQL_TYPE': 'VARCHAR',
                                                      'WIDTH': 80},
                                       'PAGE_LAST': {'NULLABLE': True,
                                                     'ORDER': 27,
                                                     'PRECISION': 0,
                                                     'PRIMARY_KEY': False,
                                                     'SQL_TYPE': 'VARCHAR',
                                                     'WIDTH': 80},
                                       'PAPER_CATEGORY': {'NULLABLE': True,
                                                          'ORDER': 28,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 80},
                                       'STRUCTURE_ID': {'NULLABLE': False,
                                                        'ORDER': 1,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': True,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 10},
                                       'SUPPL_PUBL_NUMBER': {'NULLABLE': True,
                                                             'ORDER': 29,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 80},
                                       'SUPPL_PUBL_PAGES': {'NULLABLE': True,
                                                            'ORDER': 30,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 80},
                                       'TECHEDITOR_ADDRESS': {'NULLABLE': True,
                                                              'ORDER': 31,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 200},
                                       'TECHEDITOR_CODE': {'NULLABLE': True,
                                                           'ORDER': 32,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 80},
                                       'TECHEDITOR_EMAIL': {'NULLABLE': True,
                                                            'ORDER': 33,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 80},
                                       'TECHEDITOR_FAX': {'NULLABLE': True,
                                                          'ORDER': 34,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 80},
                                       'TECHEDITOR_NAME': {'NULLABLE': True,
                                                           'ORDER': 35,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 80},
                                       'TECHEDITOR_NOTES': {'NULLABLE': True,
                                                            'ORDER': 36,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 200},
                                       'TECHEDITOR_PHONE': {'NULLABLE': True,
                                                            'ORDER': 37,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 80},
                                       'VOLUME': {'NULLABLE': True,
                                                  'ORDER': 38,
                                                  'PRECISION': 0,
                                                  'PRIMARY_KEY': False,
                                                  'SQL_TYPE': 'VARCHAR',
                                                  'WIDTH': 80},
                                       'YEAR': {'NULLABLE': True,
                                                'ORDER': 39,
                                                'PRECISION': 0,
                                                'PRIMARY_KEY': False,
                                                'SQL_TYPE': 'VARCHAR',
                                                'WIDTH': 80}},
                    'ATTRIBUTE_MAP': {'CODEN_ASTM': ('journal', 'coden_ASTM', None, None),
                                      'CODEN_CAMBRIDGE': ('journal', 'coden_Cambridge', None, None),
                                      'COEDITOR_ADDRESS': ('journal', 'coeditor_address', None, None),
                                      'COEDITOR_CODE': ('journal', 'coeditor_code', None, None),
                                      'COEDITOR_EMAIL': ('journal', 'coeditor_email', None, None),
                                      'COEDITOR_FAX': ('journal', 'coeditor_fax', None, None),
                                      'COEDITOR_NAME': ('journal', 'coeditor_name', None, None),
                                      'COEDITOR_NOTES': ('journal', 'coeditor_notes', None, None),
                                      'COEDITOR_PHONE': ('journal', 'coeditor_phone', None, None),
                                      'DATA_VALIDATION_NUMBER': ('journal', 'data_validation_number', None, None),
                                      'DATE_ACCEPTED': ('journal', 'date_accepted', None, None),
                                      'DATE_FROM_COEDITOR': ('journal', 'date_from_coeditor', None, None),
                                      'DATE_PRINTERS_FINAL': ('journal', 'date_printers_final', None, None),
                                      'DATE_PRINTERS_FIRST': ('journal', 'date_printers_first', None, None),
                                      'DATE_PROOFS_IN': ('journal', 'date_proofs_in', None, None),
                                      'DATE_PROOFS_OUT': ('journal', 'date_proofs_out', None, None),
                                      'DATE_RECD_COPYRIGHT': ('journal', 'date_recd_copyright', None, None),
                                      'DATE_RECD_ELECTRONIC': ('journal', 'date_recd_electronic', None, None),
                                      'DATE_RECD_HARD_COPY': ('journal', 'date_recd_hard_copy', None, None),
                                      'DATE_TO_COEDITOR': ('journal', 'date_to_coeditor', None, None),
                                      'ENTRY_ID': ('journal', 'entry_id', None, None),
                                      'ISSUE': ('journal', 'issue', None, None),
                                      'LANGUAGE': ('journal', 'language', None, None),
                                      'NAME_FULL': ('journal', 'name_full', None, None),
                                      'PAGE_FIRST': ('journal', 'page_first', None, None),
                                      'PAGE_LAST': ('journal', 'page_last', None, None),
                                      'PAPER_CATEGORY': ('journal', 'paper_category', None, None),
                                      'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                      'SUPPL_PUBL_NUMBER': ('journal', 'suppl_publ_number', None, None),
                                      'SUPPL_PUBL_PAGES': ('journal', 'suppl_publ_pages', None, None),
                                      'TECHEDITOR_ADDRESS': ('journal', 'techeditor_address', None, None),
                                      'TECHEDITOR_CODE': ('journal', 'techeditor_code', None, None),
                                      'TECHEDITOR_EMAIL': ('journal', 'techeditor_email', None, None),
                                      'TECHEDITOR_FAX': ('journal', 'techeditor_fax', None, None),
                                      'TECHEDITOR_NAME': ('journal', 'techeditor_name', None, None),
                                      'TECHEDITOR_NOTES': ('journal', 'techeditor_notes', None, None),
                                      'TECHEDITOR_PHONE': ('journal', 'techeditor_phone', None, None),
                                      'VOLUME': ('journal', 'volume', None, None),
                                      'YEAR': ('journal', 'year', None, None)},
                    'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID'), 'TYPE': 'UNIQUE'},
                                's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                    'MAP_MERGE_INDICES': {'journal': {'ATTRIBUTES': ('entry_id',), 'TYPE': 'EQUI-JOIN'}},
                    'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                    'TABLE_ID': 'JOURNAL',
                    'TABLE_NAME': 'journal',
                    'TABLE_TYPE': 'transactional'},
        'JOURNAL_INDEX': {'ATTRIBUTES': {'STRUCTURE_ID': 'Structure_ID', 'SUBTERM': 'subterm', 'TERM': 'term', 'TYPE': 'type'},
                          'ATTRIBUTE_INFO': {'STRUCTURE_ID': {'NULLABLE': False,
                                                              'ORDER': 1,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10},
                                             'SUBTERM': {'NULLABLE': True,
                                                         'ORDER': 2,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 80},
                                             'TERM': {'NULLABLE': False,
                                                      'ORDER': 3,
                                                      'PRECISION': 0,
                                                      'PRIMARY_KEY': True,
                                                      'SQL_TYPE': 'VARCHAR',
                                                      'WIDTH': 80},
                                             'TYPE': {'NULLABLE': False,
                                                      'ORDER': 4,
                                                      'PRECISION': 0,
                                                      'PRIMARY_KEY': True,
                                                      'SQL_TYPE': 'VARCHAR',
                                                      'WIDTH': 80}},
                          'ATTRIBUTE_MAP': {'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                            'SUBTERM': ('journal_index', 'subterm', None, None),
                                            'TERM': ('journal_index', 'term', None, None),
                                            'TYPE': ('journal_index', 'type', None, None)},
                          'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'TERM', 'TYPE'), 'TYPE': 'UNIQUE'},
                                      's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                          'MAP_MERGE_INDICES': {'journal_index': {'ATTRIBUTES': ('term', 'type'), 'TYPE': 'EQUI-JOIN'}},
                          'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                          'TABLE_ID': 'JOURNAL_INDEX',
                          'TABLE_NAME': 'journal_index',
                          'TABLE_TYPE': 'transactional'},
        'NDB_ORIGINAL_NDB_COORDINATES': {'ATTRIBUTES': {'COORD_SECTION': 'coord_section', 'STRUCTURE_ID': 'Structure_ID'},
                                         'ATTRIBUTE_INFO': {'COORD_SECTION': {'NULLABLE': False,
                                                                              'ORDER': 2,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': True,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 200},
                                                            'STRUCTURE_ID': {'NULLABLE': False,
                                                                             'ORDER': 1,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': True,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10}},
                                         'ATTRIBUTE_MAP': {'COORD_SECTION': ('ndb_original_ndb_coordinates',
                                                                             'coord_section',
                                                                             None,
                                                                             None),
                                                           'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                         'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'COORD_SECTION'), 'TYPE': 'UNIQUE'},
                                                     's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                         'MAP_MERGE_INDICES': {'ndb_original_ndb_coordinates': {'ATTRIBUTES': ('coord_section',),
                                                                                                'TYPE': 'EQUI-JOIN'}},
                                         'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                         'TABLE_ID': 'NDB_ORIGINAL_NDB_COORDINATES',
                                         'TABLE_NAME': 'ndb_original_ndb_coordinates',
                                         'TABLE_TYPE': 'transactional'},
        'NDB_STRUCT_CONF_NA': {'ATTRIBUTES': {'ENTRY_ID': 'entry_id',
                                              'FEATURE': 'feature',
                                              'FEATURE_COUNT': 'feature_count',
                                              'STRUCTURE_ID': 'Structure_ID'},
                               'ATTRIBUTE_INFO': {'ENTRY_ID': {'NULLABLE': False,
                                                               'ORDER': 2,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                                  'FEATURE': {'NULLABLE': False,
                                                              'ORDER': 3,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 80},
                                                  'FEATURE_COUNT': {'NULLABLE': True,
                                                                    'ORDER': 4,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'INT',
                                                                    'WIDTH': 10},
                                                  'STRUCTURE_ID': {'NULLABLE': False,
                                                                   'ORDER': 1,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': True,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 10}},
                               'ATTRIBUTE_MAP': {'ENTRY_ID': ('ndb_struct_conf_na', 'entry_id', None, None),
                                                 'FEATURE': ('ndb_struct_conf_na', 'feature', None, None),
                                                 'FEATURE_COUNT': ('ndb_struct_conf_na', 'feature_count', None, None),
                                                 'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                               'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID', 'FEATURE'), 'TYPE': 'UNIQUE'},
                                           's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                               'MAP_MERGE_INDICES': {'ndb_struct_conf_na': {'ATTRIBUTES': ('entry_id', 'feature'),
                                                                            'TYPE': 'EQUI-JOIN'}},
                               'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                               'TABLE_ID': 'NDB_STRUCT_CONF_NA',
                               'TABLE_NAME': 'ndb_struct_conf_na',
                               'TABLE_TYPE': 'transactional'},
        'NDB_STRUCT_FEATURE_NA': {'ATTRIBUTES': {'ENTRY_ID': 'entry_id',
                                                 'FEATURE': 'feature',
                                                 'FEATURE_COUNT': 'feature_count',
                                                 'STRUCTURE_ID': 'Structure_ID'},
                                  'ATTRIBUTE_INFO': {'ENTRY_ID': {'NULLABLE': False,
                                                                  'ORDER': 2,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': True,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10},
                                                     'FEATURE': {'NULLABLE': False,
                                                                 'ORDER': 3,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': True,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 80},
                                                     'FEATURE_COUNT': {'NULLABLE': True,
                                                                       'ORDER': 4,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'INT',
                                                                       'WIDTH': 10},
                                                     'STRUCTURE_ID': {'NULLABLE': False,
                                                                      'ORDER': 1,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10}},
                                  'ATTRIBUTE_MAP': {'ENTRY_ID': ('ndb_struct_feature_na', 'entry_id', None, None),
                                                    'FEATURE': ('ndb_struct_feature_na', 'feature', None, None),
                                                    'FEATURE_COUNT': ('ndb_struct_feature_na', 'feature_count', None, None),
                                                    'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                  'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID', 'FEATURE'), 'TYPE': 'UNIQUE'},
                                              's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                  'MAP_MERGE_INDICES': {'ndb_struct_feature_na': {'ATTRIBUTES': ('entry_id', 'feature'),
                                                                                  'TYPE': 'EQUI-JOIN'}},
                                  'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                  'TABLE_ID': 'NDB_STRUCT_FEATURE_NA',
                                  'TABLE_NAME': 'ndb_struct_feature_na',
                                  'TABLE_TYPE': 'transactional'},
        'NDB_STRUCT_NA_BASE_PAIR': {'ATTRIBUTES': {'BUCKLE': 'buckle',
                                                   'HBOND_TYPE_12': 'hbond_type_12',
                                                   'HBOND_TYPE_28': 'hbond_type_28',
                                                   'I_AUTH_ASYM_ID': 'i_auth_asym_id',
                                                   'I_AUTH_SEQ_ID': 'i_auth_seq_id',
                                                   'I_LABEL_ASYM_ID': 'i_label_asym_id',
                                                   'I_LABEL_COMP_ID': 'i_label_comp_id',
                                                   'I_LABEL_SEQ_ID': 'i_label_seq_id',
                                                   'I_PDB_INS_CODE': 'i_PDB_ins_code',
                                                   'I_SYMMETRY': 'i_symmetry',
                                                   'J_AUTH_ASYM_ID': 'j_auth_asym_id',
                                                   'J_AUTH_SEQ_ID': 'j_auth_seq_id',
                                                   'J_LABEL_ASYM_ID': 'j_label_asym_id',
                                                   'J_LABEL_COMP_ID': 'j_label_comp_id',
                                                   'J_LABEL_SEQ_ID': 'j_label_seq_id',
                                                   'J_PDB_INS_CODE': 'j_PDB_ins_code',
                                                   'J_SYMMETRY': 'j_symmetry',
                                                   'MODEL_NUMBER': 'model_number',
                                                   'OPENING': 'opening',
                                                   'PAIR_NAME': 'pair_name',
                                                   'PAIR_NUMBER': 'pair_number',
                                                   'PROPELLER': 'propeller',
                                                   'SHEAR': 'shear',
                                                   'STAGGER': 'stagger',
                                                   'STRETCH': 'stretch',
                                                   'STRUCTURE_ID': 'Structure_ID'},
                                    'ATTRIBUTE_INFO': {'BUCKLE': {'NULLABLE': True,
                                                                  'ORDER': 22,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10},
                                                       'HBOND_TYPE_12': {'NULLABLE': True,
                                                                         'ORDER': 25,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'INT',
                                                                         'WIDTH': 10},
                                                       'HBOND_TYPE_28': {'NULLABLE': True,
                                                                         'ORDER': 26,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'INT',
                                                                         'WIDTH': 10},
                                                       'I_AUTH_ASYM_ID': {'NULLABLE': True,
                                                                          'ORDER': 13,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                       'I_AUTH_SEQ_ID': {'NULLABLE': True,
                                                                         'ORDER': 14,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                                       'I_LABEL_ASYM_ID': {'NULLABLE': False,
                                                                           'ORDER': 5,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': True,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10},
                                                       'I_LABEL_COMP_ID': {'NULLABLE': False,
                                                                           'ORDER': 6,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': True,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10},
                                                       'I_LABEL_SEQ_ID': {'NULLABLE': False,
                                                                          'ORDER': 7,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': True,
                                                                          'SQL_TYPE': 'INT',
                                                                          'WIDTH': 10},
                                                       'I_PDB_INS_CODE': {'NULLABLE': True,
                                                                          'ORDER': 15,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                       'I_SYMMETRY': {'NULLABLE': False,
                                                                      'ORDER': 8,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                                       'J_AUTH_ASYM_ID': {'NULLABLE': True,
                                                                          'ORDER': 16,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                       'J_AUTH_SEQ_ID': {'NULLABLE': True,
                                                                         'ORDER': 17,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                                       'J_LABEL_ASYM_ID': {'NULLABLE': False,
                                                                           'ORDER': 9,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': True,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10},
                                                       'J_LABEL_COMP_ID': {'NULLABLE': False,
                                                                           'ORDER': 10,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': True,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10},
                                                       'J_LABEL_SEQ_ID': {'NULLABLE': False,
                                                                          'ORDER': 11,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': True,
                                                                          'SQL_TYPE': 'INT',
                                                                          'WIDTH': 10},
                                                       'J_PDB_INS_CODE': {'NULLABLE': True,
                                                                          'ORDER': 18,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                       'J_SYMMETRY': {'NULLABLE': False,
                                                                      'ORDER': 12,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                                       'MODEL_NUMBER': {'NULLABLE': False,
                                                                        'ORDER': 2,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': True,
                                                                        'SQL_TYPE': 'INT',
                                                                        'WIDTH': 10},
                                                       'OPENING': {'NULLABLE': True,
                                                                   'ORDER': 24,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                                       'PAIR_NAME': {'NULLABLE': True,
                                                                     'ORDER': 4,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 80},
                                                       'PAIR_NUMBER': {'NULLABLE': True,
                                                                       'ORDER': 3,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'INT',
                                                                       'WIDTH': 10},
                                                       'PROPELLER': {'NULLABLE': True,
                                                                     'ORDER': 23,
                                                                     'PRECISION': 6,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'FLOAT',
                                                                     'WIDTH': 10},
                                                       'SHEAR': {'NULLABLE': True,
                                                                 'ORDER': 19,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                                       'STAGGER': {'NULLABLE': True,
                                                                   'ORDER': 21,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                                       'STRETCH': {'NULLABLE': True,
                                                                   'ORDER': 20,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                                       'STRUCTURE_ID': {'NULLABLE': False,
                                                                        'ORDER': 1,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': True,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10}},
                                    'ATTRIBUTE_MAP': {'BUCKLE': ('ndb_struct_na_base_pair', 'buckle', None, None),
                                                      'HBOND_TYPE_12': ('ndb_struct_na_base_pair',
                                                                        'hbond_type_12',
                                                                        None,
                                                                        None),
                                                      'HBOND_TYPE_28': ('ndb_struct_na_base_pair',
                                                                        'hbond_type_28',
                                                                        None,
                                                                        None),
                                                      'I_AUTH_ASYM_ID': ('ndb_struct_na_base_pair',
                                                                         'i_auth_asym_id',
                                                                         None,
                                                                         None),
                                                      'I_AUTH_SEQ_ID': ('ndb_struct_na_base_pair',
                                                                        'i_auth_seq_id',
                                                                        None,
                                                                        None),
                                                      'I_LABEL_ASYM_ID': ('ndb_struct_na_base_pair',
                                                                          'i_label_asym_id',
                                                                          None,
                                                                          None),
                                                      'I_LABEL_COMP_ID': ('ndb_struct_na_base_pair',
                                                                          'i_label_comp_id',
                                                                          None,
                                                                          None),
                                                      'I_LABEL_SEQ_ID': ('ndb_struct_na_base_pair',
                                                                         'i_label_seq_id',
                                                                         None,
                                                                         None),
                                                      'I_PDB_INS_CODE': ('ndb_struct_na_base_pair',
                                                                         'i_PDB_ins_code',
                                                                         None,
                                                                         None),
                                                      'I_SYMMETRY': ('ndb_struct_na_base_pair', 'i_symmetry', None, None),
                                                      'J_AUTH_ASYM_ID': ('ndb_struct_na_base_pair',
                                                                         'j_auth_asym_id',
                                                                         None,
                                                                         None),
                                                      'J_AUTH_SEQ_ID': ('ndb_struct_na_base_pair',
                                                                        'j_auth_seq_id',
                                                                        None,
                                                                        None),
                                                      'J_LABEL_ASYM_ID': ('ndb_struct_na_base_pair',
                                                                          'j_label_asym_id',
                                                                          None,
                                                                          None),
                                                      'J_LABEL_COMP_ID': ('ndb_struct_na_base_pair',
                                                                          'j_label_comp_id',
                                                                          None,
                                                                          None),
                                                      'J_LABEL_SEQ_ID': ('ndb_struct_na_base_pair',
                                                                         'j_label_seq_id',
                                                                         None,
                                                                         None),
                                                      'J_PDB_INS_CODE': ('ndb_struct_na_base_pair',
                                                                         'j_PDB_ins_code',
                                                                         None,
                                                                         None),
                                                      'J_SYMMETRY': ('ndb_struct_na_base_pair', 'j_symmetry', None, None),
                                                      'MODEL_NUMBER': ('ndb_struct_na_base_pair', 'model_number', None, None),
                                                      'OPENING': ('ndb_struct_na_base_pair', 'opening', None, None),
                                                      'PAIR_NAME': ('ndb_struct_na_base_pair', 'pair_name', None, None),
                                                      'PAIR_NUMBER': ('ndb_struct_na_base_pair', 'pair_number', None, None),
                                                      'PROPELLER': ('ndb_struct_na_base_pair', 'propeller', None, None),
                                                      'SHEAR': ('ndb_struct_na_base_pair', 'shear', None, None),
                                                      'STAGGER': ('ndb_struct_na_base_pair', 'stagger', None, None),
                                                      'STRETCH': ('ndb_struct_na_base_pair', 'stretch', None, None),
                                                      'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                    'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID',
                                                                      'MODEL_NUMBER',
                                                                      'I_LABEL_ASYM_ID',
                                                                      'I_LABEL_COMP_ID',
                                                                      'I_LABEL_SEQ_ID',
                                                                      'I_SYMMETRY',
                                                                      'J_LABEL_ASYM_ID',
                                                                      'J_LABEL_COMP_ID',
                                                                      'J_LABEL_SEQ_ID',
                                                                      'J_SYMMETRY'),
                                                       'TYPE': 'UNIQUE'},
                                                's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                    'MAP_MERGE_INDICES': {'ndb_struct_na_base_pair': {'ATTRIBUTES': ('model_number',
                                                                                                     'i_label_asym_id',
                                                                                                     'i_label_comp_id',
                                                                                                     'i_label_seq_id',
                                                                                                     'i_symmetry',
                                                                                                     'j_label_asym_id',
                                                                                                     'j_label_comp_id',
                                                                                                     'j_label_seq_id',
                                                                                                     'j_symmetry'),
                                                                                      'TYPE': 'EQUI-JOIN'}},
                                    'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                    'TABLE_ID': 'NDB_STRUCT_NA_BASE_PAIR',
                                    'TABLE_NAME': 'ndb_struct_na_base_pair',
                                    'TABLE_TYPE': 'transactional'},
        'NDB_STRUCT_NA_BASE_PAIR_STEP': {'ATTRIBUTES': {'HELICAL_RISE': 'helical_rise',
                                                        'HELICAL_TWIST': 'helical_twist',
                                                        'INCLINATION': 'inclination',
                                                        'I_AUTH_ASYM_ID_1': 'i_auth_asym_id_1',
                                                        'I_AUTH_ASYM_ID_2': 'i_auth_asym_id_2',
                                                        'I_AUTH_SEQ_ID_1': 'i_auth_seq_id_1',
                                                        'I_AUTH_SEQ_ID_2': 'i_auth_seq_id_2',
                                                        'I_LABEL_ASYM_ID_1': 'i_label_asym_id_1',
                                                        'I_LABEL_ASYM_ID_2': 'i_label_asym_id_2',
                                                        'I_LABEL_COMP_ID_1': 'i_label_comp_id_1',
                                                        'I_LABEL_COMP_ID_2': 'i_label_comp_id_2',
                                                        'I_LABEL_SEQ_ID_1': 'i_label_seq_id_1',
                                                        'I_LABEL_SEQ_ID_2': 'i_label_seq_id_2',
                                                        'I_PDB_INS_CODE_1': 'i_PDB_ins_code_1',
                                                        'I_PDB_INS_CODE_2': 'i_PDB_ins_code_2',
                                                        'I_SYMMETRY_1': 'i_symmetry_1',
                                                        'I_SYMMETRY_2': 'i_symmetry_2',
                                                        'J_AUTH_ASYM_ID_1': 'j_auth_asym_id_1',
                                                        'J_AUTH_ASYM_ID_2': 'j_auth_asym_id_2',
                                                        'J_AUTH_SEQ_ID_1': 'j_auth_seq_id_1',
                                                        'J_AUTH_SEQ_ID_2': 'j_auth_seq_id_2',
                                                        'J_LABEL_ASYM_ID_1': 'j_label_asym_id_1',
                                                        'J_LABEL_ASYM_ID_2': 'j_label_asym_id_2',
                                                        'J_LABEL_COMP_ID_1': 'j_label_comp_id_1',
                                                        'J_LABEL_COMP_ID_2': 'j_label_comp_id_2',
                                                        'J_LABEL_SEQ_ID_1': 'j_label_seq_id_1',
                                                        'J_LABEL_SEQ_ID_2': 'j_label_seq_id_2',
                                                        'J_PDB_INS_CODE_1': 'j_PDB_ins_code_1',
                                                        'J_PDB_INS_CODE_2': 'j_PDB_ins_code_2',
                                                        'J_SYMMETRY_1': 'j_symmetry_1',
                                                        'J_SYMMETRY_2': 'j_symmetry_2',
                                                        'MODEL_NUMBER': 'model_number',
                                                        'RISE': 'rise',
                                                        'ROLL': 'roll',
                                                        'SHIFT': 'shift',
                                                        'SLIDE': 'slide',
                                                        'STEP_NAME': 'step_name',
                                                        'STEP_NUMBER': 'step_number',
                                                        'STRUCTURE_ID': 'Structure_ID',
                                                        'TILT': 'tilt',
                                                        'TIP': 'tip',
                                                        'TWIST': 'twist',
                                                        'X_DISPLACEMENT': 'x_displacement',
                                                        'Y_DISPLACEMENT': 'y_displacement'},
                                         'ATTRIBUTE_INFO': {'HELICAL_RISE': {'NULLABLE': True,
                                                                             'ORDER': 41,
                                                                             'PRECISION': 6,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'FLOAT',
                                                                             'WIDTH': 10},
                                                            'HELICAL_TWIST': {'NULLABLE': True,
                                                                              'ORDER': 44,
                                                                              'PRECISION': 6,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'FLOAT',
                                                                              'WIDTH': 10},
                                                            'INCLINATION': {'NULLABLE': True,
                                                                            'ORDER': 42,
                                                                            'PRECISION': 6,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'FLOAT',
                                                                            'WIDTH': 10},
                                                            'I_AUTH_ASYM_ID_1': {'NULLABLE': True,
                                                                                 'ORDER': 21,
                                                                                 'PRECISION': 0,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'VARCHAR',
                                                                                 'WIDTH': 10},
                                                            'I_AUTH_ASYM_ID_2': {'NULLABLE': True,
                                                                                 'ORDER': 27,
                                                                                 'PRECISION': 0,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'VARCHAR',
                                                                                 'WIDTH': 10},
                                                            'I_AUTH_SEQ_ID_1': {'NULLABLE': True,
                                                                                'ORDER': 22,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 10},
                                                            'I_AUTH_SEQ_ID_2': {'NULLABLE': True,
                                                                                'ORDER': 28,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 10},
                                                            'I_LABEL_ASYM_ID_1': {'NULLABLE': False,
                                                                                  'ORDER': 5,
                                                                                  'PRECISION': 0,
                                                                                  'PRIMARY_KEY': False,
                                                                                  'SQL_TYPE': 'VARCHAR',
                                                                                  'WIDTH': 10},
                                                            'I_LABEL_ASYM_ID_2': {'NULLABLE': False,
                                                                                  'ORDER': 13,
                                                                                  'PRECISION': 0,
                                                                                  'PRIMARY_KEY': False,
                                                                                  'SQL_TYPE': 'VARCHAR',
                                                                                  'WIDTH': 10},
                                                            'I_LABEL_COMP_ID_1': {'NULLABLE': False,
                                                                                  'ORDER': 6,
                                                                                  'PRECISION': 0,
                                                                                  'PRIMARY_KEY': False,
                                                                                  'SQL_TYPE': 'VARCHAR',
                                                                                  'WIDTH': 10},
                                                            'I_LABEL_COMP_ID_2': {'NULLABLE': False,
                                                                                  'ORDER': 14,
                                                                                  'PRECISION': 0,
                                                                                  'PRIMARY_KEY': False,
                                                                                  'SQL_TYPE': 'VARCHAR',
                                                                                  'WIDTH': 10},
                                                            'I_LABEL_SEQ_ID_1': {'NULLABLE': False,
                                                                                 'ORDER': 7,
                                                                                 'PRECISION': 0,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'INT',
                                                                                 'WIDTH': 10},
                                                            'I_LABEL_SEQ_ID_2': {'NULLABLE': False,
                                                                                 'ORDER': 15,
                                                                                 'PRECISION': 0,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'INT',
                                                                                 'WIDTH': 10},
                                                            'I_PDB_INS_CODE_1': {'NULLABLE': True,
                                                                                 'ORDER': 23,
                                                                                 'PRECISION': 0,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'VARCHAR',
                                                                                 'WIDTH': 10},
                                                            'I_PDB_INS_CODE_2': {'NULLABLE': True,
                                                                                 'ORDER': 29,
                                                                                 'PRECISION': 0,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'VARCHAR',
                                                                                 'WIDTH': 10},
                                                            'I_SYMMETRY_1': {'NULLABLE': False,
                                                                             'ORDER': 8,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                            'I_SYMMETRY_2': {'NULLABLE': False,
                                                                             'ORDER': 16,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                            'J_AUTH_ASYM_ID_1': {'NULLABLE': True,
                                                                                 'ORDER': 24,
                                                                                 'PRECISION': 0,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'VARCHAR',
                                                                                 'WIDTH': 10},
                                                            'J_AUTH_ASYM_ID_2': {'NULLABLE': True,
                                                                                 'ORDER': 30,
                                                                                 'PRECISION': 0,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'VARCHAR',
                                                                                 'WIDTH': 10},
                                                            'J_AUTH_SEQ_ID_1': {'NULLABLE': True,
                                                                                'ORDER': 25,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 10},
                                                            'J_AUTH_SEQ_ID_2': {'NULLABLE': True,
                                                                                'ORDER': 31,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 10},
                                                            'J_LABEL_ASYM_ID_1': {'NULLABLE': False,
                                                                                  'ORDER': 9,
                                                                                  'PRECISION': 0,
                                                                                  'PRIMARY_KEY': False,
                                                                                  'SQL_TYPE': 'VARCHAR',
                                                                                  'WIDTH': 10},
                                                            'J_LABEL_ASYM_ID_2': {'NULLABLE': False,
                                                                                  'ORDER': 17,
                                                                                  'PRECISION': 0,
                                                                                  'PRIMARY_KEY': False,
                                                                                  'SQL_TYPE': 'VARCHAR',
                                                                                  'WIDTH': 10},
                                                            'J_LABEL_COMP_ID_1': {'NULLABLE': False,
                                                                                  'ORDER': 10,
                                                                                  'PRECISION': 0,
                                                                                  'PRIMARY_KEY': False,
                                                                                  'SQL_TYPE': 'VARCHAR',
                                                                                  'WIDTH': 10},
                                                            'J_LABEL_COMP_ID_2': {'NULLABLE': False,
                                                                                  'ORDER': 18,
                                                                                  'PRECISION': 0,
                                                                                  'PRIMARY_KEY': False,
                                                                                  'SQL_TYPE': 'VARCHAR',
                                                                                  'WIDTH': 10},
                                                            'J_LABEL_SEQ_ID_1': {'NULLABLE': False,
                                                                                 'ORDER': 11,
                                                                                 'PRECISION': 0,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'INT',
                                                                                 'WIDTH': 10},
                                                            'J_LABEL_SEQ_ID_2': {'NULLABLE': False,
                                                                                 'ORDER': 19,
                                                                                 'PRECISION': 0,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'INT',
                                                                                 'WIDTH': 10},
                                                            'J_PDB_INS_CODE_1': {'NULLABLE': True,
                                                                                 'ORDER': 26,
                                                                                 'PRECISION': 0,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'VARCHAR',
                                                                                 'WIDTH': 10},
                                                            'J_PDB_INS_CODE_2': {'NULLABLE': True,
                                                                                 'ORDER': 32,
                                                                                 'PRECISION': 0,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'VARCHAR',
                                                                                 'WIDTH': 10},
                                                            'J_SYMMETRY_1': {'NULLABLE': False,
                                                                             'ORDER': 12,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                            'J_SYMMETRY_2': {'NULLABLE': False,
                                                                             'ORDER': 20,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                            'MODEL_NUMBER': {'NULLABLE': False,
                                                                             'ORDER': 2,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': True,
                                                                             'SQL_TYPE': 'INT',
                                                                             'WIDTH': 10},
                                                            'RISE': {'NULLABLE': True,
                                                                     'ORDER': 35,
                                                                     'PRECISION': 6,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'FLOAT',
                                                                     'WIDTH': 10},
                                                            'ROLL': {'NULLABLE': True,
                                                                     'ORDER': 37,
                                                                     'PRECISION': 6,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'FLOAT',
                                                                     'WIDTH': 10},
                                                            'SHIFT': {'NULLABLE': True,
                                                                      'ORDER': 33,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                                            'SLIDE': {'NULLABLE': True,
                                                                      'ORDER': 34,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                                            'STEP_NAME': {'NULLABLE': True,
                                                                          'ORDER': 4,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 80},
                                                            'STEP_NUMBER': {'NULLABLE': False,
                                                                            'ORDER': 3,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': True,
                                                                            'SQL_TYPE': 'INT',
                                                                            'WIDTH': 10},
                                                            'STRUCTURE_ID': {'NULLABLE': False,
                                                                             'ORDER': 1,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': True,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                            'TILT': {'NULLABLE': True,
                                                                     'ORDER': 36,
                                                                     'PRECISION': 6,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'FLOAT',
                                                                     'WIDTH': 10},
                                                            'TIP': {'NULLABLE': True,
                                                                    'ORDER': 43,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                                            'TWIST': {'NULLABLE': True,
                                                                      'ORDER': 38,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                                            'X_DISPLACEMENT': {'NULLABLE': True,
                                                                               'ORDER': 39,
                                                                               'PRECISION': 6,
                                                                               'PRIMARY_KEY': False,
                                                                               'SQL_TYPE': 'FLOAT',
                                                                               'WIDTH': 10},
                                                            'Y_DISPLACEMENT': {'NULLABLE': True,
                                                                               'ORDER': 40,
                                                                               'PRECISION': 6,
                                                                               'PRIMARY_KEY': False,
                                                                               'SQL_TYPE': 'FLOAT',
                                                                               'WIDTH': 10}},
                                         'ATTRIBUTE_MAP': {'HELICAL_RISE': ('ndb_struct_na_base_pair_step',
                                                                            'helical_rise',
                                                                            None,
                                                                            None),
                                                           'HELICAL_TWIST': ('ndb_struct_na_base_pair_step',
                                                                             'helical_twist',
                                                                             None,
                                                                             None),
                                                           'INCLINATION': ('ndb_struct_na_base_pair_step',
                                                                           'inclination',
                                                                           None,
                                                                           None),
                                                           'I_AUTH_ASYM_ID_1': ('ndb_struct_na_base_pair_step',
                                                                                'i_auth_asym_id_1',
                                                                                None,
                                                                                None),
                                                           'I_AUTH_ASYM_ID_2': ('ndb_struct_na_base_pair_step',
                                                                                'i_auth_asym_id_2',
                                                                                None,
                                                                                None),
                                                           'I_AUTH_SEQ_ID_1': ('ndb_struct_na_base_pair_step',
                                                                               'i_auth_seq_id_1',
                                                                               None,
                                                                               None),
                                                           'I_AUTH_SEQ_ID_2': ('ndb_struct_na_base_pair_step',
                                                                               'i_auth_seq_id_2',
                                                                               None,
                                                                               None),
                                                           'I_LABEL_ASYM_ID_1': ('ndb_struct_na_base_pair_step',
                                                                                 'i_label_asym_id_1',
                                                                                 None,
                                                                                 None),
                                                           'I_LABEL_ASYM_ID_2': ('ndb_struct_na_base_pair_step',
                                                                                 'i_label_asym_id_2',
                                                                                 None,
                                                                                 None),
                                                           'I_LABEL_COMP_ID_1': ('ndb_struct_na_base_pair_step',
                                                                                 'i_label_comp_id_1',
                                                                                 None,
                                                                                 None),
                                                           'I_LABEL_COMP_ID_2': ('ndb_struct_na_base_pair_step',
                                                                                 'i_label_comp_id_2',
                                                                                 None,
                                                                                 None),
                                                           'I_LABEL_SEQ_ID_1': ('ndb_struct_na_base_pair_step',
                                                                                'i_label_seq_id_1',
                                                                                None,
                                                                                None),
                                                           'I_LABEL_SEQ_ID_2': ('ndb_struct_na_base_pair_step',
                                                                                'i_label_seq_id_2',
                                                                                None,
                                                                                None),
                                                           'I_PDB_INS_CODE_1': ('ndb_struct_na_base_pair_step',
                                                                                'i_PDB_ins_code_1',
                                                                                None,
                                                                                None),
                                                           'I_PDB_INS_CODE_2': ('ndb_struct_na_base_pair_step',
                                                                                'i_PDB_ins_code_2',
                                                                                None,
                                                                                None),
                                                           'I_SYMMETRY_1': ('ndb_struct_na_base_pair_step',
                                                                            'i_symmetry_1',
                                                                            None,
                                                                            None),
                                                           'I_SYMMETRY_2': ('ndb_struct_na_base_pair_step',
                                                                            'i_symmetry_2',
                                                                            None,
                                                                            None),
                                                           'J_AUTH_ASYM_ID_1': ('ndb_struct_na_base_pair_step',
                                                                                'j_auth_asym_id_1',
                                                                                None,
                                                                                None),
                                                           'J_AUTH_ASYM_ID_2': ('ndb_struct_na_base_pair_step',
                                                                                'j_auth_asym_id_2',
                                                                                None,
                                                                                None),
                                                           'J_AUTH_SEQ_ID_1': ('ndb_struct_na_base_pair_step',
                                                                               'j_auth_seq_id_1',
                                                                               None,
                                                                               None),
                                                           'J_AUTH_SEQ_ID_2': ('ndb_struct_na_base_pair_step',
                                                                               'j_auth_seq_id_2',
                                                                               None,
                                                                               None),
                                                           'J_LABEL_ASYM_ID_1': ('ndb_struct_na_base_pair_step',
                                                                                 'j_label_asym_id_1',
                                                                                 None,
                                                                                 None),
                                                           'J_LABEL_ASYM_ID_2': ('ndb_struct_na_base_pair_step',
                                                                                 'j_label_asym_id_2',
                                                                                 None,
                                                                                 None),
                                                           'J_LABEL_COMP_ID_1': ('ndb_struct_na_base_pair_step',
                                                                                 'j_label_comp_id_1',
                                                                                 None,
                                                                                 None),
                                                           'J_LABEL_COMP_ID_2': ('ndb_struct_na_base_pair_step',
                                                                                 'j_label_comp_id_2',
                                                                                 None,
                                                                                 None),
                                                           'J_LABEL_SEQ_ID_1': ('ndb_struct_na_base_pair_step',
                                                                                'j_label_seq_id_1',
                                                                                None,
                                                                                None),
                                                           'J_LABEL_SEQ_ID_2': ('ndb_struct_na_base_pair_step',
                                                                                'j_label_seq_id_2',
                                                                                None,
                                                                                None),
                                                           'J_PDB_INS_CODE_1': ('ndb_struct_na_base_pair_step',
                                                                                'j_PDB_ins_code_1',
                                                                                None,
                                                                                None),
                                                           'J_PDB_INS_CODE_2': ('ndb_struct_na_base_pair_step',
                                                                                'j_PDB_ins_code_2',
                                                                                None,
                                                                                None),
                                                           'J_SYMMETRY_1': ('ndb_struct_na_base_pair_step',
                                                                            'j_symmetry_1',
                                                                            None,
                                                                            None),
                                                           'J_SYMMETRY_2': ('ndb_struct_na_base_pair_step',
                                                                            'j_symmetry_2',
                                                                            None,
                                                                            None),
                                                           'MODEL_NUMBER': ('ndb_struct_na_base_pair_step',
                                                                            'model_number',
                                                                            None,
                                                                            None),
                                                           'RISE': ('ndb_struct_na_base_pair_step', 'rise', None, None),
                                                           'ROLL': ('ndb_struct_na_base_pair_step', 'roll', None, None),
                                                           'SHIFT': ('ndb_struct_na_base_pair_step', 'shift', None, None),
                                                           'SLIDE': ('ndb_struct_na_base_pair_step', 'slide', None, None),
                                                           'STEP_NAME': ('ndb_struct_na_base_pair_step',
                                                                         'step_name',
                                                                         None,
                                                                         None),
                                                           'STEP_NUMBER': ('ndb_struct_na_base_pair_step',
                                                                           'step_number',
                                                                           None,
                                                                           None),
                                                           'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                           'TILT': ('ndb_struct_na_base_pair_step', 'tilt', None, None),
                                                           'TIP': ('ndb_struct_na_base_pair_step', 'tip', None, None),
                                                           'TWIST': ('ndb_struct_na_base_pair_step', 'twist', None, None),
                                                           'X_DISPLACEMENT': ('ndb_struct_na_base_pair_step',
                                                                              'x_displacement',
                                                                              None,
                                                                              None),
                                                           'Y_DISPLACEMENT': ('ndb_struct_na_base_pair_step',
                                                                              'y_displacement',
                                                                              None,
                                                                              None)},
                                         'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'MODEL_NUMBER', 'STEP_NUMBER'),
                                                            'TYPE': 'UNIQUE'},
                                                     's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                         'MAP_MERGE_INDICES': {'ndb_struct_na_base_pair_step': {'ATTRIBUTES': ('model_number',
                                                                                                               'step_number'),
                                                                                                'TYPE': 'EQUI-JOIN'}},
                                         'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                         'TABLE_ID': 'NDB_STRUCT_NA_BASE_PAIR_STEP',
                                         'TABLE_NAME': 'ndb_struct_na_base_pair_step',
                                         'TABLE_TYPE': 'transactional'},
        'PDBX_ATOM_SITE_ANISO_TLS': {'ATTRIBUTES': {'AUTH_ASYM_ID': 'auth_asym_id',
                                                    'AUTH_ATOM_ID': 'auth_atom_id',
                                                    'AUTH_COMP_ID': 'auth_comp_id',
                                                    'AUTH_SEQ_ID': 'auth_seq_id',
                                                    'ID': 'id',
                                                    'LABEL_ALT_ID': 'label_alt_id',
                                                    'LABEL_ASYM_ID': 'label_asym_id',
                                                    'LABEL_ATOM_ID': 'label_atom_id',
                                                    'LABEL_COMP_ID': 'label_comp_id',
                                                    'LABEL_SEQ_ID': 'label_seq_id',
                                                    'PDB_INS_CODE': 'PDB_ins_code',
                                                    'STRUCTURE_ID': 'Structure_ID',
                                                    'TLS_GROUP_ID': 'tls_group_id',
                                                    'TYPE_SYMBOL': 'type_symbol',
                                                    'U_TLS_1_1': 'U_tls_1_1',
                                                    'U_TLS_1_2': 'U_tls_1_2',
                                                    'U_TLS_1_3': 'U_tls_1_3',
                                                    'U_TLS_2_2': 'U_tls_2_2',
                                                    'U_TLS_2_3': 'U_tls_2_3',
                                                    'U_TLS_3_3': 'U_tls_3_3'},
                                     'ATTRIBUTE_INFO': {'AUTH_ASYM_ID': {'NULLABLE': True,
                                                                         'ORDER': 8,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                                        'AUTH_ATOM_ID': {'NULLABLE': True,
                                                                         'ORDER': 7,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 6},
                                                        'AUTH_COMP_ID': {'NULLABLE': True,
                                                                         'ORDER': 5,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                                        'AUTH_SEQ_ID': {'NULLABLE': True,
                                                                        'ORDER': 6,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                                        'ID': {'NULLABLE': False,
                                                               'ORDER': 2,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                                        'LABEL_ALT_ID': {'NULLABLE': True,
                                                                         'ORDER': 10,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                                        'LABEL_ASYM_ID': {'NULLABLE': True,
                                                                          'ORDER': 11,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                        'LABEL_ATOM_ID': {'NULLABLE': True,
                                                                          'ORDER': 12,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 6},
                                                        'LABEL_COMP_ID': {'NULLABLE': True,
                                                                          'ORDER': 13,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                        'LABEL_SEQ_ID': {'NULLABLE': True,
                                                                         'ORDER': 14,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'INT',
                                                                         'WIDTH': 10},
                                                        'PDB_INS_CODE': {'NULLABLE': True,
                                                                         'ORDER': 9,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                                        'STRUCTURE_ID': {'NULLABLE': False,
                                                                         'ORDER': 1,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': True,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                                        'TLS_GROUP_ID': {'NULLABLE': False,
                                                                         'ORDER': 4,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': True,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                                        'TYPE_SYMBOL': {'NULLABLE': True,
                                                                        'ORDER': 3,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                                        'U_TLS_1_1': {'NULLABLE': True,
                                                                      'ORDER': 15,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                                        'U_TLS_1_2': {'NULLABLE': True,
                                                                      'ORDER': 18,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                                        'U_TLS_1_3': {'NULLABLE': True,
                                                                      'ORDER': 19,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                                        'U_TLS_2_2': {'NULLABLE': True,
                                                                      'ORDER': 16,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                                        'U_TLS_2_3': {'NULLABLE': True,
                                                                      'ORDER': 20,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                                        'U_TLS_3_3': {'NULLABLE': True,
                                                                      'ORDER': 17,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10}},
                                     'ATTRIBUTE_MAP': {'AUTH_ASYM_ID': ('pdbx_atom_site_aniso_tls',
                                                                        'auth_asym_id',
                                                                        None,
                                                                        None),
                                                       'AUTH_ATOM_ID': ('pdbx_atom_site_aniso_tls',
                                                                        'auth_atom_id',
                                                                        None,
                                                                        None),
                                                       'AUTH_COMP_ID': ('pdbx_atom_site_aniso_tls',
                                                                        'auth_comp_id',
                                                                        None,
                                                                        None),
                                                       'AUTH_SEQ_ID': ('pdbx_atom_site_aniso_tls', 'auth_seq_id', None, None),
                                                       'ID': ('pdbx_atom_site_aniso_tls', 'id', None, None),
                                                       'LABEL_ALT_ID': ('pdbx_atom_site_aniso_tls',
                                                                        'label_alt_id',
                                                                        None,
                                                                        None),
                                                       'LABEL_ASYM_ID': ('pdbx_atom_site_aniso_tls',
                                                                         'label_asym_id',
                                                                         None,
                                                                         None),
                                                       'LABEL_ATOM_ID': ('pdbx_atom_site_aniso_tls',
                                                                         'label_atom_id',
                                                                         None,
                                                                         None),
                                                       'LABEL_COMP_ID': ('pdbx_atom_site_aniso_tls',
                                                                         'label_comp_id',
                                                                         None,
                                                                         None),
                                                       'LABEL_SEQ_ID': ('pdbx_atom_site_aniso_tls',
                                                                        'label_seq_id',
                                                                        None,
                                                                        None),
                                                       'PDB_INS_CODE': ('pdbx_atom_site_aniso_tls',
                                                                        'PDB_ins_code',
                                                                        None,
                                                                        None),
                                                       'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                       'TLS_GROUP_ID': ('pdbx_atom_site_aniso_tls',
                                                                        'tls_group_id',
                                                                        None,
                                                                        None),
                                                       'TYPE_SYMBOL': ('pdbx_atom_site_aniso_tls', 'type_symbol', None, None),
                                                       'U_TLS_1_1': ('pdbx_atom_site_aniso_tls', 'U_tls[1][1]', None, None),
                                                       'U_TLS_1_2': ('pdbx_atom_site_aniso_tls', 'U_tls[1][2]', None, None),
                                                       'U_TLS_1_3': ('pdbx_atom_site_aniso_tls', 'U_tls[1][3]', None, None),
                                                       'U_TLS_2_2': ('pdbx_atom_site_aniso_tls', 'U_tls[2][2]', None, None),
                                                       'U_TLS_2_3': ('pdbx_atom_site_aniso_tls', 'U_tls[2][3]', None, None),
                                                       'U_TLS_3_3': ('pdbx_atom_site_aniso_tls', 'U_tls[3][3]', None, None)},
                                     'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID', 'TLS_GROUP_ID'),
                                                        'TYPE': 'UNIQUE'},
                                                 's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                     'MAP_MERGE_INDICES': {'pdbx_atom_site_aniso_tls': {'ATTRIBUTES': ('id', 'tls_group_id'),
                                                                                        'TYPE': 'EQUI-JOIN'}},
                                     'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                     'TABLE_ID': 'PDBX_ATOM_SITE_ANISO_TLS',
                                     'TABLE_NAME': 'pdbx_atom_site_aniso_tls',
                                     'TABLE_TYPE': 'transactional'},
        'PDBX_AUDIT': {'ATTRIBUTES': {'CURRENT_VERSION': 'current_version',
                                      'ENTRY_ID': 'entry_id',
                                      'STRUCTURE_ID': 'Structure_ID'},
                       'ATTRIBUTE_INFO': {'CURRENT_VERSION': {'NULLABLE': True,
                                                              'ORDER': 3,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10},
                                          'ENTRY_ID': {'NULLABLE': False,
                                                       'ORDER': 2,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': True,
                                                       'SQL_TYPE': 'VARCHAR',
                                                       'WIDTH': 10},
                                          'STRUCTURE_ID': {'NULLABLE': False,
                                                           'ORDER': 1,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': True,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 10}},
                       'ATTRIBUTE_MAP': {'CURRENT_VERSION': ('pdbx_audit', 'current_version', None, None),
                                         'ENTRY_ID': ('pdbx_audit', 'entry_id', None, None),
                                         'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                       'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID'), 'TYPE': 'UNIQUE'},
                                   's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                       'MAP_MERGE_INDICES': {'pdbx_audit': {'ATTRIBUTES': ('entry_id',), 'TYPE': 'EQUI-JOIN'}},
                       'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                       'TABLE_ID': 'PDBX_AUDIT',
                       'TABLE_NAME': 'pdbx_audit',
                       'TABLE_TYPE': 'transactional'},
        'PDBX_AUDIT_AUTHOR': {'ATTRIBUTES': {'ADDRESS': 'address',
                                             'NAME': 'name',
                                             'ORDINAL': 'ordinal',
                                             'STRUCTURE_ID': 'Structure_ID'},
                              'ATTRIBUTE_INFO': {'ADDRESS': {'NULLABLE': True,
                                                             'ORDER': 2,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 200},
                                                 'NAME': {'NULLABLE': True,
                                                          'ORDER': 3,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 80},
                                                 'ORDINAL': {'NULLABLE': False,
                                                             'ORDER': 4,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'INT',
                                                             'WIDTH': 10},
                                                 'STRUCTURE_ID': {'NULLABLE': False,
                                                                  'ORDER': 1,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': True,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10}},
                              'ATTRIBUTE_MAP': {'ADDRESS': ('pdbx_audit_author', 'address', None, None),
                                                'NAME': ('pdbx_audit_author', 'name', None, None),
                                                'ORDINAL': ('pdbx_audit_author', 'ordinal', None, None),
                                                'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                              'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ORDINAL'), 'TYPE': 'UNIQUE'},
                                          's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                              'MAP_MERGE_INDICES': {'pdbx_audit_author': {'ATTRIBUTES': ('ordinal',), 'TYPE': 'EQUI-JOIN'}},
                              'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                              'TABLE_ID': 'PDBX_AUDIT_AUTHOR',
                              'TABLE_NAME': 'pdbx_audit_author',
                              'TABLE_TYPE': 'transactional'},
        'PDBX_BOND_DISTANCE_LIMITS': {'ATTRIBUTES': {'ATOM_TYPE_1': 'atom_type_1',
                                                     'ATOM_TYPE_2': 'atom_type_2',
                                                     'LOWER_LIMIT': 'lower_limit',
                                                     'STRUCTURE_ID': 'Structure_ID',
                                                     'UPPER_LIMIT': 'upper_limit'},
                                      'ATTRIBUTE_INFO': {'ATOM_TYPE_1': {'NULLABLE': False,
                                                                         'ORDER': 2,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': True,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                                         'ATOM_TYPE_2': {'NULLABLE': False,
                                                                         'ORDER': 3,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': True,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                                         'LOWER_LIMIT': {'NULLABLE': True,
                                                                         'ORDER': 4,
                                                                         'PRECISION': 6,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'FLOAT',
                                                                         'WIDTH': 10},
                                                         'STRUCTURE_ID': {'NULLABLE': False,
                                                                          'ORDER': 1,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': True,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                         'UPPER_LIMIT': {'NULLABLE': True,
                                                                         'ORDER': 5,
                                                                         'PRECISION': 6,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'FLOAT',
                                                                         'WIDTH': 10}},
                                      'ATTRIBUTE_MAP': {'ATOM_TYPE_1': ('pdbx_bond_distance_limits',
                                                                        'atom_type_1',
                                                                        None,
                                                                        None),
                                                        'ATOM_TYPE_2': ('pdbx_bond_distance_limits',
                                                                        'atom_type_2',
                                                                        None,
                                                                        None),
                                                        'LOWER_LIMIT': ('pdbx_bond_distance_limits',
                                                                        'lower_limit',
                                                                        None,
                                                                        None),
                                                        'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                        'UPPER_LIMIT': ('pdbx_bond_distance_limits',
                                                                        'upper_limit',
                                                                        None,
                                                                        None)},
                                      'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ATOM_TYPE_1', 'ATOM_TYPE_2'),
                                                         'TYPE': 'UNIQUE'},
                                                  's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                      'MAP_MERGE_INDICES': {'pdbx_bond_distance_limits': {'ATTRIBUTES': ('atom_type_1',
                                                                                                         'atom_type_2'),
                                                                                          'TYPE': 'EQUI-JOIN'}},
                                      'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                      'TABLE_ID': 'PDBX_BOND_DISTANCE_LIMITS',
                                      'TABLE_NAME': 'pdbx_bond_distance_limits',
                                      'TABLE_TYPE': 'transactional'},
        'PDBX_BUFFER': {'ATTRIBUTES': {'DETAILS': 'details', 'ID': 'id', 'NAME': 'name', 'STRUCTURE_ID': 'Structure_ID'},
                        'ATTRIBUTE_INFO': {'DETAILS': {'NULLABLE': True,
                                                       'ORDER': 4,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'VARCHAR',
                                                       'WIDTH': 200},
                                           'ID': {'NULLABLE': False,
                                                  'ORDER': 2,
                                                  'PRECISION': 0,
                                                  'PRIMARY_KEY': True,
                                                  'SQL_TYPE': 'VARCHAR',
                                                  'WIDTH': 10},
                                           'NAME': {'NULLABLE': True,
                                                    'ORDER': 3,
                                                    'PRECISION': 0,
                                                    'PRIMARY_KEY': False,
                                                    'SQL_TYPE': 'VARCHAR',
                                                    'WIDTH': 80},
                                           'STRUCTURE_ID': {'NULLABLE': False,
                                                            'ORDER': 1,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': True,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 10}},
                        'ATTRIBUTE_MAP': {'DETAILS': ('pdbx_buffer', 'details', None, None),
                                          'ID': ('pdbx_buffer', 'id', None, None),
                                          'NAME': ('pdbx_buffer', 'name', None, None),
                                          'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                        'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                    's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                        'MAP_MERGE_INDICES': {'pdbx_buffer': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                        'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                        'TABLE_ID': 'PDBX_BUFFER',
                        'TABLE_NAME': 'pdbx_buffer',
                        'TABLE_TYPE': 'transactional'},
        'PDBX_BUFFER_COMPONENTS': {'ATTRIBUTES': {'BUFFER_ID': 'buffer_id',
                                                  'CONC': 'conc',
                                                  'CONC_UNITS': 'conc_units',
                                                  'DETAILS': 'details',
                                                  'ID': 'id',
                                                  'ISOTOPIC_LABELING': 'isotopic_labeling',
                                                  'NAME': 'name',
                                                  'STRUCTURE_ID': 'Structure_ID',
                                                  'VOLUME': 'volume'},
                                   'ATTRIBUTE_INFO': {'BUFFER_ID': {'NULLABLE': False,
                                                                    'ORDER': 3,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': True,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10},
                                                      'CONC': {'NULLABLE': True,
                                                               'ORDER': 6,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                                      'CONC_UNITS': {'NULLABLE': True,
                                                                     'ORDER': 8,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                                      'DETAILS': {'NULLABLE': True,
                                                                  'ORDER': 7,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 200},
                                                      'ID': {'NULLABLE': False,
                                                             'ORDER': 2,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 10},
                                                      'ISOTOPIC_LABELING': {'NULLABLE': True,
                                                                            'ORDER': 9,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 80},
                                                      'NAME': {'NULLABLE': True,
                                                               'ORDER': 4,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 80},
                                                      'STRUCTURE_ID': {'NULLABLE': False,
                                                                       'ORDER': 1,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': True,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                      'VOLUME': {'NULLABLE': True,
                                                                 'ORDER': 5,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10}},
                                   'ATTRIBUTE_MAP': {'BUFFER_ID': ('pdbx_buffer_components', 'buffer_id', None, None),
                                                     'CONC': ('pdbx_buffer_components', 'conc', None, None),
                                                     'CONC_UNITS': ('pdbx_buffer_components', 'conc_units', None, None),
                                                     'DETAILS': ('pdbx_buffer_components', 'details', None, None),
                                                     'ID': ('pdbx_buffer_components', 'id', None, None),
                                                     'ISOTOPIC_LABELING': ('pdbx_buffer_components',
                                                                           'isotopic_labeling',
                                                                           None,
                                                                           None),
                                                     'NAME': ('pdbx_buffer_components', 'name', None, None),
                                                     'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                     'VOLUME': ('pdbx_buffer_components', 'volume', None, None)},
                                   'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID', 'BUFFER_ID'), 'TYPE': 'UNIQUE'},
                                               's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                   'MAP_MERGE_INDICES': {'pdbx_buffer_components': {'ATTRIBUTES': ('id', 'buffer_id'),
                                                                                    'TYPE': 'EQUI-JOIN'}},
                                   'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                   'TABLE_ID': 'PDBX_BUFFER_COMPONENTS',
                                   'TABLE_NAME': 'pdbx_buffer_components',
                                   'TABLE_TYPE': 'transactional'},
        'PDBX_CHEM_COMP_ATOM_EDIT': {'ATTRIBUTES': {'ATOM_ID': 'atom_id',
                                                    'COMP_ID': 'comp_id',
                                                    'EDIT_ATOM_ID': 'edit_atom_id',
                                                    'EDIT_ATOM_VALUE': 'edit_atom_value',
                                                    'EDIT_OP': 'edit_op',
                                                    'ORDINAL': 'ordinal',
                                                    'STRUCTURE_ID': 'Structure_ID'},
                                     'ATTRIBUTE_INFO': {'ATOM_ID': {'NULLABLE': True,
                                                                    'ORDER': 5,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 6},
                                                        'COMP_ID': {'NULLABLE': True,
                                                                    'ORDER': 3,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10},
                                                        'EDIT_ATOM_ID': {'NULLABLE': True,
                                                                         'ORDER': 6,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 6},
                                                        'EDIT_ATOM_VALUE': {'NULLABLE': True,
                                                                            'ORDER': 7,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 80},
                                                        'EDIT_OP': {'NULLABLE': True,
                                                                    'ORDER': 4,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10},
                                                        'ORDINAL': {'NULLABLE': False,
                                                                    'ORDER': 2,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': True,
                                                                    'SQL_TYPE': 'INT',
                                                                    'WIDTH': 10},
                                                        'STRUCTURE_ID': {'NULLABLE': False,
                                                                         'ORDER': 1,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': True,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10}},
                                     'ATTRIBUTE_MAP': {'ATOM_ID': ('pdbx_chem_comp_atom_edit', 'atom_id', None, None),
                                                       'COMP_ID': ('pdbx_chem_comp_atom_edit', 'comp_id', None, None),
                                                       'EDIT_ATOM_ID': ('pdbx_chem_comp_atom_edit',
                                                                        'edit_atom_id',
                                                                        None,
                                                                        None),
                                                       'EDIT_ATOM_VALUE': ('pdbx_chem_comp_atom_edit',
                                                                           'edit_atom_value',
                                                                           None,
                                                                           None),
                                                       'EDIT_OP': ('pdbx_chem_comp_atom_edit', 'edit_op', None, None),
                                                       'ORDINAL': ('pdbx_chem_comp_atom_edit', 'ordinal', None, None),
                                                       'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                     'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ORDINAL'), 'TYPE': 'UNIQUE'},
                                                 's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                     'MAP_MERGE_INDICES': {'pdbx_chem_comp_atom_edit': {'ATTRIBUTES': ('ordinal',),
                                                                                        'TYPE': 'EQUI-JOIN'}},
                                     'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                     'TABLE_ID': 'PDBX_CHEM_COMP_ATOM_EDIT',
                                     'TABLE_NAME': 'pdbx_chem_comp_atom_edit',
                                     'TABLE_TYPE': 'transactional'},
        'PDBX_CHEM_COMP_ATOM_FEATURE': {'ATTRIBUTES': {'ATOM_ID': 'atom_id',
                                                       'COMP_ID': 'comp_id',
                                                       'FEATURE_TYPE': 'feature_type',
                                                       'STRUCTURE_ID': 'Structure_ID'},
                                        'ATTRIBUTE_INFO': {'ATOM_ID': {'NULLABLE': False,
                                                                       'ORDER': 3,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': True,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 6},
                                                           'COMP_ID': {'NULLABLE': False,
                                                                       'ORDER': 2,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': True,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                           'FEATURE_TYPE': {'NULLABLE': False,
                                                                            'ORDER': 4,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': True,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 10},
                                                           'STRUCTURE_ID': {'NULLABLE': False,
                                                                            'ORDER': 1,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': True,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 10}},
                                        'ATTRIBUTE_MAP': {'ATOM_ID': ('pdbx_chem_comp_atom_feature', 'atom_id', None, None),
                                                          'COMP_ID': ('pdbx_chem_comp_atom_feature', 'comp_id', None, None),
                                                          'FEATURE_TYPE': ('pdbx_chem_comp_atom_feature',
                                                                           'feature_type',
                                                                           None,
                                                                           None),
                                                          'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                        'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID',
                                                                          'COMP_ID',
                                                                          'ATOM_ID',
                                                                          'FEATURE_TYPE'),
                                                           'TYPE': 'UNIQUE'},
                                                    's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                        'MAP_MERGE_INDICES': {'pdbx_chem_comp_atom_feature': {'ATTRIBUTES': ('comp_id',
                                                                                                             'atom_id',
                                                                                                             'feature_type'),
                                                                                              'TYPE': 'EQUI-JOIN'}},
                                        'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                        'TABLE_ID': 'PDBX_CHEM_COMP_ATOM_FEATURE',
                                        'TABLE_NAME': 'pdbx_chem_comp_atom_feature',
                                        'TABLE_TYPE': 'transactional'},
        'PDBX_CHEM_COMP_AUDIT': {'ATTRIBUTES': {'ACTION_TYPE': 'action_type',
                                                'ANNOTATOR': 'annotator',
                                                'COMP_ID': 'comp_id',
                                                'DATE': 'date',
                                                'DETAILS': 'details',
                                                'PROCESSING_SITE': 'processing_site',
                                                'STRUCTURE_ID': 'Structure_ID'},
                                 'ATTRIBUTE_INFO': {'ACTION_TYPE': {'NULLABLE': False,
                                                                    'ORDER': 7,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': True,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 80},
                                                    'ANNOTATOR': {'NULLABLE': True,
                                                                  'ORDER': 4,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10},
                                                    'COMP_ID': {'NULLABLE': False,
                                                                'ORDER': 2,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                                    'DATE': {'NULLABLE': False,
                                                             'ORDER': 3,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'DATETIME',
                                                             'WIDTH': 15},
                                                    'DETAILS': {'NULLABLE': True,
                                                                'ORDER': 6,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 200},
                                                    'PROCESSING_SITE': {'NULLABLE': True,
                                                                        'ORDER': 5,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                                    'STRUCTURE_ID': {'NULLABLE': False,
                                                                     'ORDER': 1,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': True,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10}},
                                 'ATTRIBUTE_MAP': {'ACTION_TYPE': ('pdbx_chem_comp_audit', 'action_type', None, None),
                                                   'ANNOTATOR': ('pdbx_chem_comp_audit', 'annotator', None, None),
                                                   'COMP_ID': ('pdbx_chem_comp_audit', 'comp_id', None, None),
                                                   'DATE': ('pdbx_chem_comp_audit', 'date', None, None),
                                                   'DETAILS': ('pdbx_chem_comp_audit', 'details', None, None),
                                                   'PROCESSING_SITE': ('pdbx_chem_comp_audit', 'processing_site', None, None),
                                                   'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                 'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'COMP_ID', 'DATE', 'ACTION_TYPE'),
                                                    'TYPE': 'UNIQUE'},
                                             's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                 'MAP_MERGE_INDICES': {'pdbx_chem_comp_audit': {'ATTRIBUTES': ('comp_id',
                                                                                               'date',
                                                                                               'action_type'),
                                                                                'TYPE': 'EQUI-JOIN'}},
                                 'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                 'TABLE_ID': 'PDBX_CHEM_COMP_AUDIT',
                                 'TABLE_NAME': 'pdbx_chem_comp_audit',
                                 'TABLE_TYPE': 'transactional'},
        'PDBX_CHEM_COMP_BOND_EDIT': {'ATTRIBUTES': {'ATOM_ID_1': 'atom_id_1',
                                                    'ATOM_ID_2': 'atom_id_2',
                                                    'COMP_ID': 'comp_id',
                                                    'EDIT_BOND_VALUE': 'edit_bond_value',
                                                    'EDIT_OP': 'edit_op',
                                                    'ORDINAL': 'ordinal',
                                                    'STRUCTURE_ID': 'Structure_ID'},
                                     'ATTRIBUTE_INFO': {'ATOM_ID_1': {'NULLABLE': False,
                                                                      'ORDER': 5,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 6},
                                                        'ATOM_ID_2': {'NULLABLE': False,
                                                                      'ORDER': 6,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 6},
                                                        'COMP_ID': {'NULLABLE': False,
                                                                    'ORDER': 3,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': True,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10},
                                                        'EDIT_BOND_VALUE': {'NULLABLE': True,
                                                                            'ORDER': 7,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 80},
                                                        'EDIT_OP': {'NULLABLE': False,
                                                                    'ORDER': 4,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': True,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10},
                                                        'ORDINAL': {'NULLABLE': True,
                                                                    'ORDER': 2,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'INT',
                                                                    'WIDTH': 10},
                                                        'STRUCTURE_ID': {'NULLABLE': False,
                                                                         'ORDER': 1,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': True,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10}},
                                     'ATTRIBUTE_MAP': {'ATOM_ID_1': ('pdbx_chem_comp_bond_edit', 'atom_id_1', None, None),
                                                       'ATOM_ID_2': ('pdbx_chem_comp_bond_edit', 'atom_id_2', None, None),
                                                       'COMP_ID': ('pdbx_chem_comp_bond_edit', 'comp_id', None, None),
                                                       'EDIT_BOND_VALUE': ('pdbx_chem_comp_bond_edit',
                                                                           'edit_bond_value',
                                                                           None,
                                                                           None),
                                                       'EDIT_OP': ('pdbx_chem_comp_bond_edit', 'edit_op', None, None),
                                                       'ORDINAL': ('pdbx_chem_comp_bond_edit', 'ordinal', None, None),
                                                       'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                     'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID',
                                                                       'COMP_ID',
                                                                       'EDIT_OP',
                                                                       'ATOM_ID_1',
                                                                       'ATOM_ID_2'),
                                                        'TYPE': 'UNIQUE'},
                                                 's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                     'MAP_MERGE_INDICES': {'pdbx_chem_comp_bond_edit': {'ATTRIBUTES': ('comp_id',
                                                                                                       'edit_op',
                                                                                                       'atom_id_1',
                                                                                                       'atom_id_2'),
                                                                                        'TYPE': 'EQUI-JOIN'}},
                                     'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                     'TABLE_ID': 'PDBX_CHEM_COMP_BOND_EDIT',
                                     'TABLE_NAME': 'pdbx_chem_comp_bond_edit',
                                     'TABLE_TYPE': 'transactional'},
        'PDBX_CHEM_COMP_DESCRIPTOR': {'ATTRIBUTES': {'COMP_ID': 'comp_id',
                                                     'DESCRIPTOR': 'descriptor',
                                                     'ORDINAL': 'ordinal',
                                                     'PROGRAM': 'program',
                                                     'PROGRAM_VERSION': 'program_version',
                                                     'STRUCTURE_ID': 'Structure_ID',
                                                     'TYPE': 'type'},
                                      'ATTRIBUTE_INFO': {'COMP_ID': {'NULLABLE': False,
                                                                     'ORDER': 2,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': True,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                                         'DESCRIPTOR': {'NULLABLE': True,
                                                                        'ORDER': 3,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 200},
                                                         'ORDINAL': {'NULLABLE': True,
                                                                     'ORDER': 7,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'INT',
                                                                     'WIDTH': 10},
                                                         'PROGRAM': {'NULLABLE': False,
                                                                     'ORDER': 5,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': True,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 80},
                                                         'PROGRAM_VERSION': {'NULLABLE': False,
                                                                             'ORDER': 6,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': True,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 80},
                                                         'STRUCTURE_ID': {'NULLABLE': False,
                                                                          'ORDER': 1,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': True,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                         'TYPE': {'NULLABLE': False,
                                                                  'ORDER': 4,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': True,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 80}},
                                      'ATTRIBUTE_MAP': {'COMP_ID': ('pdbx_chem_comp_descriptor', 'comp_id', None, None),
                                                        'DESCRIPTOR': ('pdbx_chem_comp_descriptor', 'descriptor', None, None),
                                                        'ORDINAL': ('pdbx_chem_comp_descriptor', 'ordinal', None, None),
                                                        'PROGRAM': ('pdbx_chem_comp_descriptor', 'program', None, None),
                                                        'PROGRAM_VERSION': ('pdbx_chem_comp_descriptor',
                                                                            'program_version',
                                                                            None,
                                                                            None),
                                                        'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                        'TYPE': ('pdbx_chem_comp_descriptor', 'type', None, None)},
                                      'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID',
                                                                        'COMP_ID',
                                                                        'TYPE',
                                                                        'PROGRAM',
                                                                        'PROGRAM_VERSION'),
                                                         'TYPE': 'UNIQUE'},
                                                  's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                      'MAP_MERGE_INDICES': {'pdbx_chem_comp_descriptor': {'ATTRIBUTES': ('comp_id',
                                                                                                         'type',
                                                                                                         'program',
                                                                                                         'program_version'),
                                                                                          'TYPE': 'EQUI-JOIN'}},
                                      'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                      'TABLE_ID': 'PDBX_CHEM_COMP_DESCRIPTOR',
                                      'TABLE_NAME': 'pdbx_chem_comp_descriptor',
                                      'TABLE_TYPE': 'transactional'},
        'PDBX_CHEM_COMP_FEATURE': {'ATTRIBUTES': {'COMP_ID': 'comp_id',
                                                  'SOURCE': 'source',
                                                  'STRUCTURE_ID': 'Structure_ID',
                                                  'SUPPORT': 'support',
                                                  'TYPE': 'type',
                                                  'VALUE': 'value'},
                                   'ATTRIBUTE_INFO': {'COMP_ID': {'NULLABLE': False,
                                                                  'ORDER': 2,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': True,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10},
                                                      'SOURCE': {'NULLABLE': False,
                                                                 'ORDER': 6,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': True,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 80},
                                                      'STRUCTURE_ID': {'NULLABLE': False,
                                                                       'ORDER': 1,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': True,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                      'SUPPORT': {'NULLABLE': True,
                                                                  'ORDER': 4,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 200},
                                                      'TYPE': {'NULLABLE': False,
                                                               'ORDER': 3,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 80},
                                                      'VALUE': {'NULLABLE': False,
                                                                'ORDER': 5,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 200}},
                                   'ATTRIBUTE_MAP': {'COMP_ID': ('pdbx_chem_comp_feature', 'comp_id', None, None),
                                                     'SOURCE': ('pdbx_chem_comp_feature', 'source', None, None),
                                                     'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                     'SUPPORT': ('pdbx_chem_comp_feature', 'support', None, None),
                                                     'TYPE': ('pdbx_chem_comp_feature', 'type', None, None),
                                                     'VALUE': ('pdbx_chem_comp_feature', 'value', None, None)},
                                   'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'COMP_ID', 'TYPE', 'VALUE', 'SOURCE'),
                                                      'TYPE': 'UNIQUE'},
                                               's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                   'MAP_MERGE_INDICES': {'pdbx_chem_comp_feature': {'ATTRIBUTES': ('comp_id',
                                                                                                   'type',
                                                                                                   'value',
                                                                                                   'source'),
                                                                                    'TYPE': 'EQUI-JOIN'}},
                                   'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                   'TABLE_ID': 'PDBX_CHEM_COMP_FEATURE',
                                   'TABLE_NAME': 'pdbx_chem_comp_feature',
                                   'TABLE_TYPE': 'transactional'},
        'PDBX_CHEM_COMP_IDENTIFIER': {'ATTRIBUTES': {'COMP_ID': 'comp_id',
                                                     'IDENTIFIER': 'identifier',
                                                     'ORDINAL': 'ordinal',
                                                     'PROGRAM': 'program',
                                                     'PROGRAM_VERSION': 'program_version',
                                                     'STRUCTURE_ID': 'Structure_ID',
                                                     'TYPE': 'type'},
                                      'ATTRIBUTE_INFO': {'COMP_ID': {'NULLABLE': False,
                                                                     'ORDER': 2,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': True,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                                         'IDENTIFIER': {'NULLABLE': True,
                                                                        'ORDER': 3,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 200},
                                                         'ORDINAL': {'NULLABLE': True,
                                                                     'ORDER': 7,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'INT',
                                                                     'WIDTH': 10},
                                                         'PROGRAM': {'NULLABLE': False,
                                                                     'ORDER': 5,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': True,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 80},
                                                         'PROGRAM_VERSION': {'NULLABLE': False,
                                                                             'ORDER': 6,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': True,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 80},
                                                         'STRUCTURE_ID': {'NULLABLE': False,
                                                                          'ORDER': 1,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': True,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                         'TYPE': {'NULLABLE': False,
                                                                  'ORDER': 4,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': True,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 80}},
                                      'ATTRIBUTE_MAP': {'COMP_ID': ('pdbx_chem_comp_identifier', 'comp_id', None, None),
                                                        'IDENTIFIER': ('pdbx_chem_comp_identifier', 'identifier', None, None),
                                                        'ORDINAL': ('pdbx_chem_comp_identifier', 'ordinal', None, None),
                                                        'PROGRAM': ('pdbx_chem_comp_identifier', 'program', None, None),
                                                        'PROGRAM_VERSION': ('pdbx_chem_comp_identifier',
                                                                            'program_version',
                                                                            None,
                                                                            None),
                                                        'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                        'TYPE': ('pdbx_chem_comp_identifier', 'type', None, None)},
                                      'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID',
                                                                        'COMP_ID',
                                                                        'TYPE',
                                                                        'PROGRAM',
                                                                        'PROGRAM_VERSION'),
                                                         'TYPE': 'UNIQUE'},
                                                  's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                      'MAP_MERGE_INDICES': {'pdbx_chem_comp_identifier': {'ATTRIBUTES': ('comp_id',
                                                                                                         'type',
                                                                                                         'program',
                                                                                                         'program_version'),
                                                                                          'TYPE': 'EQUI-JOIN'}},
                                      'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                      'TABLE_ID': 'PDBX_CHEM_COMP_IDENTIFIER',
                                      'TABLE_NAME': 'pdbx_chem_comp_identifier',
                                      'TABLE_TYPE': 'transactional'},
        'PDBX_CHEM_COMP_IMPORT': {'ATTRIBUTES': {'COMP_ID': 'comp_id', 'STRUCTURE_ID': 'Structure_ID'},
                                  'ATTRIBUTE_INFO': {'COMP_ID': {'NULLABLE': False,
                                                                 'ORDER': 2,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': True,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                                     'STRUCTURE_ID': {'NULLABLE': False,
                                                                      'ORDER': 1,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10}},
                                  'ATTRIBUTE_MAP': {'COMP_ID': ('pdbx_chem_comp_import', 'comp_id', None, None),
                                                    'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                  'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'COMP_ID'), 'TYPE': 'UNIQUE'},
                                              's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                  'MAP_MERGE_INDICES': {'pdbx_chem_comp_import': {'ATTRIBUTES': ('comp_id',),
                                                                                  'TYPE': 'EQUI-JOIN'}},
                                  'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                  'TABLE_ID': 'PDBX_CHEM_COMP_IMPORT',
                                  'TABLE_NAME': 'pdbx_chem_comp_import',
                                  'TABLE_TYPE': 'transactional'},
        'PDBX_CONSTRUCT': {'ATTRIBUTES': {'CLASS': 'class',
                                          'DATE': 'date',
                                          'DETAILS': 'details',
                                          'ENTITY_ID': 'entity_id',
                                          'ENTRY_ID': 'entry_id',
                                          'ID': 'id',
                                          'NAME': 'name',
                                          'ORGANISATION': 'organisation',
                                          'ROBOT_ID': 'robot_id',
                                          'SEQ': 'seq',
                                          'STRUCTURE_ID': 'Structure_ID',
                                          'TYPE': 'type'},
                           'ATTRIBUTE_INFO': {'CLASS': {'NULLABLE': True,
                                                        'ORDER': 10,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 10},
                                              'DATE': {'NULLABLE': True,
                                                       'ORDER': 8,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'DATETIME',
                                                       'WIDTH': 20},
                                              'DETAILS': {'NULLABLE': True,
                                                          'ORDER': 9,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 200},
                                              'ENTITY_ID': {'NULLABLE': True,
                                                            'ORDER': 6,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 10},
                                              'ENTRY_ID': {'NULLABLE': True,
                                                           'ORDER': 2,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 10},
                                              'ID': {'NULLABLE': False,
                                                     'ORDER': 3,
                                                     'PRECISION': 0,
                                                     'PRIMARY_KEY': True,
                                                     'SQL_TYPE': 'VARCHAR',
                                                     'WIDTH': 10},
                                              'NAME': {'NULLABLE': True,
                                                       'ORDER': 4,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'VARCHAR',
                                                       'WIDTH': 80},
                                              'ORGANISATION': {'NULLABLE': True,
                                                               'ORDER': 5,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 80},
                                              'ROBOT_ID': {'NULLABLE': True,
                                                           'ORDER': 7,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 10},
                                              'SEQ': {'NULLABLE': True,
                                                      'ORDER': 12,
                                                      'PRECISION': 0,
                                                      'PRIMARY_KEY': False,
                                                      'SQL_TYPE': 'VARCHAR',
                                                      'WIDTH': 200},
                                              'STRUCTURE_ID': {'NULLABLE': False,
                                                               'ORDER': 1,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                              'TYPE': {'NULLABLE': True,
                                                       'ORDER': 11,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'VARCHAR',
                                                       'WIDTH': 10}},
                           'ATTRIBUTE_MAP': {'CLASS': ('pdbx_construct', 'class', None, None),
                                             'DATE': ('pdbx_construct', 'date', None, None),
                                             'DETAILS': ('pdbx_construct', 'details', None, None),
                                             'ENTITY_ID': ('pdbx_construct', 'entity_id', None, None),
                                             'ENTRY_ID': ('pdbx_construct', 'entry_id', None, None),
                                             'ID': ('pdbx_construct', 'id', None, None),
                                             'NAME': ('pdbx_construct', 'name', None, None),
                                             'ORGANISATION': ('pdbx_construct', 'organisation', None, None),
                                             'ROBOT_ID': ('pdbx_construct', 'robot_id', None, None),
                                             'SEQ': ('pdbx_construct', 'seq', None, None),
                                             'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                             'TYPE': ('pdbx_construct', 'type', None, None)},
                           'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                       's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                           'MAP_MERGE_INDICES': {'pdbx_construct': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                           'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                           'TABLE_ID': 'PDBX_CONSTRUCT',
                           'TABLE_NAME': 'pdbx_construct',
                           'TABLE_TYPE': 'transactional'},
        'PDBX_CONSTRUCT_FEATURE': {'ATTRIBUTES': {'CONSTRUCT_ID': 'construct_id',
                                                  'DETAILS': 'details',
                                                  'END_SEQ': 'end_seq',
                                                  'ENTRY_ID': 'entry_id',
                                                  'ID': 'id',
                                                  'START_SEQ': 'start_seq',
                                                  'STRUCTURE_ID': 'Structure_ID',
                                                  'TYPE': 'type'},
                                   'ATTRIBUTE_INFO': {'CONSTRUCT_ID': {'NULLABLE': False,
                                                                       'ORDER': 3,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': True,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                      'DETAILS': {'NULLABLE': True,
                                                                  'ORDER': 8,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 200},
                                                      'END_SEQ': {'NULLABLE': True,
                                                                  'ORDER': 6,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'INT',
                                                                  'WIDTH': 10},
                                                      'ENTRY_ID': {'NULLABLE': True,
                                                                   'ORDER': 4,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 10},
                                                      'ID': {'NULLABLE': False,
                                                             'ORDER': 2,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 10},
                                                      'START_SEQ': {'NULLABLE': True,
                                                                    'ORDER': 5,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'INT',
                                                                    'WIDTH': 10},
                                                      'STRUCTURE_ID': {'NULLABLE': False,
                                                                       'ORDER': 1,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': True,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                      'TYPE': {'NULLABLE': True,
                                                               'ORDER': 7,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 80}},
                                   'ATTRIBUTE_MAP': {'CONSTRUCT_ID': ('pdbx_construct_feature', 'construct_id', None, None),
                                                     'DETAILS': ('pdbx_construct_feature', 'details', None, None),
                                                     'END_SEQ': ('pdbx_construct_feature', 'end_seq', None, None),
                                                     'ENTRY_ID': ('pdbx_construct_feature', 'entry_id', None, None),
                                                     'ID': ('pdbx_construct_feature', 'id', None, None),
                                                     'START_SEQ': ('pdbx_construct_feature', 'start_seq', None, None),
                                                     'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                     'TYPE': ('pdbx_construct_feature', 'type', None, None)},
                                   'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID', 'CONSTRUCT_ID'), 'TYPE': 'UNIQUE'},
                                               's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                   'MAP_MERGE_INDICES': {'pdbx_construct_feature': {'ATTRIBUTES': ('id', 'construct_id'),
                                                                                    'TYPE': 'EQUI-JOIN'}},
                                   'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                   'TABLE_ID': 'PDBX_CONSTRUCT_FEATURE',
                                   'TABLE_NAME': 'pdbx_construct_feature',
                                   'TABLE_TYPE': 'transactional'},
        'PDBX_CONTACT_AUTHOR': {'ATTRIBUTES': {'ADDRESS_1': 'address_1',
                                               'ADDRESS_2': 'address_2',
                                               'ADDRESS_3': 'address_3',
                                               'CITY': 'city',
                                               'CONTINENT': 'continent',
                                               'COUNTRY': 'country',
                                               'EMAIL': 'email',
                                               'FAX': 'fax',
                                               'ID': 'id',
                                               'NAME_FIRST': 'name_first',
                                               'NAME_LAST': 'name_last',
                                               'NAME_MI': 'name_mi',
                                               'NAME_SALUTATION': 'name_salutation',
                                               'ORGANIZATION_TYPE': 'organization_type',
                                               'PHONE': 'phone',
                                               'POSTAL_CODE': 'postal_code',
                                               'ROLE': 'role',
                                               'STATE_PROVINCE': 'state_province',
                                               'STRUCTURE_ID': 'Structure_ID'},
                                'ATTRIBUTE_INFO': {'ADDRESS_1': {'NULLABLE': True,
                                                                 'ORDER': 3,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 200},
                                                   'ADDRESS_2': {'NULLABLE': True,
                                                                 'ORDER': 4,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 200},
                                                   'ADDRESS_3': {'NULLABLE': True,
                                                                 'ORDER': 5,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 200},
                                                   'CITY': {'NULLABLE': True,
                                                            'ORDER': 6,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 80},
                                                   'CONTINENT': {'NULLABLE': True,
                                                                 'ORDER': 16,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 80},
                                                   'COUNTRY': {'NULLABLE': True,
                                                               'ORDER': 15,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 80},
                                                   'EMAIL': {'NULLABLE': True,
                                                             'ORDER': 9,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 80},
                                                   'FAX': {'NULLABLE': True,
                                                           'ORDER': 10,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 80},
                                                   'ID': {'NULLABLE': False,
                                                          'ORDER': 2,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': True,
                                                          'SQL_TYPE': 'INT',
                                                          'WIDTH': 10},
                                                   'NAME_FIRST': {'NULLABLE': True,
                                                                  'ORDER': 11,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 80},
                                                   'NAME_LAST': {'NULLABLE': True,
                                                                 'ORDER': 12,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 80},
                                                   'NAME_MI': {'NULLABLE': True,
                                                               'ORDER': 13,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 80},
                                                   'NAME_SALUTATION': {'NULLABLE': True,
                                                                       'ORDER': 14,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 80},
                                                   'ORGANIZATION_TYPE': {'NULLABLE': True,
                                                                         'ORDER': 19,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 80},
                                                   'PHONE': {'NULLABLE': True,
                                                             'ORDER': 17,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 80},
                                                   'POSTAL_CODE': {'NULLABLE': True,
                                                                   'ORDER': 8,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 80},
                                                   'ROLE': {'NULLABLE': True,
                                                            'ORDER': 18,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 80},
                                                   'STATE_PROVINCE': {'NULLABLE': True,
                                                                      'ORDER': 7,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 80},
                                                   'STRUCTURE_ID': {'NULLABLE': False,
                                                                    'ORDER': 1,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': True,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10}},
                                'ATTRIBUTE_MAP': {'ADDRESS_1': ('pdbx_contact_author', 'address_1', None, None),
                                                  'ADDRESS_2': ('pdbx_contact_author', 'address_2', None, None),
                                                  'ADDRESS_3': ('pdbx_contact_author', 'address_3', None, None),
                                                  'CITY': ('pdbx_contact_author', 'city', None, None),
                                                  'CONTINENT': ('pdbx_contact_author', 'continent', None, None),
                                                  'COUNTRY': ('pdbx_contact_author', 'country', None, None),
                                                  'EMAIL': ('pdbx_contact_author', 'email', None, None),
                                                  'FAX': ('pdbx_contact_author', 'fax', None, None),
                                                  'ID': ('pdbx_contact_author', 'id', None, None),
                                                  'NAME_FIRST': ('pdbx_contact_author', 'name_first', None, None),
                                                  'NAME_LAST': ('pdbx_contact_author', 'name_last', None, None),
                                                  'NAME_MI': ('pdbx_contact_author', 'name_mi', None, None),
                                                  'NAME_SALUTATION': ('pdbx_contact_author', 'name_salutation', None, None),
                                                  'ORGANIZATION_TYPE': ('pdbx_contact_author',
                                                                        'organization_type',
                                                                        None,
                                                                        None),
                                                  'PHONE': ('pdbx_contact_author', 'phone', None, None),
                                                  'POSTAL_CODE': ('pdbx_contact_author', 'postal_code', None, None),
                                                  'ROLE': ('pdbx_contact_author', 'role', None, None),
                                                  'STATE_PROVINCE': ('pdbx_contact_author', 'state_province', None, None),
                                                  'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                            's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                'MAP_MERGE_INDICES': {'pdbx_contact_author': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                                'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                'TABLE_ID': 'PDBX_CONTACT_AUTHOR',
                                'TABLE_NAME': 'pdbx_contact_author',
                                'TABLE_TYPE': 'transactional'},
        'PDBX_COORDINATE_MODEL': {'ATTRIBUTES': {'ASYM_ID': 'asym_id', 'STRUCTURE_ID': 'Structure_ID', 'TYPE': 'type'},
                                  'ATTRIBUTE_INFO': {'ASYM_ID': {'NULLABLE': False,
                                                                 'ORDER': 2,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': True,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                                     'STRUCTURE_ID': {'NULLABLE': False,
                                                                      'ORDER': 1,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                                     'TYPE': {'NULLABLE': True,
                                                              'ORDER': 3,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 80}},
                                  'ATTRIBUTE_MAP': {'ASYM_ID': ('pdbx_coordinate_model', 'asym_id', None, None),
                                                    'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                    'TYPE': ('pdbx_coordinate_model', 'type', None, None)},
                                  'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ASYM_ID'), 'TYPE': 'UNIQUE'},
                                              's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                  'MAP_MERGE_INDICES': {'pdbx_coordinate_model': {'ATTRIBUTES': ('asym_id',),
                                                                                  'TYPE': 'EQUI-JOIN'}},
                                  'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                  'TABLE_ID': 'PDBX_COORDINATE_MODEL',
                                  'TABLE_NAME': 'pdbx_coordinate_model',
                                  'TABLE_TYPE': 'transactional'},
        'PDBX_DATABASE_MESSAGE': {'ATTRIBUTES': {'CONTENT_TYPE': 'content_type',
                                                 'DATE': 'date',
                                                 'ENTRY_ID': 'entry_id',
                                                 'MESSAGE': 'message',
                                                 'MESSAGE_ID': 'message_id',
                                                 'MESSAGE_TYPE': 'message_type',
                                                 'RECEIVER': 'receiver',
                                                 'RECEIVER_ADDRESS_EMAIL': 'receiver_address_email',
                                                 'RECEIVER_ADDRESS_FAX': 'receiver_address_fax',
                                                 'RECEIVER_ADDRESS_MAIL': 'receiver_address_mail',
                                                 'RECEIVER_ADDRESS_PHONE': 'receiver_address_phone',
                                                 'SENDER': 'sender',
                                                 'SENDER_ADDRESS_EMAIL': 'sender_address_email',
                                                 'SENDER_ADDRESS_FAX': 'sender_address_fax',
                                                 'SENDER_ADDRESS_MAIL': 'sender_address_mail',
                                                 'SENDER_ADDRESS_PHONE': 'sender_address_phone',
                                                 'STRUCTURE_ID': 'Structure_ID'},
                                  'ATTRIBUTE_INFO': {'CONTENT_TYPE': {'NULLABLE': True,
                                                                      'ORDER': 5,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                                     'DATE': {'NULLABLE': True,
                                                              'ORDER': 4,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'DATETIME',
                                                              'WIDTH': 20},
                                                     'ENTRY_ID': {'NULLABLE': False,
                                                                  'ORDER': 2,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': True,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10},
                                                     'MESSAGE': {'NULLABLE': True,
                                                                 'ORDER': 17,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 200},
                                                     'MESSAGE_ID': {'NULLABLE': False,
                                                                    'ORDER': 3,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': True,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 200},
                                                     'MESSAGE_TYPE': {'NULLABLE': True,
                                                                      'ORDER': 6,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                                     'RECEIVER': {'NULLABLE': True,
                                                                  'ORDER': 12,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 200},
                                                     'RECEIVER_ADDRESS_EMAIL': {'NULLABLE': True,
                                                                                'ORDER': 15,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 80},
                                                     'RECEIVER_ADDRESS_FAX': {'NULLABLE': True,
                                                                              'ORDER': 13,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 25},
                                                     'RECEIVER_ADDRESS_MAIL': {'NULLABLE': True,
                                                                               'ORDER': 16,
                                                                               'PRECISION': 0,
                                                                               'PRIMARY_KEY': False,
                                                                               'SQL_TYPE': 'VARCHAR',
                                                                               'WIDTH': 200},
                                                     'RECEIVER_ADDRESS_PHONE': {'NULLABLE': True,
                                                                                'ORDER': 14,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 25},
                                                     'SENDER': {'NULLABLE': True,
                                                                'ORDER': 7,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 200},
                                                     'SENDER_ADDRESS_EMAIL': {'NULLABLE': True,
                                                                              'ORDER': 10,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 80},
                                                     'SENDER_ADDRESS_FAX': {'NULLABLE': True,
                                                                            'ORDER': 8,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 25},
                                                     'SENDER_ADDRESS_MAIL': {'NULLABLE': True,
                                                                             'ORDER': 11,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 200},
                                                     'SENDER_ADDRESS_PHONE': {'NULLABLE': True,
                                                                              'ORDER': 9,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 25},
                                                     'STRUCTURE_ID': {'NULLABLE': False,
                                                                      'ORDER': 1,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10}},
                                  'ATTRIBUTE_MAP': {'CONTENT_TYPE': ('pdbx_database_message', 'content_type', None, None),
                                                    'DATE': ('pdbx_database_message', 'date', None, None),
                                                    'ENTRY_ID': ('pdbx_database_message', 'entry_id', None, None),
                                                    'MESSAGE': ('pdbx_database_message', 'message', None, None),
                                                    'MESSAGE_ID': ('pdbx_database_message', 'message_id', None, None),
                                                    'MESSAGE_TYPE': ('pdbx_database_message', 'message_type', None, None),
                                                    'RECEIVER': ('pdbx_database_message', 'receiver', None, None),
                                                    'RECEIVER_ADDRESS_EMAIL': ('pdbx_database_message',
                                                                               'receiver_address_email',
                                                                               None,
                                                                               None),
                                                    'RECEIVER_ADDRESS_FAX': ('pdbx_database_message',
                                                                             'receiver_address_fax',
                                                                             None,
                                                                             None),
                                                    'RECEIVER_ADDRESS_MAIL': ('pdbx_database_message',
                                                                              'receiver_address_mail',
                                                                              None,
                                                                              None),
                                                    'RECEIVER_ADDRESS_PHONE': ('pdbx_database_message',
                                                                               'receiver_address_phone',
                                                                               None,
                                                                               None),
                                                    'SENDER': ('pdbx_database_message', 'sender', None, None),
                                                    'SENDER_ADDRESS_EMAIL': ('pdbx_database_message',
                                                                             'sender_address_email',
                                                                             None,
                                                                             None),
                                                    'SENDER_ADDRESS_FAX': ('pdbx_database_message',
                                                                           'sender_address_fax',
                                                                           None,
                                                                           None),
                                                    'SENDER_ADDRESS_MAIL': ('pdbx_database_message',
                                                                            'sender_address_mail',
                                                                            None,
                                                                            None),
                                                    'SENDER_ADDRESS_PHONE': ('pdbx_database_message',
                                                                             'sender_address_phone',
                                                                             None,
                                                                             None),
                                                    'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                  'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID', 'MESSAGE_ID'),
                                                     'TYPE': 'UNIQUE'},
                                              's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                  'MAP_MERGE_INDICES': {'pdbx_database_message': {'ATTRIBUTES': ('entry_id', 'message_id'),
                                                                                  'TYPE': 'EQUI-JOIN'}},
                                  'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                  'TABLE_ID': 'PDBX_DATABASE_MESSAGE',
                                  'TABLE_NAME': 'pdbx_database_message',
                                  'TABLE_TYPE': 'transactional'},
        'PDBX_DATABASE_PDB_OBS_SPR': {'ATTRIBUTES': {'DATE': 'date',
                                                     'DETAILS': 'details',
                                                     'ID': 'id',
                                                     'PDB_ID': 'pdb_id',
                                                     'REPLACE_PDB_ID': 'replace_pdb_id',
                                                     'STRUCTURE_ID': 'Structure_ID'},
                                      'ATTRIBUTE_INFO': {'DATE': {'NULLABLE': True,
                                                                  'ORDER': 3,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'DATETIME',
                                                                  'WIDTH': 20},
                                                         'DETAILS': {'NULLABLE': True,
                                                                     'ORDER': 6,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 511},
                                                         'ID': {'NULLABLE': True,
                                                                'ORDER': 2,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                                         'PDB_ID': {'NULLABLE': False,
                                                                    'ORDER': 4,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': True,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 15},
                                                         'REPLACE_PDB_ID': {'NULLABLE': False,
                                                                            'ORDER': 5,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': True,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 80},
                                                         'STRUCTURE_ID': {'NULLABLE': False,
                                                                          'ORDER': 1,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': True,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10}},
                                      'ATTRIBUTE_MAP': {'DATE': ('pdbx_database_PDB_obs_spr', 'date', None, None),
                                                        'DETAILS': ('pdbx_database_PDB_obs_spr', 'details', None, None),
                                                        'ID': ('pdbx_database_PDB_obs_spr', 'id', None, None),
                                                        'PDB_ID': ('pdbx_database_PDB_obs_spr', 'pdb_id', None, None),
                                                        'REPLACE_PDB_ID': ('pdbx_database_PDB_obs_spr',
                                                                           'replace_pdb_id',
                                                                           None,
                                                                           None),
                                                        'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                      'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'PDB_ID', 'REPLACE_PDB_ID'),
                                                         'TYPE': 'UNIQUE'},
                                                  's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                      'MAP_MERGE_INDICES': {'pdbx_database_PDB_obs_spr': {'ATTRIBUTES': ('pdb_id',
                                                                                                         'replace_pdb_id'),
                                                                                          'TYPE': 'EQUI-JOIN'}},
                                      'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                      'TABLE_ID': 'PDBX_DATABASE_PDB_OBS_SPR',
                                      'TABLE_NAME': 'pdbx_database_PDB_obs_spr',
                                      'TABLE_TYPE': 'transactional'},
        'PDBX_DATABASE_PROC': {'ATTRIBUTES': {'CYCLE_ID': 'cycle_id',
                                              'DATE_BEGIN_CYCLE': 'date_begin_cycle',
                                              'DATE_END_CYCLE': 'date_end_cycle',
                                              'DETAILS': 'details',
                                              'ENTRY_ID': 'entry_id',
                                              'STRUCTURE_ID': 'Structure_ID'},
                               'ATTRIBUTE_INFO': {'CYCLE_ID': {'NULLABLE': False,
                                                               'ORDER': 3,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                                  'DATE_BEGIN_CYCLE': {'NULLABLE': True,
                                                                       'ORDER': 4,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'DATETIME',
                                                                       'WIDTH': 20},
                                                  'DATE_END_CYCLE': {'NULLABLE': True,
                                                                     'ORDER': 5,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'DATETIME',
                                                                     'WIDTH': 20},
                                                  'DETAILS': {'NULLABLE': True,
                                                              'ORDER': 6,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 200},
                                                  'ENTRY_ID': {'NULLABLE': False,
                                                               'ORDER': 2,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                                  'STRUCTURE_ID': {'NULLABLE': False,
                                                                   'ORDER': 1,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': True,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 10}},
                               'ATTRIBUTE_MAP': {'CYCLE_ID': ('pdbx_database_proc', 'cycle_id', None, None),
                                                 'DATE_BEGIN_CYCLE': ('pdbx_database_proc', 'date_begin_cycle', None, None),
                                                 'DATE_END_CYCLE': ('pdbx_database_proc', 'date_end_cycle', None, None),
                                                 'DETAILS': ('pdbx_database_proc', 'details', None, None),
                                                 'ENTRY_ID': ('pdbx_database_proc', 'entry_id', None, None),
                                                 'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                               'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID', 'CYCLE_ID'), 'TYPE': 'UNIQUE'},
                                           's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                               'MAP_MERGE_INDICES': {'pdbx_database_proc': {'ATTRIBUTES': ('entry_id', 'cycle_id'),
                                                                            'TYPE': 'EQUI-JOIN'}},
                               'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                               'TABLE_ID': 'PDBX_DATABASE_PROC',
                               'TABLE_NAME': 'pdbx_database_proc',
                               'TABLE_TYPE': 'transactional'},
        'PDBX_DATABASE_RELATED': {'ATTRIBUTES': {'CONTENT_TYPE': 'content_type',
                                                 'DB_ID': 'db_id',
                                                 'DB_NAME': 'db_name',
                                                 'DETAILS': 'details',
                                                 'STRUCTURE_ID': 'Structure_ID'},
                                  'ATTRIBUTE_INFO': {'CONTENT_TYPE': {'NULLABLE': False,
                                                                      'ORDER': 5,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 80},
                                                     'DB_ID': {'NULLABLE': False,
                                                               'ORDER': 4,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 80},
                                                     'DB_NAME': {'NULLABLE': False,
                                                                 'ORDER': 2,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': True,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 12},
                                                     'DETAILS': {'NULLABLE': True,
                                                                 'ORDER': 3,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 4095},
                                                     'STRUCTURE_ID': {'NULLABLE': False,
                                                                      'ORDER': 1,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10}},
                                  'ATTRIBUTE_MAP': {'CONTENT_TYPE': ('pdbx_database_related', 'content_type', None, None),
                                                    'DB_ID': ('pdbx_database_related', 'db_id', None, None),
                                                    'DB_NAME': ('pdbx_database_related', 'db_name', None, None),
                                                    'DETAILS': ('pdbx_database_related', 'details', None, None),
                                                    'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                  'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'DB_NAME', 'DB_ID', 'CONTENT_TYPE'),
                                                     'TYPE': 'UNIQUE'},
                                              's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                  'MAP_MERGE_INDICES': {'pdbx_database_related': {'ATTRIBUTES': ('db_name',
                                                                                                 'db_id',
                                                                                                 'content_type'),
                                                                                  'TYPE': 'EQUI-JOIN'}},
                                  'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                  'TABLE_ID': 'PDBX_DATABASE_RELATED',
                                  'TABLE_NAME': 'pdbx_database_related',
                                  'TABLE_TYPE': 'transactional'},
        'PDBX_DATABASE_REMARK': {'ATTRIBUTES': {'ID': 'id', 'STRUCTURE_ID': 'Structure_ID', 'TEXT': 'text'},
                                 'ATTRIBUTE_INFO': {'ID': {'NULLABLE': False,
                                                           'ORDER': 2,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': True,
                                                           'SQL_TYPE': 'INT',
                                                           'WIDTH': 10},
                                                    'STRUCTURE_ID': {'NULLABLE': False,
                                                                     'ORDER': 1,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': True,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                                    'TEXT': {'NULLABLE': True,
                                                             'ORDER': 3,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 16383}},
                                 'ATTRIBUTE_MAP': {'ID': ('pdbx_database_remark', 'id', None, None),
                                                   'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                   'TEXT': ('pdbx_database_remark', 'text', None, None)},
                                 'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                             's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                 'MAP_MERGE_INDICES': {'pdbx_database_remark': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                                 'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                 'TABLE_ID': 'PDBX_DATABASE_REMARK',
                                 'TABLE_NAME': 'pdbx_database_remark',
                                 'TABLE_TYPE': 'transactional'},
        'PDBX_DATABASE_STATUS': {'ATTRIBUTES': {'AUTHOR_APPROVAL_TYPE': 'author_approval_type',
                                                'AUTHOR_RELEASE_STATUS_CODE': 'author_release_status_code',
                                                'DATE_AUTHOR_APPROVAL': 'date_author_approval',
                                                'DATE_CHEMICAL_SHIFTS': 'date_chemical_shifts',
                                                'DATE_COORDINATES': 'date_coordinates',
                                                'DATE_DEPOSITION_FORM': 'date_deposition_form',
                                                'DATE_HOLD_CHEMICAL_SHIFTS': 'date_hold_chemical_shifts',
                                                'DATE_HOLD_COORDINATES': 'date_hold_coordinates',
                                                'DATE_HOLD_NMR_CONSTRAINTS': 'date_hold_nmr_constraints',
                                                'DATE_HOLD_STRUCT_FACT': 'date_hold_struct_fact',
                                                'DATE_MANUSCRIPT': 'date_manuscript',
                                                'DATE_NMR_CONSTRAINTS': 'date_nmr_constraints',
                                                'DATE_OF_CS_RELEASE': 'date_of_cs_release',
                                                'DATE_OF_MR_RELEASE': 'date_of_mr_release',
                                                'DATE_OF_PDB_RELEASE': 'date_of_PDB_release',
                                                'DATE_OF_SF_RELEASE': 'date_of_sf_release',
                                                'DATE_STRUCT_FACT': 'date_struct_fact',
                                                'DATE_SUBMITTED': 'date_submitted',
                                                'DEPOSIT_SITE': 'deposit_site',
                                                'DEP_RELEASE_CODE_CHEMICAL_SHIFTS': 'dep_release_code_chemical_shifts',
                                                'DEP_RELEASE_CODE_COORDINATES': 'dep_release_code_coordinates',
                                                'DEP_RELEASE_CODE_NMR_CONSTRAINTS': 'dep_release_code_nmr_constraints',
                                                'DEP_RELEASE_CODE_SEQUENCE': 'dep_release_code_sequence',
                                                'DEP_RELEASE_CODE_STRUCT_FACT': 'dep_release_code_struct_fact',
                                                'ENTRY_ID': 'entry_id',
                                                'HOLD_FOR_PUBLICATION': 'hold_for_publication',
                                                'METHODS_DEVELOPMENT_CATEGORY': 'methods_development_category',
                                                'NAME_DEPOSITOR': 'name_depositor',
                                                'PDB_DATE_OF_AUTHOR_APPROVAL': 'pdb_date_of_author_approval',
                                                'PROCESS_SITE': 'process_site',
                                                'RCSB_ANNOTATOR': 'rcsb_annotator',
                                                'RECVD_AUTHOR_APPROVAL': 'recvd_author_approval',
                                                'RECVD_CHEMICAL_SHIFTS': 'recvd_chemical_shifts',
                                                'RECVD_COORDINATES': 'recvd_coordinates',
                                                'RECVD_DEPOSIT_FORM': 'recvd_deposit_form',
                                                'RECVD_INITIAL_DEPOSITION_DATE': 'recvd_initial_deposition_date',
                                                'RECVD_INTERNAL_APPROVAL': 'recvd_internal_approval',
                                                'RECVD_MANUSCRIPT': 'recvd_manuscript',
                                                'RECVD_NMR_CONSTRAINTS': 'recvd_nmr_constraints',
                                                'RECVD_STRUCT_FACT': 'recvd_struct_fact',
                                                'SG_ENTRY': 'SG_entry',
                                                'STATUS_CODE': 'status_code',
                                                'STATUS_CODE_CS': 'status_code_cs',
                                                'STATUS_CODE_MR': 'status_code_mr',
                                                'STATUS_CODE_SF': 'status_code_sf',
                                                'STRUCTURE_ID': 'Structure_ID'},
                                 'ATTRIBUTE_INFO': {'AUTHOR_APPROVAL_TYPE': {'NULLABLE': True,
                                                                             'ORDER': 24,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                    'AUTHOR_RELEASE_STATUS_CODE': {'NULLABLE': True,
                                                                                   'ORDER': 3,
                                                                                   'PRECISION': 0,
                                                                                   'PRIMARY_KEY': False,
                                                                                   'SQL_TYPE': 'VARCHAR',
                                                                                   'WIDTH': 10},
                                                    'DATE_AUTHOR_APPROVAL': {'NULLABLE': True,
                                                                             'ORDER': 25,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'DATETIME',
                                                                             'WIDTH': 20},
                                                    'DATE_CHEMICAL_SHIFTS': {'NULLABLE': True,
                                                                             'ORDER': 42,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'DATETIME',
                                                                             'WIDTH': 20},
                                                    'DATE_COORDINATES': {'NULLABLE': True,
                                                                         'ORDER': 14,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'DATETIME',
                                                                         'WIDTH': 20},
                                                    'DATE_DEPOSITION_FORM': {'NULLABLE': True,
                                                                             'ORDER': 12,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'DATETIME',
                                                                             'WIDTH': 20},
                                                    'DATE_HOLD_CHEMICAL_SHIFTS': {'NULLABLE': True,
                                                                                  'ORDER': 43,
                                                                                  'PRECISION': 0,
                                                                                  'PRIMARY_KEY': False,
                                                                                  'SQL_TYPE': 'DATETIME',
                                                                                  'WIDTH': 20},
                                                    'DATE_HOLD_COORDINATES': {'NULLABLE': True,
                                                                              'ORDER': 32,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'DATETIME',
                                                                              'WIDTH': 20},
                                                    'DATE_HOLD_NMR_CONSTRAINTS': {'NULLABLE': True,
                                                                                  'ORDER': 34,
                                                                                  'PRECISION': 0,
                                                                                  'PRIMARY_KEY': False,
                                                                                  'SQL_TYPE': 'DATETIME',
                                                                                  'WIDTH': 20},
                                                    'DATE_HOLD_STRUCT_FACT': {'NULLABLE': True,
                                                                              'ORDER': 33,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'DATETIME',
                                                                              'WIDTH': 20},
                                                    'DATE_MANUSCRIPT': {'NULLABLE': True,
                                                                        'ORDER': 21,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'DATETIME',
                                                                        'WIDTH': 20},
                                                    'DATE_NMR_CONSTRAINTS': {'NULLABLE': True,
                                                                             'ORDER': 18,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'DATETIME',
                                                                             'WIDTH': 20},
                                                    'DATE_OF_CS_RELEASE': {'NULLABLE': True,
                                                                           'ORDER': 45,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'DATETIME',
                                                                           'WIDTH': 15},
                                                    'DATE_OF_MR_RELEASE': {'NULLABLE': True,
                                                                           'ORDER': 30,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'DATETIME',
                                                                           'WIDTH': 15},
                                                    'DATE_OF_PDB_RELEASE': {'NULLABLE': True,
                                                                            'ORDER': 31,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'DATETIME',
                                                                            'WIDTH': 20},
                                                    'DATE_OF_SF_RELEASE': {'NULLABLE': True,
                                                                           'ORDER': 29,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'DATETIME',
                                                                           'WIDTH': 15},
                                                    'DATE_STRUCT_FACT': {'NULLABLE': True,
                                                                         'ORDER': 16,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'DATETIME',
                                                                         'WIDTH': 20},
                                                    'DATE_SUBMITTED': {'NULLABLE': True,
                                                                       'ORDER': 27,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'DATETIME',
                                                                       'WIDTH': 20},
                                                    'DEPOSIT_SITE': {'NULLABLE': True,
                                                                     'ORDER': 38,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                                    'DEP_RELEASE_CODE_CHEMICAL_SHIFTS': {'NULLABLE': True,
                                                                                         'ORDER': 40,
                                                                                         'PRECISION': 0,
                                                                                         'PRIMARY_KEY': False,
                                                                                         'SQL_TYPE': 'VARCHAR',
                                                                                         'WIDTH': 80},
                                                    'DEP_RELEASE_CODE_COORDINATES': {'NULLABLE': True,
                                                                                     'ORDER': 6,
                                                                                     'PRECISION': 0,
                                                                                     'PRIMARY_KEY': False,
                                                                                     'SQL_TYPE': 'VARCHAR',
                                                                                     'WIDTH': 80},
                                                    'DEP_RELEASE_CODE_NMR_CONSTRAINTS': {'NULLABLE': True,
                                                                                         'ORDER': 9,
                                                                                         'PRECISION': 0,
                                                                                         'PRIMARY_KEY': False,
                                                                                         'SQL_TYPE': 'VARCHAR',
                                                                                         'WIDTH': 80},
                                                    'DEP_RELEASE_CODE_SEQUENCE': {'NULLABLE': True,
                                                                                  'ORDER': 7,
                                                                                  'PRECISION': 0,
                                                                                  'PRIMARY_KEY': False,
                                                                                  'SQL_TYPE': 'VARCHAR',
                                                                                  'WIDTH': 80},
                                                    'DEP_RELEASE_CODE_STRUCT_FACT': {'NULLABLE': True,
                                                                                     'ORDER': 8,
                                                                                     'PRECISION': 0,
                                                                                     'PRIMARY_KEY': False,
                                                                                     'SQL_TYPE': 'VARCHAR',
                                                                                     'WIDTH': 80},
                                                    'ENTRY_ID': {'NULLABLE': False,
                                                                 'ORDER': 10,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': True,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                                    'HOLD_FOR_PUBLICATION': {'NULLABLE': True,
                                                                             'ORDER': 35,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 2},
                                                    'METHODS_DEVELOPMENT_CATEGORY': {'NULLABLE': True,
                                                                                     'ORDER': 46,
                                                                                     'PRECISION': 0,
                                                                                     'PRIMARY_KEY': False,
                                                                                     'SQL_TYPE': 'VARCHAR',
                                                                                     'WIDTH': 80},
                                                    'NAME_DEPOSITOR': {'NULLABLE': True,
                                                                       'ORDER': 22,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 200},
                                                    'PDB_DATE_OF_AUTHOR_APPROVAL': {'NULLABLE': True,
                                                                                    'ORDER': 37,
                                                                                    'PRECISION': 0,
                                                                                    'PRIMARY_KEY': False,
                                                                                    'SQL_TYPE': 'DATETIME',
                                                                                    'WIDTH': 20},
                                                    'PROCESS_SITE': {'NULLABLE': True,
                                                                     'ORDER': 39,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                                    'RCSB_ANNOTATOR': {'NULLABLE': True,
                                                                       'ORDER': 28,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                    'RECVD_AUTHOR_APPROVAL': {'NULLABLE': True,
                                                                              'ORDER': 23,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 2},
                                                    'RECVD_CHEMICAL_SHIFTS': {'NULLABLE': True,
                                                                              'ORDER': 41,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 2},
                                                    'RECVD_COORDINATES': {'NULLABLE': True,
                                                                          'ORDER': 13,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 2},
                                                    'RECVD_DEPOSIT_FORM': {'NULLABLE': True,
                                                                           'ORDER': 11,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 2},
                                                    'RECVD_INITIAL_DEPOSITION_DATE': {'NULLABLE': True,
                                                                                      'ORDER': 26,
                                                                                      'PRECISION': 0,
                                                                                      'PRIMARY_KEY': False,
                                                                                      'SQL_TYPE': 'DATETIME',
                                                                                      'WIDTH': 20},
                                                    'RECVD_INTERNAL_APPROVAL': {'NULLABLE': True,
                                                                                'ORDER': 19,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 2},
                                                    'RECVD_MANUSCRIPT': {'NULLABLE': True,
                                                                         'ORDER': 20,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 2},
                                                    'RECVD_NMR_CONSTRAINTS': {'NULLABLE': True,
                                                                              'ORDER': 17,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 2},
                                                    'RECVD_STRUCT_FACT': {'NULLABLE': True,
                                                                          'ORDER': 15,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 2},
                                                    'SG_ENTRY': {'NULLABLE': True,
                                                                 'ORDER': 36,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 2},
                                                    'STATUS_CODE': {'NULLABLE': True,
                                                                    'ORDER': 2,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10},
                                                    'STATUS_CODE_CS': {'NULLABLE': True,
                                                                       'ORDER': 44,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                    'STATUS_CODE_MR': {'NULLABLE': True,
                                                                       'ORDER': 5,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                    'STATUS_CODE_SF': {'NULLABLE': True,
                                                                       'ORDER': 4,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                    'STRUCTURE_ID': {'NULLABLE': False,
                                                                     'ORDER': 1,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': True,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10}},
                                 'ATTRIBUTE_MAP': {'AUTHOR_APPROVAL_TYPE': ('pdbx_database_status',
                                                                            'author_approval_type',
                                                                            None,
                                                                            None),
                                                   'AUTHOR_RELEASE_STATUS_CODE': ('pdbx_database_status',
                                                                                  'author_release_status_code',
                                                                                  None,
                                                                                  None),
                                                   'DATE_AUTHOR_APPROVAL': ('pdbx_database_status',
                                                                            'date_author_approval',
                                                                            None,
                                                                            None),
                                                   'DATE_CHEMICAL_SHIFTS': ('pdbx_database_status',
                                                                            'date_chemical_shifts',
                                                                            None,
                                                                            None),
                                                   'DATE_COORDINATES': ('pdbx_database_status',
                                                                        'date_coordinates',
                                                                        None,
                                                                        None),
                                                   'DATE_DEPOSITION_FORM': ('pdbx_database_status',
                                                                            'date_deposition_form',
                                                                            None,
                                                                            None),
                                                   'DATE_HOLD_CHEMICAL_SHIFTS': ('pdbx_database_status',
                                                                                 'date_hold_chemical_shifts',
                                                                                 None,
                                                                                 None),
                                                   'DATE_HOLD_COORDINATES': ('pdbx_database_status',
                                                                             'date_hold_coordinates',
                                                                             None,
                                                                             None),
                                                   'DATE_HOLD_NMR_CONSTRAINTS': ('pdbx_database_status',
                                                                                 'date_hold_nmr_constraints',
                                                                                 None,
                                                                                 None),
                                                   'DATE_HOLD_STRUCT_FACT': ('pdbx_database_status',
                                                                             'date_hold_struct_fact',
                                                                             None,
                                                                             None),
                                                   'DATE_MANUSCRIPT': ('pdbx_database_status', 'date_manuscript', None, None),
                                                   'DATE_NMR_CONSTRAINTS': ('pdbx_database_status',
                                                                            'date_nmr_constraints',
                                                                            None,
                                                                            None),
                                                   'DATE_OF_CS_RELEASE': ('pdbx_database_status',
                                                                          'date_of_cs_release',
                                                                          None,
                                                                          None),
                                                   'DATE_OF_MR_RELEASE': ('pdbx_database_status',
                                                                          'date_of_mr_release',
                                                                          None,
                                                                          None),
                                                   'DATE_OF_PDB_RELEASE': ('pdbx_database_status',
                                                                           'date_of_PDB_release',
                                                                           None,
                                                                           None),
                                                   'DATE_OF_SF_RELEASE': ('pdbx_database_status',
                                                                          'date_of_sf_release',
                                                                          None,
                                                                          None),
                                                   'DATE_STRUCT_FACT': ('pdbx_database_status',
                                                                        'date_struct_fact',
                                                                        None,
                                                                        None),
                                                   'DATE_SUBMITTED': ('pdbx_database_status', 'date_submitted', None, None),
                                                   'DEPOSIT_SITE': ('pdbx_database_status', 'deposit_site', None, None),
                                                   'DEP_RELEASE_CODE_CHEMICAL_SHIFTS': ('pdbx_database_status',
                                                                                        'dep_release_code_chemical_shifts',
                                                                                        None,
                                                                                        None),
                                                   'DEP_RELEASE_CODE_COORDINATES': ('pdbx_database_status',
                                                                                    'dep_release_code_coordinates',
                                                                                    None,
                                                                                    None),
                                                   'DEP_RELEASE_CODE_NMR_CONSTRAINTS': ('pdbx_database_status',
                                                                                        'dep_release_code_nmr_constraints',
                                                                                        None,
                                                                                        None),
                                                   'DEP_RELEASE_CODE_SEQUENCE': ('pdbx_database_status',
                                                                                 'dep_release_code_sequence',
                                                                                 None,
                                                                                 None),
                                                   'DEP_RELEASE_CODE_STRUCT_FACT': ('pdbx_database_status',
                                                                                    'dep_release_code_struct_fact',
                                                                                    None,
                                                                                    None),
                                                   'ENTRY_ID': ('pdbx_database_status', 'entry_id', None, None),
                                                   'HOLD_FOR_PUBLICATION': ('pdbx_database_status',
                                                                            'hold_for_publication',
                                                                            None,
                                                                            None),
                                                   'METHODS_DEVELOPMENT_CATEGORY': ('pdbx_database_status',
                                                                                    'methods_development_category',
                                                                                    None,
                                                                                    None),
                                                   'NAME_DEPOSITOR': ('pdbx_database_status', 'name_depositor', None, None),
                                                   'PDB_DATE_OF_AUTHOR_APPROVAL': ('pdbx_database_status',
                                                                                   'pdb_date_of_author_approval',
                                                                                   None,
                                                                                   None),
                                                   'PROCESS_SITE': ('pdbx_database_status', 'process_site', None, None),
                                                   'RCSB_ANNOTATOR': ('pdbx_database_status', 'rcsb_annotator', None, None),
                                                   'RECVD_AUTHOR_APPROVAL': ('pdbx_database_status',
                                                                             'recvd_author_approval',
                                                                             None,
                                                                             None),
                                                   'RECVD_CHEMICAL_SHIFTS': ('pdbx_database_status',
                                                                             'recvd_chemical_shifts',
                                                                             None,
                                                                             None),
                                                   'RECVD_COORDINATES': ('pdbx_database_status',
                                                                         'recvd_coordinates',
                                                                         None,
                                                                         None),
                                                   'RECVD_DEPOSIT_FORM': ('pdbx_database_status',
                                                                          'recvd_deposit_form',
                                                                          None,
                                                                          None),
                                                   'RECVD_INITIAL_DEPOSITION_DATE': ('pdbx_database_status',
                                                                                     'recvd_initial_deposition_date',
                                                                                     None,
                                                                                     None),
                                                   'RECVD_INTERNAL_APPROVAL': ('pdbx_database_status',
                                                                               'recvd_internal_approval',
                                                                               None,
                                                                               None),
                                                   'RECVD_MANUSCRIPT': ('pdbx_database_status',
                                                                        'recvd_manuscript',
                                                                        None,
                                                                        None),
                                                   'RECVD_NMR_CONSTRAINTS': ('pdbx_database_status',
                                                                             'recvd_nmr_constraints',
                                                                             None,
                                                                             None),
                                                   'RECVD_STRUCT_FACT': ('pdbx_database_status',
                                                                         'recvd_struct_fact',
                                                                         None,
                                                                         None),
                                                   'SG_ENTRY': ('pdbx_database_status', 'SG_entry', None, None),
                                                   'STATUS_CODE': ('pdbx_database_status', 'status_code', None, None),
                                                   'STATUS_CODE_CS': ('pdbx_database_status', 'status_code_cs', None, None),
                                                   'STATUS_CODE_MR': ('pdbx_database_status', 'status_code_mr', None, None),
                                                   'STATUS_CODE_SF': ('pdbx_database_status', 'status_code_sf', None, None),
                                                   'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                 'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID'), 'TYPE': 'UNIQUE'},
                                             's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                 'MAP_MERGE_INDICES': {'pdbx_database_status': {'ATTRIBUTES': ('entry_id',),
                                                                                'TYPE': 'EQUI-JOIN'}},
                                 'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                 'TABLE_ID': 'PDBX_DATABASE_STATUS',
                                 'TABLE_NAME': 'pdbx_database_status',
                                 'TABLE_TYPE': 'transactional'},
        'PDBX_DIFFRN_REFLNS_SHELL': {'ATTRIBUTES': {'CHI_SQUARED': 'chi_squared',
                                                    'DIFFRN_ID': 'diffrn_id',
                                                    'D_RES_HIGH': 'd_res_high',
                                                    'D_RES_LOW': 'd_res_low',
                                                    'NUMBER_OBS': 'number_obs',
                                                    'PERCENT_POSSIBLE_OBS': 'percent_possible_obs',
                                                    'REDUNDANCY': 'redundancy',
                                                    'REJECTS': 'rejects',
                                                    'RMERGE_I_OBS': 'Rmerge_I_obs',
                                                    'RSYM_VALUE': 'Rsym_value',
                                                    'STRUCTURE_ID': 'Structure_ID'},
                                     'ATTRIBUTE_INFO': {'CHI_SQUARED': {'NULLABLE': True,
                                                                        'ORDER': 8,
                                                                        'PRECISION': 6,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'FLOAT',
                                                                        'WIDTH': 10},
                                                        'DIFFRN_ID': {'NULLABLE': False,
                                                                      'ORDER': 2,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                                        'D_RES_HIGH': {'NULLABLE': False,
                                                                       'ORDER': 4,
                                                                       'PRECISION': 6,
                                                                       'PRIMARY_KEY': True,
                                                                       'SQL_TYPE': 'FLOAT',
                                                                       'WIDTH': 10},
                                                        'D_RES_LOW': {'NULLABLE': False,
                                                                      'ORDER': 3,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                                        'NUMBER_OBS': {'NULLABLE': True,
                                                                       'ORDER': 11,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'INT',
                                                                       'WIDTH': 10},
                                                        'PERCENT_POSSIBLE_OBS': {'NULLABLE': True,
                                                                                 'ORDER': 5,
                                                                                 'PRECISION': 6,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'FLOAT',
                                                                                 'WIDTH': 10},
                                                        'REDUNDANCY': {'NULLABLE': True,
                                                                       'ORDER': 9,
                                                                       'PRECISION': 6,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'FLOAT',
                                                                       'WIDTH': 10},
                                                        'REJECTS': {'NULLABLE': True,
                                                                    'ORDER': 10,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'INT',
                                                                    'WIDTH': 10},
                                                        'RMERGE_I_OBS': {'NULLABLE': True,
                                                                         'ORDER': 6,
                                                                         'PRECISION': 6,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'FLOAT',
                                                                         'WIDTH': 10},
                                                        'RSYM_VALUE': {'NULLABLE': True,
                                                                       'ORDER': 7,
                                                                       'PRECISION': 6,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'FLOAT',
                                                                       'WIDTH': 10},
                                                        'STRUCTURE_ID': {'NULLABLE': False,
                                                                         'ORDER': 1,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': True,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10}},
                                     'ATTRIBUTE_MAP': {'CHI_SQUARED': ('pdbx_diffrn_reflns_shell', 'chi_squared', None, None),
                                                       'DIFFRN_ID': ('pdbx_diffrn_reflns_shell', 'diffrn_id', None, None),
                                                       'D_RES_HIGH': ('pdbx_diffrn_reflns_shell', 'd_res_high', None, None),
                                                       'D_RES_LOW': ('pdbx_diffrn_reflns_shell', 'd_res_low', None, None),
                                                       'NUMBER_OBS': ('pdbx_diffrn_reflns_shell', 'number_obs', None, None),
                                                       'PERCENT_POSSIBLE_OBS': ('pdbx_diffrn_reflns_shell',
                                                                                'percent_possible_obs',
                                                                                None,
                                                                                None),
                                                       'REDUNDANCY': ('pdbx_diffrn_reflns_shell', 'redundancy', None, None),
                                                       'REJECTS': ('pdbx_diffrn_reflns_shell', 'rejects', None, None),
                                                       'RMERGE_I_OBS': ('pdbx_diffrn_reflns_shell',
                                                                        'Rmerge_I_obs',
                                                                        None,
                                                                        None),
                                                       'RSYM_VALUE': ('pdbx_diffrn_reflns_shell', 'Rsym_value', None, None),
                                                       'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                     'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'DIFFRN_ID', 'D_RES_LOW', 'D_RES_HIGH'),
                                                        'TYPE': 'UNIQUE'},
                                                 's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                     'MAP_MERGE_INDICES': {'pdbx_diffrn_reflns_shell': {'ATTRIBUTES': ('diffrn_id',
                                                                                                       'd_res_low',
                                                                                                       'd_res_high'),
                                                                                        'TYPE': 'EQUI-JOIN'}},
                                     'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                     'TABLE_ID': 'PDBX_DIFFRN_REFLNS_SHELL',
                                     'TABLE_NAME': 'pdbx_diffrn_reflns_shell',
                                     'TABLE_TYPE': 'transactional'},
        'PDBX_DISTANT_SOLVENT_ATOMS': {'ATTRIBUTES': {'AUTH_ASYM_ID': 'auth_asym_id',
                                                      'AUTH_ATOM_ID': 'auth_atom_id',
                                                      'AUTH_COMP_ID': 'auth_comp_id',
                                                      'AUTH_SEQ_ID': 'auth_seq_id',
                                                      'ID': 'id',
                                                      'LABEL_ALT_ID': 'label_alt_id',
                                                      'LABEL_ASYM_ID': 'label_asym_id',
                                                      'LABEL_ATOM_ID': 'label_atom_id',
                                                      'LABEL_COMP_ID': 'label_comp_id',
                                                      'LABEL_SEQ_ID': 'label_seq_id',
                                                      'NEIGHBOR_LIGAND_DISTANCE': 'neighbor_ligand_distance',
                                                      'NEIGHBOR_MACROMOLECULE_DISTANCE': 'neighbor_macromolecule_distance',
                                                      'PDB_INS_CODE': 'PDB_ins_code',
                                                      'PDB_MODEL_NUM': 'PDB_model_num',
                                                      'STRUCTURE_ID': 'Structure_ID'},
                                       'ATTRIBUTE_INFO': {'AUTH_ASYM_ID': {'NULLABLE': True,
                                                                           'ORDER': 4,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10},
                                                          'AUTH_ATOM_ID': {'NULLABLE': True,
                                                                           'ORDER': 5,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 6},
                                                          'AUTH_COMP_ID': {'NULLABLE': True,
                                                                           'ORDER': 6,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10},
                                                          'AUTH_SEQ_ID': {'NULLABLE': True,
                                                                          'ORDER': 7,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                          'ID': {'NULLABLE': False,
                                                                 'ORDER': 2,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': True,
                                                                 'SQL_TYPE': 'INT',
                                                                 'WIDTH': 10},
                                                          'LABEL_ALT_ID': {'NULLABLE': True,
                                                                           'ORDER': 9,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10},
                                                          'LABEL_ASYM_ID': {'NULLABLE': True,
                                                                            'ORDER': 11,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 10},
                                                          'LABEL_ATOM_ID': {'NULLABLE': True,
                                                                            'ORDER': 10,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 6},
                                                          'LABEL_COMP_ID': {'NULLABLE': True,
                                                                            'ORDER': 12,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 10},
                                                          'LABEL_SEQ_ID': {'NULLABLE': True,
                                                                           'ORDER': 13,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'INT',
                                                                           'WIDTH': 10},
                                                          'NEIGHBOR_LIGAND_DISTANCE': {'NULLABLE': True,
                                                                                       'ORDER': 15,
                                                                                       'PRECISION': 6,
                                                                                       'PRIMARY_KEY': False,
                                                                                       'SQL_TYPE': 'FLOAT',
                                                                                       'WIDTH': 10},
                                                          'NEIGHBOR_MACROMOLECULE_DISTANCE': {'NULLABLE': True,
                                                                                              'ORDER': 14,
                                                                                              'PRECISION': 6,
                                                                                              'PRIMARY_KEY': False,
                                                                                              'SQL_TYPE': 'FLOAT',
                                                                                              'WIDTH': 10},
                                                          'PDB_INS_CODE': {'NULLABLE': True,
                                                                           'ORDER': 8,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10},
                                                          'PDB_MODEL_NUM': {'NULLABLE': True,
                                                                            'ORDER': 3,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'INT',
                                                                            'WIDTH': 10},
                                                          'STRUCTURE_ID': {'NULLABLE': False,
                                                                           'ORDER': 1,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': True,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10}},
                                       'ATTRIBUTE_MAP': {'AUTH_ASYM_ID': ('pdbx_distant_solvent_atoms',
                                                                          'auth_asym_id',
                                                                          None,
                                                                          None),
                                                         'AUTH_ATOM_ID': ('pdbx_distant_solvent_atoms',
                                                                          'auth_atom_id',
                                                                          None,
                                                                          None),
                                                         'AUTH_COMP_ID': ('pdbx_distant_solvent_atoms',
                                                                          'auth_comp_id',
                                                                          None,
                                                                          None),
                                                         'AUTH_SEQ_ID': ('pdbx_distant_solvent_atoms',
                                                                         'auth_seq_id',
                                                                         None,
                                                                         None),
                                                         'ID': ('pdbx_distant_solvent_atoms', 'id', None, None),
                                                         'LABEL_ALT_ID': ('pdbx_distant_solvent_atoms',
                                                                          'label_alt_id',
                                                                          None,
                                                                          None),
                                                         'LABEL_ASYM_ID': ('pdbx_distant_solvent_atoms',
                                                                           'label_asym_id',
                                                                           None,
                                                                           None),
                                                         'LABEL_ATOM_ID': ('pdbx_distant_solvent_atoms',
                                                                           'label_atom_id',
                                                                           None,
                                                                           None),
                                                         'LABEL_COMP_ID': ('pdbx_distant_solvent_atoms',
                                                                           'label_comp_id',
                                                                           None,
                                                                           None),
                                                         'LABEL_SEQ_ID': ('pdbx_distant_solvent_atoms',
                                                                          'label_seq_id',
                                                                          None,
                                                                          None),
                                                         'NEIGHBOR_LIGAND_DISTANCE': ('pdbx_distant_solvent_atoms',
                                                                                      'neighbor_ligand_distance',
                                                                                      None,
                                                                                      None),
                                                         'NEIGHBOR_MACROMOLECULE_DISTANCE': ('pdbx_distant_solvent_atoms',
                                                                                             'neighbor_macromolecule_distance',
                                                                                             None,
                                                                                             None),
                                                         'PDB_INS_CODE': ('pdbx_distant_solvent_atoms',
                                                                          'PDB_ins_code',
                                                                          None,
                                                                          None),
                                                         'PDB_MODEL_NUM': ('pdbx_distant_solvent_atoms',
                                                                           'PDB_model_num',
                                                                           None,
                                                                           None),
                                                         'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                       'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                                   's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                       'MAP_MERGE_INDICES': {'pdbx_distant_solvent_atoms': {'ATTRIBUTES': ('id',),
                                                                                            'TYPE': 'EQUI-JOIN'}},
                                       'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                       'TABLE_ID': 'PDBX_DISTANT_SOLVENT_ATOMS',
                                       'TABLE_NAME': 'pdbx_distant_solvent_atoms',
                                       'TABLE_TYPE': 'transactional'},
        'PDBX_DOMAIN': {'ATTRIBUTES': {'DETAILS': 'details', 'ID': 'id', 'STRUCTURE_ID': 'Structure_ID'},
                        'ATTRIBUTE_INFO': {'DETAILS': {'NULLABLE': True,
                                                       'ORDER': 2,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'VARCHAR',
                                                       'WIDTH': 200},
                                           'ID': {'NULLABLE': False,
                                                  'ORDER': 3,
                                                  'PRECISION': 0,
                                                  'PRIMARY_KEY': True,
                                                  'SQL_TYPE': 'VARCHAR',
                                                  'WIDTH': 10},
                                           'STRUCTURE_ID': {'NULLABLE': False,
                                                            'ORDER': 1,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': True,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 10}},
                        'ATTRIBUTE_MAP': {'DETAILS': ('pdbx_domain', 'details', None, None),
                                          'ID': ('pdbx_domain', 'id', None, None),
                                          'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                        'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                    's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                        'MAP_MERGE_INDICES': {'pdbx_domain': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                        'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                        'TABLE_ID': 'PDBX_DOMAIN',
                        'TABLE_NAME': 'pdbx_domain',
                        'TABLE_TYPE': 'transactional'},
        'PDBX_DOMAIN_RANGE': {'ATTRIBUTES': {'BEG_AUTH_ASYM_ID': 'beg_auth_asym_id',
                                             'BEG_AUTH_COMP_ID': 'beg_auth_comp_id',
                                             'BEG_AUTH_SEQ_ID': 'beg_auth_seq_id',
                                             'BEG_LABEL_ALT_ID': 'beg_label_alt_id',
                                             'BEG_LABEL_ASYM_ID': 'beg_label_asym_id',
                                             'BEG_LABEL_COMP_ID': 'beg_label_comp_id',
                                             'BEG_LABEL_SEQ_ID': 'beg_label_seq_id',
                                             'DOMAIN_ID': 'domain_id',
                                             'END_AUTH_ASYM_ID': 'end_auth_asym_id',
                                             'END_AUTH_COMP_ID': 'end_auth_comp_id',
                                             'END_AUTH_SEQ_ID': 'end_auth_seq_id',
                                             'END_LABEL_ALT_ID': 'end_label_alt_id',
                                             'END_LABEL_ASYM_ID': 'end_label_asym_id',
                                             'END_LABEL_COMP_ID': 'end_label_comp_id',
                                             'END_LABEL_SEQ_ID': 'end_label_seq_id',
                                             'STRUCTURE_ID': 'Structure_ID'},
                              'ATTRIBUTE_INFO': {'BEG_AUTH_ASYM_ID': {'NULLABLE': True,
                                                                      'ORDER': 6,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                                 'BEG_AUTH_COMP_ID': {'NULLABLE': True,
                                                                      'ORDER': 7,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                                 'BEG_AUTH_SEQ_ID': {'NULLABLE': True,
                                                                     'ORDER': 8,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                                 'BEG_LABEL_ALT_ID': {'NULLABLE': False,
                                                                      'ORDER': 2,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                                 'BEG_LABEL_ASYM_ID': {'NULLABLE': False,
                                                                       'ORDER': 3,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': True,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                 'BEG_LABEL_COMP_ID': {'NULLABLE': False,
                                                                       'ORDER': 4,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': True,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                 'BEG_LABEL_SEQ_ID': {'NULLABLE': False,
                                                                      'ORDER': 5,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'INT',
                                                                      'WIDTH': 10},
                                                 'DOMAIN_ID': {'NULLABLE': False,
                                                               'ORDER': 9,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                                 'END_AUTH_ASYM_ID': {'NULLABLE': True,
                                                                      'ORDER': 14,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                                 'END_AUTH_COMP_ID': {'NULLABLE': True,
                                                                      'ORDER': 15,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                                 'END_AUTH_SEQ_ID': {'NULLABLE': True,
                                                                     'ORDER': 16,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                                 'END_LABEL_ALT_ID': {'NULLABLE': False,
                                                                      'ORDER': 10,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                                 'END_LABEL_ASYM_ID': {'NULLABLE': False,
                                                                       'ORDER': 11,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': True,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                 'END_LABEL_COMP_ID': {'NULLABLE': False,
                                                                       'ORDER': 12,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': True,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                 'END_LABEL_SEQ_ID': {'NULLABLE': False,
                                                                      'ORDER': 13,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'INT',
                                                                      'WIDTH': 10},
                                                 'STRUCTURE_ID': {'NULLABLE': False,
                                                                  'ORDER': 1,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': True,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10}},
                              'ATTRIBUTE_MAP': {'BEG_AUTH_ASYM_ID': ('pdbx_domain_range', 'beg_auth_asym_id', None, None),
                                                'BEG_AUTH_COMP_ID': ('pdbx_domain_range', 'beg_auth_comp_id', None, None),
                                                'BEG_AUTH_SEQ_ID': ('pdbx_domain_range', 'beg_auth_seq_id', None, None),
                                                'BEG_LABEL_ALT_ID': ('pdbx_domain_range', 'beg_label_alt_id', None, None),
                                                'BEG_LABEL_ASYM_ID': ('pdbx_domain_range', 'beg_label_asym_id', None, None),
                                                'BEG_LABEL_COMP_ID': ('pdbx_domain_range', 'beg_label_comp_id', None, None),
                                                'BEG_LABEL_SEQ_ID': ('pdbx_domain_range', 'beg_label_seq_id', None, None),
                                                'DOMAIN_ID': ('pdbx_domain_range', 'domain_id', None, None),
                                                'END_AUTH_ASYM_ID': ('pdbx_domain_range', 'end_auth_asym_id', None, None),
                                                'END_AUTH_COMP_ID': ('pdbx_domain_range', 'end_auth_comp_id', None, None),
                                                'END_AUTH_SEQ_ID': ('pdbx_domain_range', 'end_auth_seq_id', None, None),
                                                'END_LABEL_ALT_ID': ('pdbx_domain_range', 'end_label_alt_id', None, None),
                                                'END_LABEL_ASYM_ID': ('pdbx_domain_range', 'end_label_asym_id', None, None),
                                                'END_LABEL_COMP_ID': ('pdbx_domain_range', 'end_label_comp_id', None, None),
                                                'END_LABEL_SEQ_ID': ('pdbx_domain_range', 'end_label_seq_id', None, None),
                                                'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                              'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID',
                                                                'BEG_LABEL_ALT_ID',
                                                                'BEG_LABEL_ASYM_ID',
                                                                'BEG_LABEL_COMP_ID',
                                                                'BEG_LABEL_SEQ_ID',
                                                                'DOMAIN_ID',
                                                                'END_LABEL_ALT_ID',
                                                                'END_LABEL_ASYM_ID',
                                                                'END_LABEL_COMP_ID',
                                                                'END_LABEL_SEQ_ID'),
                                                 'TYPE': 'UNIQUE'},
                                          's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                              'MAP_MERGE_INDICES': {'pdbx_domain_range': {'ATTRIBUTES': ('beg_label_alt_id',
                                                                                         'beg_label_asym_id',
                                                                                         'beg_label_comp_id',
                                                                                         'beg_label_seq_id',
                                                                                         'domain_id',
                                                                                         'end_label_alt_id',
                                                                                         'end_label_asym_id',
                                                                                         'end_label_comp_id',
                                                                                         'end_label_seq_id'),
                                                                          'TYPE': 'EQUI-JOIN'}},
                              'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                              'TABLE_ID': 'PDBX_DOMAIN_RANGE',
                              'TABLE_NAME': 'pdbx_domain_range',
                              'TABLE_TYPE': 'transactional'},
        'PDBX_ENTITY_ASSEMBLY': {'ATTRIBUTES': {'BIOL_ID': 'biol_id',
                                                'ENTITY_ID': 'entity_id',
                                                'ID': 'id',
                                                'NUM_COPIES': 'num_copies',
                                                'STRUCTURE_ID': 'Structure_ID'},
                                 'ATTRIBUTE_INFO': {'BIOL_ID': {'NULLABLE': True,
                                                                'ORDER': 4,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 80},
                                                    'ENTITY_ID': {'NULLABLE': False,
                                                                  'ORDER': 3,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': True,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10},
                                                    'ID': {'NULLABLE': False,
                                                           'ORDER': 2,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': True,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 10},
                                                    'NUM_COPIES': {'NULLABLE': True,
                                                                   'ORDER': 5,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'INT',
                                                                   'WIDTH': 10},
                                                    'STRUCTURE_ID': {'NULLABLE': False,
                                                                     'ORDER': 1,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': True,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10}},
                                 'ATTRIBUTE_MAP': {'BIOL_ID': ('pdbx_entity_assembly', 'biol_id', None, None),
                                                   'ENTITY_ID': ('pdbx_entity_assembly', 'entity_id', None, None),
                                                   'ID': ('pdbx_entity_assembly', 'id', None, None),
                                                   'NUM_COPIES': ('pdbx_entity_assembly', 'num_copies', None, None),
                                                   'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                 'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID', 'ENTITY_ID'), 'TYPE': 'UNIQUE'},
                                             's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                 'MAP_MERGE_INDICES': {'pdbx_entity_assembly': {'ATTRIBUTES': ('id', 'entity_id'),
                                                                                'TYPE': 'EQUI-JOIN'}},
                                 'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                 'TABLE_ID': 'PDBX_ENTITY_ASSEMBLY',
                                 'TABLE_NAME': 'pdbx_entity_assembly',
                                 'TABLE_TYPE': 'transactional'},
        'PDBX_ENTITY_GROUP_COMPONENTS': {'ATTRIBUTES': {'BEG_SEQ_ID': 'beg_seq_id',
                                                        'END_SEQ_ID': 'end_seq_id',
                                                        'ENTITY_GROUP_ID': 'entity_group_id',
                                                        'ENTITY_ID': 'entity_id',
                                                        'ID': 'id',
                                                        'NAME': 'name',
                                                        'NONPOLY_RESIDUE_NUMBER': 'nonpoly_residue_number',
                                                        'STRUCTURE_ID': 'Structure_ID'},
                                         'ATTRIBUTE_INFO': {'BEG_SEQ_ID': {'NULLABLE': True,
                                                                           'ORDER': 6,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'INT',
                                                                           'WIDTH': 10},
                                                            'END_SEQ_ID': {'NULLABLE': True,
                                                                           'ORDER': 7,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'INT',
                                                                           'WIDTH': 10},
                                                            'ENTITY_GROUP_ID': {'NULLABLE': False,
                                                                                'ORDER': 3,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': True,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 10},
                                                            'ENTITY_ID': {'NULLABLE': True,
                                                                          'ORDER': 2,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                            'ID': {'NULLABLE': False,
                                                                   'ORDER': 4,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': True,
                                                                   'SQL_TYPE': 'INT',
                                                                   'WIDTH': 10},
                                                            'NAME': {'NULLABLE': True,
                                                                     'ORDER': 5,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 200},
                                                            'NONPOLY_RESIDUE_NUMBER': {'NULLABLE': True,
                                                                                       'ORDER': 8,
                                                                                       'PRECISION': 0,
                                                                                       'PRIMARY_KEY': False,
                                                                                       'SQL_TYPE': 'INT',
                                                                                       'WIDTH': 10},
                                                            'STRUCTURE_ID': {'NULLABLE': False,
                                                                             'ORDER': 1,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': True,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10}},
                                         'ATTRIBUTE_MAP': {'BEG_SEQ_ID': ('pdbx_entity_group_components',
                                                                          'beg_seq_id',
                                                                          None,
                                                                          None),
                                                           'END_SEQ_ID': ('pdbx_entity_group_components',
                                                                          'end_seq_id',
                                                                          None,
                                                                          None),
                                                           'ENTITY_GROUP_ID': ('pdbx_entity_group_components',
                                                                               'entity_group_id',
                                                                               None,
                                                                               None),
                                                           'ENTITY_ID': ('pdbx_entity_group_components',
                                                                         'entity_id',
                                                                         None,
                                                                         None),
                                                           'ID': ('pdbx_entity_group_components', 'id', None, None),
                                                           'NAME': ('pdbx_entity_group_components', 'name', None, None),
                                                           'NONPOLY_RESIDUE_NUMBER': ('pdbx_entity_group_components',
                                                                                      'nonpoly_residue_number',
                                                                                      None,
                                                                                      None),
                                                           'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                         'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTITY_GROUP_ID', 'ID'),
                                                            'TYPE': 'UNIQUE'},
                                                     's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                         'MAP_MERGE_INDICES': {'pdbx_entity_group_components': {'ATTRIBUTES': ('entity_group_id',
                                                                                                               'id'),
                                                                                                'TYPE': 'EQUI-JOIN'}},
                                         'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                         'TABLE_ID': 'PDBX_ENTITY_GROUP_COMPONENTS',
                                         'TABLE_NAME': 'pdbx_entity_group_components',
                                         'TABLE_TYPE': 'transactional'},
        'PDBX_ENTITY_GROUP_INSTANCES': {'ATTRIBUTES': {'ENTITY_GROUP_ID': 'entity_group_id',
                                                       'ORDINAL': 'ordinal',
                                                       'STRUCTURE_ID': 'Structure_ID',
                                                       'STRUCT_GROUP_ID': 'struct_group_id'},
                                        'ATTRIBUTE_INFO': {'ENTITY_GROUP_ID': {'NULLABLE': True,
                                                                               'ORDER': 2,
                                                                               'PRECISION': 0,
                                                                               'PRIMARY_KEY': False,
                                                                               'SQL_TYPE': 'VARCHAR',
                                                                               'WIDTH': 10},
                                                           'ORDINAL': {'NULLABLE': False,
                                                                       'ORDER': 4,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': True,
                                                                       'SQL_TYPE': 'INT',
                                                                       'WIDTH': 10},
                                                           'STRUCTURE_ID': {'NULLABLE': False,
                                                                            'ORDER': 1,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': True,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 10},
                                                           'STRUCT_GROUP_ID': {'NULLABLE': True,
                                                                               'ORDER': 3,
                                                                               'PRECISION': 0,
                                                                               'PRIMARY_KEY': False,
                                                                               'SQL_TYPE': 'VARCHAR',
                                                                               'WIDTH': 10}},
                                        'ATTRIBUTE_MAP': {'ENTITY_GROUP_ID': ('pdbx_entity_group_instances',
                                                                              'entity_group_id',
                                                                              None,
                                                                              None),
                                                          'ORDINAL': ('pdbx_entity_group_instances', 'ordinal', None, None),
                                                          'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                          'STRUCT_GROUP_ID': ('pdbx_entity_group_instances',
                                                                              'struct_group_id',
                                                                              None,
                                                                              None)},
                                        'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ORDINAL'), 'TYPE': 'UNIQUE'},
                                                    's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                        'MAP_MERGE_INDICES': {'pdbx_entity_group_instances': {'ATTRIBUTES': ('ordinal',),
                                                                                              'TYPE': 'EQUI-JOIN'}},
                                        'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                        'TABLE_ID': 'PDBX_ENTITY_GROUP_INSTANCES',
                                        'TABLE_NAME': 'pdbx_entity_group_instances',
                                        'TABLE_TYPE': 'transactional'},
        'PDBX_ENTITY_GROUP_LIST': {'ATTRIBUTES': {'DESCRIPTION': 'description',
                                                  'ENTITY_GROUP_ID': 'entity_group_id',
                                                  'NAME': 'name',
                                                  'PRD_ID': 'prd_id',
                                                  'STRUCTURE_ID': 'Structure_ID'},
                                   'ATTRIBUTE_INFO': {'DESCRIPTION': {'NULLABLE': True,
                                                                      'ORDER': 4,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 511},
                                                      'ENTITY_GROUP_ID': {'NULLABLE': False,
                                                                          'ORDER': 2,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': True,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                      'NAME': {'NULLABLE': True,
                                                               'ORDER': 3,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 200},
                                                      'PRD_ID': {'NULLABLE': True,
                                                                 'ORDER': 5,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                                      'STRUCTURE_ID': {'NULLABLE': False,
                                                                       'ORDER': 1,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': True,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10}},
                                   'ATTRIBUTE_MAP': {'DESCRIPTION': ('pdbx_entity_group_list', 'description', None, None),
                                                     'ENTITY_GROUP_ID': ('pdbx_entity_group_list',
                                                                         'entity_group_id',
                                                                         None,
                                                                         None),
                                                     'NAME': ('pdbx_entity_group_list', 'name', None, None),
                                                     'PRD_ID': ('pdbx_entity_group_list', 'prd_id', None, None),
                                                     'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                   'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTITY_GROUP_ID'), 'TYPE': 'UNIQUE'},
                                               's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                   'MAP_MERGE_INDICES': {'pdbx_entity_group_list': {'ATTRIBUTES': ('entity_group_id',),
                                                                                    'TYPE': 'EQUI-JOIN'}},
                                   'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                   'TABLE_ID': 'PDBX_ENTITY_GROUP_LIST',
                                   'TABLE_NAME': 'pdbx_entity_group_list',
                                   'TABLE_TYPE': 'transactional'},
        'PDBX_ENTITY_NAME': {'ATTRIBUTES': {'ENTITY_ID': 'entity_id',
                                            'NAME': 'name',
                                            'NAME_TYPE': 'name_type',
                                            'STRUCTURE_ID': 'Structure_ID'},
                             'ATTRIBUTE_INFO': {'ENTITY_ID': {'NULLABLE': False,
                                                              'ORDER': 2,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10},
                                                'NAME': {'NULLABLE': False,
                                                         'ORDER': 3,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': True,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 511},
                                                'NAME_TYPE': {'NULLABLE': False,
                                                              'ORDER': 4,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 80},
                                                'STRUCTURE_ID': {'NULLABLE': False,
                                                                 'ORDER': 1,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': True,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10}},
                             'ATTRIBUTE_MAP': {'ENTITY_ID': ('pdbx_entity_name', 'entity_id', None, None),
                                               'NAME': ('pdbx_entity_name', 'name', None, None),
                                               'NAME_TYPE': ('pdbx_entity_name', 'name_type', None, None),
                                               'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                             'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTITY_ID', 'NAME', 'NAME_TYPE'),
                                                'TYPE': 'UNIQUE'},
                                         's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                             'MAP_MERGE_INDICES': {'pdbx_entity_name': {'ATTRIBUTES': ('entity_id', 'name', 'name_type'),
                                                                        'TYPE': 'EQUI-JOIN'}},
                             'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                             'TABLE_ID': 'PDBX_ENTITY_NAME',
                             'TABLE_NAME': 'pdbx_entity_name',
                             'TABLE_TYPE': 'transactional'},
        'PDBX_ENTITY_NONPOLY': {'ATTRIBUTES': {'COMP_ID': 'comp_id',
                                               'ENTITY_ID': 'entity_id',
                                               'NAME': 'name',
                                               'STRUCTURE_ID': 'Structure_ID'},
                                'ATTRIBUTE_INFO': {'COMP_ID': {'NULLABLE': True,
                                                               'ORDER': 3,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                                   'ENTITY_ID': {'NULLABLE': False,
                                                                 'ORDER': 2,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': True,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                                   'NAME': {'NULLABLE': True,
                                                            'ORDER': 4,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 1023},
                                                   'STRUCTURE_ID': {'NULLABLE': False,
                                                                    'ORDER': 1,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': True,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10}},
                                'ATTRIBUTE_MAP': {'COMP_ID': ('pdbx_entity_nonpoly', 'comp_id', None, None),
                                                  'ENTITY_ID': ('pdbx_entity_nonpoly', 'entity_id', None, None),
                                                  'NAME': ('pdbx_entity_nonpoly', 'name', None, None),
                                                  'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTITY_ID'), 'TYPE': 'UNIQUE'},
                                            's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                'MAP_MERGE_INDICES': {'pdbx_entity_nonpoly': {'ATTRIBUTES': ('entity_id',),
                                                                              'TYPE': 'EQUI-JOIN'}},
                                'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                'TABLE_ID': 'PDBX_ENTITY_NONPOLY',
                                'TABLE_NAME': 'pdbx_entity_nonpoly',
                                'TABLE_TYPE': 'transactional'},
        'PDBX_ENTITY_PROD_PROTOCOL': {'ATTRIBUTES': {'ENTITY_ID': 'entity_id',
                                                     'ENTRY_ID': 'entry_id',
                                                     'PROTOCOL': 'protocol',
                                                     'PROTOCOL_TYPE': 'protocol_type',
                                                     'STRUCTURE_ID': 'Structure_ID'},
                                      'ATTRIBUTE_INFO': {'ENTITY_ID': {'NULLABLE': False,
                                                                       'ORDER': 3,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': True,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                         'ENTRY_ID': {'NULLABLE': False,
                                                                      'ORDER': 2,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                                         'PROTOCOL': {'NULLABLE': True,
                                                                      'ORDER': 4,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 200},
                                                         'PROTOCOL_TYPE': {'NULLABLE': False,
                                                                           'ORDER': 5,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': True,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10},
                                                         'STRUCTURE_ID': {'NULLABLE': False,
                                                                          'ORDER': 1,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': True,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10}},
                                      'ATTRIBUTE_MAP': {'ENTITY_ID': ('pdbx_entity_prod_protocol', 'entity_id', None, None),
                                                        'ENTRY_ID': ('pdbx_entity_prod_protocol', 'entry_id', None, None),
                                                        'PROTOCOL': ('pdbx_entity_prod_protocol', 'protocol', None, None),
                                                        'PROTOCOL_TYPE': ('pdbx_entity_prod_protocol',
                                                                          'protocol_type',
                                                                          None,
                                                                          None),
                                                        'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                      'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID',
                                                                        'ENTRY_ID',
                                                                        'ENTITY_ID',
                                                                        'PROTOCOL_TYPE'),
                                                         'TYPE': 'UNIQUE'},
                                                  's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                      'MAP_MERGE_INDICES': {'pdbx_entity_prod_protocol': {'ATTRIBUTES': ('entry_id',
                                                                                                         'entity_id',
                                                                                                         'protocol_type'),
                                                                                          'TYPE': 'EQUI-JOIN'}},
                                      'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                      'TABLE_ID': 'PDBX_ENTITY_PROD_PROTOCOL',
                                      'TABLE_NAME': 'pdbx_entity_prod_protocol',
                                      'TABLE_TYPE': 'transactional'},
        'PDBX_ENTITY_SRC_GEN_CHARACTER': {'ATTRIBUTES': {'DATE': 'date',
                                                         'DETAILS': 'details',
                                                         'ENTITY_ID': 'entity_id',
                                                         'ENTRY_ID': 'entry_id',
                                                         'METHOD': 'method',
                                                         'RESULT': 'result',
                                                         'ROBOT_ID': 'robot_id',
                                                         'STEP_ID': 'step_id',
                                                         'STRUCTURE_ID': 'Structure_ID'},
                                          'ATTRIBUTE_INFO': {'DATE': {'NULLABLE': True,
                                                                      'ORDER': 6,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'DATETIME',
                                                                      'WIDTH': 20},
                                                             'DETAILS': {'NULLABLE': True,
                                                                         'ORDER': 9,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 200},
                                                             'ENTITY_ID': {'NULLABLE': False,
                                                                           'ORDER': 3,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': True,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10},
                                                             'ENTRY_ID': {'NULLABLE': False,
                                                                          'ORDER': 2,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': True,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                             'METHOD': {'NULLABLE': True,
                                                                        'ORDER': 7,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 200},
                                                             'RESULT': {'NULLABLE': True,
                                                                        'ORDER': 8,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 200},
                                                             'ROBOT_ID': {'NULLABLE': True,
                                                                          'ORDER': 5,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                             'STEP_ID': {'NULLABLE': False,
                                                                         'ORDER': 4,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': True,
                                                                         'SQL_TYPE': 'INT',
                                                                         'WIDTH': 10},
                                                             'STRUCTURE_ID': {'NULLABLE': False,
                                                                              'ORDER': 1,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': True,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10}},
                                          'ATTRIBUTE_MAP': {'DATE': ('pdbx_entity_src_gen_character', 'date', None, None),
                                                            'DETAILS': ('pdbx_entity_src_gen_character',
                                                                        'details',
                                                                        None,
                                                                        None),
                                                            'ENTITY_ID': ('pdbx_entity_src_gen_character',
                                                                          'entity_id',
                                                                          None,
                                                                          None),
                                                            'ENTRY_ID': ('pdbx_entity_src_gen_character',
                                                                         'entry_id',
                                                                         None,
                                                                         None),
                                                            'METHOD': ('pdbx_entity_src_gen_character', 'method', None, None),
                                                            'RESULT': ('pdbx_entity_src_gen_character', 'result', None, None),
                                                            'ROBOT_ID': ('pdbx_entity_src_gen_character',
                                                                         'robot_id',
                                                                         None,
                                                                         None),
                                                            'STEP_ID': ('pdbx_entity_src_gen_character',
                                                                        'step_id',
                                                                        None,
                                                                        None),
                                                            'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                          'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID',
                                                                            'ENTRY_ID',
                                                                            'ENTITY_ID',
                                                                            'STEP_ID'),
                                                             'TYPE': 'UNIQUE'},
                                                      's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                          'MAP_MERGE_INDICES': {'pdbx_entity_src_gen_character': {'ATTRIBUTES': ('entry_id',
                                                                                                                 'entity_id',
                                                                                                                 'step_id'),
                                                                                                  'TYPE': 'EQUI-JOIN'}},
                                          'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                          'TABLE_ID': 'PDBX_ENTITY_SRC_GEN_CHARACTER',
                                          'TABLE_NAME': 'pdbx_entity_src_gen_character',
                                          'TABLE_TYPE': 'transactional'},
        'PDBX_ENTITY_SRC_GEN_CHROM': {'ATTRIBUTES': {'COLUMN_TEMPERATURE': 'column_temperature',
                                                     'COLUMN_TYPE': 'column_type',
                                                     'COLUMN_VOLUME': 'column_volume',
                                                     'DATE': 'date',
                                                     'ELUTION_BUFFER_ID': 'elution_buffer_id',
                                                     'ELUTION_PROTOCOL': 'elution_protocol',
                                                     'END_CONSTRUCT_ID': 'end_construct_id',
                                                     'ENTITY_ID': 'entity_id',
                                                     'ENTRY_ID': 'entry_id',
                                                     'EQUILIBRATION_BUFFER_ID': 'equilibration_buffer_id',
                                                     'FLOW_RATE': 'flow_rate',
                                                     'NEXT_STEP_ID': 'next_step_id',
                                                     'POST_TREATMENT': 'post_treatment',
                                                     'ROBOT_ID': 'robot_id',
                                                     'SAMPLE_CONCENTRATION': 'sample_concentration',
                                                     'SAMPLE_CONC_METHOD': 'sample_conc_method',
                                                     'SAMPLE_PREP_DETAILS': 'sample_prep_details',
                                                     'SAMPLE_VOLUME': 'sample_volume',
                                                     'STEP_ID': 'step_id',
                                                     'STRUCTURE_ID': 'Structure_ID',
                                                     'VOLUME_POOLED_FRACTIONS': 'volume_pooled_fractions',
                                                     'YIELD_METHOD': 'yield_method',
                                                     'YIELD_POOLED_FRACTIONS': 'yield_pooled_fractions'},
                                      'ATTRIBUTE_INFO': {'COLUMN_TEMPERATURE': {'NULLABLE': True,
                                                                                'ORDER': 11,
                                                                                'PRECISION': 6,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'FLOAT',
                                                                                'WIDTH': 10},
                                                         'COLUMN_TYPE': {'NULLABLE': True,
                                                                         'ORDER': 9,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 200},
                                                         'COLUMN_VOLUME': {'NULLABLE': True,
                                                                           'ORDER': 10,
                                                                           'PRECISION': 6,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'FLOAT',
                                                                           'WIDTH': 10},
                                                         'DATE': {'NULLABLE': True,
                                                                  'ORDER': 8,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'DATETIME',
                                                                  'WIDTH': 20},
                                                         'ELUTION_BUFFER_ID': {'NULLABLE': True,
                                                                               'ORDER': 14,
                                                                               'PRECISION': 0,
                                                                               'PRIMARY_KEY': False,
                                                                               'SQL_TYPE': 'VARCHAR',
                                                                               'WIDTH': 10},
                                                         'ELUTION_PROTOCOL': {'NULLABLE': True,
                                                                              'ORDER': 15,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 200},
                                                         'END_CONSTRUCT_ID': {'NULLABLE': True,
                                                                              'ORDER': 6,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                                         'ENTITY_ID': {'NULLABLE': False,
                                                                       'ORDER': 3,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': True,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                         'ENTRY_ID': {'NULLABLE': False,
                                                                      'ORDER': 2,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                                         'EQUILIBRATION_BUFFER_ID': {'NULLABLE': True,
                                                                                     'ORDER': 12,
                                                                                     'PRECISION': 0,
                                                                                     'PRIMARY_KEY': False,
                                                                                     'SQL_TYPE': 'VARCHAR',
                                                                                     'WIDTH': 10},
                                                         'FLOW_RATE': {'NULLABLE': True,
                                                                       'ORDER': 13,
                                                                       'PRECISION': 6,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'FLOAT',
                                                                       'WIDTH': 10},
                                                         'NEXT_STEP_ID': {'NULLABLE': True,
                                                                          'ORDER': 5,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'INT',
                                                                          'WIDTH': 10},
                                                         'POST_TREATMENT': {'NULLABLE': True,
                                                                            'ORDER': 23,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 200},
                                                         'ROBOT_ID': {'NULLABLE': True,
                                                                      'ORDER': 7,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                                         'SAMPLE_CONCENTRATION': {'NULLABLE': True,
                                                                                  'ORDER': 18,
                                                                                  'PRECISION': 6,
                                                                                  'PRIMARY_KEY': False,
                                                                                  'SQL_TYPE': 'FLOAT',
                                                                                  'WIDTH': 10},
                                                         'SAMPLE_CONC_METHOD': {'NULLABLE': True,
                                                                                'ORDER': 19,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 200},
                                                         'SAMPLE_PREP_DETAILS': {'NULLABLE': True,
                                                                                 'ORDER': 16,
                                                                                 'PRECISION': 0,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'VARCHAR',
                                                                                 'WIDTH': 200},
                                                         'SAMPLE_VOLUME': {'NULLABLE': True,
                                                                           'ORDER': 17,
                                                                           'PRECISION': 6,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'FLOAT',
                                                                           'WIDTH': 10},
                                                         'STEP_ID': {'NULLABLE': False,
                                                                     'ORDER': 4,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': True,
                                                                     'SQL_TYPE': 'INT',
                                                                     'WIDTH': 10},
                                                         'STRUCTURE_ID': {'NULLABLE': False,
                                                                          'ORDER': 1,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': True,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                         'VOLUME_POOLED_FRACTIONS': {'NULLABLE': True,
                                                                                     'ORDER': 20,
                                                                                     'PRECISION': 6,
                                                                                     'PRIMARY_KEY': False,
                                                                                     'SQL_TYPE': 'FLOAT',
                                                                                     'WIDTH': 10},
                                                         'YIELD_METHOD': {'NULLABLE': True,
                                                                          'ORDER': 22,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 200},
                                                         'YIELD_POOLED_FRACTIONS': {'NULLABLE': True,
                                                                                    'ORDER': 21,
                                                                                    'PRECISION': 6,
                                                                                    'PRIMARY_KEY': False,
                                                                                    'SQL_TYPE': 'FLOAT',
                                                                                    'WIDTH': 10}},
                                      'ATTRIBUTE_MAP': {'COLUMN_TEMPERATURE': ('pdbx_entity_src_gen_chrom',
                                                                               'column_temperature',
                                                                               None,
                                                                               None),
                                                        'COLUMN_TYPE': ('pdbx_entity_src_gen_chrom',
                                                                        'column_type',
                                                                        None,
                                                                        None),
                                                        'COLUMN_VOLUME': ('pdbx_entity_src_gen_chrom',
                                                                          'column_volume',
                                                                          None,
                                                                          None),
                                                        'DATE': ('pdbx_entity_src_gen_chrom', 'date', None, None),
                                                        'ELUTION_BUFFER_ID': ('pdbx_entity_src_gen_chrom',
                                                                              'elution_buffer_id',
                                                                              None,
                                                                              None),
                                                        'ELUTION_PROTOCOL': ('pdbx_entity_src_gen_chrom',
                                                                             'elution_protocol',
                                                                             None,
                                                                             None),
                                                        'END_CONSTRUCT_ID': ('pdbx_entity_src_gen_chrom',
                                                                             'end_construct_id',
                                                                             None,
                                                                             None),
                                                        'ENTITY_ID': ('pdbx_entity_src_gen_chrom', 'entity_id', None, None),
                                                        'ENTRY_ID': ('pdbx_entity_src_gen_chrom', 'entry_id', None, None),
                                                        'EQUILIBRATION_BUFFER_ID': ('pdbx_entity_src_gen_chrom',
                                                                                    'equilibration_buffer_id',
                                                                                    None,
                                                                                    None),
                                                        'FLOW_RATE': ('pdbx_entity_src_gen_chrom', 'flow_rate', None, None),
                                                        'NEXT_STEP_ID': ('pdbx_entity_src_gen_chrom',
                                                                         'next_step_id',
                                                                         None,
                                                                         None),
                                                        'POST_TREATMENT': ('pdbx_entity_src_gen_chrom',
                                                                           'post_treatment',
                                                                           None,
                                                                           None),
                                                        'ROBOT_ID': ('pdbx_entity_src_gen_chrom', 'robot_id', None, None),
                                                        'SAMPLE_CONCENTRATION': ('pdbx_entity_src_gen_chrom',
                                                                                 'sample_concentration',
                                                                                 None,
                                                                                 None),
                                                        'SAMPLE_CONC_METHOD': ('pdbx_entity_src_gen_chrom',
                                                                               'sample_conc_method',
                                                                               None,
                                                                               None),
                                                        'SAMPLE_PREP_DETAILS': ('pdbx_entity_src_gen_chrom',
                                                                                'sample_prep_details',
                                                                                None,
                                                                                None),
                                                        'SAMPLE_VOLUME': ('pdbx_entity_src_gen_chrom',
                                                                          'sample_volume',
                                                                          None,
                                                                          None),
                                                        'STEP_ID': ('pdbx_entity_src_gen_chrom', 'step_id', None, None),
                                                        'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                        'VOLUME_POOLED_FRACTIONS': ('pdbx_entity_src_gen_chrom',
                                                                                    'volume_pooled_fractions',
                                                                                    None,
                                                                                    None),
                                                        'YIELD_METHOD': ('pdbx_entity_src_gen_chrom',
                                                                         'yield_method',
                                                                         None,
                                                                         None),
                                                        'YIELD_POOLED_FRACTIONS': ('pdbx_entity_src_gen_chrom',
                                                                                   'yield_pooled_fractions',
                                                                                   None,
                                                                                   None)},
                                      'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID', 'ENTITY_ID', 'STEP_ID'),
                                                         'TYPE': 'UNIQUE'},
                                                  's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                      'MAP_MERGE_INDICES': {'pdbx_entity_src_gen_chrom': {'ATTRIBUTES': ('entry_id',
                                                                                                         'entity_id',
                                                                                                         'step_id'),
                                                                                          'TYPE': 'EQUI-JOIN'}},
                                      'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                      'TABLE_ID': 'PDBX_ENTITY_SRC_GEN_CHROM',
                                      'TABLE_NAME': 'pdbx_entity_src_gen_chrom',
                                      'TABLE_TYPE': 'transactional'},
        'PDBX_ENTITY_SRC_GEN_CLONE': {'ATTRIBUTES': {'DATE': 'date',
                                                     'END_CONSTRUCT_ID': 'end_construct_id',
                                                     'ENTITY_ID': 'entity_id',
                                                     'ENTRY_ID': 'entry_id',
                                                     'GENE_INSERT_METHOD': 'gene_insert_method',
                                                     'MARKER': 'marker',
                                                     'NEXT_STEP_ID': 'next_step_id',
                                                     'PURIFICATION_DETAILS': 'purification_details',
                                                     'ROBOT_ID': 'robot_id',
                                                     'STEP_ID': 'step_id',
                                                     'STRUCTURE_ID': 'Structure_ID',
                                                     'SUMMARY': 'summary',
                                                     'TRANSFORMATION_METHOD': 'transformation_method',
                                                     'VECTOR_DETAILS': 'vector_details',
                                                     'VECTOR_NAME': 'vector_name',
                                                     'VERIFICATION_METHOD': 'verification_method'},
                                      'ATTRIBUTE_INFO': {'DATE': {'NULLABLE': True,
                                                                  'ORDER': 8,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'DATETIME',
                                                                  'WIDTH': 20},
                                                         'END_CONSTRUCT_ID': {'NULLABLE': True,
                                                                              'ORDER': 6,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                                         'ENTITY_ID': {'NULLABLE': False,
                                                                       'ORDER': 3,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': True,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                         'ENTRY_ID': {'NULLABLE': False,
                                                                      'ORDER': 2,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                                         'GENE_INSERT_METHOD': {'NULLABLE': True,
                                                                                'ORDER': 9,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 10},
                                                         'MARKER': {'NULLABLE': True,
                                                                    'ORDER': 13,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10},
                                                         'NEXT_STEP_ID': {'NULLABLE': True,
                                                                          'ORDER': 5,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'INT',
                                                                          'WIDTH': 10},
                                                         'PURIFICATION_DETAILS': {'NULLABLE': True,
                                                                                  'ORDER': 15,
                                                                                  'PRECISION': 0,
                                                                                  'PRIMARY_KEY': False,
                                                                                  'SQL_TYPE': 'VARCHAR',
                                                                                  'WIDTH': 200},
                                                         'ROBOT_ID': {'NULLABLE': True,
                                                                      'ORDER': 7,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                                         'STEP_ID': {'NULLABLE': False,
                                                                     'ORDER': 4,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': True,
                                                                     'SQL_TYPE': 'INT',
                                                                     'WIDTH': 10},
                                                         'STRUCTURE_ID': {'NULLABLE': False,
                                                                          'ORDER': 1,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': True,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                         'SUMMARY': {'NULLABLE': True,
                                                                     'ORDER': 16,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 200},
                                                         'TRANSFORMATION_METHOD': {'NULLABLE': True,
                                                                                   'ORDER': 12,
                                                                                   'PRECISION': 0,
                                                                                   'PRIMARY_KEY': False,
                                                                                   'SQL_TYPE': 'VARCHAR',
                                                                                   'WIDTH': 10},
                                                         'VECTOR_DETAILS': {'NULLABLE': True,
                                                                            'ORDER': 11,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 200},
                                                         'VECTOR_NAME': {'NULLABLE': True,
                                                                         'ORDER': 10,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 200},
                                                         'VERIFICATION_METHOD': {'NULLABLE': True,
                                                                                 'ORDER': 14,
                                                                                 'PRECISION': 0,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'VARCHAR',
                                                                                 'WIDTH': 10}},
                                      'ATTRIBUTE_MAP': {'DATE': ('pdbx_entity_src_gen_clone', 'date', None, None),
                                                        'END_CONSTRUCT_ID': ('pdbx_entity_src_gen_clone',
                                                                             'end_construct_id',
                                                                             None,
                                                                             None),
                                                        'ENTITY_ID': ('pdbx_entity_src_gen_clone', 'entity_id', None, None),
                                                        'ENTRY_ID': ('pdbx_entity_src_gen_clone', 'entry_id', None, None),
                                                        'GENE_INSERT_METHOD': ('pdbx_entity_src_gen_clone',
                                                                               'gene_insert_method',
                                                                               None,
                                                                               None),
                                                        'MARKER': ('pdbx_entity_src_gen_clone', 'marker', None, None),
                                                        'NEXT_STEP_ID': ('pdbx_entity_src_gen_clone',
                                                                         'next_step_id',
                                                                         None,
                                                                         None),
                                                        'PURIFICATION_DETAILS': ('pdbx_entity_src_gen_clone',
                                                                                 'purification_details',
                                                                                 None,
                                                                                 None),
                                                        'ROBOT_ID': ('pdbx_entity_src_gen_clone', 'robot_id', None, None),
                                                        'STEP_ID': ('pdbx_entity_src_gen_clone', 'step_id', None, None),
                                                        'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                        'SUMMARY': ('pdbx_entity_src_gen_clone', 'summary', None, None),
                                                        'TRANSFORMATION_METHOD': ('pdbx_entity_src_gen_clone',
                                                                                  'transformation_method',
                                                                                  None,
                                                                                  None),
                                                        'VECTOR_DETAILS': ('pdbx_entity_src_gen_clone',
                                                                           'vector_details',
                                                                           None,
                                                                           None),
                                                        'VECTOR_NAME': ('pdbx_entity_src_gen_clone',
                                                                        'vector_name',
                                                                        None,
                                                                        None),
                                                        'VERIFICATION_METHOD': ('pdbx_entity_src_gen_clone',
                                                                                'verification_method',
                                                                                None,
                                                                                None)},
                                      'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID', 'ENTITY_ID', 'STEP_ID'),
                                                         'TYPE': 'UNIQUE'},
                                                  's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                      'MAP_MERGE_INDICES': {'pdbx_entity_src_gen_clone': {'ATTRIBUTES': ('entry_id',
                                                                                                         'entity_id',
                                                                                                         'step_id'),
                                                                                          'TYPE': 'EQUI-JOIN'}},
                                      'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                      'TABLE_ID': 'PDBX_ENTITY_SRC_GEN_CLONE',
                                      'TABLE_NAME': 'pdbx_entity_src_gen_clone',
                                      'TABLE_TYPE': 'transactional'},
        'PDBX_ENTITY_SRC_GEN_CLONE_LIGATION': {'ATTRIBUTES': {'CLEAVAGE_ENZYMES': 'cleavage_enzymes',
                                                              'DETAILS': 'details',
                                                              'ENTITY_ID': 'entity_id',
                                                              'ENTRY_ID': 'entry_id',
                                                              'LIGATION_ENZYMES': 'ligation_enzymes',
                                                              'STEP_ID': 'step_id',
                                                              'STRUCTURE_ID': 'Structure_ID',
                                                              'TEMPERATURE': 'temperature',
                                                              'TIME': 'time'},
                                               'ATTRIBUTE_INFO': {'CLEAVAGE_ENZYMES': {'NULLABLE': True,
                                                                                       'ORDER': 5,
                                                                                       'PRECISION': 0,
                                                                                       'PRIMARY_KEY': False,
                                                                                       'SQL_TYPE': 'VARCHAR',
                                                                                       'WIDTH': 200},
                                                                  'DETAILS': {'NULLABLE': True,
                                                                              'ORDER': 9,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 200},
                                                                  'ENTITY_ID': {'NULLABLE': False,
                                                                                'ORDER': 3,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': True,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 10},
                                                                  'ENTRY_ID': {'NULLABLE': False,
                                                                               'ORDER': 2,
                                                                               'PRECISION': 0,
                                                                               'PRIMARY_KEY': True,
                                                                               'SQL_TYPE': 'VARCHAR',
                                                                               'WIDTH': 10},
                                                                  'LIGATION_ENZYMES': {'NULLABLE': True,
                                                                                       'ORDER': 6,
                                                                                       'PRECISION': 0,
                                                                                       'PRIMARY_KEY': False,
                                                                                       'SQL_TYPE': 'VARCHAR',
                                                                                       'WIDTH': 200},
                                                                  'STEP_ID': {'NULLABLE': False,
                                                                              'ORDER': 4,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': True,
                                                                              'SQL_TYPE': 'INT',
                                                                              'WIDTH': 10},
                                                                  'STRUCTURE_ID': {'NULLABLE': False,
                                                                                   'ORDER': 1,
                                                                                   'PRECISION': 0,
                                                                                   'PRIMARY_KEY': True,
                                                                                   'SQL_TYPE': 'VARCHAR',
                                                                                   'WIDTH': 10},
                                                                  'TEMPERATURE': {'NULLABLE': True,
                                                                                  'ORDER': 7,
                                                                                  'PRECISION': 6,
                                                                                  'PRIMARY_KEY': False,
                                                                                  'SQL_TYPE': 'FLOAT',
                                                                                  'WIDTH': 10},
                                                                  'TIME': {'NULLABLE': True,
                                                                           'ORDER': 8,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'INT',
                                                                           'WIDTH': 10}},
                                               'ATTRIBUTE_MAP': {'CLEAVAGE_ENZYMES': ('pdbx_entity_src_gen_clone_ligation',
                                                                                      'cleavage_enzymes',
                                                                                      None,
                                                                                      None),
                                                                 'DETAILS': ('pdbx_entity_src_gen_clone_ligation',
                                                                             'details',
                                                                             None,
                                                                             None),
                                                                 'ENTITY_ID': ('pdbx_entity_src_gen_clone_ligation',
                                                                               'entity_id',
                                                                               None,
                                                                               None),
                                                                 'ENTRY_ID': ('pdbx_entity_src_gen_clone_ligation',
                                                                              'entry_id',
                                                                              None,
                                                                              None),
                                                                 'LIGATION_ENZYMES': ('pdbx_entity_src_gen_clone_ligation',
                                                                                      'ligation_enzymes',
                                                                                      None,
                                                                                      None),
                                                                 'STEP_ID': ('pdbx_entity_src_gen_clone_ligation',
                                                                             'step_id',
                                                                             None,
                                                                             None),
                                                                 'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                                 'TEMPERATURE': ('pdbx_entity_src_gen_clone_ligation',
                                                                                 'temperature',
                                                                                 None,
                                                                                 None),
                                                                 'TIME': ('pdbx_entity_src_gen_clone_ligation',
                                                                          'time',
                                                                          None,
                                                                          None)},
                                               'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID',
                                                                                 'ENTRY_ID',
                                                                                 'ENTITY_ID',
                                                                                 'STEP_ID'),
                                                                  'TYPE': 'UNIQUE'},
                                                           's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                               'MAP_MERGE_INDICES': {'pdbx_entity_src_gen_clone_ligation': {'ATTRIBUTES': ('entry_id',
                                                                                                                           'entity_id',
                                                                                                                           'step_id'),
                                                                                                            'TYPE': 'EQUI-JOIN'}},
                                               'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                               'TABLE_ID': 'PDBX_ENTITY_SRC_GEN_CLONE_LIGATION',
                                               'TABLE_NAME': 'pdbx_entity_src_gen_clone_ligation',
                                               'TABLE_TYPE': 'transactional'},
        'PDBX_ENTITY_SRC_GEN_CLONE_RECOMBINATION': {'ATTRIBUTES': {'DETAILS': 'details',
                                                                   'ENTITY_ID': 'entity_id',
                                                                   'ENTRY_ID': 'entry_id',
                                                                   'RECOMBINATION_ENZYMES': 'recombination_enzymes',
                                                                   'STEP_ID': 'step_id',
                                                                   'STRUCTURE_ID': 'Structure_ID',
                                                                   'SYSTEM': 'system'},
                                                    'ATTRIBUTE_INFO': {'DETAILS': {'NULLABLE': True,
                                                                                   'ORDER': 7,
                                                                                   'PRECISION': 0,
                                                                                   'PRIMARY_KEY': False,
                                                                                   'SQL_TYPE': 'VARCHAR',
                                                                                   'WIDTH': 200},
                                                                       'ENTITY_ID': {'NULLABLE': False,
                                                                                     'ORDER': 3,
                                                                                     'PRECISION': 0,
                                                                                     'PRIMARY_KEY': True,
                                                                                     'SQL_TYPE': 'VARCHAR',
                                                                                     'WIDTH': 10},
                                                                       'ENTRY_ID': {'NULLABLE': False,
                                                                                    'ORDER': 2,
                                                                                    'PRECISION': 0,
                                                                                    'PRIMARY_KEY': True,
                                                                                    'SQL_TYPE': 'VARCHAR',
                                                                                    'WIDTH': 10},
                                                                       'RECOMBINATION_ENZYMES': {'NULLABLE': True,
                                                                                                 'ORDER': 6,
                                                                                                 'PRECISION': 0,
                                                                                                 'PRIMARY_KEY': False,
                                                                                                 'SQL_TYPE': 'VARCHAR',
                                                                                                 'WIDTH': 10},
                                                                       'STEP_ID': {'NULLABLE': False,
                                                                                   'ORDER': 4,
                                                                                   'PRECISION': 0,
                                                                                   'PRIMARY_KEY': True,
                                                                                   'SQL_TYPE': 'INT',
                                                                                   'WIDTH': 10},
                                                                       'STRUCTURE_ID': {'NULLABLE': False,
                                                                                        'ORDER': 1,
                                                                                        'PRECISION': 0,
                                                                                        'PRIMARY_KEY': True,
                                                                                        'SQL_TYPE': 'VARCHAR',
                                                                                        'WIDTH': 10},
                                                                       'SYSTEM': {'NULLABLE': True,
                                                                                  'ORDER': 5,
                                                                                  'PRECISION': 0,
                                                                                  'PRIMARY_KEY': False,
                                                                                  'SQL_TYPE': 'VARCHAR',
                                                                                  'WIDTH': 10}},
                                                    'ATTRIBUTE_MAP': {'DETAILS': ('pdbx_entity_src_gen_clone_recombination',
                                                                                  'details',
                                                                                  None,
                                                                                  None),
                                                                      'ENTITY_ID': ('pdbx_entity_src_gen_clone_recombination',
                                                                                    'entity_id',
                                                                                    None,
                                                                                    None),
                                                                      'ENTRY_ID': ('pdbx_entity_src_gen_clone_recombination',
                                                                                   'entry_id',
                                                                                   None,
                                                                                   None),
                                                                      'RECOMBINATION_ENZYMES': ('pdbx_entity_src_gen_clone_recombination',
                                                                                                'recombination_enzymes',
                                                                                                None,
                                                                                                None),
                                                                      'STEP_ID': ('pdbx_entity_src_gen_clone_recombination',
                                                                                  'step_id',
                                                                                  None,
                                                                                  None),
                                                                      'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                                      'SYSTEM': ('pdbx_entity_src_gen_clone_recombination',
                                                                                 'system',
                                                                                 None,
                                                                                 None)},
                                                    'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID',
                                                                                      'ENTRY_ID',
                                                                                      'ENTITY_ID',
                                                                                      'STEP_ID'),
                                                                       'TYPE': 'UNIQUE'},
                                                                's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                                    'MAP_MERGE_INDICES': {'pdbx_entity_src_gen_clone_recombination': {'ATTRIBUTES': ('entry_id',
                                                                                                                                     'entity_id',
                                                                                                                                     'step_id'),
                                                                                                                      'TYPE': 'EQUI-JOIN'}},
                                                    'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                                    'TABLE_ID': 'PDBX_ENTITY_SRC_GEN_CLONE_RECOMBINATION',
                                                    'TABLE_NAME': 'pdbx_entity_src_gen_clone_recombination',
                                                    'TABLE_TYPE': 'transactional'},
        'PDBX_ENTITY_SRC_GEN_EXPRESS': {'ATTRIBUTES': {'CULTURE_ADDITIVES': 'culture_additives',
                                                       'CULTURE_BASE_MEDIA': 'culture_base_media',
                                                       'CULTURE_TEMPERATURE': 'culture_temperature',
                                                       'CULTURE_TIME': 'culture_time',
                                                       'CULTURE_VOLUME': 'culture_volume',
                                                       'C_TERMINAL_SEQ_TAG': 'C_terminal_seq_tag',
                                                       'DATE': 'date',
                                                       'END_CONSTRUCT_ID': 'end_construct_id',
                                                       'ENTITY_ID': 'entity_id',
                                                       'ENTRY_ID': 'entry_id',
                                                       'HARVESTING_DETAILS': 'harvesting_details',
                                                       'HOST_ORG_CELL_LINE': 'host_org_cell_line',
                                                       'HOST_ORG_COMMON_NAME': 'host_org_common_name',
                                                       'HOST_ORG_CULTURE_COLLECTION': 'host_org_culture_collection',
                                                       'HOST_ORG_DETAILS': 'host_org_details',
                                                       'HOST_ORG_SCIENTIFIC_NAME': 'host_org_scientific_name',
                                                       'HOST_ORG_STRAIN': 'host_org_strain',
                                                       'HOST_ORG_TAX_ID': 'host_org_tax_id',
                                                       'HOST_ORG_TISSUE': 'host_org_tissue',
                                                       'HOST_ORG_VARIANT': 'host_org_variant',
                                                       'INDUCER': 'inducer',
                                                       'INDUCER_CONCENTRATION': 'inducer_concentration',
                                                       'INDUCTION_DETAILS': 'induction_details',
                                                       'INDUCTION_TEMPERATURE': 'induction_temperature',
                                                       'INDUCTION_TIMEPOINT': 'induction_timepoint',
                                                       'MULTIPLICITY_OF_INFECTION': 'multiplicity_of_infection',
                                                       'NEXT_STEP_ID': 'next_step_id',
                                                       'N_TERMINAL_SEQ_TAG': 'N_terminal_seq_tag',
                                                       'PLASMID_ID': 'plasmid_id',
                                                       'PROMOTER_TYPE': 'promoter_type',
                                                       'ROBOT_ID': 'robot_id',
                                                       'STEP_ID': 'step_id',
                                                       'STORAGE_DETAILS': 'storage_details',
                                                       'STRUCTURE_ID': 'Structure_ID',
                                                       'SUMMARY': 'summary',
                                                       'VECTOR_TYPE': 'vector_type'},
                                        'ATTRIBUTE_INFO': {'CULTURE_ADDITIVES': {'NULLABLE': True,
                                                                                 'ORDER': 24,
                                                                                 'PRECISION': 0,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'VARCHAR',
                                                                                 'WIDTH': 200},
                                                           'CULTURE_BASE_MEDIA': {'NULLABLE': True,
                                                                                  'ORDER': 23,
                                                                                  'PRECISION': 0,
                                                                                  'PRIMARY_KEY': False,
                                                                                  'SQL_TYPE': 'VARCHAR',
                                                                                  'WIDTH': 200},
                                                           'CULTURE_TEMPERATURE': {'NULLABLE': True,
                                                                                   'ORDER': 27,
                                                                                   'PRECISION': 6,
                                                                                   'PRIMARY_KEY': False,
                                                                                   'SQL_TYPE': 'FLOAT',
                                                                                   'WIDTH': 10},
                                                           'CULTURE_TIME': {'NULLABLE': True,
                                                                            'ORDER': 26,
                                                                            'PRECISION': 6,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'FLOAT',
                                                                            'WIDTH': 10},
                                                           'CULTURE_VOLUME': {'NULLABLE': True,
                                                                              'ORDER': 25,
                                                                              'PRECISION': 6,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'FLOAT',
                                                                              'WIDTH': 10},
                                                           'C_TERMINAL_SEQ_TAG': {'NULLABLE': True,
                                                                                  'ORDER': 13,
                                                                                  'PRECISION': 0,
                                                                                  'PRIMARY_KEY': False,
                                                                                  'SQL_TYPE': 'VARCHAR',
                                                                                  'WIDTH': 200},
                                                           'DATE': {'NULLABLE': True,
                                                                    'ORDER': 8,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'DATETIME',
                                                                    'WIDTH': 20},
                                                           'END_CONSTRUCT_ID': {'NULLABLE': True,
                                                                                'ORDER': 6,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 10},
                                                           'ENTITY_ID': {'NULLABLE': False,
                                                                         'ORDER': 3,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': True,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                                           'ENTRY_ID': {'NULLABLE': False,
                                                                        'ORDER': 2,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': True,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                                           'HARVESTING_DETAILS': {'NULLABLE': True,
                                                                                  'ORDER': 34,
                                                                                  'PRECISION': 0,
                                                                                  'PRIMARY_KEY': False,
                                                                                  'SQL_TYPE': 'VARCHAR',
                                                                                  'WIDTH': 200},
                                                           'HOST_ORG_CELL_LINE': {'NULLABLE': True,
                                                                                  'ORDER': 20,
                                                                                  'PRECISION': 0,
                                                                                  'PRIMARY_KEY': False,
                                                                                  'SQL_TYPE': 'VARCHAR',
                                                                                  'WIDTH': 80},
                                                           'HOST_ORG_COMMON_NAME': {'NULLABLE': True,
                                                                                    'ORDER': 15,
                                                                                    'PRECISION': 0,
                                                                                    'PRIMARY_KEY': False,
                                                                                    'SQL_TYPE': 'VARCHAR',
                                                                                    'WIDTH': 80},
                                                           'HOST_ORG_CULTURE_COLLECTION': {'NULLABLE': True,
                                                                                           'ORDER': 19,
                                                                                           'PRECISION': 0,
                                                                                           'PRIMARY_KEY': False,
                                                                                           'SQL_TYPE': 'VARCHAR',
                                                                                           'WIDTH': 80},
                                                           'HOST_ORG_DETAILS': {'NULLABLE': True,
                                                                                'ORDER': 22,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 200},
                                                           'HOST_ORG_SCIENTIFIC_NAME': {'NULLABLE': True,
                                                                                        'ORDER': 14,
                                                                                        'PRECISION': 0,
                                                                                        'PRIMARY_KEY': False,
                                                                                        'SQL_TYPE': 'VARCHAR',
                                                                                        'WIDTH': 80},
                                                           'HOST_ORG_STRAIN': {'NULLABLE': True,
                                                                               'ORDER': 17,
                                                                               'PRECISION': 0,
                                                                               'PRIMARY_KEY': False,
                                                                               'SQL_TYPE': 'VARCHAR',
                                                                               'WIDTH': 80},
                                                           'HOST_ORG_TAX_ID': {'NULLABLE': True,
                                                                               'ORDER': 21,
                                                                               'PRECISION': 0,
                                                                               'PRIMARY_KEY': False,
                                                                               'SQL_TYPE': 'VARCHAR',
                                                                               'WIDTH': 80},
                                                           'HOST_ORG_TISSUE': {'NULLABLE': True,
                                                                               'ORDER': 18,
                                                                               'PRECISION': 0,
                                                                               'PRIMARY_KEY': False,
                                                                               'SQL_TYPE': 'VARCHAR',
                                                                               'WIDTH': 80},
                                                           'HOST_ORG_VARIANT': {'NULLABLE': True,
                                                                                'ORDER': 16,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 80},
                                                           'INDUCER': {'NULLABLE': True,
                                                                       'ORDER': 28,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 80},
                                                           'INDUCER_CONCENTRATION': {'NULLABLE': True,
                                                                                     'ORDER': 29,
                                                                                     'PRECISION': 6,
                                                                                     'PRIMARY_KEY': False,
                                                                                     'SQL_TYPE': 'FLOAT',
                                                                                     'WIDTH': 10},
                                                           'INDUCTION_DETAILS': {'NULLABLE': True,
                                                                                 'ORDER': 30,
                                                                                 'PRECISION': 0,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'VARCHAR',
                                                                                 'WIDTH': 200},
                                                           'INDUCTION_TEMPERATURE': {'NULLABLE': True,
                                                                                     'ORDER': 33,
                                                                                     'PRECISION': 6,
                                                                                     'PRIMARY_KEY': False,
                                                                                     'SQL_TYPE': 'FLOAT',
                                                                                     'WIDTH': 10},
                                                           'INDUCTION_TIMEPOINT': {'NULLABLE': True,
                                                                                   'ORDER': 32,
                                                                                   'PRECISION': 6,
                                                                                   'PRIMARY_KEY': False,
                                                                                   'SQL_TYPE': 'FLOAT',
                                                                                   'WIDTH': 10},
                                                           'MULTIPLICITY_OF_INFECTION': {'NULLABLE': True,
                                                                                         'ORDER': 31,
                                                                                         'PRECISION': 6,
                                                                                         'PRIMARY_KEY': False,
                                                                                         'SQL_TYPE': 'FLOAT',
                                                                                         'WIDTH': 10},
                                                           'NEXT_STEP_ID': {'NULLABLE': True,
                                                                            'ORDER': 5,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'INT',
                                                                            'WIDTH': 10},
                                                           'N_TERMINAL_SEQ_TAG': {'NULLABLE': True,
                                                                                  'ORDER': 12,
                                                                                  'PRECISION': 0,
                                                                                  'PRIMARY_KEY': False,
                                                                                  'SQL_TYPE': 'VARCHAR',
                                                                                  'WIDTH': 200},
                                                           'PLASMID_ID': {'NULLABLE': True,
                                                                          'ORDER': 10,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                           'PROMOTER_TYPE': {'NULLABLE': True,
                                                                             'ORDER': 9,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 200},
                                                           'ROBOT_ID': {'NULLABLE': True,
                                                                        'ORDER': 7,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                                           'STEP_ID': {'NULLABLE': False,
                                                                       'ORDER': 4,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': True,
                                                                       'SQL_TYPE': 'INT',
                                                                       'WIDTH': 10},
                                                           'STORAGE_DETAILS': {'NULLABLE': True,
                                                                               'ORDER': 35,
                                                                               'PRECISION': 0,
                                                                               'PRIMARY_KEY': False,
                                                                               'SQL_TYPE': 'VARCHAR',
                                                                               'WIDTH': 200},
                                                           'STRUCTURE_ID': {'NULLABLE': False,
                                                                            'ORDER': 1,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': True,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 10},
                                                           'SUMMARY': {'NULLABLE': True,
                                                                       'ORDER': 36,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 200},
                                                           'VECTOR_TYPE': {'NULLABLE': True,
                                                                           'ORDER': 11,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10}},
                                        'ATTRIBUTE_MAP': {'CULTURE_ADDITIVES': ('pdbx_entity_src_gen_express',
                                                                                'culture_additives',
                                                                                None,
                                                                                None),
                                                          'CULTURE_BASE_MEDIA': ('pdbx_entity_src_gen_express',
                                                                                 'culture_base_media',
                                                                                 None,
                                                                                 None),
                                                          'CULTURE_TEMPERATURE': ('pdbx_entity_src_gen_express',
                                                                                  'culture_temperature',
                                                                                  None,
                                                                                  None),
                                                          'CULTURE_TIME': ('pdbx_entity_src_gen_express',
                                                                           'culture_time',
                                                                           None,
                                                                           None),
                                                          'CULTURE_VOLUME': ('pdbx_entity_src_gen_express',
                                                                             'culture_volume',
                                                                             None,
                                                                             None),
                                                          'C_TERMINAL_SEQ_TAG': ('pdbx_entity_src_gen_express',
                                                                                 'C_terminal_seq_tag',
                                                                                 None,
                                                                                 None),
                                                          'DATE': ('pdbx_entity_src_gen_express', 'date', None, None),
                                                          'END_CONSTRUCT_ID': ('pdbx_entity_src_gen_express',
                                                                               'end_construct_id',
                                                                               None,
                                                                               None),
                                                          'ENTITY_ID': ('pdbx_entity_src_gen_express',
                                                                        'entity_id',
                                                                        None,
                                                                        None),
                                                          'ENTRY_ID': ('pdbx_entity_src_gen_express', 'entry_id', None, None),
                                                          'HARVESTING_DETAILS': ('pdbx_entity_src_gen_express',
                                                                                 'harvesting_details',
                                                                                 None,
                                                                                 None),
                                                          'HOST_ORG_CELL_LINE': ('pdbx_entity_src_gen_express',
                                                                                 'host_org_cell_line',
                                                                                 None,
                                                                                 None),
                                                          'HOST_ORG_COMMON_NAME': ('pdbx_entity_src_gen_express',
                                                                                   'host_org_common_name',
                                                                                   None,
                                                                                   None),
                                                          'HOST_ORG_CULTURE_COLLECTION': ('pdbx_entity_src_gen_express',
                                                                                          'host_org_culture_collection',
                                                                                          None,
                                                                                          None),
                                                          'HOST_ORG_DETAILS': ('pdbx_entity_src_gen_express',
                                                                               'host_org_details',
                                                                               None,
                                                                               None),
                                                          'HOST_ORG_SCIENTIFIC_NAME': ('pdbx_entity_src_gen_express',
                                                                                       'host_org_scientific_name',
                                                                                       None,
                                                                                       None),
                                                          'HOST_ORG_STRAIN': ('pdbx_entity_src_gen_express',
                                                                              'host_org_strain',
                                                                              None,
                                                                              None),
                                                          'HOST_ORG_TAX_ID': ('pdbx_entity_src_gen_express',
                                                                              'host_org_tax_id',
                                                                              None,
                                                                              None),
                                                          'HOST_ORG_TISSUE': ('pdbx_entity_src_gen_express',
                                                                              'host_org_tissue',
                                                                              None,
                                                                              None),
                                                          'HOST_ORG_VARIANT': ('pdbx_entity_src_gen_express',
                                                                               'host_org_variant',
                                                                               None,
                                                                               None),
                                                          'INDUCER': ('pdbx_entity_src_gen_express', 'inducer', None, None),
                                                          'INDUCER_CONCENTRATION': ('pdbx_entity_src_gen_express',
                                                                                    'inducer_concentration',
                                                                                    None,
                                                                                    None),
                                                          'INDUCTION_DETAILS': ('pdbx_entity_src_gen_express',
                                                                                'induction_details',
                                                                                None,
                                                                                None),
                                                          'INDUCTION_TEMPERATURE': ('pdbx_entity_src_gen_express',
                                                                                    'induction_temperature',
                                                                                    None,
                                                                                    None),
                                                          'INDUCTION_TIMEPOINT': ('pdbx_entity_src_gen_express',
                                                                                  'induction_timepoint',
                                                                                  None,
                                                                                  None),
                                                          'MULTIPLICITY_OF_INFECTION': ('pdbx_entity_src_gen_express',
                                                                                        'multiplicity_of_infection',
                                                                                        None,
                                                                                        None),
                                                          'NEXT_STEP_ID': ('pdbx_entity_src_gen_express',
                                                                           'next_step_id',
                                                                           None,
                                                                           None),
                                                          'N_TERMINAL_SEQ_TAG': ('pdbx_entity_src_gen_express',
                                                                                 'N_terminal_seq_tag',
                                                                                 None,
                                                                                 None),
                                                          'PLASMID_ID': ('pdbx_entity_src_gen_express',
                                                                         'plasmid_id',
                                                                         None,
                                                                         None),
                                                          'PROMOTER_TYPE': ('pdbx_entity_src_gen_express',
                                                                            'promoter_type',
                                                                            None,
                                                                            None),
                                                          'ROBOT_ID': ('pdbx_entity_src_gen_express', 'robot_id', None, None),
                                                          'STEP_ID': ('pdbx_entity_src_gen_express', 'step_id', None, None),
                                                          'STORAGE_DETAILS': ('pdbx_entity_src_gen_express',
                                                                              'storage_details',
                                                                              None,
                                                                              None),
                                                          'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                          'SUMMARY': ('pdbx_entity_src_gen_express', 'summary', None, None),
                                                          'VECTOR_TYPE': ('pdbx_entity_src_gen_express',
                                                                          'vector_type',
                                                                          None,
                                                                          None)},
                                        'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID', 'ENTITY_ID', 'STEP_ID'),
                                                           'TYPE': 'UNIQUE'},
                                                    's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                        'MAP_MERGE_INDICES': {'pdbx_entity_src_gen_express': {'ATTRIBUTES': ('entry_id',
                                                                                                             'entity_id',
                                                                                                             'step_id'),
                                                                                              'TYPE': 'EQUI-JOIN'}},
                                        'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                        'TABLE_ID': 'PDBX_ENTITY_SRC_GEN_EXPRESS',
                                        'TABLE_NAME': 'pdbx_entity_src_gen_express',
                                        'TABLE_TYPE': 'transactional'},
        'PDBX_ENTITY_SRC_GEN_EXPRESS_TIMEPOINT': {'ATTRIBUTES': {'ENTITY_ID': 'entity_id',
                                                                 'ENTRY_ID': 'entry_id',
                                                                 'OD': 'OD',
                                                                 'SERIAL': 'serial',
                                                                 'STEP_ID': 'step_id',
                                                                 'STRUCTURE_ID': 'Structure_ID',
                                                                 'TIME': 'time'},
                                                  'ATTRIBUTE_INFO': {'ENTITY_ID': {'NULLABLE': False,
                                                                                   'ORDER': 3,
                                                                                   'PRECISION': 0,
                                                                                   'PRIMARY_KEY': True,
                                                                                   'SQL_TYPE': 'VARCHAR',
                                                                                   'WIDTH': 10},
                                                                     'ENTRY_ID': {'NULLABLE': False,
                                                                                  'ORDER': 2,
                                                                                  'PRECISION': 0,
                                                                                  'PRIMARY_KEY': True,
                                                                                  'SQL_TYPE': 'VARCHAR',
                                                                                  'WIDTH': 10},
                                                                     'OD': {'NULLABLE': True,
                                                                            'ORDER': 6,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'INT',
                                                                            'WIDTH': 10},
                                                                     'SERIAL': {'NULLABLE': False,
                                                                                'ORDER': 5,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': True,
                                                                                'SQL_TYPE': 'INT',
                                                                                'WIDTH': 10},
                                                                     'STEP_ID': {'NULLABLE': False,
                                                                                 'ORDER': 4,
                                                                                 'PRECISION': 0,
                                                                                 'PRIMARY_KEY': True,
                                                                                 'SQL_TYPE': 'INT',
                                                                                 'WIDTH': 10},
                                                                     'STRUCTURE_ID': {'NULLABLE': False,
                                                                                      'ORDER': 1,
                                                                                      'PRECISION': 0,
                                                                                      'PRIMARY_KEY': True,
                                                                                      'SQL_TYPE': 'VARCHAR',
                                                                                      'WIDTH': 10},
                                                                     'TIME': {'NULLABLE': True,
                                                                              'ORDER': 7,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'INT',
                                                                              'WIDTH': 10}},
                                                  'ATTRIBUTE_MAP': {'ENTITY_ID': ('pdbx_entity_src_gen_express_timepoint',
                                                                                  'entity_id',
                                                                                  None,
                                                                                  None),
                                                                    'ENTRY_ID': ('pdbx_entity_src_gen_express_timepoint',
                                                                                 'entry_id',
                                                                                 None,
                                                                                 None),
                                                                    'OD': ('pdbx_entity_src_gen_express_timepoint',
                                                                           'OD',
                                                                           None,
                                                                           None),
                                                                    'SERIAL': ('pdbx_entity_src_gen_express_timepoint',
                                                                               'serial',
                                                                               None,
                                                                               None),
                                                                    'STEP_ID': ('pdbx_entity_src_gen_express_timepoint',
                                                                                'step_id',
                                                                                None,
                                                                                None),
                                                                    'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                                    'TIME': ('pdbx_entity_src_gen_express_timepoint',
                                                                             'time',
                                                                             None,
                                                                             None)},
                                                  'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID',
                                                                                    'ENTRY_ID',
                                                                                    'ENTITY_ID',
                                                                                    'STEP_ID',
                                                                                    'SERIAL'),
                                                                     'TYPE': 'UNIQUE'},
                                                              's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                                  'MAP_MERGE_INDICES': {'pdbx_entity_src_gen_express_timepoint': {'ATTRIBUTES': ('entry_id',
                                                                                                                                 'entity_id',
                                                                                                                                 'step_id',
                                                                                                                                 'serial'),
                                                                                                                  'TYPE': 'EQUI-JOIN'}},
                                                  'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                                  'TABLE_ID': 'PDBX_ENTITY_SRC_GEN_EXPRESS_TIMEPOINT',
                                                  'TABLE_NAME': 'pdbx_entity_src_gen_express_timepoint',
                                                  'TABLE_TYPE': 'transactional'},
        'PDBX_ENTITY_SRC_GEN_FRACT': {'ATTRIBUTES': {'DATE': 'date',
                                                     'DETAILS': 'details',
                                                     'END_CONSTRUCT_ID': 'end_construct_id',
                                                     'ENTITY_ID': 'entity_id',
                                                     'ENTRY_ID': 'entry_id',
                                                     'METHOD': 'method',
                                                     'NEXT_STEP_ID': 'next_step_id',
                                                     'PROTEIN_LOCATION': 'protein_location',
                                                     'PROTEIN_VOLUME': 'protein_volume',
                                                     'PROTEIN_YIELD': 'protein_yield',
                                                     'PROTEIN_YIELD_METHOD': 'protein_yield_method',
                                                     'ROBOT_ID': 'robot_id',
                                                     'STEP_ID': 'step_id',
                                                     'STRUCTURE_ID': 'Structure_ID',
                                                     'TEMPERATURE': 'temperature'},
                                      'ATTRIBUTE_INFO': {'DATE': {'NULLABLE': True,
                                                                  'ORDER': 8,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'DATETIME',
                                                                  'WIDTH': 20},
                                                         'DETAILS': {'NULLABLE': True,
                                                                     'ORDER': 11,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 200},
                                                         'END_CONSTRUCT_ID': {'NULLABLE': True,
                                                                              'ORDER': 6,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                                         'ENTITY_ID': {'NULLABLE': False,
                                                                       'ORDER': 3,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': True,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                         'ENTRY_ID': {'NULLABLE': False,
                                                                      'ORDER': 2,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                                         'METHOD': {'NULLABLE': True,
                                                                    'ORDER': 9,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10},
                                                         'NEXT_STEP_ID': {'NULLABLE': True,
                                                                          'ORDER': 5,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'INT',
                                                                          'WIDTH': 10},
                                                         'PROTEIN_LOCATION': {'NULLABLE': True,
                                                                              'ORDER': 12,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                                         'PROTEIN_VOLUME': {'NULLABLE': True,
                                                                            'ORDER': 13,
                                                                            'PRECISION': 6,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'FLOAT',
                                                                            'WIDTH': 10},
                                                         'PROTEIN_YIELD': {'NULLABLE': True,
                                                                           'ORDER': 14,
                                                                           'PRECISION': 6,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'FLOAT',
                                                                           'WIDTH': 10},
                                                         'PROTEIN_YIELD_METHOD': {'NULLABLE': True,
                                                                                  'ORDER': 15,
                                                                                  'PRECISION': 0,
                                                                                  'PRIMARY_KEY': False,
                                                                                  'SQL_TYPE': 'VARCHAR',
                                                                                  'WIDTH': 200},
                                                         'ROBOT_ID': {'NULLABLE': True,
                                                                      'ORDER': 7,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                                         'STEP_ID': {'NULLABLE': False,
                                                                     'ORDER': 4,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': True,
                                                                     'SQL_TYPE': 'INT',
                                                                     'WIDTH': 10},
                                                         'STRUCTURE_ID': {'NULLABLE': False,
                                                                          'ORDER': 1,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': True,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                         'TEMPERATURE': {'NULLABLE': True,
                                                                         'ORDER': 10,
                                                                         'PRECISION': 6,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'FLOAT',
                                                                         'WIDTH': 10}},
                                      'ATTRIBUTE_MAP': {'DATE': ('pdbx_entity_src_gen_fract', 'date', None, None),
                                                        'DETAILS': ('pdbx_entity_src_gen_fract', 'details', None, None),
                                                        'END_CONSTRUCT_ID': ('pdbx_entity_src_gen_fract',
                                                                             'end_construct_id',
                                                                             None,
                                                                             None),
                                                        'ENTITY_ID': ('pdbx_entity_src_gen_fract', 'entity_id', None, None),
                                                        'ENTRY_ID': ('pdbx_entity_src_gen_fract', 'entry_id', None, None),
                                                        'METHOD': ('pdbx_entity_src_gen_fract', 'method', None, None),
                                                        'NEXT_STEP_ID': ('pdbx_entity_src_gen_fract',
                                                                         'next_step_id',
                                                                         None,
                                                                         None),
                                                        'PROTEIN_LOCATION': ('pdbx_entity_src_gen_fract',
                                                                             'protein_location',
                                                                             None,
                                                                             None),
                                                        'PROTEIN_VOLUME': ('pdbx_entity_src_gen_fract',
                                                                           'protein_volume',
                                                                           None,
                                                                           None),
                                                        'PROTEIN_YIELD': ('pdbx_entity_src_gen_fract',
                                                                          'protein_yield',
                                                                          None,
                                                                          None),
                                                        'PROTEIN_YIELD_METHOD': ('pdbx_entity_src_gen_fract',
                                                                                 'protein_yield_method',
                                                                                 None,
                                                                                 None),
                                                        'ROBOT_ID': ('pdbx_entity_src_gen_fract', 'robot_id', None, None),
                                                        'STEP_ID': ('pdbx_entity_src_gen_fract', 'step_id', None, None),
                                                        'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                        'TEMPERATURE': ('pdbx_entity_src_gen_fract',
                                                                        'temperature',
                                                                        None,
                                                                        None)},
                                      'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID', 'ENTITY_ID', 'STEP_ID'),
                                                         'TYPE': 'UNIQUE'},
                                                  's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                      'MAP_MERGE_INDICES': {'pdbx_entity_src_gen_fract': {'ATTRIBUTES': ('entry_id',
                                                                                                         'entity_id',
                                                                                                         'step_id'),
                                                                                          'TYPE': 'EQUI-JOIN'}},
                                      'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                      'TABLE_ID': 'PDBX_ENTITY_SRC_GEN_FRACT',
                                      'TABLE_NAME': 'pdbx_entity_src_gen_fract',
                                      'TABLE_TYPE': 'transactional'},
        'PDBX_ENTITY_SRC_GEN_LYSIS': {'ATTRIBUTES': {'BUFFER_ID': 'buffer_id',
                                                     'BUFFER_VOLUME': 'buffer_volume',
                                                     'DATE': 'date',
                                                     'DETAILS': 'details',
                                                     'END_CONSTRUCT_ID': 'end_construct_id',
                                                     'ENTITY_ID': 'entity_id',
                                                     'ENTRY_ID': 'entry_id',
                                                     'METHOD': 'method',
                                                     'NEXT_STEP_ID': 'next_step_id',
                                                     'ROBOT_ID': 'robot_id',
                                                     'STEP_ID': 'step_id',
                                                     'STRUCTURE_ID': 'Structure_ID',
                                                     'TEMPERATURE': 'temperature',
                                                     'TIME': 'time'},
                                      'ATTRIBUTE_INFO': {'BUFFER_ID': {'NULLABLE': True,
                                                                       'ORDER': 10,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                         'BUFFER_VOLUME': {'NULLABLE': True,
                                                                           'ORDER': 11,
                                                                           'PRECISION': 6,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'FLOAT',
                                                                           'WIDTH': 10},
                                                         'DATE': {'NULLABLE': True,
                                                                  'ORDER': 8,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'DATETIME',
                                                                  'WIDTH': 20},
                                                         'DETAILS': {'NULLABLE': True,
                                                                     'ORDER': 14,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 200},
                                                         'END_CONSTRUCT_ID': {'NULLABLE': True,
                                                                              'ORDER': 6,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                                         'ENTITY_ID': {'NULLABLE': False,
                                                                       'ORDER': 3,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': True,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                         'ENTRY_ID': {'NULLABLE': False,
                                                                      'ORDER': 2,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                                         'METHOD': {'NULLABLE': True,
                                                                    'ORDER': 9,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10},
                                                         'NEXT_STEP_ID': {'NULLABLE': True,
                                                                          'ORDER': 5,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'INT',
                                                                          'WIDTH': 10},
                                                         'ROBOT_ID': {'NULLABLE': True,
                                                                      'ORDER': 7,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                                         'STEP_ID': {'NULLABLE': False,
                                                                     'ORDER': 4,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': True,
                                                                     'SQL_TYPE': 'INT',
                                                                     'WIDTH': 10},
                                                         'STRUCTURE_ID': {'NULLABLE': False,
                                                                          'ORDER': 1,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': True,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                         'TEMPERATURE': {'NULLABLE': True,
                                                                         'ORDER': 12,
                                                                         'PRECISION': 6,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'FLOAT',
                                                                         'WIDTH': 10},
                                                         'TIME': {'NULLABLE': True,
                                                                  'ORDER': 13,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10}},
                                      'ATTRIBUTE_MAP': {'BUFFER_ID': ('pdbx_entity_src_gen_lysis', 'buffer_id', None, None),
                                                        'BUFFER_VOLUME': ('pdbx_entity_src_gen_lysis',
                                                                          'buffer_volume',
                                                                          None,
                                                                          None),
                                                        'DATE': ('pdbx_entity_src_gen_lysis', 'date', None, None),
                                                        'DETAILS': ('pdbx_entity_src_gen_lysis', 'details', None, None),
                                                        'END_CONSTRUCT_ID': ('pdbx_entity_src_gen_lysis',
                                                                             'end_construct_id',
                                                                             None,
                                                                             None),
                                                        'ENTITY_ID': ('pdbx_entity_src_gen_lysis', 'entity_id', None, None),
                                                        'ENTRY_ID': ('pdbx_entity_src_gen_lysis', 'entry_id', None, None),
                                                        'METHOD': ('pdbx_entity_src_gen_lysis', 'method', None, None),
                                                        'NEXT_STEP_ID': ('pdbx_entity_src_gen_lysis',
                                                                         'next_step_id',
                                                                         None,
                                                                         None),
                                                        'ROBOT_ID': ('pdbx_entity_src_gen_lysis', 'robot_id', None, None),
                                                        'STEP_ID': ('pdbx_entity_src_gen_lysis', 'step_id', None, None),
                                                        'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                        'TEMPERATURE': ('pdbx_entity_src_gen_lysis',
                                                                        'temperature',
                                                                        None,
                                                                        None),
                                                        'TIME': ('pdbx_entity_src_gen_lysis', 'time', None, None)},
                                      'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID', 'ENTITY_ID', 'STEP_ID'),
                                                         'TYPE': 'UNIQUE'},
                                                  's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                      'MAP_MERGE_INDICES': {'pdbx_entity_src_gen_lysis': {'ATTRIBUTES': ('entry_id',
                                                                                                         'entity_id',
                                                                                                         'step_id'),
                                                                                          'TYPE': 'EQUI-JOIN'}},
                                      'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                      'TABLE_ID': 'PDBX_ENTITY_SRC_GEN_LYSIS',
                                      'TABLE_NAME': 'pdbx_entity_src_gen_lysis',
                                      'TABLE_TYPE': 'transactional'},
        'PDBX_ENTITY_SRC_GEN_PROD_DIGEST': {'ATTRIBUTES': {'DATE': 'date',
                                                           'END_CONSTRUCT_ID': 'end_construct_id',
                                                           'ENTITY_ID': 'entity_id',
                                                           'ENTRY_ID': 'entry_id',
                                                           'NEXT_STEP_ID': 'next_step_id',
                                                           'PURIFICATION_DETAILS': 'purification_details',
                                                           'RESTRICTION_ENZYME_1': 'restriction_enzyme_1',
                                                           'RESTRICTION_ENZYME_2': 'restriction_enzyme_2',
                                                           'ROBOT_ID': 'robot_id',
                                                           'STEP_ID': 'step_id',
                                                           'STRUCTURE_ID': 'Structure_ID',
                                                           'SUMMARY': 'summary'},
                                            'ATTRIBUTE_INFO': {'DATE': {'NULLABLE': True,
                                                                        'ORDER': 8,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'DATETIME',
                                                                        'WIDTH': 20},
                                                               'END_CONSTRUCT_ID': {'NULLABLE': True,
                                                                                    'ORDER': 6,
                                                                                    'PRECISION': 0,
                                                                                    'PRIMARY_KEY': False,
                                                                                    'SQL_TYPE': 'VARCHAR',
                                                                                    'WIDTH': 10},
                                                               'ENTITY_ID': {'NULLABLE': False,
                                                                             'ORDER': 3,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': True,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                               'ENTRY_ID': {'NULLABLE': False,
                                                                            'ORDER': 2,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': True,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 10},
                                                               'NEXT_STEP_ID': {'NULLABLE': True,
                                                                                'ORDER': 5,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'INT',
                                                                                'WIDTH': 10},
                                                               'PURIFICATION_DETAILS': {'NULLABLE': True,
                                                                                        'ORDER': 11,
                                                                                        'PRECISION': 0,
                                                                                        'PRIMARY_KEY': False,
                                                                                        'SQL_TYPE': 'VARCHAR',
                                                                                        'WIDTH': 200},
                                                               'RESTRICTION_ENZYME_1': {'NULLABLE': True,
                                                                                        'ORDER': 9,
                                                                                        'PRECISION': 0,
                                                                                        'PRIMARY_KEY': False,
                                                                                        'SQL_TYPE': 'VARCHAR',
                                                                                        'WIDTH': 200},
                                                               'RESTRICTION_ENZYME_2': {'NULLABLE': True,
                                                                                        'ORDER': 10,
                                                                                        'PRECISION': 0,
                                                                                        'PRIMARY_KEY': False,
                                                                                        'SQL_TYPE': 'VARCHAR',
                                                                                        'WIDTH': 200},
                                                               'ROBOT_ID': {'NULLABLE': True,
                                                                            'ORDER': 7,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 10},
                                                               'STEP_ID': {'NULLABLE': False,
                                                                           'ORDER': 4,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': True,
                                                                           'SQL_TYPE': 'INT',
                                                                           'WIDTH': 10},
                                                               'STRUCTURE_ID': {'NULLABLE': False,
                                                                                'ORDER': 1,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': True,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 10},
                                                               'SUMMARY': {'NULLABLE': True,
                                                                           'ORDER': 12,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 200}},
                                            'ATTRIBUTE_MAP': {'DATE': ('pdbx_entity_src_gen_prod_digest', 'date', None, None),
                                                              'END_CONSTRUCT_ID': ('pdbx_entity_src_gen_prod_digest',
                                                                                   'end_construct_id',
                                                                                   None,
                                                                                   None),
                                                              'ENTITY_ID': ('pdbx_entity_src_gen_prod_digest',
                                                                            'entity_id',
                                                                            None,
                                                                            None),
                                                              'ENTRY_ID': ('pdbx_entity_src_gen_prod_digest',
                                                                           'entry_id',
                                                                           None,
                                                                           None),
                                                              'NEXT_STEP_ID': ('pdbx_entity_src_gen_prod_digest',
                                                                               'next_step_id',
                                                                               None,
                                                                               None),
                                                              'PURIFICATION_DETAILS': ('pdbx_entity_src_gen_prod_digest',
                                                                                       'purification_details',
                                                                                       None,
                                                                                       None),
                                                              'RESTRICTION_ENZYME_1': ('pdbx_entity_src_gen_prod_digest',
                                                                                       'restriction_enzyme_1',
                                                                                       None,
                                                                                       None),
                                                              'RESTRICTION_ENZYME_2': ('pdbx_entity_src_gen_prod_digest',
                                                                                       'restriction_enzyme_2',
                                                                                       None,
                                                                                       None),
                                                              'ROBOT_ID': ('pdbx_entity_src_gen_prod_digest',
                                                                           'robot_id',
                                                                           None,
                                                                           None),
                                                              'STEP_ID': ('pdbx_entity_src_gen_prod_digest',
                                                                          'step_id',
                                                                          None,
                                                                          None),
                                                              'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                              'SUMMARY': ('pdbx_entity_src_gen_prod_digest',
                                                                          'summary',
                                                                          None,
                                                                          None)},
                                            'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID',
                                                                              'ENTRY_ID',
                                                                              'ENTITY_ID',
                                                                              'STEP_ID'),
                                                               'TYPE': 'UNIQUE'},
                                                        's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                            'MAP_MERGE_INDICES': {'pdbx_entity_src_gen_prod_digest': {'ATTRIBUTES': ('entry_id',
                                                                                                                     'entity_id',
                                                                                                                     'step_id'),
                                                                                                      'TYPE': 'EQUI-JOIN'}},
                                            'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                            'TABLE_ID': 'PDBX_ENTITY_SRC_GEN_PROD_DIGEST',
                                            'TABLE_NAME': 'pdbx_entity_src_gen_prod_digest',
                                            'TABLE_TYPE': 'transactional'},
        'PDBX_ENTITY_SRC_GEN_PROD_OTHER': {'ATTRIBUTES': {'DATE': 'date',
                                                          'DETAILS': 'details',
                                                          'END_CONSTRUCT_ID': 'end_construct_id',
                                                          'ENTITY_ID': 'entity_id',
                                                          'ENTRY_ID': 'entry_id',
                                                          'NEXT_STEP_ID': 'next_step_id',
                                                          'PROCESS_NAME': 'process_name',
                                                          'ROBOT_ID': 'robot_id',
                                                          'STEP_ID': 'step_id',
                                                          'STRUCTURE_ID': 'Structure_ID'},
                                           'ATTRIBUTE_INFO': {'DATE': {'NULLABLE': True,
                                                                       'ORDER': 8,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'DATETIME',
                                                                       'WIDTH': 20},
                                                              'DETAILS': {'NULLABLE': True,
                                                                          'ORDER': 10,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 200},
                                                              'END_CONSTRUCT_ID': {'NULLABLE': True,
                                                                                   'ORDER': 6,
                                                                                   'PRECISION': 0,
                                                                                   'PRIMARY_KEY': False,
                                                                                   'SQL_TYPE': 'VARCHAR',
                                                                                   'WIDTH': 10},
                                                              'ENTITY_ID': {'NULLABLE': False,
                                                                            'ORDER': 3,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': True,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 10},
                                                              'ENTRY_ID': {'NULLABLE': False,
                                                                           'ORDER': 2,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': True,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10},
                                                              'NEXT_STEP_ID': {'NULLABLE': True,
                                                                               'ORDER': 5,
                                                                               'PRECISION': 0,
                                                                               'PRIMARY_KEY': False,
                                                                               'SQL_TYPE': 'INT',
                                                                               'WIDTH': 10},
                                                              'PROCESS_NAME': {'NULLABLE': True,
                                                                               'ORDER': 9,
                                                                               'PRECISION': 0,
                                                                               'PRIMARY_KEY': False,
                                                                               'SQL_TYPE': 'VARCHAR',
                                                                               'WIDTH': 200},
                                                              'ROBOT_ID': {'NULLABLE': True,
                                                                           'ORDER': 7,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10},
                                                              'STEP_ID': {'NULLABLE': False,
                                                                          'ORDER': 4,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': True,
                                                                          'SQL_TYPE': 'INT',
                                                                          'WIDTH': 10},
                                                              'STRUCTURE_ID': {'NULLABLE': False,
                                                                               'ORDER': 1,
                                                                               'PRECISION': 0,
                                                                               'PRIMARY_KEY': True,
                                                                               'SQL_TYPE': 'VARCHAR',
                                                                               'WIDTH': 10}},
                                           'ATTRIBUTE_MAP': {'DATE': ('pdbx_entity_src_gen_prod_other', 'date', None, None),
                                                             'DETAILS': ('pdbx_entity_src_gen_prod_other',
                                                                         'details',
                                                                         None,
                                                                         None),
                                                             'END_CONSTRUCT_ID': ('pdbx_entity_src_gen_prod_other',
                                                                                  'end_construct_id',
                                                                                  None,
                                                                                  None),
                                                             'ENTITY_ID': ('pdbx_entity_src_gen_prod_other',
                                                                           'entity_id',
                                                                           None,
                                                                           None),
                                                             'ENTRY_ID': ('pdbx_entity_src_gen_prod_other',
                                                                          'entry_id',
                                                                          None,
                                                                          None),
                                                             'NEXT_STEP_ID': ('pdbx_entity_src_gen_prod_other',
                                                                              'next_step_id',
                                                                              None,
                                                                              None),
                                                             'PROCESS_NAME': ('pdbx_entity_src_gen_prod_other',
                                                                              'process_name',
                                                                              None,
                                                                              None),
                                                             'ROBOT_ID': ('pdbx_entity_src_gen_prod_other',
                                                                          'robot_id',
                                                                          None,
                                                                          None),
                                                             'STEP_ID': ('pdbx_entity_src_gen_prod_other',
                                                                         'step_id',
                                                                         None,
                                                                         None),
                                                             'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                           'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID',
                                                                             'ENTRY_ID',
                                                                             'ENTITY_ID',
                                                                             'STEP_ID'),
                                                              'TYPE': 'UNIQUE'},
                                                       's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                           'MAP_MERGE_INDICES': {'pdbx_entity_src_gen_prod_other': {'ATTRIBUTES': ('entry_id',
                                                                                                                   'entity_id',
                                                                                                                   'step_id'),
                                                                                                    'TYPE': 'EQUI-JOIN'}},
                                           'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                           'TABLE_ID': 'PDBX_ENTITY_SRC_GEN_PROD_OTHER',
                                           'TABLE_NAME': 'pdbx_entity_src_gen_prod_other',
                                           'TABLE_TYPE': 'transactional'},
        'PDBX_ENTITY_SRC_GEN_PROD_OTHER_PARAMETER': {'ATTRIBUTES': {'DETAILS': 'details',
                                                                    'ENTITY_ID': 'entity_id',
                                                                    'ENTRY_ID': 'entry_id',
                                                                    'PARAMETER': 'parameter',
                                                                    'STEP_ID': 'step_id',
                                                                    'STRUCTURE_ID': 'Structure_ID',
                                                                    'VALUE': 'value'},
                                                     'ATTRIBUTE_INFO': {'DETAILS': {'NULLABLE': True,
                                                                                    'ORDER': 7,
                                                                                    'PRECISION': 0,
                                                                                    'PRIMARY_KEY': False,
                                                                                    'SQL_TYPE': 'VARCHAR',
                                                                                    'WIDTH': 200},
                                                                        'ENTITY_ID': {'NULLABLE': False,
                                                                                      'ORDER': 3,
                                                                                      'PRECISION': 0,
                                                                                      'PRIMARY_KEY': True,
                                                                                      'SQL_TYPE': 'VARCHAR',
                                                                                      'WIDTH': 10},
                                                                        'ENTRY_ID': {'NULLABLE': False,
                                                                                     'ORDER': 2,
                                                                                     'PRECISION': 0,
                                                                                     'PRIMARY_KEY': True,
                                                                                     'SQL_TYPE': 'VARCHAR',
                                                                                     'WIDTH': 10},
                                                                        'PARAMETER': {'NULLABLE': False,
                                                                                      'ORDER': 5,
                                                                                      'PRECISION': 0,
                                                                                      'PRIMARY_KEY': True,
                                                                                      'SQL_TYPE': 'VARCHAR',
                                                                                      'WIDTH': 80},
                                                                        'STEP_ID': {'NULLABLE': False,
                                                                                    'ORDER': 4,
                                                                                    'PRECISION': 0,
                                                                                    'PRIMARY_KEY': True,
                                                                                    'SQL_TYPE': 'INT',
                                                                                    'WIDTH': 10},
                                                                        'STRUCTURE_ID': {'NULLABLE': False,
                                                                                         'ORDER': 1,
                                                                                         'PRECISION': 0,
                                                                                         'PRIMARY_KEY': True,
                                                                                         'SQL_TYPE': 'VARCHAR',
                                                                                         'WIDTH': 10},
                                                                        'VALUE': {'NULLABLE': True,
                                                                                  'ORDER': 6,
                                                                                  'PRECISION': 0,
                                                                                  'PRIMARY_KEY': False,
                                                                                  'SQL_TYPE': 'VARCHAR',
                                                                                  'WIDTH': 200}},
                                                     'ATTRIBUTE_MAP': {'DETAILS': ('pdbx_entity_src_gen_prod_other_parameter',
                                                                                   'details',
                                                                                   None,
                                                                                   None),
                                                                       'ENTITY_ID': ('pdbx_entity_src_gen_prod_other_parameter',
                                                                                     'entity_id',
                                                                                     None,
                                                                                     None),
                                                                       'ENTRY_ID': ('pdbx_entity_src_gen_prod_other_parameter',
                                                                                    'entry_id',
                                                                                    None,
                                                                                    None),
                                                                       'PARAMETER': ('pdbx_entity_src_gen_prod_other_parameter',
                                                                                     'parameter',
                                                                                     None,
                                                                                     None),
                                                                       'STEP_ID': ('pdbx_entity_src_gen_prod_other_parameter',
                                                                                   'step_id',
                                                                                   None,
                                                                                   None),
                                                                       'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                                       'VALUE': ('pdbx_entity_src_gen_prod_other_parameter',
                                                                                 'value',
                                                                                 None,
                                                                                 None)},
                                                     'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID',
                                                                                       'ENTRY_ID',
                                                                                       'ENTITY_ID',
                                                                                       'STEP_ID',
                                                                                       'PARAMETER'),
                                                                        'TYPE': 'UNIQUE'},
                                                                 's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                                     'MAP_MERGE_INDICES': {'pdbx_entity_src_gen_prod_other_parameter': {'ATTRIBUTES': ('entry_id',
                                                                                                                                       'entity_id',
                                                                                                                                       'step_id',
                                                                                                                                       'parameter'),
                                                                                                                        'TYPE': 'EQUI-JOIN'}},
                                                     'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                                     'TABLE_ID': 'PDBX_ENTITY_SRC_GEN_PROD_OTHER_PARAMETER',
                                                     'TABLE_NAME': 'pdbx_entity_src_gen_prod_other_parameter',
                                                     'TABLE_TYPE': 'transactional'},
        'PDBX_ENTITY_SRC_GEN_PROD_PCR': {'ATTRIBUTES': {'DATE': 'date',
                                                        'END_CONSTRUCT_ID': 'end_construct_id',
                                                        'ENTITY_ID': 'entity_id',
                                                        'ENTRY_ID': 'entry_id',
                                                        'FORWARD_PRIMER_ID': 'forward_primer_id',
                                                        'NEXT_STEP_ID': 'next_step_id',
                                                        'PURIFICATION_DETAILS': 'purification_details',
                                                        'REACTION_DETAILS': 'reaction_details',
                                                        'REVERSE_PRIMER_ID': 'reverse_primer_id',
                                                        'ROBOT_ID': 'robot_id',
                                                        'STEP_ID': 'step_id',
                                                        'STRUCTURE_ID': 'Structure_ID',
                                                        'SUMMARY': 'summary'},
                                         'ATTRIBUTE_INFO': {'DATE': {'NULLABLE': True,
                                                                     'ORDER': 8,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'DATETIME',
                                                                     'WIDTH': 20},
                                                            'END_CONSTRUCT_ID': {'NULLABLE': True,
                                                                                 'ORDER': 6,
                                                                                 'PRECISION': 0,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'VARCHAR',
                                                                                 'WIDTH': 10},
                                                            'ENTITY_ID': {'NULLABLE': False,
                                                                          'ORDER': 3,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': True,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                            'ENTRY_ID': {'NULLABLE': False,
                                                                         'ORDER': 2,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': True,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                                            'FORWARD_PRIMER_ID': {'NULLABLE': True,
                                                                                  'ORDER': 9,
                                                                                  'PRECISION': 0,
                                                                                  'PRIMARY_KEY': False,
                                                                                  'SQL_TYPE': 'VARCHAR',
                                                                                  'WIDTH': 10},
                                                            'NEXT_STEP_ID': {'NULLABLE': True,
                                                                             'ORDER': 5,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'INT',
                                                                             'WIDTH': 10},
                                                            'PURIFICATION_DETAILS': {'NULLABLE': True,
                                                                                     'ORDER': 12,
                                                                                     'PRECISION': 0,
                                                                                     'PRIMARY_KEY': False,
                                                                                     'SQL_TYPE': 'VARCHAR',
                                                                                     'WIDTH': 200},
                                                            'REACTION_DETAILS': {'NULLABLE': True,
                                                                                 'ORDER': 11,
                                                                                 'PRECISION': 0,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'VARCHAR',
                                                                                 'WIDTH': 200},
                                                            'REVERSE_PRIMER_ID': {'NULLABLE': True,
                                                                                  'ORDER': 10,
                                                                                  'PRECISION': 0,
                                                                                  'PRIMARY_KEY': False,
                                                                                  'SQL_TYPE': 'VARCHAR',
                                                                                  'WIDTH': 10},
                                                            'ROBOT_ID': {'NULLABLE': True,
                                                                         'ORDER': 7,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                                            'STEP_ID': {'NULLABLE': False,
                                                                        'ORDER': 4,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': True,
                                                                        'SQL_TYPE': 'INT',
                                                                        'WIDTH': 10},
                                                            'STRUCTURE_ID': {'NULLABLE': False,
                                                                             'ORDER': 1,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': True,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                            'SUMMARY': {'NULLABLE': True,
                                                                        'ORDER': 13,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 200}},
                                         'ATTRIBUTE_MAP': {'DATE': ('pdbx_entity_src_gen_prod_pcr', 'date', None, None),
                                                           'END_CONSTRUCT_ID': ('pdbx_entity_src_gen_prod_pcr',
                                                                                'end_construct_id',
                                                                                None,
                                                                                None),
                                                           'ENTITY_ID': ('pdbx_entity_src_gen_prod_pcr',
                                                                         'entity_id',
                                                                         None,
                                                                         None),
                                                           'ENTRY_ID': ('pdbx_entity_src_gen_prod_pcr',
                                                                        'entry_id',
                                                                        None,
                                                                        None),
                                                           'FORWARD_PRIMER_ID': ('pdbx_entity_src_gen_prod_pcr',
                                                                                 'forward_primer_id',
                                                                                 None,
                                                                                 None),
                                                           'NEXT_STEP_ID': ('pdbx_entity_src_gen_prod_pcr',
                                                                            'next_step_id',
                                                                            None,
                                                                            None),
                                                           'PURIFICATION_DETAILS': ('pdbx_entity_src_gen_prod_pcr',
                                                                                    'purification_details',
                                                                                    None,
                                                                                    None),
                                                           'REACTION_DETAILS': ('pdbx_entity_src_gen_prod_pcr',
                                                                                'reaction_details',
                                                                                None,
                                                                                None),
                                                           'REVERSE_PRIMER_ID': ('pdbx_entity_src_gen_prod_pcr',
                                                                                 'reverse_primer_id',
                                                                                 None,
                                                                                 None),
                                                           'ROBOT_ID': ('pdbx_entity_src_gen_prod_pcr',
                                                                        'robot_id',
                                                                        None,
                                                                        None),
                                                           'STEP_ID': ('pdbx_entity_src_gen_prod_pcr', 'step_id', None, None),
                                                           'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                           'SUMMARY': ('pdbx_entity_src_gen_prod_pcr', 'summary', None, None)},
                                         'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID', 'ENTITY_ID', 'STEP_ID'),
                                                            'TYPE': 'UNIQUE'},
                                                     's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                         'MAP_MERGE_INDICES': {'pdbx_entity_src_gen_prod_pcr': {'ATTRIBUTES': ('entry_id',
                                                                                                               'entity_id',
                                                                                                               'step_id'),
                                                                                                'TYPE': 'EQUI-JOIN'}},
                                         'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                         'TABLE_ID': 'PDBX_ENTITY_SRC_GEN_PROD_PCR',
                                         'TABLE_NAME': 'pdbx_entity_src_gen_prod_pcr',
                                         'TABLE_TYPE': 'transactional'},
        'PDBX_ENTITY_SRC_GEN_PROTEOLYSIS': {'ATTRIBUTES': {'CLEAVAGE_BUFFER_ID': 'cleavage_buffer_id',
                                                           'CLEAVAGE_TEMPERATURE': 'cleavage_temperature',
                                                           'CLEAVAGE_TIME': 'cleavage_time',
                                                           'DATE': 'date',
                                                           'DETAILS': 'details',
                                                           'END_CONSTRUCT_ID': 'end_construct_id',
                                                           'ENTITY_ID': 'entity_id',
                                                           'ENTRY_ID': 'entry_id',
                                                           'NEXT_STEP_ID': 'next_step_id',
                                                           'PROTEASE': 'protease',
                                                           'PROTEIN_PROTEASE_RATIO': 'protein_protease_ratio',
                                                           'ROBOT_ID': 'robot_id',
                                                           'STEP_ID': 'step_id',
                                                           'STRUCTURE_ID': 'Structure_ID'},
                                            'ATTRIBUTE_INFO': {'CLEAVAGE_BUFFER_ID': {'NULLABLE': True,
                                                                                      'ORDER': 12,
                                                                                      'PRECISION': 0,
                                                                                      'PRIMARY_KEY': False,
                                                                                      'SQL_TYPE': 'VARCHAR',
                                                                                      'WIDTH': 10},
                                                               'CLEAVAGE_TEMPERATURE': {'NULLABLE': True,
                                                                                        'ORDER': 13,
                                                                                        'PRECISION': 6,
                                                                                        'PRIMARY_KEY': False,
                                                                                        'SQL_TYPE': 'FLOAT',
                                                                                        'WIDTH': 10},
                                                               'CLEAVAGE_TIME': {'NULLABLE': True,
                                                                                 'ORDER': 14,
                                                                                 'PRECISION': 6,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'FLOAT',
                                                                                 'WIDTH': 10},
                                                               'DATE': {'NULLABLE': True,
                                                                        'ORDER': 8,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'DATETIME',
                                                                        'WIDTH': 20},
                                                               'DETAILS': {'NULLABLE': True,
                                                                           'ORDER': 9,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 200},
                                                               'END_CONSTRUCT_ID': {'NULLABLE': True,
                                                                                    'ORDER': 6,
                                                                                    'PRECISION': 0,
                                                                                    'PRIMARY_KEY': False,
                                                                                    'SQL_TYPE': 'VARCHAR',
                                                                                    'WIDTH': 10},
                                                               'ENTITY_ID': {'NULLABLE': False,
                                                                             'ORDER': 3,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': True,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                               'ENTRY_ID': {'NULLABLE': False,
                                                                            'ORDER': 2,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': True,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 10},
                                                               'NEXT_STEP_ID': {'NULLABLE': True,
                                                                                'ORDER': 5,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'INT',
                                                                                'WIDTH': 10},
                                                               'PROTEASE': {'NULLABLE': True,
                                                                            'ORDER': 10,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 200},
                                                               'PROTEIN_PROTEASE_RATIO': {'NULLABLE': True,
                                                                                          'ORDER': 11,
                                                                                          'PRECISION': 6,
                                                                                          'PRIMARY_KEY': False,
                                                                                          'SQL_TYPE': 'FLOAT',
                                                                                          'WIDTH': 10},
                                                               'ROBOT_ID': {'NULLABLE': True,
                                                                            'ORDER': 7,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 10},
                                                               'STEP_ID': {'NULLABLE': False,
                                                                           'ORDER': 4,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': True,
                                                                           'SQL_TYPE': 'INT',
                                                                           'WIDTH': 10},
                                                               'STRUCTURE_ID': {'NULLABLE': False,
                                                                                'ORDER': 1,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': True,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 10}},
                                            'ATTRIBUTE_MAP': {'CLEAVAGE_BUFFER_ID': ('pdbx_entity_src_gen_proteolysis',
                                                                                     'cleavage_buffer_id',
                                                                                     None,
                                                                                     None),
                                                              'CLEAVAGE_TEMPERATURE': ('pdbx_entity_src_gen_proteolysis',
                                                                                       'cleavage_temperature',
                                                                                       None,
                                                                                       None),
                                                              'CLEAVAGE_TIME': ('pdbx_entity_src_gen_proteolysis',
                                                                                'cleavage_time',
                                                                                None,
                                                                                None),
                                                              'DATE': ('pdbx_entity_src_gen_proteolysis', 'date', None, None),
                                                              'DETAILS': ('pdbx_entity_src_gen_proteolysis',
                                                                          'details',
                                                                          None,
                                                                          None),
                                                              'END_CONSTRUCT_ID': ('pdbx_entity_src_gen_proteolysis',
                                                                                   'end_construct_id',
                                                                                   None,
                                                                                   None),
                                                              'ENTITY_ID': ('pdbx_entity_src_gen_proteolysis',
                                                                            'entity_id',
                                                                            None,
                                                                            None),
                                                              'ENTRY_ID': ('pdbx_entity_src_gen_proteolysis',
                                                                           'entry_id',
                                                                           None,
                                                                           None),
                                                              'NEXT_STEP_ID': ('pdbx_entity_src_gen_proteolysis',
                                                                               'next_step_id',
                                                                               None,
                                                                               None),
                                                              'PROTEASE': ('pdbx_entity_src_gen_proteolysis',
                                                                           'protease',
                                                                           None,
                                                                           None),
                                                              'PROTEIN_PROTEASE_RATIO': ('pdbx_entity_src_gen_proteolysis',
                                                                                         'protein_protease_ratio',
                                                                                         None,
                                                                                         None),
                                                              'ROBOT_ID': ('pdbx_entity_src_gen_proteolysis',
                                                                           'robot_id',
                                                                           None,
                                                                           None),
                                                              'STEP_ID': ('pdbx_entity_src_gen_proteolysis',
                                                                          'step_id',
                                                                          None,
                                                                          None),
                                                              'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                            'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID',
                                                                              'ENTRY_ID',
                                                                              'ENTITY_ID',
                                                                              'STEP_ID'),
                                                               'TYPE': 'UNIQUE'},
                                                        's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                            'MAP_MERGE_INDICES': {'pdbx_entity_src_gen_proteolysis': {'ATTRIBUTES': ('entry_id',
                                                                                                                     'entity_id',
                                                                                                                     'step_id'),
                                                                                                      'TYPE': 'EQUI-JOIN'}},
                                            'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                            'TABLE_ID': 'PDBX_ENTITY_SRC_GEN_PROTEOLYSIS',
                                            'TABLE_NAME': 'pdbx_entity_src_gen_proteolysis',
                                            'TABLE_TYPE': 'transactional'},
        'PDBX_ENTITY_SRC_GEN_PURE': {'ATTRIBUTES': {'CONC_ASSAY_METHOD': 'conc_assay_method',
                                                    'CONC_DETAILS': 'conc_details',
                                                    'CONC_DEVICE_ID': 'conc_device_id',
                                                    'DATE': 'date',
                                                    'ENTITY_ID': 'entity_id',
                                                    'ENTRY_ID': 'entry_id',
                                                    'PRODUCT_ID': 'product_id',
                                                    'PROTEIN_CONCENTRATION': 'protein_concentration',
                                                    'PROTEIN_OLIGOMERIC_STATE': 'protein_oligomeric_state',
                                                    'PROTEIN_PURITY': 'protein_purity',
                                                    'PROTEIN_YIELD': 'protein_yield',
                                                    'STEP_ID': 'step_id',
                                                    'STORAGE_BUFFER_ID': 'storage_buffer_id',
                                                    'STORAGE_TEMPERATURE': 'storage_temperature',
                                                    'STRUCTURE_ID': 'Structure_ID',
                                                    'SUMMARY': 'summary'},
                                     'ATTRIBUTE_INFO': {'CONC_ASSAY_METHOD': {'NULLABLE': True,
                                                                              'ORDER': 9,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 200},
                                                        'CONC_DETAILS': {'NULLABLE': True,
                                                                         'ORDER': 8,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 200},
                                                        'CONC_DEVICE_ID': {'NULLABLE': True,
                                                                           'ORDER': 7,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10},
                                                        'DATE': {'NULLABLE': True,
                                                                 'ORDER': 6,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'DATETIME',
                                                                 'WIDTH': 20},
                                                        'ENTITY_ID': {'NULLABLE': False,
                                                                      'ORDER': 3,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                                        'ENTRY_ID': {'NULLABLE': False,
                                                                     'ORDER': 2,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': True,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                                        'PRODUCT_ID': {'NULLABLE': True,
                                                                       'ORDER': 5,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                        'PROTEIN_CONCENTRATION': {'NULLABLE': True,
                                                                                  'ORDER': 10,
                                                                                  'PRECISION': 6,
                                                                                  'PRIMARY_KEY': False,
                                                                                  'SQL_TYPE': 'FLOAT',
                                                                                  'WIDTH': 10},
                                                        'PROTEIN_OLIGOMERIC_STATE': {'NULLABLE': True,
                                                                                     'ORDER': 13,
                                                                                     'PRECISION': 0,
                                                                                     'PRIMARY_KEY': False,
                                                                                     'SQL_TYPE': 'INT',
                                                                                     'WIDTH': 10},
                                                        'PROTEIN_PURITY': {'NULLABLE': True,
                                                                           'ORDER': 12,
                                                                           'PRECISION': 6,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'FLOAT',
                                                                           'WIDTH': 10},
                                                        'PROTEIN_YIELD': {'NULLABLE': True,
                                                                          'ORDER': 11,
                                                                          'PRECISION': 6,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'FLOAT',
                                                                          'WIDTH': 10},
                                                        'STEP_ID': {'NULLABLE': False,
                                                                    'ORDER': 4,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': True,
                                                                    'SQL_TYPE': 'INT',
                                                                    'WIDTH': 10},
                                                        'STORAGE_BUFFER_ID': {'NULLABLE': True,
                                                                              'ORDER': 14,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                                        'STORAGE_TEMPERATURE': {'NULLABLE': True,
                                                                                'ORDER': 15,
                                                                                'PRECISION': 6,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'FLOAT',
                                                                                'WIDTH': 10},
                                                        'STRUCTURE_ID': {'NULLABLE': False,
                                                                         'ORDER': 1,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': True,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                                        'SUMMARY': {'NULLABLE': True,
                                                                    'ORDER': 16,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 200}},
                                     'ATTRIBUTE_MAP': {'CONC_ASSAY_METHOD': ('pdbx_entity_src_gen_pure',
                                                                             'conc_assay_method',
                                                                             None,
                                                                             None),
                                                       'CONC_DETAILS': ('pdbx_entity_src_gen_pure',
                                                                        'conc_details',
                                                                        None,
                                                                        None),
                                                       'CONC_DEVICE_ID': ('pdbx_entity_src_gen_pure',
                                                                          'conc_device_id',
                                                                          None,
                                                                          None),
                                                       'DATE': ('pdbx_entity_src_gen_pure', 'date', None, None),
                                                       'ENTITY_ID': ('pdbx_entity_src_gen_pure', 'entity_id', None, None),
                                                       'ENTRY_ID': ('pdbx_entity_src_gen_pure', 'entry_id', None, None),
                                                       'PRODUCT_ID': ('pdbx_entity_src_gen_pure', 'product_id', None, None),
                                                       'PROTEIN_CONCENTRATION': ('pdbx_entity_src_gen_pure',
                                                                                 'protein_concentration',
                                                                                 None,
                                                                                 None),
                                                       'PROTEIN_OLIGOMERIC_STATE': ('pdbx_entity_src_gen_pure',
                                                                                    'protein_oligomeric_state',
                                                                                    None,
                                                                                    None),
                                                       'PROTEIN_PURITY': ('pdbx_entity_src_gen_pure',
                                                                          'protein_purity',
                                                                          None,
                                                                          None),
                                                       'PROTEIN_YIELD': ('pdbx_entity_src_gen_pure',
                                                                         'protein_yield',
                                                                         None,
                                                                         None),
                                                       'STEP_ID': ('pdbx_entity_src_gen_pure', 'step_id', None, None),
                                                       'STORAGE_BUFFER_ID': ('pdbx_entity_src_gen_pure',
                                                                             'storage_buffer_id',
                                                                             None,
                                                                             None),
                                                       'STORAGE_TEMPERATURE': ('pdbx_entity_src_gen_pure',
                                                                               'storage_temperature',
                                                                               None,
                                                                               None),
                                                       'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                       'SUMMARY': ('pdbx_entity_src_gen_pure', 'summary', None, None)},
                                     'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID', 'ENTITY_ID', 'STEP_ID'),
                                                        'TYPE': 'UNIQUE'},
                                                 's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                     'MAP_MERGE_INDICES': {'pdbx_entity_src_gen_pure': {'ATTRIBUTES': ('entry_id',
                                                                                                       'entity_id',
                                                                                                       'step_id'),
                                                                                        'TYPE': 'EQUI-JOIN'}},
                                     'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                     'TABLE_ID': 'PDBX_ENTITY_SRC_GEN_PURE',
                                     'TABLE_NAME': 'pdbx_entity_src_gen_pure',
                                     'TABLE_TYPE': 'transactional'},
        'PDBX_ENTITY_SRC_GEN_REFOLD': {'ATTRIBUTES': {'DATE': 'date',
                                                      'DENATURE_BUFFER_ID': 'denature_buffer_id',
                                                      'DETAILS': 'details',
                                                      'END_CONSTRUCT_ID': 'end_construct_id',
                                                      'ENTITY_ID': 'entity_id',
                                                      'ENTRY_ID': 'entry_id',
                                                      'NEXT_STEP_ID': 'next_step_id',
                                                      'REFOLD_BUFFER_ID': 'refold_buffer_id',
                                                      'ROBOT_ID': 'robot_id',
                                                      'STEP_ID': 'step_id',
                                                      'STORAGE_BUFFER_ID': 'storage_buffer_id',
                                                      'STRUCTURE_ID': 'Structure_ID',
                                                      'TEMPERATURE': 'temperature',
                                                      'TIME': 'time'},
                                       'ATTRIBUTE_INFO': {'DATE': {'NULLABLE': True,
                                                                   'ORDER': 8,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'DATETIME',
                                                                   'WIDTH': 20},
                                                          'DENATURE_BUFFER_ID': {'NULLABLE': True,
                                                                                 'ORDER': 9,
                                                                                 'PRECISION': 0,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'VARCHAR',
                                                                                 'WIDTH': 10},
                                                          'DETAILS': {'NULLABLE': True,
                                                                      'ORDER': 14,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 200},
                                                          'END_CONSTRUCT_ID': {'NULLABLE': True,
                                                                               'ORDER': 6,
                                                                               'PRECISION': 0,
                                                                               'PRIMARY_KEY': False,
                                                                               'SQL_TYPE': 'VARCHAR',
                                                                               'WIDTH': 10},
                                                          'ENTITY_ID': {'NULLABLE': False,
                                                                        'ORDER': 3,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': True,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                                          'ENTRY_ID': {'NULLABLE': False,
                                                                       'ORDER': 2,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': True,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                          'NEXT_STEP_ID': {'NULLABLE': True,
                                                                           'ORDER': 5,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'INT',
                                                                           'WIDTH': 10},
                                                          'REFOLD_BUFFER_ID': {'NULLABLE': True,
                                                                               'ORDER': 10,
                                                                               'PRECISION': 0,
                                                                               'PRIMARY_KEY': False,
                                                                               'SQL_TYPE': 'VARCHAR',
                                                                               'WIDTH': 10},
                                                          'ROBOT_ID': {'NULLABLE': True,
                                                                       'ORDER': 7,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                          'STEP_ID': {'NULLABLE': False,
                                                                      'ORDER': 4,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'INT',
                                                                      'WIDTH': 10},
                                                          'STORAGE_BUFFER_ID': {'NULLABLE': True,
                                                                                'ORDER': 13,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 10},
                                                          'STRUCTURE_ID': {'NULLABLE': False,
                                                                           'ORDER': 1,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': True,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10},
                                                          'TEMPERATURE': {'NULLABLE': True,
                                                                          'ORDER': 11,
                                                                          'PRECISION': 6,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'FLOAT',
                                                                          'WIDTH': 10},
                                                          'TIME': {'NULLABLE': True,
                                                                   'ORDER': 12,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10}},
                                       'ATTRIBUTE_MAP': {'DATE': ('pdbx_entity_src_gen_refold', 'date', None, None),
                                                         'DENATURE_BUFFER_ID': ('pdbx_entity_src_gen_refold',
                                                                                'denature_buffer_id',
                                                                                None,
                                                                                None),
                                                         'DETAILS': ('pdbx_entity_src_gen_refold', 'details', None, None),
                                                         'END_CONSTRUCT_ID': ('pdbx_entity_src_gen_refold',
                                                                              'end_construct_id',
                                                                              None,
                                                                              None),
                                                         'ENTITY_ID': ('pdbx_entity_src_gen_refold', 'entity_id', None, None),
                                                         'ENTRY_ID': ('pdbx_entity_src_gen_refold', 'entry_id', None, None),
                                                         'NEXT_STEP_ID': ('pdbx_entity_src_gen_refold',
                                                                          'next_step_id',
                                                                          None,
                                                                          None),
                                                         'REFOLD_BUFFER_ID': ('pdbx_entity_src_gen_refold',
                                                                              'refold_buffer_id',
                                                                              None,
                                                                              None),
                                                         'ROBOT_ID': ('pdbx_entity_src_gen_refold', 'robot_id', None, None),
                                                         'STEP_ID': ('pdbx_entity_src_gen_refold', 'step_id', None, None),
                                                         'STORAGE_BUFFER_ID': ('pdbx_entity_src_gen_refold',
                                                                               'storage_buffer_id',
                                                                               None,
                                                                               None),
                                                         'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                         'TEMPERATURE': ('pdbx_entity_src_gen_refold',
                                                                         'temperature',
                                                                         None,
                                                                         None),
                                                         'TIME': ('pdbx_entity_src_gen_refold', 'time', None, None)},
                                       'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID', 'ENTITY_ID', 'STEP_ID'),
                                                          'TYPE': 'UNIQUE'},
                                                   's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                       'MAP_MERGE_INDICES': {'pdbx_entity_src_gen_refold': {'ATTRIBUTES': ('entry_id',
                                                                                                           'entity_id',
                                                                                                           'step_id'),
                                                                                            'TYPE': 'EQUI-JOIN'}},
                                       'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                       'TABLE_ID': 'PDBX_ENTITY_SRC_GEN_REFOLD',
                                       'TABLE_NAME': 'pdbx_entity_src_gen_refold',
                                       'TABLE_TYPE': 'transactional'},
        'PDBX_ENTITY_SRC_SYN': {'ATTRIBUTES': {'DETAILS': 'details',
                                               'ENTITY_ID': 'entity_id',
                                               'NCBI_TAXONOMY_ID': 'ncbi_taxonomy_id',
                                               'ORGANISM_COMMON_NAME': 'organism_common_name',
                                               'ORGANISM_SCIENTIFIC': 'organism_scientific',
                                               'STRAIN': 'strain',
                                               'STRUCTURE_ID': 'Structure_ID'},
                                'ATTRIBUTE_INFO': {'DETAILS': {'NULLABLE': True,
                                                               'ORDER': 2,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 1023},
                                                   'ENTITY_ID': {'NULLABLE': False,
                                                                 'ORDER': 7,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': True,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                                   'NCBI_TAXONOMY_ID': {'NULLABLE': True,
                                                                        'ORDER': 6,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 80},
                                                   'ORGANISM_COMMON_NAME': {'NULLABLE': True,
                                                                            'ORDER': 4,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 200},
                                                   'ORGANISM_SCIENTIFIC': {'NULLABLE': True,
                                                                           'ORDER': 3,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 200},
                                                   'STRAIN': {'NULLABLE': True,
                                                              'ORDER': 5,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 200},
                                                   'STRUCTURE_ID': {'NULLABLE': False,
                                                                    'ORDER': 1,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': True,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10}},
                                'ATTRIBUTE_MAP': {'DETAILS': ('pdbx_entity_src_syn', 'details', None, None),
                                                  'ENTITY_ID': ('pdbx_entity_src_syn', 'entity_id', None, None),
                                                  'NCBI_TAXONOMY_ID': ('pdbx_entity_src_syn', 'ncbi_taxonomy_id', None, None),
                                                  'ORGANISM_COMMON_NAME': ('pdbx_entity_src_syn',
                                                                           'organism_common_name',
                                                                           None,
                                                                           None),
                                                  'ORGANISM_SCIENTIFIC': ('pdbx_entity_src_syn',
                                                                          'organism_scientific',
                                                                          None,
                                                                          None),
                                                  'STRAIN': ('pdbx_entity_src_syn', 'strain', None, None),
                                                  'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTITY_ID'), 'TYPE': 'UNIQUE'},
                                            's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                'MAP_MERGE_INDICES': {'pdbx_entity_src_syn': {'ATTRIBUTES': ('entity_id',),
                                                                              'TYPE': 'EQUI-JOIN'}},
                                'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                'TABLE_ID': 'PDBX_ENTITY_SRC_SYN',
                                'TABLE_NAME': 'pdbx_entity_src_syn',
                                'TABLE_TYPE': 'transactional'},
        'PDBX_ENTRY_DETAILS': {'ATTRIBUTES': {'COMPOUND_DETAILS': 'compound_details',
                                              'ENTRY_ID': 'entry_id',
                                              'NONPOLYMER_DETAILS': 'nonpolymer_details',
                                              'SEQUENCE_DETAILS': 'sequence_details',
                                              'SOURCE_DETAILS': 'source_details',
                                              'STRUCTURE_ID': 'Structure_ID'},
                               'ATTRIBUTE_INFO': {'COMPOUND_DETAILS': {'NULLABLE': True,
                                                                       'ORDER': 5,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 4095},
                                                  'ENTRY_ID': {'NULLABLE': False,
                                                               'ORDER': 2,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                                  'NONPOLYMER_DETAILS': {'NULLABLE': True,
                                                                         'ORDER': 3,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 4095},
                                                  'SEQUENCE_DETAILS': {'NULLABLE': True,
                                                                       'ORDER': 4,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 16383},
                                                  'SOURCE_DETAILS': {'NULLABLE': True,
                                                                     'ORDER': 6,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 1023},
                                                  'STRUCTURE_ID': {'NULLABLE': False,
                                                                   'ORDER': 1,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': True,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 10}},
                               'ATTRIBUTE_MAP': {'COMPOUND_DETAILS': ('pdbx_entry_details', 'compound_details', None, None),
                                                 'ENTRY_ID': ('pdbx_entry_details', 'entry_id', None, None),
                                                 'NONPOLYMER_DETAILS': ('pdbx_entry_details',
                                                                        'nonpolymer_details',
                                                                        None,
                                                                        None),
                                                 'SEQUENCE_DETAILS': ('pdbx_entry_details', 'sequence_details', None, None),
                                                 'SOURCE_DETAILS': ('pdbx_entry_details', 'source_details', None, None),
                                                 'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                               'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID'), 'TYPE': 'UNIQUE'},
                                           's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                               'MAP_MERGE_INDICES': {'pdbx_entry_details': {'ATTRIBUTES': ('entry_id',), 'TYPE': 'EQUI-JOIN'}},
                               'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                               'TABLE_ID': 'PDBX_ENTRY_DETAILS',
                               'TABLE_NAME': 'pdbx_entry_details',
                               'TABLE_TYPE': 'transactional'},
        'PDBX_EXPTL_CRYSTAL_CRYO_TREATMENT': {'ATTRIBUTES': {'ANNEALING_DETAILS': 'annealing_details',
                                                             'COOLING_DETAILS': 'cooling_details',
                                                             'CRYSTAL_ID': 'crystal_id',
                                                             'FINAL_SOLUTION_DETAILS': 'final_solution_details',
                                                             'SOAKING_DETAILS': 'soaking_details',
                                                             'STRUCTURE_ID': 'Structure_ID'},
                                              'ATTRIBUTE_INFO': {'ANNEALING_DETAILS': {'NULLABLE': True,
                                                                                       'ORDER': 6,
                                                                                       'PRECISION': 0,
                                                                                       'PRIMARY_KEY': False,
                                                                                       'SQL_TYPE': 'VARCHAR',
                                                                                       'WIDTH': 200},
                                                                 'COOLING_DETAILS': {'NULLABLE': True,
                                                                                     'ORDER': 5,
                                                                                     'PRECISION': 0,
                                                                                     'PRIMARY_KEY': False,
                                                                                     'SQL_TYPE': 'VARCHAR',
                                                                                     'WIDTH': 200},
                                                                 'CRYSTAL_ID': {'NULLABLE': False,
                                                                                'ORDER': 2,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': True,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 10},
                                                                 'FINAL_SOLUTION_DETAILS': {'NULLABLE': True,
                                                                                            'ORDER': 3,
                                                                                            'PRECISION': 0,
                                                                                            'PRIMARY_KEY': False,
                                                                                            'SQL_TYPE': 'VARCHAR',
                                                                                            'WIDTH': 200},
                                                                 'SOAKING_DETAILS': {'NULLABLE': True,
                                                                                     'ORDER': 4,
                                                                                     'PRECISION': 0,
                                                                                     'PRIMARY_KEY': False,
                                                                                     'SQL_TYPE': 'VARCHAR',
                                                                                     'WIDTH': 511},
                                                                 'STRUCTURE_ID': {'NULLABLE': False,
                                                                                  'ORDER': 1,
                                                                                  'PRECISION': 0,
                                                                                  'PRIMARY_KEY': True,
                                                                                  'SQL_TYPE': 'VARCHAR',
                                                                                  'WIDTH': 10}},
                                              'ATTRIBUTE_MAP': {'ANNEALING_DETAILS': ('pdbx_exptl_crystal_cryo_treatment',
                                                                                      'annealing_details',
                                                                                      None,
                                                                                      None),
                                                                'COOLING_DETAILS': ('pdbx_exptl_crystal_cryo_treatment',
                                                                                    'cooling_details',
                                                                                    None,
                                                                                    None),
                                                                'CRYSTAL_ID': ('pdbx_exptl_crystal_cryo_treatment',
                                                                               'crystal_id',
                                                                               None,
                                                                               None),
                                                                'FINAL_SOLUTION_DETAILS': ('pdbx_exptl_crystal_cryo_treatment',
                                                                                           'final_solution_details',
                                                                                           None,
                                                                                           None),
                                                                'SOAKING_DETAILS': ('pdbx_exptl_crystal_cryo_treatment',
                                                                                    'soaking_details',
                                                                                    None,
                                                                                    None),
                                                                'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                              'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'CRYSTAL_ID'),
                                                                 'TYPE': 'UNIQUE'},
                                                          's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                              'MAP_MERGE_INDICES': {'pdbx_exptl_crystal_cryo_treatment': {'ATTRIBUTES': ('crystal_id',),
                                                                                                          'TYPE': 'EQUI-JOIN'}},
                                              'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                              'TABLE_ID': 'PDBX_EXPTL_CRYSTAL_CRYO_TREATMENT',
                                              'TABLE_NAME': 'pdbx_exptl_crystal_cryo_treatment',
                                              'TABLE_TYPE': 'transactional'},
        'PDBX_EXPTL_CRYSTAL_GROW_COMP': {'ATTRIBUTES': {'COMP_ID': 'comp_id',
                                                        'COMP_NAME': 'comp_name',
                                                        'CONC': 'conc',
                                                        'CONC_RANGE': 'conc_range',
                                                        'CONC_UNITS': 'conc_units',
                                                        'CRYSTAL_ID': 'crystal_id',
                                                        'SOL_ID': 'sol_id',
                                                        'STRUCTURE_ID': 'Structure_ID'},
                                         'ATTRIBUTE_INFO': {'COMP_ID': {'NULLABLE': False,
                                                                        'ORDER': 3,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': True,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                                            'COMP_NAME': {'NULLABLE': True,
                                                                          'ORDER': 4,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 80},
                                                            'CONC': {'NULLABLE': True,
                                                                     'ORDER': 6,
                                                                     'PRECISION': 6,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'FLOAT',
                                                                     'WIDTH': 10},
                                                            'CONC_RANGE': {'NULLABLE': True,
                                                                           'ORDER': 7,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 80},
                                                            'CONC_UNITS': {'NULLABLE': True,
                                                                           'ORDER': 8,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 80},
                                                            'CRYSTAL_ID': {'NULLABLE': False,
                                                                           'ORDER': 2,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': True,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10},
                                                            'SOL_ID': {'NULLABLE': True,
                                                                       'ORDER': 5,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 80},
                                                            'STRUCTURE_ID': {'NULLABLE': False,
                                                                             'ORDER': 1,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': True,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10}},
                                         'ATTRIBUTE_MAP': {'COMP_ID': ('pdbx_exptl_crystal_grow_comp', 'comp_id', None, None),
                                                           'COMP_NAME': ('pdbx_exptl_crystal_grow_comp',
                                                                         'comp_name',
                                                                         None,
                                                                         None),
                                                           'CONC': ('pdbx_exptl_crystal_grow_comp', 'conc', None, None),
                                                           'CONC_RANGE': ('pdbx_exptl_crystal_grow_comp',
                                                                          'conc_range',
                                                                          None,
                                                                          None),
                                                           'CONC_UNITS': ('pdbx_exptl_crystal_grow_comp',
                                                                          'conc_units',
                                                                          None,
                                                                          None),
                                                           'CRYSTAL_ID': ('pdbx_exptl_crystal_grow_comp',
                                                                          'crystal_id',
                                                                          None,
                                                                          None),
                                                           'SOL_ID': ('pdbx_exptl_crystal_grow_comp', 'sol_id', None, None),
                                                           'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                         'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'CRYSTAL_ID', 'COMP_ID'),
                                                            'TYPE': 'UNIQUE'},
                                                     's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                         'MAP_MERGE_INDICES': {'pdbx_exptl_crystal_grow_comp': {'ATTRIBUTES': ('crystal_id',
                                                                                                               'comp_id'),
                                                                                                'TYPE': 'EQUI-JOIN'}},
                                         'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                         'TABLE_ID': 'PDBX_EXPTL_CRYSTAL_GROW_COMP',
                                         'TABLE_NAME': 'pdbx_exptl_crystal_grow_comp',
                                         'TABLE_TYPE': 'transactional'},
        'PDBX_EXPTL_CRYSTAL_GROW_SOL': {'ATTRIBUTES': {'CRYSTAL_ID': 'crystal_id',
                                                       'PH': 'pH',
                                                       'SOL_ID': 'sol_id',
                                                       'STRUCTURE_ID': 'Structure_ID',
                                                       'VOLUME': 'volume',
                                                       'VOLUME_UNITS': 'volume_units'},
                                        'ATTRIBUTE_INFO': {'CRYSTAL_ID': {'NULLABLE': False,
                                                                          'ORDER': 2,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': True,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                           'PH': {'NULLABLE': True,
                                                                  'ORDER': 6,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10},
                                                           'SOL_ID': {'NULLABLE': False,
                                                                      'ORDER': 3,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 80},
                                                           'STRUCTURE_ID': {'NULLABLE': False,
                                                                            'ORDER': 1,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': True,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 10},
                                                           'VOLUME': {'NULLABLE': True,
                                                                      'ORDER': 4,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                                           'VOLUME_UNITS': {'NULLABLE': True,
                                                                            'ORDER': 5,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 80}},
                                        'ATTRIBUTE_MAP': {'CRYSTAL_ID': ('pdbx_exptl_crystal_grow_sol',
                                                                         'crystal_id',
                                                                         None,
                                                                         None),
                                                          'PH': ('pdbx_exptl_crystal_grow_sol', 'pH', None, None),
                                                          'SOL_ID': ('pdbx_exptl_crystal_grow_sol', 'sol_id', None, None),
                                                          'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                          'VOLUME': ('pdbx_exptl_crystal_grow_sol', 'volume', None, None),
                                                          'VOLUME_UNITS': ('pdbx_exptl_crystal_grow_sol',
                                                                           'volume_units',
                                                                           None,
                                                                           None)},
                                        'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'CRYSTAL_ID', 'SOL_ID'),
                                                           'TYPE': 'UNIQUE'},
                                                    's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                        'MAP_MERGE_INDICES': {'pdbx_exptl_crystal_grow_sol': {'ATTRIBUTES': ('crystal_id',
                                                                                                             'sol_id'),
                                                                                              'TYPE': 'EQUI-JOIN'}},
                                        'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                        'TABLE_ID': 'PDBX_EXPTL_CRYSTAL_GROW_SOL',
                                        'TABLE_NAME': 'pdbx_exptl_crystal_grow_sol',
                                        'TABLE_TYPE': 'transactional'},
        'PDBX_EXPTL_PD': {'ATTRIBUTES': {'ENTRY_ID': 'entry_id',
                                         'SPEC_PREPARATION': 'spec_preparation',
                                         'SPEC_PREPARATION_PH': 'spec_preparation_pH',
                                         'SPEC_PREPARATION_PH_RANGE': 'spec_preparation_pH_range',
                                         'STRUCTURE_ID': 'Structure_ID'},
                          'ATTRIBUTE_INFO': {'ENTRY_ID': {'NULLABLE': False,
                                                          'ORDER': 2,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': True,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 10},
                                             'SPEC_PREPARATION': {'NULLABLE': True,
                                                                  'ORDER': 5,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 200},
                                             'SPEC_PREPARATION_PH': {'NULLABLE': True,
                                                                     'ORDER': 3,
                                                                     'PRECISION': 6,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'FLOAT',
                                                                     'WIDTH': 10},
                                             'SPEC_PREPARATION_PH_RANGE': {'NULLABLE': True,
                                                                           'ORDER': 4,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 80},
                                             'STRUCTURE_ID': {'NULLABLE': False,
                                                              'ORDER': 1,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10}},
                          'ATTRIBUTE_MAP': {'ENTRY_ID': ('pdbx_exptl_pd', 'entry_id', None, None),
                                            'SPEC_PREPARATION': ('pdbx_exptl_pd', 'spec_preparation', None, None),
                                            'SPEC_PREPARATION_PH': ('pdbx_exptl_pd', 'spec_preparation_pH', None, None),
                                            'SPEC_PREPARATION_PH_RANGE': ('pdbx_exptl_pd',
                                                                          'spec_preparation_pH_range',
                                                                          None,
                                                                          None),
                                            'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                          'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID'), 'TYPE': 'UNIQUE'},
                                      's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                          'MAP_MERGE_INDICES': {'pdbx_exptl_pd': {'ATTRIBUTES': ('entry_id',), 'TYPE': 'EQUI-JOIN'}},
                          'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                          'TABLE_ID': 'PDBX_EXPTL_PD',
                          'TABLE_NAME': 'pdbx_exptl_pd',
                          'TABLE_TYPE': 'transactional'},
        'PDBX_FAMILY_PRD_AUDIT': {'ATTRIBUTES': {'ACTION_TYPE': 'action_type',
                                                 'ANNOTATOR': 'annotator',
                                                 'DATE': 'date',
                                                 'DETAILS': 'details',
                                                 'FAMILY_PRD_ID': 'family_prd_id',
                                                 'PROCESSING_SITE': 'processing_site',
                                                 'STRUCTURE_ID': 'Structure_ID'},
                                  'ATTRIBUTE_INFO': {'ACTION_TYPE': {'NULLABLE': False,
                                                                     'ORDER': 7,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': True,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 80},
                                                     'ANNOTATOR': {'NULLABLE': True,
                                                                   'ORDER': 4,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 10},
                                                     'DATE': {'NULLABLE': False,
                                                              'ORDER': 3,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'DATETIME',
                                                              'WIDTH': 15},
                                                     'DETAILS': {'NULLABLE': True,
                                                                 'ORDER': 6,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 200},
                                                     'FAMILY_PRD_ID': {'NULLABLE': False,
                                                                       'ORDER': 2,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': True,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                     'PROCESSING_SITE': {'NULLABLE': True,
                                                                         'ORDER': 5,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                                     'STRUCTURE_ID': {'NULLABLE': False,
                                                                      'ORDER': 1,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10}},
                                  'ATTRIBUTE_MAP': {'ACTION_TYPE': ('pdbx_family_prd_audit', 'action_type', None, None),
                                                    'ANNOTATOR': ('pdbx_family_prd_audit', 'annotator', None, None),
                                                    'DATE': ('pdbx_family_prd_audit', 'date', None, None),
                                                    'DETAILS': ('pdbx_family_prd_audit', 'details', None, None),
                                                    'FAMILY_PRD_ID': ('pdbx_family_prd_audit', 'family_prd_id', None, None),
                                                    'PROCESSING_SITE': ('pdbx_family_prd_audit',
                                                                        'processing_site',
                                                                        None,
                                                                        None),
                                                    'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                  'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'FAMILY_PRD_ID', 'DATE', 'ACTION_TYPE'),
                                                     'TYPE': 'UNIQUE'},
                                              's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                  'MAP_MERGE_INDICES': {'pdbx_family_prd_audit': {'ATTRIBUTES': ('family_prd_id',
                                                                                                 'date',
                                                                                                 'action_type'),
                                                                                  'TYPE': 'EQUI-JOIN'}},
                                  'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                  'TABLE_ID': 'PDBX_FAMILY_PRD_AUDIT',
                                  'TABLE_NAME': 'pdbx_family_prd_audit',
                                  'TABLE_TYPE': 'transactional'},
        'PDBX_FEATURE_ASSEMBLY': {'ATTRIBUTES': {'ASSEMBLY_ID': 'assembly_id',
                                                 'FEATURE': 'feature',
                                                 'FEATURE_ASSIGNED_BY': 'feature_assigned_by',
                                                 'FEATURE_CITATION_ID': 'feature_citation_id',
                                                 'FEATURE_IDENTIFIER': 'feature_identifier',
                                                 'FEATURE_NAME': 'feature_name',
                                                 'FEATURE_SOFTWARE_ID': 'feature_software_id',
                                                 'FEATURE_TYPE': 'feature_type',
                                                 'ID': 'id',
                                                 'STRUCTURE_ID': 'Structure_ID'},
                                  'ATTRIBUTE_INFO': {'ASSEMBLY_ID': {'NULLABLE': True,
                                                                     'ORDER': 3,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 80},
                                                     'FEATURE': {'NULLABLE': True,
                                                                 'ORDER': 6,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 200},
                                                     'FEATURE_ASSIGNED_BY': {'NULLABLE': True,
                                                                             'ORDER': 8,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 200},
                                                     'FEATURE_CITATION_ID': {'NULLABLE': True,
                                                                             'ORDER': 9,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                     'FEATURE_IDENTIFIER': {'NULLABLE': True,
                                                                            'ORDER': 7,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 200},
                                                     'FEATURE_NAME': {'NULLABLE': True,
                                                                      'ORDER': 4,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 200},
                                                     'FEATURE_SOFTWARE_ID': {'NULLABLE': True,
                                                                             'ORDER': 10,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 200},
                                                     'FEATURE_TYPE': {'NULLABLE': True,
                                                                      'ORDER': 5,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 200},
                                                     'ID': {'NULLABLE': False,
                                                            'ORDER': 2,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': True,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 10},
                                                     'STRUCTURE_ID': {'NULLABLE': False,
                                                                      'ORDER': 1,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10}},
                                  'ATTRIBUTE_MAP': {'ASSEMBLY_ID': ('pdbx_feature_assembly', 'assembly_id', None, None),
                                                    'FEATURE': ('pdbx_feature_assembly', 'feature', None, None),
                                                    'FEATURE_ASSIGNED_BY': ('pdbx_feature_assembly',
                                                                            'feature_assigned_by',
                                                                            None,
                                                                            None),
                                                    'FEATURE_CITATION_ID': ('pdbx_feature_assembly',
                                                                            'feature_citation_id',
                                                                            None,
                                                                            None),
                                                    'FEATURE_IDENTIFIER': ('pdbx_feature_assembly',
                                                                           'feature_identifier',
                                                                           None,
                                                                           None),
                                                    'FEATURE_NAME': ('pdbx_feature_assembly', 'feature_name', None, None),
                                                    'FEATURE_SOFTWARE_ID': ('pdbx_feature_assembly',
                                                                            'feature_software_id',
                                                                            None,
                                                                            None),
                                                    'FEATURE_TYPE': ('pdbx_feature_assembly', 'feature_type', None, None),
                                                    'ID': ('pdbx_feature_assembly', 'id', None, None),
                                                    'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                  'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                              's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                  'MAP_MERGE_INDICES': {'pdbx_feature_assembly': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                                  'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                  'TABLE_ID': 'PDBX_FEATURE_ASSEMBLY',
                                  'TABLE_NAME': 'pdbx_feature_assembly',
                                  'TABLE_TYPE': 'transactional'},
        'PDBX_FEATURE_DOMAIN': {'ATTRIBUTES': {'DOMAIN_ID': 'domain_id',
                                               'FEATURE': 'feature',
                                               'FEATURE_ASSIGNED_BY': 'feature_assigned_by',
                                               'FEATURE_CITATION_ID': 'feature_citation_id',
                                               'FEATURE_IDENTIFIER': 'feature_identifier',
                                               'FEATURE_NAME': 'feature_name',
                                               'FEATURE_SOFTWARE_ID': 'feature_software_id',
                                               'FEATURE_TYPE': 'feature_type',
                                               'ID': 'id',
                                               'STRUCTURE_ID': 'Structure_ID'},
                                'ATTRIBUTE_INFO': {'DOMAIN_ID': {'NULLABLE': True,
                                                                 'ORDER': 3,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                                   'FEATURE': {'NULLABLE': True,
                                                               'ORDER': 6,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 200},
                                                   'FEATURE_ASSIGNED_BY': {'NULLABLE': True,
                                                                           'ORDER': 8,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 200},
                                                   'FEATURE_CITATION_ID': {'NULLABLE': True,
                                                                           'ORDER': 9,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10},
                                                   'FEATURE_IDENTIFIER': {'NULLABLE': True,
                                                                          'ORDER': 7,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 200},
                                                   'FEATURE_NAME': {'NULLABLE': True,
                                                                    'ORDER': 4,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 200},
                                                   'FEATURE_SOFTWARE_ID': {'NULLABLE': True,
                                                                           'ORDER': 10,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 200},
                                                   'FEATURE_TYPE': {'NULLABLE': True,
                                                                    'ORDER': 5,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 200},
                                                   'ID': {'NULLABLE': False,
                                                          'ORDER': 2,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': True,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 10},
                                                   'STRUCTURE_ID': {'NULLABLE': False,
                                                                    'ORDER': 1,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': True,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10}},
                                'ATTRIBUTE_MAP': {'DOMAIN_ID': ('pdbx_feature_domain', 'domain_id', None, None),
                                                  'FEATURE': ('pdbx_feature_domain', 'feature', None, None),
                                                  'FEATURE_ASSIGNED_BY': ('pdbx_feature_domain',
                                                                          'feature_assigned_by',
                                                                          None,
                                                                          None),
                                                  'FEATURE_CITATION_ID': ('pdbx_feature_domain',
                                                                          'feature_citation_id',
                                                                          None,
                                                                          None),
                                                  'FEATURE_IDENTIFIER': ('pdbx_feature_domain',
                                                                         'feature_identifier',
                                                                         None,
                                                                         None),
                                                  'FEATURE_NAME': ('pdbx_feature_domain', 'feature_name', None, None),
                                                  'FEATURE_SOFTWARE_ID': ('pdbx_feature_domain',
                                                                          'feature_software_id',
                                                                          None,
                                                                          None),
                                                  'FEATURE_TYPE': ('pdbx_feature_domain', 'feature_type', None, None),
                                                  'ID': ('pdbx_feature_domain', 'id', None, None),
                                                  'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                            's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                'MAP_MERGE_INDICES': {'pdbx_feature_domain': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                                'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                'TABLE_ID': 'PDBX_FEATURE_DOMAIN',
                                'TABLE_NAME': 'pdbx_feature_domain',
                                'TABLE_TYPE': 'transactional'},
        'PDBX_FEATURE_ENTRY': {'ATTRIBUTES': {'FEATURE': 'feature',
                                              'FEATURE_ASSIGNED_BY': 'feature_assigned_by',
                                              'FEATURE_CITATION_ID': 'feature_citation_id',
                                              'FEATURE_IDENTIFIER': 'feature_identifier',
                                              'FEATURE_NAME': 'feature_name',
                                              'FEATURE_SOFTWARE_ID': 'feature_software_id',
                                              'FEATURE_TYPE': 'feature_type',
                                              'ID': 'id',
                                              'STRUCTURE_ID': 'Structure_ID'},
                               'ATTRIBUTE_INFO': {'FEATURE': {'NULLABLE': True,
                                                              'ORDER': 5,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 200},
                                                  'FEATURE_ASSIGNED_BY': {'NULLABLE': True,
                                                                          'ORDER': 7,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 200},
                                                  'FEATURE_CITATION_ID': {'NULLABLE': True,
                                                                          'ORDER': 8,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                  'FEATURE_IDENTIFIER': {'NULLABLE': True,
                                                                         'ORDER': 6,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 200},
                                                  'FEATURE_NAME': {'NULLABLE': True,
                                                                   'ORDER': 3,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 200},
                                                  'FEATURE_SOFTWARE_ID': {'NULLABLE': True,
                                                                          'ORDER': 9,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 200},
                                                  'FEATURE_TYPE': {'NULLABLE': True,
                                                                   'ORDER': 4,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 200},
                                                  'ID': {'NULLABLE': False,
                                                         'ORDER': 2,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': True,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 10},
                                                  'STRUCTURE_ID': {'NULLABLE': False,
                                                                   'ORDER': 1,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': True,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 10}},
                               'ATTRIBUTE_MAP': {'FEATURE': ('pdbx_feature_entry', 'feature', None, None),
                                                 'FEATURE_ASSIGNED_BY': ('pdbx_feature_entry',
                                                                         'feature_assigned_by',
                                                                         None,
                                                                         None),
                                                 'FEATURE_CITATION_ID': ('pdbx_feature_entry',
                                                                         'feature_citation_id',
                                                                         None,
                                                                         None),
                                                 'FEATURE_IDENTIFIER': ('pdbx_feature_entry',
                                                                        'feature_identifier',
                                                                        None,
                                                                        None),
                                                 'FEATURE_NAME': ('pdbx_feature_entry', 'feature_name', None, None),
                                                 'FEATURE_SOFTWARE_ID': ('pdbx_feature_entry',
                                                                         'feature_software_id',
                                                                         None,
                                                                         None),
                                                 'FEATURE_TYPE': ('pdbx_feature_entry', 'feature_type', None, None),
                                                 'ID': ('pdbx_feature_entry', 'id', None, None),
                                                 'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                               'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                           's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                               'MAP_MERGE_INDICES': {'pdbx_feature_entry': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                               'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                               'TABLE_ID': 'PDBX_FEATURE_ENTRY',
                               'TABLE_NAME': 'pdbx_feature_entry',
                               'TABLE_TYPE': 'transactional'},
        'PDBX_FEATURE_MONOMER': {'ATTRIBUTES': {'AUTH_ASYM_ID': 'auth_asym_id',
                                                'AUTH_COMP_ID': 'auth_comp_id',
                                                'AUTH_SEQ_ID': 'auth_seq_id',
                                                'FEATURE': 'feature',
                                                'FEATURE_ASSIGNED_BY': 'feature_assigned_by',
                                                'FEATURE_CITATION_ID': 'feature_citation_id',
                                                'FEATURE_IDENTIFIER': 'feature_identifier',
                                                'FEATURE_NAME': 'feature_name',
                                                'FEATURE_SOFTWARE_ID': 'feature_software_id',
                                                'FEATURE_TYPE': 'feature_type',
                                                'ID': 'id',
                                                'LABEL_ALT_ID': 'label_alt_id',
                                                'LABEL_ASYM_ID': 'label_asym_id',
                                                'LABEL_COMP_ID': 'label_comp_id',
                                                'LABEL_SEQ_ID': 'label_seq_id',
                                                'STRUCTURE_ID': 'Structure_ID'},
                                 'ATTRIBUTE_INFO': {'AUTH_ASYM_ID': {'NULLABLE': True,
                                                                     'ORDER': 14,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                                    'AUTH_COMP_ID': {'NULLABLE': True,
                                                                     'ORDER': 15,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                                    'AUTH_SEQ_ID': {'NULLABLE': True,
                                                                    'ORDER': 16,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10},
                                                    'FEATURE': {'NULLABLE': True,
                                                                'ORDER': 5,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 200},
                                                    'FEATURE_ASSIGNED_BY': {'NULLABLE': True,
                                                                            'ORDER': 7,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 200},
                                                    'FEATURE_CITATION_ID': {'NULLABLE': True,
                                                                            'ORDER': 8,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 10},
                                                    'FEATURE_IDENTIFIER': {'NULLABLE': True,
                                                                           'ORDER': 6,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 200},
                                                    'FEATURE_NAME': {'NULLABLE': True,
                                                                     'ORDER': 3,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 200},
                                                    'FEATURE_SOFTWARE_ID': {'NULLABLE': True,
                                                                            'ORDER': 9,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 200},
                                                    'FEATURE_TYPE': {'NULLABLE': True,
                                                                     'ORDER': 4,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 200},
                                                    'ID': {'NULLABLE': False,
                                                           'ORDER': 2,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': True,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 10},
                                                    'LABEL_ALT_ID': {'NULLABLE': True,
                                                                     'ORDER': 10,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                                    'LABEL_ASYM_ID': {'NULLABLE': True,
                                                                      'ORDER': 11,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                                    'LABEL_COMP_ID': {'NULLABLE': True,
                                                                      'ORDER': 12,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                                    'LABEL_SEQ_ID': {'NULLABLE': True,
                                                                     'ORDER': 13,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'INT',
                                                                     'WIDTH': 10},
                                                    'STRUCTURE_ID': {'NULLABLE': False,
                                                                     'ORDER': 1,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': True,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10}},
                                 'ATTRIBUTE_MAP': {'AUTH_ASYM_ID': ('pdbx_feature_monomer', 'auth_asym_id', None, None),
                                                   'AUTH_COMP_ID': ('pdbx_feature_monomer', 'auth_comp_id', None, None),
                                                   'AUTH_SEQ_ID': ('pdbx_feature_monomer', 'auth_seq_id', None, None),
                                                   'FEATURE': ('pdbx_feature_monomer', 'feature', None, None),
                                                   'FEATURE_ASSIGNED_BY': ('pdbx_feature_monomer',
                                                                           'feature_assigned_by',
                                                                           None,
                                                                           None),
                                                   'FEATURE_CITATION_ID': ('pdbx_feature_monomer',
                                                                           'feature_citation_id',
                                                                           None,
                                                                           None),
                                                   'FEATURE_IDENTIFIER': ('pdbx_feature_monomer',
                                                                          'feature_identifier',
                                                                          None,
                                                                          None),
                                                   'FEATURE_NAME': ('pdbx_feature_monomer', 'feature_name', None, None),
                                                   'FEATURE_SOFTWARE_ID': ('pdbx_feature_monomer',
                                                                           'feature_software_id',
                                                                           None,
                                                                           None),
                                                   'FEATURE_TYPE': ('pdbx_feature_monomer', 'feature_type', None, None),
                                                   'ID': ('pdbx_feature_monomer', 'id', None, None),
                                                   'LABEL_ALT_ID': ('pdbx_feature_monomer', 'label_alt_id', None, None),
                                                   'LABEL_ASYM_ID': ('pdbx_feature_monomer', 'label_asym_id', None, None),
                                                   'LABEL_COMP_ID': ('pdbx_feature_monomer', 'label_comp_id', None, None),
                                                   'LABEL_SEQ_ID': ('pdbx_feature_monomer', 'label_seq_id', None, None),
                                                   'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                 'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                             's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                 'MAP_MERGE_INDICES': {'pdbx_feature_monomer': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                                 'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                 'TABLE_ID': 'PDBX_FEATURE_MONOMER',
                                 'TABLE_NAME': 'pdbx_feature_monomer',
                                 'TABLE_TYPE': 'transactional'},
        'PDBX_FEATURE_SEQUENCE_RANGE': {'ATTRIBUTES': {'FEATURE': 'feature',
                                                       'FEATURE_ASSIGNED_BY': 'feature_assigned_by',
                                                       'FEATURE_CITATION_ID': 'feature_citation_id',
                                                       'FEATURE_IDENTIFIER': 'feature_identifier',
                                                       'FEATURE_NAME': 'feature_name',
                                                       'FEATURE_SOFTWARE_ID': 'feature_software_id',
                                                       'FEATURE_TYPE': 'feature_type',
                                                       'ID': 'id',
                                                       'SEQ_RANGE_ID': 'seq_range_id',
                                                       'STRUCTURE_ID': 'Structure_ID'},
                                        'ATTRIBUTE_INFO': {'FEATURE': {'NULLABLE': True,
                                                                       'ORDER': 6,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 200},
                                                           'FEATURE_ASSIGNED_BY': {'NULLABLE': True,
                                                                                   'ORDER': 8,
                                                                                   'PRECISION': 0,
                                                                                   'PRIMARY_KEY': False,
                                                                                   'SQL_TYPE': 'VARCHAR',
                                                                                   'WIDTH': 200},
                                                           'FEATURE_CITATION_ID': {'NULLABLE': True,
                                                                                   'ORDER': 9,
                                                                                   'PRECISION': 0,
                                                                                   'PRIMARY_KEY': False,
                                                                                   'SQL_TYPE': 'VARCHAR',
                                                                                   'WIDTH': 10},
                                                           'FEATURE_IDENTIFIER': {'NULLABLE': True,
                                                                                  'ORDER': 7,
                                                                                  'PRECISION': 0,
                                                                                  'PRIMARY_KEY': False,
                                                                                  'SQL_TYPE': 'VARCHAR',
                                                                                  'WIDTH': 200},
                                                           'FEATURE_NAME': {'NULLABLE': True,
                                                                            'ORDER': 4,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 200},
                                                           'FEATURE_SOFTWARE_ID': {'NULLABLE': True,
                                                                                   'ORDER': 10,
                                                                                   'PRECISION': 0,
                                                                                   'PRIMARY_KEY': False,
                                                                                   'SQL_TYPE': 'VARCHAR',
                                                                                   'WIDTH': 200},
                                                           'FEATURE_TYPE': {'NULLABLE': True,
                                                                            'ORDER': 5,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 200},
                                                           'ID': {'NULLABLE': False,
                                                                  'ORDER': 2,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': True,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10},
                                                           'SEQ_RANGE_ID': {'NULLABLE': True,
                                                                            'ORDER': 3,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 10},
                                                           'STRUCTURE_ID': {'NULLABLE': False,
                                                                            'ORDER': 1,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': True,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 10}},
                                        'ATTRIBUTE_MAP': {'FEATURE': ('pdbx_feature_sequence_range', 'feature', None, None),
                                                          'FEATURE_ASSIGNED_BY': ('pdbx_feature_sequence_range',
                                                                                  'feature_assigned_by',
                                                                                  None,
                                                                                  None),
                                                          'FEATURE_CITATION_ID': ('pdbx_feature_sequence_range',
                                                                                  'feature_citation_id',
                                                                                  None,
                                                                                  None),
                                                          'FEATURE_IDENTIFIER': ('pdbx_feature_sequence_range',
                                                                                 'feature_identifier',
                                                                                 None,
                                                                                 None),
                                                          'FEATURE_NAME': ('pdbx_feature_sequence_range',
                                                                           'feature_name',
                                                                           None,
                                                                           None),
                                                          'FEATURE_SOFTWARE_ID': ('pdbx_feature_sequence_range',
                                                                                  'feature_software_id',
                                                                                  None,
                                                                                  None),
                                                          'FEATURE_TYPE': ('pdbx_feature_sequence_range',
                                                                           'feature_type',
                                                                           None,
                                                                           None),
                                                          'ID': ('pdbx_feature_sequence_range', 'id', None, None),
                                                          'SEQ_RANGE_ID': ('pdbx_feature_sequence_range',
                                                                           'seq_range_id',
                                                                           None,
                                                                           None),
                                                          'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                        'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                                    's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                        'MAP_MERGE_INDICES': {'pdbx_feature_sequence_range': {'ATTRIBUTES': ('id',),
                                                                                              'TYPE': 'EQUI-JOIN'}},
                                        'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                        'TABLE_ID': 'PDBX_FEATURE_SEQUENCE_RANGE',
                                        'TABLE_NAME': 'pdbx_feature_sequence_range',
                                        'TABLE_TYPE': 'transactional'},
        'PDBX_HELICAL_SYMMETRY': {'ATTRIBUTES': {'CIRCULAR_SYMMETRY': 'circular_symmetry',
                                                 'DYAD_AXIS': 'dyad_axis',
                                                 'ENTRY_ID': 'entry_id',
                                                 'NUMBER_OF_OPERATIONS': 'number_of_operations',
                                                 'N_SUBUNITS_DIVISOR': 'n_subunits_divisor',
                                                 'RISE_PER_N_SUBUNITS': 'rise_per_n_subunits',
                                                 'ROTATION_PER_N_SUBUNITS': 'rotation_per_n_subunits',
                                                 'STRUCTURE_ID': 'Structure_ID'},
                                  'ATTRIBUTE_INFO': {'CIRCULAR_SYMMETRY': {'NULLABLE': True,
                                                                           'ORDER': 8,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'INT',
                                                                           'WIDTH': 10},
                                                     'DYAD_AXIS': {'NULLABLE': True,
                                                                   'ORDER': 7,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 10},
                                                     'ENTRY_ID': {'NULLABLE': False,
                                                                  'ORDER': 2,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': True,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10},
                                                     'NUMBER_OF_OPERATIONS': {'NULLABLE': True,
                                                                              'ORDER': 3,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'INT',
                                                                              'WIDTH': 10},
                                                     'N_SUBUNITS_DIVISOR': {'NULLABLE': True,
                                                                            'ORDER': 6,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'INT',
                                                                            'WIDTH': 10},
                                                     'RISE_PER_N_SUBUNITS': {'NULLABLE': True,
                                                                             'ORDER': 5,
                                                                             'PRECISION': 6,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'FLOAT',
                                                                             'WIDTH': 10},
                                                     'ROTATION_PER_N_SUBUNITS': {'NULLABLE': True,
                                                                                 'ORDER': 4,
                                                                                 'PRECISION': 6,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'FLOAT',
                                                                                 'WIDTH': 10},
                                                     'STRUCTURE_ID': {'NULLABLE': False,
                                                                      'ORDER': 1,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10}},
                                  'ATTRIBUTE_MAP': {'CIRCULAR_SYMMETRY': ('pdbx_helical_symmetry',
                                                                          'circular_symmetry',
                                                                          None,
                                                                          None),
                                                    'DYAD_AXIS': ('pdbx_helical_symmetry', 'dyad_axis', None, None),
                                                    'ENTRY_ID': ('pdbx_helical_symmetry', 'entry_id', None, None),
                                                    'NUMBER_OF_OPERATIONS': ('pdbx_helical_symmetry',
                                                                             'number_of_operations',
                                                                             None,
                                                                             None),
                                                    'N_SUBUNITS_DIVISOR': ('pdbx_helical_symmetry',
                                                                           'n_subunits_divisor',
                                                                           None,
                                                                           None),
                                                    'RISE_PER_N_SUBUNITS': ('pdbx_helical_symmetry',
                                                                            'rise_per_n_subunits',
                                                                            None,
                                                                            None),
                                                    'ROTATION_PER_N_SUBUNITS': ('pdbx_helical_symmetry',
                                                                                'rotation_per_n_subunits',
                                                                                None,
                                                                                None),
                                                    'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                  'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID'), 'TYPE': 'UNIQUE'},
                                              's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                  'MAP_MERGE_INDICES': {'pdbx_helical_symmetry': {'ATTRIBUTES': ('entry_id',),
                                                                                  'TYPE': 'EQUI-JOIN'}},
                                  'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                  'TABLE_ID': 'PDBX_HELICAL_SYMMETRY',
                                  'TABLE_NAME': 'pdbx_helical_symmetry',
                                  'TABLE_TYPE': 'transactional'},
        'PDBX_MOLECULE': {'ATTRIBUTES': {'ASYM_ID': 'asym_id',
                                         'INSTANCE_ID': 'instance_id',
                                         'PRD_ID': 'prd_id',
                                         'STRUCTURE_ID': 'Structure_ID'},
                          'ATTRIBUTE_INFO': {'ASYM_ID': {'NULLABLE': False,
                                                         'ORDER': 4,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': True,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 10},
                                             'INSTANCE_ID': {'NULLABLE': False,
                                                             'ORDER': 3,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'INT',
                                                             'WIDTH': 10},
                                             'PRD_ID': {'NULLABLE': False,
                                                        'ORDER': 2,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': True,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 10},
                                             'STRUCTURE_ID': {'NULLABLE': False,
                                                              'ORDER': 1,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10}},
                          'ATTRIBUTE_MAP': {'ASYM_ID': ('pdbx_molecule', 'asym_id', None, None),
                                            'INSTANCE_ID': ('pdbx_molecule', 'instance_id', None, None),
                                            'PRD_ID': ('pdbx_molecule', 'prd_id', None, None),
                                            'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                          'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'PRD_ID', 'INSTANCE_ID', 'ASYM_ID'),
                                             'TYPE': 'UNIQUE'},
                                      's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                          'MAP_MERGE_INDICES': {'pdbx_molecule': {'ATTRIBUTES': ('prd_id', 'instance_id', 'asym_id'),
                                                                  'TYPE': 'EQUI-JOIN'}},
                          'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                          'TABLE_ID': 'PDBX_MOLECULE',
                          'TABLE_NAME': 'pdbx_molecule',
                          'TABLE_TYPE': 'transactional'},
        'PDBX_MOLECULE_FEATURES': {'ATTRIBUTES': {'CLASS': 'class',
                                                  'DETAILS': 'details',
                                                  'NAME': 'name',
                                                  'PRD_ID': 'prd_id',
                                                  'STRUCTURE_ID': 'Structure_ID',
                                                  'TYPE': 'type'},
                                   'ATTRIBUTE_INFO': {'CLASS': {'NULLABLE': True,
                                                                'ORDER': 3,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 200},
                                                      'DETAILS': {'NULLABLE': True,
                                                                  'ORDER': 6,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 200},
                                                      'NAME': {'NULLABLE': True,
                                                               'ORDER': 5,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 200},
                                                      'PRD_ID': {'NULLABLE': False,
                                                                 'ORDER': 2,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': True,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                                      'STRUCTURE_ID': {'NULLABLE': False,
                                                                       'ORDER': 1,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': True,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                      'TYPE': {'NULLABLE': True,
                                                               'ORDER': 4,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 80}},
                                   'ATTRIBUTE_MAP': {'CLASS': ('pdbx_molecule_features', 'class', None, None),
                                                     'DETAILS': ('pdbx_molecule_features', 'details', None, None),
                                                     'NAME': ('pdbx_molecule_features', 'name', None, None),
                                                     'PRD_ID': ('pdbx_molecule_features', 'prd_id', None, None),
                                                     'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                     'TYPE': ('pdbx_molecule_features', 'type', None, None)},
                                   'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'PRD_ID'), 'TYPE': 'UNIQUE'},
                                               's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                   'MAP_MERGE_INDICES': {'pdbx_molecule_features': {'ATTRIBUTES': ('prd_id',),
                                                                                    'TYPE': 'EQUI-JOIN'}},
                                   'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                   'TABLE_ID': 'PDBX_MOLECULE_FEATURES',
                                   'TABLE_NAME': 'pdbx_molecule_features',
                                   'TABLE_TYPE': 'transactional'},
        'PDBX_NMR_CONSTRAINTS': {'ATTRIBUTES': {'DISULFIDE_BOND_CONSTRAINTS_TOTAL_COUNT': 'disulfide_bond_constraints_total_count',
                                                'ENTRY_ID': 'entry_id',
                                                'HYDROGEN_BOND_CONSTRAINTS_TOTAL_COUNT': 'hydrogen_bond_constraints_total_count',
                                                'NA_ALPHA_ANGLE_CONSTRAINTS_TOTAL_COUNT': 'NA_alpha_angle_constraints_total_count',
                                                'NA_BETA_ANGLE_CONSTRAINTS_TOTAL_COUNT': 'NA_beta_angle_constraints_total_count',
                                                'NA_CHI_ANGLE_CONSTRAINTS_TOTAL_COUNT': 'NA_chi_angle_constraints_total_count',
                                                'NA_DELTA_ANGLE_CONSTRAINTS_TOTAL_COUNT': 'NA_delta_angle_constraints_total_count',
                                                'NA_EPSILON_ANGLE_CONSTRAINTS_TOTAL_COUNT': 'NA_epsilon_angle_constraints_total_count',
                                                'NA_GAMMA_ANGLE_CONSTRAINTS_TOTAL_COUNT': 'NA_gamma_angle_constraints_total_count',
                                                'NA_OTHER_ANGLE_CONSTRAINTS_TOTAL_COUNT': 'NA_other_angle_constraints_total_count',
                                                'NA_SUGAR_PUCKER_CONSTRAINTS_TOTAL_COUNT': 'NA_sugar_pucker_constraints_total_count',
                                                'NOE_CONSTRAINTS_TOTAL': 'NOE_constraints_total',
                                                'NOE_INTERENTITY_TOTAL_COUNT': 'NOE_interentity_total_count',
                                                'NOE_INTERPROTON_DISTANCE_EVALUATION': 'NOE_interproton_distance_evaluation',
                                                'NOE_INTRARESIDUE_TOTAL_COUNT': 'NOE_intraresidue_total_count',
                                                'NOE_LONG_RANGE_TOTAL_COUNT': 'NOE_long_range_total_count',
                                                'NOE_MEDIUM_RANGE_TOTAL_COUNT': 'NOE_medium_range_total_count',
                                                'NOE_MOTIONAL_AVERAGING_CORRECTION': 'NOE_motional_averaging_correction',
                                                'NOE_PSEUDOATOM_CORRECTIONS': 'NOE_pseudoatom_corrections',
                                                'NOE_SEQUENTIAL_TOTAL_COUNT': 'NOE_sequential_total_count',
                                                'PROTEIN_CHI_ANGLE_CONSTRAINTS_TOTAL_COUNT': 'protein_chi_angle_constraints_total_count',
                                                'PROTEIN_OTHER_ANGLE_CONSTRAINTS_TOTAL_COUNT': 'protein_other_angle_constraints_total_count',
                                                'PROTEIN_PHI_ANGLE_CONSTRAINTS_TOTAL_COUNT': 'protein_phi_angle_constraints_total_count',
                                                'PROTEIN_PSI_ANGLE_CONSTRAINTS_TOTAL_COUNT': 'protein_psi_angle_constraints_total_count',
                                                'STRUCTURE_ID': 'Structure_ID'},
                                 'ATTRIBUTE_INFO': {'DISULFIDE_BOND_CONSTRAINTS_TOTAL_COUNT': {'NULLABLE': True,
                                                                                               'ORDER': 17,
                                                                                               'PRECISION': 0,
                                                                                               'PRIMARY_KEY': False,
                                                                                               'SQL_TYPE': 'INT',
                                                                                               'WIDTH': 10},
                                                    'ENTRY_ID': {'NULLABLE': False,
                                                                 'ORDER': 2,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': True,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                                    'HYDROGEN_BOND_CONSTRAINTS_TOTAL_COUNT': {'NULLABLE': True,
                                                                                              'ORDER': 16,
                                                                                              'PRECISION': 0,
                                                                                              'PRIMARY_KEY': False,
                                                                                              'SQL_TYPE': 'INT',
                                                                                              'WIDTH': 10},
                                                    'NA_ALPHA_ANGLE_CONSTRAINTS_TOTAL_COUNT': {'NULLABLE': True,
                                                                                               'ORDER': 18,
                                                                                               'PRECISION': 0,
                                                                                               'PRIMARY_KEY': False,
                                                                                               'SQL_TYPE': 'INT',
                                                                                               'WIDTH': 10},
                                                    'NA_BETA_ANGLE_CONSTRAINTS_TOTAL_COUNT': {'NULLABLE': True,
                                                                                              'ORDER': 19,
                                                                                              'PRECISION': 0,
                                                                                              'PRIMARY_KEY': False,
                                                                                              'SQL_TYPE': 'INT',
                                                                                              'WIDTH': 10},
                                                    'NA_CHI_ANGLE_CONSTRAINTS_TOTAL_COUNT': {'NULLABLE': True,
                                                                                             'ORDER': 23,
                                                                                             'PRECISION': 0,
                                                                                             'PRIMARY_KEY': False,
                                                                                             'SQL_TYPE': 'INT',
                                                                                             'WIDTH': 10},
                                                    'NA_DELTA_ANGLE_CONSTRAINTS_TOTAL_COUNT': {'NULLABLE': True,
                                                                                               'ORDER': 21,
                                                                                               'PRECISION': 0,
                                                                                               'PRIMARY_KEY': False,
                                                                                               'SQL_TYPE': 'INT',
                                                                                               'WIDTH': 10},
                                                    'NA_EPSILON_ANGLE_CONSTRAINTS_TOTAL_COUNT': {'NULLABLE': True,
                                                                                                 'ORDER': 22,
                                                                                                 'PRECISION': 0,
                                                                                                 'PRIMARY_KEY': False,
                                                                                                 'SQL_TYPE': 'INT',
                                                                                                 'WIDTH': 10},
                                                    'NA_GAMMA_ANGLE_CONSTRAINTS_TOTAL_COUNT': {'NULLABLE': True,
                                                                                               'ORDER': 20,
                                                                                               'PRECISION': 0,
                                                                                               'PRIMARY_KEY': False,
                                                                                               'SQL_TYPE': 'INT',
                                                                                               'WIDTH': 10},
                                                    'NA_OTHER_ANGLE_CONSTRAINTS_TOTAL_COUNT': {'NULLABLE': True,
                                                                                               'ORDER': 24,
                                                                                               'PRECISION': 0,
                                                                                               'PRIMARY_KEY': False,
                                                                                               'SQL_TYPE': 'INT',
                                                                                               'WIDTH': 10},
                                                    'NA_SUGAR_PUCKER_CONSTRAINTS_TOTAL_COUNT': {'NULLABLE': True,
                                                                                                'ORDER': 25,
                                                                                                'PRECISION': 0,
                                                                                                'PRIMARY_KEY': False,
                                                                                                'SQL_TYPE': 'INT',
                                                                                                'WIDTH': 10},
                                                    'NOE_CONSTRAINTS_TOTAL': {'NULLABLE': True,
                                                                              'ORDER': 3,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'INT',
                                                                              'WIDTH': 10},
                                                    'NOE_INTERENTITY_TOTAL_COUNT': {'NULLABLE': True,
                                                                                    'ORDER': 5,
                                                                                    'PRECISION': 0,
                                                                                    'PRIMARY_KEY': False,
                                                                                    'SQL_TYPE': 'INT',
                                                                                    'WIDTH': 10},
                                                    'NOE_INTERPROTON_DISTANCE_EVALUATION': {'NULLABLE': True,
                                                                                            'ORDER': 13,
                                                                                            'PRECISION': 0,
                                                                                            'PRIMARY_KEY': False,
                                                                                            'SQL_TYPE': 'VARCHAR',
                                                                                            'WIDTH': 200},
                                                    'NOE_INTRARESIDUE_TOTAL_COUNT': {'NULLABLE': True,
                                                                                     'ORDER': 4,
                                                                                     'PRECISION': 0,
                                                                                     'PRIMARY_KEY': False,
                                                                                     'SQL_TYPE': 'INT',
                                                                                     'WIDTH': 10},
                                                    'NOE_LONG_RANGE_TOTAL_COUNT': {'NULLABLE': True,
                                                                                   'ORDER': 8,
                                                                                   'PRECISION': 0,
                                                                                   'PRIMARY_KEY': False,
                                                                                   'SQL_TYPE': 'INT',
                                                                                   'WIDTH': 10},
                                                    'NOE_MEDIUM_RANGE_TOTAL_COUNT': {'NULLABLE': True,
                                                                                     'ORDER': 7,
                                                                                     'PRECISION': 0,
                                                                                     'PRIMARY_KEY': False,
                                                                                     'SQL_TYPE': 'INT',
                                                                                     'WIDTH': 10},
                                                    'NOE_MOTIONAL_AVERAGING_CORRECTION': {'NULLABLE': True,
                                                                                          'ORDER': 15,
                                                                                          'PRECISION': 0,
                                                                                          'PRIMARY_KEY': False,
                                                                                          'SQL_TYPE': 'VARCHAR',
                                                                                          'WIDTH': 200},
                                                    'NOE_PSEUDOATOM_CORRECTIONS': {'NULLABLE': True,
                                                                                   'ORDER': 14,
                                                                                   'PRECISION': 0,
                                                                                   'PRIMARY_KEY': False,
                                                                                   'SQL_TYPE': 'VARCHAR',
                                                                                   'WIDTH': 200},
                                                    'NOE_SEQUENTIAL_TOTAL_COUNT': {'NULLABLE': True,
                                                                                   'ORDER': 6,
                                                                                   'PRECISION': 0,
                                                                                   'PRIMARY_KEY': False,
                                                                                   'SQL_TYPE': 'INT',
                                                                                   'WIDTH': 10},
                                                    'PROTEIN_CHI_ANGLE_CONSTRAINTS_TOTAL_COUNT': {'NULLABLE': True,
                                                                                                  'ORDER': 11,
                                                                                                  'PRECISION': 0,
                                                                                                  'PRIMARY_KEY': False,
                                                                                                  'SQL_TYPE': 'INT',
                                                                                                  'WIDTH': 10},
                                                    'PROTEIN_OTHER_ANGLE_CONSTRAINTS_TOTAL_COUNT': {'NULLABLE': True,
                                                                                                    'ORDER': 12,
                                                                                                    'PRECISION': 0,
                                                                                                    'PRIMARY_KEY': False,
                                                                                                    'SQL_TYPE': 'INT',
                                                                                                    'WIDTH': 10},
                                                    'PROTEIN_PHI_ANGLE_CONSTRAINTS_TOTAL_COUNT': {'NULLABLE': True,
                                                                                                  'ORDER': 9,
                                                                                                  'PRECISION': 0,
                                                                                                  'PRIMARY_KEY': False,
                                                                                                  'SQL_TYPE': 'INT',
                                                                                                  'WIDTH': 10},
                                                    'PROTEIN_PSI_ANGLE_CONSTRAINTS_TOTAL_COUNT': {'NULLABLE': True,
                                                                                                  'ORDER': 10,
                                                                                                  'PRECISION': 0,
                                                                                                  'PRIMARY_KEY': False,
                                                                                                  'SQL_TYPE': 'INT',
                                                                                                  'WIDTH': 10},
                                                    'STRUCTURE_ID': {'NULLABLE': False,
                                                                     'ORDER': 1,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': True,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10}},
                                 'ATTRIBUTE_MAP': {'DISULFIDE_BOND_CONSTRAINTS_TOTAL_COUNT': ('pdbx_nmr_constraints',
                                                                                              'disulfide_bond_constraints_total_count',
                                                                                              None,
                                                                                              None),
                                                   'ENTRY_ID': ('pdbx_nmr_constraints', 'entry_id', None, None),
                                                   'HYDROGEN_BOND_CONSTRAINTS_TOTAL_COUNT': ('pdbx_nmr_constraints',
                                                                                             'hydrogen_bond_constraints_total_count',
                                                                                             None,
                                                                                             None),
                                                   'NA_ALPHA_ANGLE_CONSTRAINTS_TOTAL_COUNT': ('pdbx_nmr_constraints',
                                                                                              'NA_alpha-angle_constraints_total_count',
                                                                                              None,
                                                                                              None),
                                                   'NA_BETA_ANGLE_CONSTRAINTS_TOTAL_COUNT': ('pdbx_nmr_constraints',
                                                                                             'NA_beta-angle_constraints_total_count',
                                                                                             None,
                                                                                             None),
                                                   'NA_CHI_ANGLE_CONSTRAINTS_TOTAL_COUNT': ('pdbx_nmr_constraints',
                                                                                            'NA_chi-angle_constraints_total_count',
                                                                                            None,
                                                                                            None),
                                                   'NA_DELTA_ANGLE_CONSTRAINTS_TOTAL_COUNT': ('pdbx_nmr_constraints',
                                                                                              'NA_delta-angle_constraints_total_count',
                                                                                              None,
                                                                                              None),
                                                   'NA_EPSILON_ANGLE_CONSTRAINTS_TOTAL_COUNT': ('pdbx_nmr_constraints',
                                                                                                'NA_epsilon-angle_constraints_total_count',
                                                                                                None,
                                                                                                None),
                                                   'NA_GAMMA_ANGLE_CONSTRAINTS_TOTAL_COUNT': ('pdbx_nmr_constraints',
                                                                                              'NA_gamma-angle_constraints_total_count',
                                                                                              None,
                                                                                              None),
                                                   'NA_OTHER_ANGLE_CONSTRAINTS_TOTAL_COUNT': ('pdbx_nmr_constraints',
                                                                                              'NA_other-angle_constraints_total_count',
                                                                                              None,
                                                                                              None),
                                                   'NA_SUGAR_PUCKER_CONSTRAINTS_TOTAL_COUNT': ('pdbx_nmr_constraints',
                                                                                               'NA_sugar_pucker_constraints_total_count',
                                                                                               None,
                                                                                               None),
                                                   'NOE_CONSTRAINTS_TOTAL': ('pdbx_nmr_constraints',
                                                                             'NOE_constraints_total',
                                                                             None,
                                                                             None),
                                                   'NOE_INTERENTITY_TOTAL_COUNT': ('pdbx_nmr_constraints',
                                                                                   'NOE_interentity_total_count',
                                                                                   None,
                                                                                   None),
                                                   'NOE_INTERPROTON_DISTANCE_EVALUATION': ('pdbx_nmr_constraints',
                                                                                           'NOE_interproton_distance_evaluation',
                                                                                           None,
                                                                                           None),
                                                   'NOE_INTRARESIDUE_TOTAL_COUNT': ('pdbx_nmr_constraints',
                                                                                    'NOE_intraresidue_total_count',
                                                                                    None,
                                                                                    None),
                                                   'NOE_LONG_RANGE_TOTAL_COUNT': ('pdbx_nmr_constraints',
                                                                                  'NOE_long_range_total_count',
                                                                                  None,
                                                                                  None),
                                                   'NOE_MEDIUM_RANGE_TOTAL_COUNT': ('pdbx_nmr_constraints',
                                                                                    'NOE_medium_range_total_count',
                                                                                    None,
                                                                                    None),
                                                   'NOE_MOTIONAL_AVERAGING_CORRECTION': ('pdbx_nmr_constraints',
                                                                                         'NOE_motional_averaging_correction',
                                                                                         None,
                                                                                         None),
                                                   'NOE_PSEUDOATOM_CORRECTIONS': ('pdbx_nmr_constraints',
                                                                                  'NOE_pseudoatom_corrections',
                                                                                  None,
                                                                                  None),
                                                   'NOE_SEQUENTIAL_TOTAL_COUNT': ('pdbx_nmr_constraints',
                                                                                  'NOE_sequential_total_count',
                                                                                  None,
                                                                                  None),
                                                   'PROTEIN_CHI_ANGLE_CONSTRAINTS_TOTAL_COUNT': ('pdbx_nmr_constraints',
                                                                                                 'protein_chi_angle_constraints_total_count',
                                                                                                 None,
                                                                                                 None),
                                                   'PROTEIN_OTHER_ANGLE_CONSTRAINTS_TOTAL_COUNT': ('pdbx_nmr_constraints',
                                                                                                   'protein_other_angle_constraints_total_count',
                                                                                                   None,
                                                                                                   None),
                                                   'PROTEIN_PHI_ANGLE_CONSTRAINTS_TOTAL_COUNT': ('pdbx_nmr_constraints',
                                                                                                 'protein_phi_angle_constraints_total_count',
                                                                                                 None,
                                                                                                 None),
                                                   'PROTEIN_PSI_ANGLE_CONSTRAINTS_TOTAL_COUNT': ('pdbx_nmr_constraints',
                                                                                                 'protein_psi_angle_constraints_total_count',
                                                                                                 None,
                                                                                                 None),
                                                   'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                 'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID'), 'TYPE': 'UNIQUE'},
                                             's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                 'MAP_MERGE_INDICES': {'pdbx_nmr_constraints': {'ATTRIBUTES': ('entry_id',),
                                                                                'TYPE': 'EQUI-JOIN'}},
                                 'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                 'TABLE_ID': 'PDBX_NMR_CONSTRAINTS',
                                 'TABLE_NAME': 'pdbx_nmr_constraints',
                                 'TABLE_TYPE': 'transactional'},
        'PDBX_NMR_DETAILS': {'ATTRIBUTES': {'ENTRY_ID': 'entry_id', 'STRUCTURE_ID': 'Structure_ID', 'TEXT': 'text'},
                             'ATTRIBUTE_INFO': {'ENTRY_ID': {'NULLABLE': False,
                                                             'ORDER': 2,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 10},
                                                'STRUCTURE_ID': {'NULLABLE': False,
                                                                 'ORDER': 1,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': True,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                                'TEXT': {'NULLABLE': True,
                                                         'ORDER': 3,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 16383}},
                             'ATTRIBUTE_MAP': {'ENTRY_ID': ('pdbx_nmr_details', 'entry_id', None, None),
                                               'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                               'TEXT': ('pdbx_nmr_details', 'text', None, None)},
                             'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID'), 'TYPE': 'UNIQUE'},
                                         's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                             'MAP_MERGE_INDICES': {'pdbx_nmr_details': {'ATTRIBUTES': ('entry_id',), 'TYPE': 'EQUI-JOIN'}},
                             'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                             'TABLE_ID': 'PDBX_NMR_DETAILS',
                             'TABLE_NAME': 'pdbx_nmr_details',
                             'TABLE_TYPE': 'transactional'},
        'PDBX_NMR_ENSEMBLE': {'ATTRIBUTES': {'AVERAGE_CONSTRAINTS_PER_RESIDUE': 'average_constraints_per_residue',
                                             'AVERAGE_CONSTRAINT_VIOLATIONS_PER_RESIDUE': 'average_constraint_violations_per_residue',
                                             'AVERAGE_DISTANCE_CONSTRAINT_VIOLATION': 'average_distance_constraint_violation',
                                             'AVERAGE_TORSION_ANGLE_CONSTRAINT_VIOLATION': 'average_torsion_angle_constraint_violation',
                                             'CONFORMERS_CALCULATED_TOTAL_NUMBER': 'conformers_calculated_total_number',
                                             'CONFORMERS_SUBMITTED_TOTAL_NUMBER': 'conformers_submitted_total_number',
                                             'CONFORMER_SELECTION_CRITERIA': 'conformer_selection_criteria',
                                             'DISTANCE_CONSTRAINT_VIOLATION_METHOD': 'distance_constraint_violation_method',
                                             'ENTRY_ID': 'entry_id',
                                             'MAXIMUM_DISTANCE_CONSTRAINT_VIOLATION': 'maximum_distance_constraint_violation',
                                             'MAXIMUM_LOWER_DISTANCE_CONSTRAINT_VIOLATION': 'maximum_lower_distance_constraint_violation',
                                             'MAXIMUM_TORSION_ANGLE_CONSTRAINT_VIOLATION': 'maximum_torsion_angle_constraint_violation',
                                             'MAXIMUM_UPPER_DISTANCE_CONSTRAINT_VIOLATION': 'maximum_upper_distance_constraint_violation',
                                             'REPRESENTATIVE_CONFORMER': 'representative_conformer',
                                             'STRUCTURE_ID': 'Structure_ID',
                                             'TORSION_ANGLE_CONSTRAINT_VIOLATION_METHOD': 'torsion_angle_constraint_violation_method'},
                              'ATTRIBUTE_INFO': {'AVERAGE_CONSTRAINTS_PER_RESIDUE': {'NULLABLE': True,
                                                                                     'ORDER': 7,
                                                                                     'PRECISION': 0,
                                                                                     'PRIMARY_KEY': False,
                                                                                     'SQL_TYPE': 'INT',
                                                                                     'WIDTH': 10},
                                                 'AVERAGE_CONSTRAINT_VIOLATIONS_PER_RESIDUE': {'NULLABLE': True,
                                                                                               'ORDER': 8,
                                                                                               'PRECISION': 0,
                                                                                               'PRIMARY_KEY': False,
                                                                                               'SQL_TYPE': 'INT',
                                                                                               'WIDTH': 10},
                                                 'AVERAGE_DISTANCE_CONSTRAINT_VIOLATION': {'NULLABLE': True,
                                                                                           'ORDER': 10,
                                                                                           'PRECISION': 6,
                                                                                           'PRIMARY_KEY': False,
                                                                                           'SQL_TYPE': 'FLOAT',
                                                                                           'WIDTH': 10},
                                                 'AVERAGE_TORSION_ANGLE_CONSTRAINT_VIOLATION': {'NULLABLE': True,
                                                                                                'ORDER': 15,
                                                                                                'PRECISION': 6,
                                                                                                'PRIMARY_KEY': False,
                                                                                                'SQL_TYPE': 'FLOAT',
                                                                                                'WIDTH': 10},
                                                 'CONFORMERS_CALCULATED_TOTAL_NUMBER': {'NULLABLE': True,
                                                                                        'ORDER': 3,
                                                                                        'PRECISION': 0,
                                                                                        'PRIMARY_KEY': False,
                                                                                        'SQL_TYPE': 'INT',
                                                                                        'WIDTH': 10},
                                                 'CONFORMERS_SUBMITTED_TOTAL_NUMBER': {'NULLABLE': True,
                                                                                       'ORDER': 4,
                                                                                       'PRECISION': 0,
                                                                                       'PRIMARY_KEY': False,
                                                                                       'SQL_TYPE': 'INT',
                                                                                       'WIDTH': 10},
                                                 'CONFORMER_SELECTION_CRITERIA': {'NULLABLE': True,
                                                                                  'ORDER': 5,
                                                                                  'PRECISION': 0,
                                                                                  'PRIMARY_KEY': False,
                                                                                  'SQL_TYPE': 'VARCHAR',
                                                                                  'WIDTH': 1023},
                                                 'DISTANCE_CONSTRAINT_VIOLATION_METHOD': {'NULLABLE': True,
                                                                                          'ORDER': 13,
                                                                                          'PRECISION': 0,
                                                                                          'PRIMARY_KEY': False,
                                                                                          'SQL_TYPE': 'VARCHAR',
                                                                                          'WIDTH': 255},
                                                 'ENTRY_ID': {'NULLABLE': False,
                                                              'ORDER': 2,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10},
                                                 'MAXIMUM_DISTANCE_CONSTRAINT_VIOLATION': {'NULLABLE': True,
                                                                                           'ORDER': 9,
                                                                                           'PRECISION': 6,
                                                                                           'PRIMARY_KEY': False,
                                                                                           'SQL_TYPE': 'FLOAT',
                                                                                           'WIDTH': 10},
                                                 'MAXIMUM_LOWER_DISTANCE_CONSTRAINT_VIOLATION': {'NULLABLE': True,
                                                                                                 'ORDER': 12,
                                                                                                 'PRECISION': 6,
                                                                                                 'PRIMARY_KEY': False,
                                                                                                 'SQL_TYPE': 'FLOAT',
                                                                                                 'WIDTH': 10},
                                                 'MAXIMUM_TORSION_ANGLE_CONSTRAINT_VIOLATION': {'NULLABLE': True,
                                                                                                'ORDER': 14,
                                                                                                'PRECISION': 6,
                                                                                                'PRIMARY_KEY': False,
                                                                                                'SQL_TYPE': 'FLOAT',
                                                                                                'WIDTH': 10},
                                                 'MAXIMUM_UPPER_DISTANCE_CONSTRAINT_VIOLATION': {'NULLABLE': True,
                                                                                                 'ORDER': 11,
                                                                                                 'PRECISION': 6,
                                                                                                 'PRIMARY_KEY': False,
                                                                                                 'SQL_TYPE': 'FLOAT',
                                                                                                 'WIDTH': 10},
                                                 'REPRESENTATIVE_CONFORMER': {'NULLABLE': True,
                                                                              'ORDER': 6,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'INT',
                                                                              'WIDTH': 10},
                                                 'STRUCTURE_ID': {'NULLABLE': False,
                                                                  'ORDER': 1,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': True,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10},
                                                 'TORSION_ANGLE_CONSTRAINT_VIOLATION_METHOD': {'NULLABLE': True,
                                                                                               'ORDER': 16,
                                                                                               'PRECISION': 0,
                                                                                               'PRIMARY_KEY': False,
                                                                                               'SQL_TYPE': 'VARCHAR',
                                                                                               'WIDTH': 200}},
                              'ATTRIBUTE_MAP': {'AVERAGE_CONSTRAINTS_PER_RESIDUE': ('pdbx_nmr_ensemble',
                                                                                    'average_constraints_per_residue',
                                                                                    None,
                                                                                    None),
                                                'AVERAGE_CONSTRAINT_VIOLATIONS_PER_RESIDUE': ('pdbx_nmr_ensemble',
                                                                                              'average_constraint_violations_per_residue',
                                                                                              None,
                                                                                              None),
                                                'AVERAGE_DISTANCE_CONSTRAINT_VIOLATION': ('pdbx_nmr_ensemble',
                                                                                          'average_distance_constraint_violation',
                                                                                          None,
                                                                                          None),
                                                'AVERAGE_TORSION_ANGLE_CONSTRAINT_VIOLATION': ('pdbx_nmr_ensemble',
                                                                                               'average_torsion_angle_constraint_violation',
                                                                                               None,
                                                                                               None),
                                                'CONFORMERS_CALCULATED_TOTAL_NUMBER': ('pdbx_nmr_ensemble',
                                                                                       'conformers_calculated_total_number',
                                                                                       None,
                                                                                       None),
                                                'CONFORMERS_SUBMITTED_TOTAL_NUMBER': ('pdbx_nmr_ensemble',
                                                                                      'conformers_submitted_total_number',
                                                                                      None,
                                                                                      None),
                                                'CONFORMER_SELECTION_CRITERIA': ('pdbx_nmr_ensemble',
                                                                                 'conformer_selection_criteria',
                                                                                 None,
                                                                                 None),
                                                'DISTANCE_CONSTRAINT_VIOLATION_METHOD': ('pdbx_nmr_ensemble',
                                                                                         'distance_constraint_violation_method',
                                                                                         None,
                                                                                         None),
                                                'ENTRY_ID': ('pdbx_nmr_ensemble', 'entry_id', None, None),
                                                'MAXIMUM_DISTANCE_CONSTRAINT_VIOLATION': ('pdbx_nmr_ensemble',
                                                                                          'maximum_distance_constraint_violation',
                                                                                          None,
                                                                                          None),
                                                'MAXIMUM_LOWER_DISTANCE_CONSTRAINT_VIOLATION': ('pdbx_nmr_ensemble',
                                                                                                'maximum_lower_distance_constraint_violation',
                                                                                                None,
                                                                                                None),
                                                'MAXIMUM_TORSION_ANGLE_CONSTRAINT_VIOLATION': ('pdbx_nmr_ensemble',
                                                                                               'maximum_torsion_angle_constraint_violation',
                                                                                               None,
                                                                                               None),
                                                'MAXIMUM_UPPER_DISTANCE_CONSTRAINT_VIOLATION': ('pdbx_nmr_ensemble',
                                                                                                'maximum_upper_distance_constraint_violation',
                                                                                                None,
                                                                                                None),
                                                'REPRESENTATIVE_CONFORMER': ('pdbx_nmr_ensemble',
                                                                             'representative_conformer',
                                                                             None,
                                                                             None),
                                                'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                'TORSION_ANGLE_CONSTRAINT_VIOLATION_METHOD': ('pdbx_nmr_ensemble',
                                                                                              'torsion_angle_constraint_violation_method',
                                                                                              None,
                                                                                              None)},
                              'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID'), 'TYPE': 'UNIQUE'},
                                          's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                              'MAP_MERGE_INDICES': {'pdbx_nmr_ensemble': {'ATTRIBUTES': ('entry_id',), 'TYPE': 'EQUI-JOIN'}},
                              'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                              'TABLE_ID': 'PDBX_NMR_ENSEMBLE',
                              'TABLE_NAME': 'pdbx_nmr_ensemble',
                              'TABLE_TYPE': 'transactional'},
        'PDBX_NMR_ENSEMBLE_RMS': {'ATTRIBUTES': {'ATOM_TYPE': 'atom_type',
                                                 'BOND_ANGLE_RMS_DEV': 'bond_angle_rms_dev',
                                                 'BOND_ANGLE_RMS_DEV_ERROR': 'bond_angle_rms_dev_error',
                                                 'CHAIN_RANGE_BEGIN': 'chain_range_begin',
                                                 'CHAIN_RANGE_END': 'chain_range_end',
                                                 'COORD_AVERAGE_RMSD_METHOD': 'coord_average_rmsd_method',
                                                 'COVALENT_BOND_RMS_DEV': 'covalent_bond_rms_dev',
                                                 'COVALENT_BOND_RMS_DEV_ERROR': 'covalent_bond_rms_dev_error',
                                                 'DIHEDRAL_ANGLES_RMS_DEV': 'dihedral_angles_rms_dev',
                                                 'DIHEDRAL_ANGLES_RMS_DEV_ERROR': 'dihedral_angles_rms_dev_error',
                                                 'DISTANCE_RMS_DEV': 'distance_rms_dev',
                                                 'DISTANCE_RMS_DEV_ERROR': 'distance_rms_dev_error',
                                                 'ENTRY_ID': 'entry_id',
                                                 'IMPROPER_TORSION_ANGLE_RMS_DEV': 'improper_torsion_angle_rms_dev',
                                                 'IMPROPER_TORSION_ANGLE_RMS_DEV_ERROR': 'improper_torsion_angle_rms_dev_error',
                                                 'PEPTIDE_PLANARITY_RMS_DEV': 'peptide_planarity_rms_dev',
                                                 'PEPTIDE_PLANARITY_RMS_DEV_ERROR': 'peptide_planarity_rms_dev_error',
                                                 'RESIDUE_RANGE_BEGIN': 'residue_range_begin',
                                                 'RESIDUE_RANGE_END': 'residue_range_end',
                                                 'STRUCTURE_ID': 'Structure_ID'},
                                  'ATTRIBUTE_INFO': {'ATOM_TYPE': {'NULLABLE': True,
                                                                   'ORDER': 7,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 80},
                                                     'BOND_ANGLE_RMS_DEV': {'NULLABLE': True,
                                                                            'ORDER': 12,
                                                                            'PRECISION': 6,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'FLOAT',
                                                                            'WIDTH': 10},
                                                     'BOND_ANGLE_RMS_DEV_ERROR': {'NULLABLE': True,
                                                                                  'ORDER': 13,
                                                                                  'PRECISION': 6,
                                                                                  'PRIMARY_KEY': False,
                                                                                  'SQL_TYPE': 'FLOAT',
                                                                                  'WIDTH': 10},
                                                     'CHAIN_RANGE_BEGIN': {'NULLABLE': True,
                                                                           'ORDER': 4,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10},
                                                     'CHAIN_RANGE_END': {'NULLABLE': True,
                                                                         'ORDER': 6,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                                     'COORD_AVERAGE_RMSD_METHOD': {'NULLABLE': True,
                                                                                   'ORDER': 20,
                                                                                   'PRECISION': 0,
                                                                                   'PRIMARY_KEY': False,
                                                                                   'SQL_TYPE': 'VARCHAR',
                                                                                   'WIDTH': 200},
                                                     'COVALENT_BOND_RMS_DEV': {'NULLABLE': True,
                                                                               'ORDER': 10,
                                                                               'PRECISION': 6,
                                                                               'PRIMARY_KEY': False,
                                                                               'SQL_TYPE': 'FLOAT',
                                                                               'WIDTH': 10},
                                                     'COVALENT_BOND_RMS_DEV_ERROR': {'NULLABLE': True,
                                                                                     'ORDER': 11,
                                                                                     'PRECISION': 6,
                                                                                     'PRIMARY_KEY': False,
                                                                                     'SQL_TYPE': 'FLOAT',
                                                                                     'WIDTH': 10},
                                                     'DIHEDRAL_ANGLES_RMS_DEV': {'NULLABLE': True,
                                                                                 'ORDER': 18,
                                                                                 'PRECISION': 6,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'FLOAT',
                                                                                 'WIDTH': 10},
                                                     'DIHEDRAL_ANGLES_RMS_DEV_ERROR': {'NULLABLE': True,
                                                                                       'ORDER': 19,
                                                                                       'PRECISION': 6,
                                                                                       'PRIMARY_KEY': False,
                                                                                       'SQL_TYPE': 'FLOAT',
                                                                                       'WIDTH': 10},
                                                     'DISTANCE_RMS_DEV': {'NULLABLE': True,
                                                                          'ORDER': 8,
                                                                          'PRECISION': 6,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'FLOAT',
                                                                          'WIDTH': 10},
                                                     'DISTANCE_RMS_DEV_ERROR': {'NULLABLE': True,
                                                                                'ORDER': 9,
                                                                                'PRECISION': 6,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'FLOAT',
                                                                                'WIDTH': 10},
                                                     'ENTRY_ID': {'NULLABLE': False,
                                                                  'ORDER': 2,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': True,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10},
                                                     'IMPROPER_TORSION_ANGLE_RMS_DEV': {'NULLABLE': True,
                                                                                        'ORDER': 14,
                                                                                        'PRECISION': 6,
                                                                                        'PRIMARY_KEY': False,
                                                                                        'SQL_TYPE': 'FLOAT',
                                                                                        'WIDTH': 10},
                                                     'IMPROPER_TORSION_ANGLE_RMS_DEV_ERROR': {'NULLABLE': True,
                                                                                              'ORDER': 15,
                                                                                              'PRECISION': 6,
                                                                                              'PRIMARY_KEY': False,
                                                                                              'SQL_TYPE': 'FLOAT',
                                                                                              'WIDTH': 10},
                                                     'PEPTIDE_PLANARITY_RMS_DEV': {'NULLABLE': True,
                                                                                   'ORDER': 16,
                                                                                   'PRECISION': 6,
                                                                                   'PRIMARY_KEY': False,
                                                                                   'SQL_TYPE': 'FLOAT',
                                                                                   'WIDTH': 10},
                                                     'PEPTIDE_PLANARITY_RMS_DEV_ERROR': {'NULLABLE': True,
                                                                                         'ORDER': 17,
                                                                                         'PRECISION': 6,
                                                                                         'PRIMARY_KEY': False,
                                                                                         'SQL_TYPE': 'FLOAT',
                                                                                         'WIDTH': 10},
                                                     'RESIDUE_RANGE_BEGIN': {'NULLABLE': True,
                                                                             'ORDER': 3,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'INT',
                                                                             'WIDTH': 10},
                                                     'RESIDUE_RANGE_END': {'NULLABLE': True,
                                                                           'ORDER': 5,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'INT',
                                                                           'WIDTH': 10},
                                                     'STRUCTURE_ID': {'NULLABLE': False,
                                                                      'ORDER': 1,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10}},
                                  'ATTRIBUTE_MAP': {'ATOM_TYPE': ('pdbx_nmr_ensemble_rms', 'atom_type', None, None),
                                                    'BOND_ANGLE_RMS_DEV': ('pdbx_nmr_ensemble_rms',
                                                                           'bond_angle_rms_dev',
                                                                           None,
                                                                           None),
                                                    'BOND_ANGLE_RMS_DEV_ERROR': ('pdbx_nmr_ensemble_rms',
                                                                                 'bond_angle_rms_dev_error',
                                                                                 None,
                                                                                 None),
                                                    'CHAIN_RANGE_BEGIN': ('pdbx_nmr_ensemble_rms',
                                                                          'chain_range_begin',
                                                                          None,
                                                                          None),
                                                    'CHAIN_RANGE_END': ('pdbx_nmr_ensemble_rms',
                                                                        'chain_range_end',
                                                                        None,
                                                                        None),
                                                    'COORD_AVERAGE_RMSD_METHOD': ('pdbx_nmr_ensemble_rms',
                                                                                  'coord_average_rmsd_method',
                                                                                  None,
                                                                                  None),
                                                    'COVALENT_BOND_RMS_DEV': ('pdbx_nmr_ensemble_rms',
                                                                              'covalent_bond_rms_dev',
                                                                              None,
                                                                              None),
                                                    'COVALENT_BOND_RMS_DEV_ERROR': ('pdbx_nmr_ensemble_rms',
                                                                                    'covalent_bond_rms_dev_error',
                                                                                    None,
                                                                                    None),
                                                    'DIHEDRAL_ANGLES_RMS_DEV': ('pdbx_nmr_ensemble_rms',
                                                                                'dihedral_angles_rms_dev',
                                                                                None,
                                                                                None),
                                                    'DIHEDRAL_ANGLES_RMS_DEV_ERROR': ('pdbx_nmr_ensemble_rms',
                                                                                      'dihedral_angles_rms_dev_error',
                                                                                      None,
                                                                                      None),
                                                    'DISTANCE_RMS_DEV': ('pdbx_nmr_ensemble_rms',
                                                                         'distance_rms_dev',
                                                                         None,
                                                                         None),
                                                    'DISTANCE_RMS_DEV_ERROR': ('pdbx_nmr_ensemble_rms',
                                                                               'distance_rms_dev_error',
                                                                               None,
                                                                               None),
                                                    'ENTRY_ID': ('pdbx_nmr_ensemble_rms', 'entry_id', None, None),
                                                    'IMPROPER_TORSION_ANGLE_RMS_DEV': ('pdbx_nmr_ensemble_rms',
                                                                                       'improper_torsion_angle_rms_dev',
                                                                                       None,
                                                                                       None),
                                                    'IMPROPER_TORSION_ANGLE_RMS_DEV_ERROR': ('pdbx_nmr_ensemble_rms',
                                                                                             'improper_torsion_angle_rms_dev_error',
                                                                                             None,
                                                                                             None),
                                                    'PEPTIDE_PLANARITY_RMS_DEV': ('pdbx_nmr_ensemble_rms',
                                                                                  'peptide_planarity_rms_dev',
                                                                                  None,
                                                                                  None),
                                                    'PEPTIDE_PLANARITY_RMS_DEV_ERROR': ('pdbx_nmr_ensemble_rms',
                                                                                        'peptide_planarity_rms_dev_error',
                                                                                        None,
                                                                                        None),
                                                    'RESIDUE_RANGE_BEGIN': ('pdbx_nmr_ensemble_rms',
                                                                            'residue_range_begin',
                                                                            None,
                                                                            None),
                                                    'RESIDUE_RANGE_END': ('pdbx_nmr_ensemble_rms',
                                                                          'residue_range_end',
                                                                          None,
                                                                          None),
                                                    'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                  'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID'), 'TYPE': 'UNIQUE'},
                                              's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                  'MAP_MERGE_INDICES': {'pdbx_nmr_ensemble_rms': {'ATTRIBUTES': ('entry_id',),
                                                                                  'TYPE': 'EQUI-JOIN'}},
                                  'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                  'TABLE_ID': 'PDBX_NMR_ENSEMBLE_RMS',
                                  'TABLE_NAME': 'pdbx_nmr_ensemble_rms',
                                  'TABLE_TYPE': 'transactional'},
        'PDBX_NMR_EXPTL': {'ATTRIBUTES': {'CONDITIONS_ID': 'conditions_id',
                                          'EXPERIMENT_ID': 'experiment_id',
                                          'SOLUTION_ID': 'solution_id',
                                          'STRUCTURE_ID': 'Structure_ID',
                                          'TYPE': 'type'},
                           'ATTRIBUTE_INFO': {'CONDITIONS_ID': {'NULLABLE': False,
                                                                'ORDER': 3,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                              'EXPERIMENT_ID': {'NULLABLE': False,
                                                                'ORDER': 2,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                              'SOLUTION_ID': {'NULLABLE': False,
                                                              'ORDER': 4,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10},
                                              'STRUCTURE_ID': {'NULLABLE': False,
                                                               'ORDER': 1,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                              'TYPE': {'NULLABLE': True,
                                                       'ORDER': 5,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'VARCHAR',
                                                       'WIDTH': 1023}},
                           'ATTRIBUTE_MAP': {'CONDITIONS_ID': ('pdbx_nmr_exptl', 'conditions_id', None, None),
                                             'EXPERIMENT_ID': ('pdbx_nmr_exptl', 'experiment_id', None, None),
                                             'SOLUTION_ID': ('pdbx_nmr_exptl', 'solution_id', None, None),
                                             'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                             'TYPE': ('pdbx_nmr_exptl', 'type', None, None)},
                           'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'EXPERIMENT_ID', 'CONDITIONS_ID', 'SOLUTION_ID'),
                                              'TYPE': 'UNIQUE'},
                                       's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                           'MAP_MERGE_INDICES': {'pdbx_nmr_exptl': {'ATTRIBUTES': ('experiment_id',
                                                                                   'conditions_id',
                                                                                   'solution_id'),
                                                                    'TYPE': 'EQUI-JOIN'}},
                           'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                           'TABLE_ID': 'PDBX_NMR_EXPTL',
                           'TABLE_NAME': 'pdbx_nmr_exptl',
                           'TABLE_TYPE': 'transactional'},
        'PDBX_NMR_EXPTL_SAMPLE': {'ATTRIBUTES': {'COMPONENT': 'component',
                                                 'CONCENTRATION': 'concentration',
                                                 'CONCENTRATION_RANGE': 'concentration_range',
                                                 'CONCENTRATION_UNITS': 'concentration_units',
                                                 'ISOTOPIC_LABELING': 'isotopic_labeling',
                                                 'SOLUTION_ID': 'solution_id',
                                                 'STRUCTURE_ID': 'Structure_ID'},
                                  'ATTRIBUTE_INFO': {'COMPONENT': {'NULLABLE': False,
                                                                   'ORDER': 3,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': True,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 128},
                                                     'CONCENTRATION': {'NULLABLE': True,
                                                                       'ORDER': 4,
                                                                       'PRECISION': 6,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'FLOAT',
                                                                       'WIDTH': 10},
                                                     'CONCENTRATION_RANGE': {'NULLABLE': True,
                                                                             'ORDER': 5,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 30},
                                                     'CONCENTRATION_UNITS': {'NULLABLE': True,
                                                                             'ORDER': 6,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                     'ISOTOPIC_LABELING': {'NULLABLE': True,
                                                                           'ORDER': 7,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 255},
                                                     'SOLUTION_ID': {'NULLABLE': False,
                                                                     'ORDER': 2,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': True,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                                     'STRUCTURE_ID': {'NULLABLE': False,
                                                                      'ORDER': 1,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10}},
                                  'ATTRIBUTE_MAP': {'COMPONENT': ('pdbx_nmr_exptl_sample', 'component', None, None),
                                                    'CONCENTRATION': ('pdbx_nmr_exptl_sample', 'concentration', None, None),
                                                    'CONCENTRATION_RANGE': ('pdbx_nmr_exptl_sample',
                                                                            'concentration_range',
                                                                            None,
                                                                            None),
                                                    'CONCENTRATION_UNITS': ('pdbx_nmr_exptl_sample',
                                                                            'concentration_units',
                                                                            None,
                                                                            None),
                                                    'ISOTOPIC_LABELING': ('pdbx_nmr_exptl_sample',
                                                                          'isotopic_labeling',
                                                                          None,
                                                                          None),
                                                    'SOLUTION_ID': ('pdbx_nmr_exptl_sample', 'solution_id', None, None),
                                                    'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                  'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'SOLUTION_ID', 'COMPONENT'),
                                                     'TYPE': 'UNIQUE'},
                                              's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                  'MAP_MERGE_INDICES': {'pdbx_nmr_exptl_sample': {'ATTRIBUTES': ('solution_id', 'component'),
                                                                                  'TYPE': 'EQUI-JOIN'}},
                                  'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                  'TABLE_ID': 'PDBX_NMR_EXPTL_SAMPLE',
                                  'TABLE_NAME': 'pdbx_nmr_exptl_sample',
                                  'TABLE_TYPE': 'transactional'},
        'PDBX_NMR_EXPTL_SAMPLE_CONDITIONS': {'ATTRIBUTES': {'CONDITIONS_ID': 'conditions_id',
                                                            'IONIC_STRENGTH': 'ionic_strength',
                                                            'PH': 'pH',
                                                            'PRESSURE': 'pressure',
                                                            'PRESSURE_UNITS': 'pressure_units',
                                                            'STRUCTURE_ID': 'Structure_ID',
                                                            'TEMPERATURE': 'temperature'},
                                             'ATTRIBUTE_INFO': {'CONDITIONS_ID': {'NULLABLE': False,
                                                                                  'ORDER': 2,
                                                                                  'PRECISION': 0,
                                                                                  'PRIMARY_KEY': True,
                                                                                  'SQL_TYPE': 'VARCHAR',
                                                                                  'WIDTH': 10},
                                                                'IONIC_STRENGTH': {'NULLABLE': True,
                                                                                   'ORDER': 7,
                                                                                   'PRECISION': 0,
                                                                                   'PRIMARY_KEY': False,
                                                                                   'SQL_TYPE': 'VARCHAR',
                                                                                   'WIDTH': 255},
                                                                'PH': {'NULLABLE': True,
                                                                       'ORDER': 6,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 30},
                                                                'PRESSURE': {'NULLABLE': True,
                                                                             'ORDER': 5,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 80},
                                                                'PRESSURE_UNITS': {'NULLABLE': True,
                                                                                   'ORDER': 4,
                                                                                   'PRECISION': 0,
                                                                                   'PRIMARY_KEY': False,
                                                                                   'SQL_TYPE': 'VARCHAR',
                                                                                   'WIDTH': 10},
                                                                'STRUCTURE_ID': {'NULLABLE': False,
                                                                                 'ORDER': 1,
                                                                                 'PRECISION': 0,
                                                                                 'PRIMARY_KEY': True,
                                                                                 'SQL_TYPE': 'VARCHAR',
                                                                                 'WIDTH': 10},
                                                                'TEMPERATURE': {'NULLABLE': True,
                                                                                'ORDER': 3,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 30}},
                                             'ATTRIBUTE_MAP': {'CONDITIONS_ID': ('pdbx_nmr_exptl_sample_conditions',
                                                                                 'conditions_id',
                                                                                 None,
                                                                                 None),
                                                               'IONIC_STRENGTH': ('pdbx_nmr_exptl_sample_conditions',
                                                                                  'ionic_strength',
                                                                                  None,
                                                                                  None),
                                                               'PH': ('pdbx_nmr_exptl_sample_conditions', 'pH', None, None),
                                                               'PRESSURE': ('pdbx_nmr_exptl_sample_conditions',
                                                                            'pressure',
                                                                            None,
                                                                            None),
                                                               'PRESSURE_UNITS': ('pdbx_nmr_exptl_sample_conditions',
                                                                                  'pressure_units',
                                                                                  None,
                                                                                  None),
                                                               'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                               'TEMPERATURE': ('pdbx_nmr_exptl_sample_conditions',
                                                                               'temperature',
                                                                               None,
                                                                               None)},
                                             'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'CONDITIONS_ID'),
                                                                'TYPE': 'UNIQUE'},
                                                         's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                             'MAP_MERGE_INDICES': {'pdbx_nmr_exptl_sample_conditions': {'ATTRIBUTES': ('conditions_id',),
                                                                                                        'TYPE': 'EQUI-JOIN'}},
                                             'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                             'TABLE_ID': 'PDBX_NMR_EXPTL_SAMPLE_CONDITIONS',
                                             'TABLE_NAME': 'pdbx_nmr_exptl_sample_conditions',
                                             'TABLE_TYPE': 'transactional'},
        'PDBX_NMR_FORCE_CONSTANTS': {'ATTRIBUTES': {'COVALENT_GEOM_ANGLES_TERM': 'covalent_geom_angles_term',
                                                    'COVALENT_GEOM_ANGLES_TERM_UNITS': 'covalent_geom_angles_term_units',
                                                    'COVALENT_GEOM_BOND_TERM': 'covalent_geom_bond_term',
                                                    'COVALENT_GEOM_BOND_TERM_UNITS': 'covalent_geom_bond_term_units',
                                                    'COVALENT_GEOM_IMPROPERS_TERM': 'covalent_geom_impropers_term',
                                                    'COVALENT_GEOM_IMPROPERS_TERM_UNITS': 'covalent_geom_impropers_term_units',
                                                    'ENTRY_ID': 'entry_id',
                                                    'EXPTL_13C_SHIFT_TERM': 'exptl_13C_shift_term',
                                                    'EXPTL_13C_SHIFT_TERM_UNITS': 'exptl_13C_shift_term_units',
                                                    'EXPTL_1H_SHIFT_TERM': 'exptl_1H_shift_term',
                                                    'EXPTL_1H_SHIFT_TERM_UNITS': 'exptl_1H_shift_term_units',
                                                    'EXPTL_DIPOLAR_COUPLING_TERM': 'exptl_dipolar_coupling_term',
                                                    'EXPTL_DIPOLAR_COUPLING_TERM_UNITS': 'exptl_dipolar_coupling_term_units',
                                                    'EXPTL_DISTANCE_TERM': 'exptl_distance_term',
                                                    'EXPTL_DISTANCE_TERM_UNITS': 'exptl_distance_term_units',
                                                    'EXPTL_D_ISOTOPE_SHIFT_TERM': 'exptl_D_isotope_shift_term',
                                                    'EXPTL_D_ISOTOPE_SHIFT_TERM_UNITS': 'exptl_D_isotope_shift_term_units',
                                                    'EXPTL_J_COUPLING_TERM': 'exptl_J_coupling_term',
                                                    'EXPTL_J_COUPLING_TERM_UNITS': 'exptl_J_coupling_term_units',
                                                    'EXPTL_TORSION_ANGLES_TERM': 'exptl_torsion_angles_term',
                                                    'EXPTL_TORSION_ANGLES_TERM_UNITS': 'exptl_torsion_angles_term_units',
                                                    'NON_BONDED_INTER_CONF_DB_POTENTIAL_TERM': 'non_bonded_inter_conf_db_potential_term',
                                                    'NON_BONDED_INTER_RADIUS_OF_GYRATION_TERM': 'non_bonded_inter_radius_of_gyration_term',
                                                    'NON_BONDED_INTER_RADIUS_OF_GYRATION_TERM_UNITS': 'non_bonded_inter_radius_of_gyration_term_units',
                                                    'NON_BONDED_INTER_VAN_DER_WAALS_TERM': 'non_bonded_inter_van_der_Waals_term',
                                                    'NON_BONDED_INTER_VAN_DER_WAALS_TERM_TYPE': 'non_bonded_inter_van_der_Waals_term_type',
                                                    'NON_BONDED_INTER_VAN_DER_WAALS_TERM_UNITS': 'non_bonded_inter_van_der_Waals_term_units',
                                                    'STRUCTURE_ID': 'Structure_ID'},
                                     'ATTRIBUTE_INFO': {'COVALENT_GEOM_ANGLES_TERM': {'NULLABLE': True,
                                                                                      'ORDER': 19,
                                                                                      'PRECISION': 6,
                                                                                      'PRIMARY_KEY': False,
                                                                                      'SQL_TYPE': 'FLOAT',
                                                                                      'WIDTH': 10},
                                                        'COVALENT_GEOM_ANGLES_TERM_UNITS': {'NULLABLE': True,
                                                                                            'ORDER': 20,
                                                                                            'PRECISION': 0,
                                                                                            'PRIMARY_KEY': False,
                                                                                            'SQL_TYPE': 'VARCHAR',
                                                                                            'WIDTH': 10},
                                                        'COVALENT_GEOM_BOND_TERM': {'NULLABLE': True,
                                                                                    'ORDER': 17,
                                                                                    'PRECISION': 6,
                                                                                    'PRIMARY_KEY': False,
                                                                                    'SQL_TYPE': 'FLOAT',
                                                                                    'WIDTH': 10},
                                                        'COVALENT_GEOM_BOND_TERM_UNITS': {'NULLABLE': True,
                                                                                          'ORDER': 18,
                                                                                          'PRECISION': 0,
                                                                                          'PRIMARY_KEY': False,
                                                                                          'SQL_TYPE': 'VARCHAR',
                                                                                          'WIDTH': 10},
                                                        'COVALENT_GEOM_IMPROPERS_TERM': {'NULLABLE': True,
                                                                                         'ORDER': 21,
                                                                                         'PRECISION': 6,
                                                                                         'PRIMARY_KEY': False,
                                                                                         'SQL_TYPE': 'FLOAT',
                                                                                         'WIDTH': 10},
                                                        'COVALENT_GEOM_IMPROPERS_TERM_UNITS': {'NULLABLE': True,
                                                                                               'ORDER': 22,
                                                                                               'PRECISION': 0,
                                                                                               'PRIMARY_KEY': False,
                                                                                               'SQL_TYPE': 'VARCHAR',
                                                                                               'WIDTH': 10},
                                                        'ENTRY_ID': {'NULLABLE': False,
                                                                     'ORDER': 2,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': True,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                                        'EXPTL_13C_SHIFT_TERM': {'NULLABLE': True,
                                                                                 'ORDER': 9,
                                                                                 'PRECISION': 6,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'FLOAT',
                                                                                 'WIDTH': 10},
                                                        'EXPTL_13C_SHIFT_TERM_UNITS': {'NULLABLE': True,
                                                                                       'ORDER': 10,
                                                                                       'PRECISION': 0,
                                                                                       'PRIMARY_KEY': False,
                                                                                       'SQL_TYPE': 'VARCHAR',
                                                                                       'WIDTH': 10},
                                                        'EXPTL_1H_SHIFT_TERM': {'NULLABLE': True,
                                                                                'ORDER': 11,
                                                                                'PRECISION': 6,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'FLOAT',
                                                                                'WIDTH': 10},
                                                        'EXPTL_1H_SHIFT_TERM_UNITS': {'NULLABLE': True,
                                                                                      'ORDER': 12,
                                                                                      'PRECISION': 0,
                                                                                      'PRIMARY_KEY': False,
                                                                                      'SQL_TYPE': 'VARCHAR',
                                                                                      'WIDTH': 10},
                                                        'EXPTL_DIPOLAR_COUPLING_TERM': {'NULLABLE': True,
                                                                                        'ORDER': 13,
                                                                                        'PRECISION': 6,
                                                                                        'PRIMARY_KEY': False,
                                                                                        'SQL_TYPE': 'FLOAT',
                                                                                        'WIDTH': 10},
                                                        'EXPTL_DIPOLAR_COUPLING_TERM_UNITS': {'NULLABLE': True,
                                                                                              'ORDER': 14,
                                                                                              'PRECISION': 0,
                                                                                              'PRIMARY_KEY': False,
                                                                                              'SQL_TYPE': 'VARCHAR',
                                                                                              'WIDTH': 10},
                                                        'EXPTL_DISTANCE_TERM': {'NULLABLE': True,
                                                                                'ORDER': 3,
                                                                                'PRECISION': 6,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'FLOAT',
                                                                                'WIDTH': 10},
                                                        'EXPTL_DISTANCE_TERM_UNITS': {'NULLABLE': True,
                                                                                      'ORDER': 4,
                                                                                      'PRECISION': 0,
                                                                                      'PRIMARY_KEY': False,
                                                                                      'SQL_TYPE': 'VARCHAR',
                                                                                      'WIDTH': 10},
                                                        'EXPTL_D_ISOTOPE_SHIFT_TERM': {'NULLABLE': True,
                                                                                       'ORDER': 15,
                                                                                       'PRECISION': 6,
                                                                                       'PRIMARY_KEY': False,
                                                                                       'SQL_TYPE': 'FLOAT',
                                                                                       'WIDTH': 10},
                                                        'EXPTL_D_ISOTOPE_SHIFT_TERM_UNITS': {'NULLABLE': True,
                                                                                             'ORDER': 16,
                                                                                             'PRECISION': 0,
                                                                                             'PRIMARY_KEY': False,
                                                                                             'SQL_TYPE': 'VARCHAR',
                                                                                             'WIDTH': 10},
                                                        'EXPTL_J_COUPLING_TERM': {'NULLABLE': True,
                                                                                  'ORDER': 7,
                                                                                  'PRECISION': 6,
                                                                                  'PRIMARY_KEY': False,
                                                                                  'SQL_TYPE': 'FLOAT',
                                                                                  'WIDTH': 10},
                                                        'EXPTL_J_COUPLING_TERM_UNITS': {'NULLABLE': True,
                                                                                        'ORDER': 8,
                                                                                        'PRECISION': 0,
                                                                                        'PRIMARY_KEY': False,
                                                                                        'SQL_TYPE': 'VARCHAR',
                                                                                        'WIDTH': 10},
                                                        'EXPTL_TORSION_ANGLES_TERM': {'NULLABLE': True,
                                                                                      'ORDER': 5,
                                                                                      'PRECISION': 6,
                                                                                      'PRIMARY_KEY': False,
                                                                                      'SQL_TYPE': 'FLOAT',
                                                                                      'WIDTH': 10},
                                                        'EXPTL_TORSION_ANGLES_TERM_UNITS': {'NULLABLE': True,
                                                                                            'ORDER': 6,
                                                                                            'PRECISION': 0,
                                                                                            'PRIMARY_KEY': False,
                                                                                            'SQL_TYPE': 'VARCHAR',
                                                                                            'WIDTH': 10},
                                                        'NON_BONDED_INTER_CONF_DB_POTENTIAL_TERM': {'NULLABLE': True,
                                                                                                    'ORDER': 26,
                                                                                                    'PRECISION': 6,
                                                                                                    'PRIMARY_KEY': False,
                                                                                                    'SQL_TYPE': 'FLOAT',
                                                                                                    'WIDTH': 10},
                                                        'NON_BONDED_INTER_RADIUS_OF_GYRATION_TERM': {'NULLABLE': True,
                                                                                                     'ORDER': 27,
                                                                                                     'PRECISION': 6,
                                                                                                     'PRIMARY_KEY': False,
                                                                                                     'SQL_TYPE': 'FLOAT',
                                                                                                     'WIDTH': 10},
                                                        'NON_BONDED_INTER_RADIUS_OF_GYRATION_TERM_UNITS': {'NULLABLE': True,
                                                                                                           'ORDER': 28,
                                                                                                           'PRECISION': 0,
                                                                                                           'PRIMARY_KEY': False,
                                                                                                           'SQL_TYPE': 'VARCHAR',
                                                                                                           'WIDTH': 10},
                                                        'NON_BONDED_INTER_VAN_DER_WAALS_TERM': {'NULLABLE': True,
                                                                                                'ORDER': 24,
                                                                                                'PRECISION': 6,
                                                                                                'PRIMARY_KEY': False,
                                                                                                'SQL_TYPE': 'FLOAT',
                                                                                                'WIDTH': 10},
                                                        'NON_BONDED_INTER_VAN_DER_WAALS_TERM_TYPE': {'NULLABLE': True,
                                                                                                     'ORDER': 23,
                                                                                                     'PRECISION': 0,
                                                                                                     'PRIMARY_KEY': False,
                                                                                                     'SQL_TYPE': 'VARCHAR',
                                                                                                     'WIDTH': 200},
                                                        'NON_BONDED_INTER_VAN_DER_WAALS_TERM_UNITS': {'NULLABLE': True,
                                                                                                      'ORDER': 25,
                                                                                                      'PRECISION': 0,
                                                                                                      'PRIMARY_KEY': False,
                                                                                                      'SQL_TYPE': 'VARCHAR',
                                                                                                      'WIDTH': 10},
                                                        'STRUCTURE_ID': {'NULLABLE': False,
                                                                         'ORDER': 1,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': True,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10}},
                                     'ATTRIBUTE_MAP': {'COVALENT_GEOM_ANGLES_TERM': ('pdbx_nmr_force_constants',
                                                                                     'covalent_geom_angles_term',
                                                                                     None,
                                                                                     None),
                                                       'COVALENT_GEOM_ANGLES_TERM_UNITS': ('pdbx_nmr_force_constants',
                                                                                           'covalent_geom_angles_term_units',
                                                                                           None,
                                                                                           None),
                                                       'COVALENT_GEOM_BOND_TERM': ('pdbx_nmr_force_constants',
                                                                                   'covalent_geom_bond_term',
                                                                                   None,
                                                                                   None),
                                                       'COVALENT_GEOM_BOND_TERM_UNITS': ('pdbx_nmr_force_constants',
                                                                                         'covalent_geom_bond_term_units',
                                                                                         None,
                                                                                         None),
                                                       'COVALENT_GEOM_IMPROPERS_TERM': ('pdbx_nmr_force_constants',
                                                                                        'covalent_geom_impropers_term',
                                                                                        None,
                                                                                        None),
                                                       'COVALENT_GEOM_IMPROPERS_TERM_UNITS': ('pdbx_nmr_force_constants',
                                                                                              'covalent_geom_impropers_term_units',
                                                                                              None,
                                                                                              None),
                                                       'ENTRY_ID': ('pdbx_nmr_force_constants', 'entry_id', None, None),
                                                       'EXPTL_13C_SHIFT_TERM': ('pdbx_nmr_force_constants',
                                                                                'exptl_13C_shift_term',
                                                                                None,
                                                                                None),
                                                       'EXPTL_13C_SHIFT_TERM_UNITS': ('pdbx_nmr_force_constants',
                                                                                      'exptl_13C_shift_term_units',
                                                                                      None,
                                                                                      None),
                                                       'EXPTL_1H_SHIFT_TERM': ('pdbx_nmr_force_constants',
                                                                               'exptl_1H_shift_term',
                                                                               None,
                                                                               None),
                                                       'EXPTL_1H_SHIFT_TERM_UNITS': ('pdbx_nmr_force_constants',
                                                                                     'exptl_1H_shift_term_units',
                                                                                     None,
                                                                                     None),
                                                       'EXPTL_DIPOLAR_COUPLING_TERM': ('pdbx_nmr_force_constants',
                                                                                       'exptl_dipolar_coupling_term',
                                                                                       None,
                                                                                       None),
                                                       'EXPTL_DIPOLAR_COUPLING_TERM_UNITS': ('pdbx_nmr_force_constants',
                                                                                             'exptl_dipolar_coupling_term_units',
                                                                                             None,
                                                                                             None),
                                                       'EXPTL_DISTANCE_TERM': ('pdbx_nmr_force_constants',
                                                                               'exptl_distance_term',
                                                                               None,
                                                                               None),
                                                       'EXPTL_DISTANCE_TERM_UNITS': ('pdbx_nmr_force_constants',
                                                                                     'exptl_distance_term_units',
                                                                                     None,
                                                                                     None),
                                                       'EXPTL_D_ISOTOPE_SHIFT_TERM': ('pdbx_nmr_force_constants',
                                                                                      'exptl_D_isotope_shift_term',
                                                                                      None,
                                                                                      None),
                                                       'EXPTL_D_ISOTOPE_SHIFT_TERM_UNITS': ('pdbx_nmr_force_constants',
                                                                                            'exptl_D_isotope_shift_term_units',
                                                                                            None,
                                                                                            None),
                                                       'EXPTL_J_COUPLING_TERM': ('pdbx_nmr_force_constants',
                                                                                 'exptl_J_coupling_term',
                                                                                 None,
                                                                                 None),
                                                       'EXPTL_J_COUPLING_TERM_UNITS': ('pdbx_nmr_force_constants',
                                                                                       'exptl_J_coupling_term_units',
                                                                                       None,
                                                                                       None),
                                                       'EXPTL_TORSION_ANGLES_TERM': ('pdbx_nmr_force_constants',
                                                                                     'exptl_torsion_angles_term',
                                                                                     None,
                                                                                     None),
                                                       'EXPTL_TORSION_ANGLES_TERM_UNITS': ('pdbx_nmr_force_constants',
                                                                                           'exptl_torsion_angles_term_units',
                                                                                           None,
                                                                                           None),
                                                       'NON_BONDED_INTER_CONF_DB_POTENTIAL_TERM': ('pdbx_nmr_force_constants',
                                                                                                   'non-bonded_inter_conf_db_potential_term',
                                                                                                   None,
                                                                                                   None),
                                                       'NON_BONDED_INTER_RADIUS_OF_GYRATION_TERM': ('pdbx_nmr_force_constants',
                                                                                                    'non-bonded_inter_radius_of_gyration_term',
                                                                                                    None,
                                                                                                    None),
                                                       'NON_BONDED_INTER_RADIUS_OF_GYRATION_TERM_UNITS': ('pdbx_nmr_force_constants',
                                                                                                          'non-bonded_inter_radius_of_gyration_term_units',
                                                                                                          None,
                                                                                                          None),
                                                       'NON_BONDED_INTER_VAN_DER_WAALS_TERM': ('pdbx_nmr_force_constants',
                                                                                               'non-bonded_inter_van_der_Waals_term',
                                                                                               None,
                                                                                               None),
                                                       'NON_BONDED_INTER_VAN_DER_WAALS_TERM_TYPE': ('pdbx_nmr_force_constants',
                                                                                                    'non-bonded_inter_van_der_Waals_term_type',
                                                                                                    None,
                                                                                                    None),
                                                       'NON_BONDED_INTER_VAN_DER_WAALS_TERM_UNITS': ('pdbx_nmr_force_constants',
                                                                                                     'non-bonded_inter_van_der_Waals_term_units',
                                                                                                     None,
                                                                                                     None),
                                                       'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                     'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID'), 'TYPE': 'UNIQUE'},
                                                 's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                     'MAP_MERGE_INDICES': {'pdbx_nmr_force_constants': {'ATTRIBUTES': ('entry_id',),
                                                                                        'TYPE': 'EQUI-JOIN'}},
                                     'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                     'TABLE_ID': 'PDBX_NMR_FORCE_CONSTANTS',
                                     'TABLE_NAME': 'pdbx_nmr_force_constants',
                                     'TABLE_TYPE': 'transactional'},
        'PDBX_NMR_REFINE': {'ATTRIBUTES': {'DETAILS': 'details',
                                           'ENTRY_ID': 'entry_id',
                                           'METHOD': 'method',
                                           'STRUCTURE_ID': 'Structure_ID'},
                            'ATTRIBUTE_INFO': {'DETAILS': {'NULLABLE': True,
                                                           'ORDER': 4,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 16383},
                                               'ENTRY_ID': {'NULLABLE': False,
                                                            'ORDER': 2,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': True,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 10},
                                               'METHOD': {'NULLABLE': True,
                                                          'ORDER': 3,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 4095},
                                               'STRUCTURE_ID': {'NULLABLE': False,
                                                                'ORDER': 1,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10}},
                            'ATTRIBUTE_MAP': {'DETAILS': ('pdbx_nmr_refine', 'details', None, None),
                                              'ENTRY_ID': ('pdbx_nmr_refine', 'entry_id', None, None),
                                              'METHOD': ('pdbx_nmr_refine', 'method', None, None),
                                              'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                            'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID'), 'TYPE': 'UNIQUE'},
                                        's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                            'MAP_MERGE_INDICES': {'pdbx_nmr_refine': {'ATTRIBUTES': ('entry_id',), 'TYPE': 'EQUI-JOIN'}},
                            'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                            'TABLE_ID': 'PDBX_NMR_REFINE',
                            'TABLE_NAME': 'pdbx_nmr_refine',
                            'TABLE_TYPE': 'transactional'},
        'PDBX_NMR_REPRESENTATIVE': {'ATTRIBUTES': {'CONFORMER_ID': 'conformer_id',
                                                   'ENTRY_ID': 'entry_id',
                                                   'SELECTION_CRITERIA': 'selection_criteria',
                                                   'STRUCTURE_ID': 'Structure_ID'},
                                    'ATTRIBUTE_INFO': {'CONFORMER_ID': {'NULLABLE': True,
                                                                        'ORDER': 3,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 80},
                                                       'ENTRY_ID': {'NULLABLE': False,
                                                                    'ORDER': 2,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': True,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10},
                                                       'SELECTION_CRITERIA': {'NULLABLE': True,
                                                                              'ORDER': 4,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 255},
                                                       'STRUCTURE_ID': {'NULLABLE': False,
                                                                        'ORDER': 1,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': True,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10}},
                                    'ATTRIBUTE_MAP': {'CONFORMER_ID': ('pdbx_nmr_representative', 'conformer_id', None, None),
                                                      'ENTRY_ID': ('pdbx_nmr_representative', 'entry_id', None, None),
                                                      'SELECTION_CRITERIA': ('pdbx_nmr_representative',
                                                                             'selection_criteria',
                                                                             None,
                                                                             None),
                                                      'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                    'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID'), 'TYPE': 'UNIQUE'},
                                                's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                    'MAP_MERGE_INDICES': {'pdbx_nmr_representative': {'ATTRIBUTES': ('entry_id',),
                                                                                      'TYPE': 'EQUI-JOIN'}},
                                    'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                    'TABLE_ID': 'PDBX_NMR_REPRESENTATIVE',
                                    'TABLE_NAME': 'pdbx_nmr_representative',
                                    'TABLE_TYPE': 'transactional'},
        'PDBX_NMR_SAMPLE_DETAILS': {'ATTRIBUTES': {'CONTENTS': 'contents',
                                                   'SOLUTION_ID': 'solution_id',
                                                   'SOLVENT_SYSTEM': 'solvent_system',
                                                   'STRUCTURE_ID': 'Structure_ID'},
                                    'ATTRIBUTE_INFO': {'CONTENTS': {'NULLABLE': True,
                                                                    'ORDER': 3,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 4095},
                                                       'SOLUTION_ID': {'NULLABLE': False,
                                                                       'ORDER': 2,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': True,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                       'SOLVENT_SYSTEM': {'NULLABLE': True,
                                                                          'ORDER': 4,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 511},
                                                       'STRUCTURE_ID': {'NULLABLE': False,
                                                                        'ORDER': 1,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': True,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10}},
                                    'ATTRIBUTE_MAP': {'CONTENTS': ('pdbx_nmr_sample_details', 'contents', None, None),
                                                      'SOLUTION_ID': ('pdbx_nmr_sample_details', 'solution_id', None, None),
                                                      'SOLVENT_SYSTEM': ('pdbx_nmr_sample_details',
                                                                         'solvent_system',
                                                                         None,
                                                                         None),
                                                      'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                    'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'SOLUTION_ID'), 'TYPE': 'UNIQUE'},
                                                's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                    'MAP_MERGE_INDICES': {'pdbx_nmr_sample_details': {'ATTRIBUTES': ('solution_id',),
                                                                                      'TYPE': 'EQUI-JOIN'}},
                                    'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                    'TABLE_ID': 'PDBX_NMR_SAMPLE_DETAILS',
                                    'TABLE_NAME': 'pdbx_nmr_sample_details',
                                    'TABLE_TYPE': 'transactional'},
        'PDBX_NMR_SOFTWARE': {'ATTRIBUTES': {'AUTHORS': 'authors',
                                             'CLASSIFICATION': 'classification',
                                             'NAME': 'name',
                                             'ORDINAL': 'ordinal',
                                             'STRUCTURE_ID': 'Structure_ID',
                                             'VERSION': 'version'},
                              'ATTRIBUTE_INFO': {'AUTHORS': {'NULLABLE': True,
                                                             'ORDER': 6,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 511},
                                                 'CLASSIFICATION': {'NULLABLE': True,
                                                                    'ORDER': 3,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 128},
                                                 'NAME': {'NULLABLE': True,
                                                          'ORDER': 4,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 255},
                                                 'ORDINAL': {'NULLABLE': False,
                                                             'ORDER': 2,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'INT',
                                                             'WIDTH': 10},
                                                 'STRUCTURE_ID': {'NULLABLE': False,
                                                                  'ORDER': 1,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': True,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10},
                                                 'VERSION': {'NULLABLE': True,
                                                             'ORDER': 5,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 80}},
                              'ATTRIBUTE_MAP': {'AUTHORS': ('pdbx_nmr_software', 'authors', None, None),
                                                'CLASSIFICATION': ('pdbx_nmr_software', 'classification', None, None),
                                                'NAME': ('pdbx_nmr_software', 'name', None, None),
                                                'ORDINAL': ('pdbx_nmr_software', 'ordinal', None, None),
                                                'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                'VERSION': ('pdbx_nmr_software', 'version', None, None)},
                              'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ORDINAL'), 'TYPE': 'UNIQUE'},
                                          's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                              'MAP_MERGE_INDICES': {'pdbx_nmr_software': {'ATTRIBUTES': ('ordinal',), 'TYPE': 'EQUI-JOIN'}},
                              'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                              'TABLE_ID': 'PDBX_NMR_SOFTWARE',
                              'TABLE_NAME': 'pdbx_nmr_software',
                              'TABLE_TYPE': 'transactional'},
        'PDBX_NMR_SPECTROMETER': {'ATTRIBUTES': {'FIELD_STRENGTH': 'field_strength',
                                                 'MANUFACTURER': 'manufacturer',
                                                 'MODEL': 'model',
                                                 'SPECTROMETER_ID': 'spectrometer_id',
                                                 'STRUCTURE_ID': 'Structure_ID',
                                                 'TYPE': 'type'},
                                  'ATTRIBUTE_INFO': {'FIELD_STRENGTH': {'NULLABLE': True,
                                                                        'ORDER': 6,
                                                                        'PRECISION': 6,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'FLOAT',
                                                                        'WIDTH': 10},
                                                     'MANUFACTURER': {'NULLABLE': True,
                                                                      'ORDER': 5,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 80},
                                                     'MODEL': {'NULLABLE': True,
                                                               'ORDER': 3,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 80},
                                                     'SPECTROMETER_ID': {'NULLABLE': False,
                                                                         'ORDER': 2,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': True,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 17},
                                                     'STRUCTURE_ID': {'NULLABLE': False,
                                                                      'ORDER': 1,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                                     'TYPE': {'NULLABLE': True,
                                                              'ORDER': 4,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 80}},
                                  'ATTRIBUTE_MAP': {'FIELD_STRENGTH': ('pdbx_nmr_spectrometer', 'field_strength', None, None),
                                                    'MANUFACTURER': ('pdbx_nmr_spectrometer', 'manufacturer', None, None),
                                                    'MODEL': ('pdbx_nmr_spectrometer', 'model', None, None),
                                                    'SPECTROMETER_ID': ('pdbx_nmr_spectrometer',
                                                                        'spectrometer_id',
                                                                        None,
                                                                        None),
                                                    'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                    'TYPE': ('pdbx_nmr_spectrometer', 'type', None, None)},
                                  'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'SPECTROMETER_ID'), 'TYPE': 'UNIQUE'},
                                              's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                  'MAP_MERGE_INDICES': {'pdbx_nmr_spectrometer': {'ATTRIBUTES': ('spectrometer_id',),
                                                                                  'TYPE': 'EQUI-JOIN'}},
                                  'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                  'TABLE_ID': 'PDBX_NMR_SPECTROMETER',
                                  'TABLE_NAME': 'pdbx_nmr_spectrometer',
                                  'TABLE_TYPE': 'transactional'},
        'PDBX_NONPOLY_SCHEME': {'ATTRIBUTES': {'ASYM_ID': 'asym_id',
                                               'AUTH_MON_ID': 'auth_mon_id',
                                               'AUTH_SEQ_NUM': 'auth_seq_num',
                                               'ENTITY_ID': 'entity_id',
                                               'MON_ID': 'mon_id',
                                               'NDB_SEQ_NUM': 'ndb_seq_num',
                                               'PDB_INS_CODE': 'pdb_ins_code',
                                               'PDB_MON_ID': 'pdb_mon_id',
                                               'PDB_SEQ_NUM': 'pdb_seq_num',
                                               'PDB_STRAND_ID': 'pdb_strand_id',
                                               'STRUCTURE_ID': 'Structure_ID'},
                                'ATTRIBUTE_INFO': {'ASYM_ID': {'NULLABLE': False,
                                                               'ORDER': 2,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                                   'AUTH_MON_ID': {'NULLABLE': True,
                                                                   'ORDER': 10,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 10},
                                                   'AUTH_SEQ_NUM': {'NULLABLE': True,
                                                                    'ORDER': 8,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10},
                                                   'ENTITY_ID': {'NULLABLE': True,
                                                                 'ORDER': 3,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                                   'MON_ID': {'NULLABLE': True,
                                                              'ORDER': 4,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10},
                                                   'NDB_SEQ_NUM': {'NULLABLE': False,
                                                                   'ORDER': 6,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': True,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 10},
                                                   'PDB_INS_CODE': {'NULLABLE': True,
                                                                    'ORDER': 11,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10},
                                                   'PDB_MON_ID': {'NULLABLE': True,
                                                                  'ORDER': 9,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10},
                                                   'PDB_SEQ_NUM': {'NULLABLE': True,
                                                                   'ORDER': 7,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 10},
                                                   'PDB_STRAND_ID': {'NULLABLE': True,
                                                                     'ORDER': 5,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                                   'STRUCTURE_ID': {'NULLABLE': False,
                                                                    'ORDER': 1,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': True,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10}},
                                'ATTRIBUTE_MAP': {'ASYM_ID': ('pdbx_nonpoly_scheme', 'asym_id', None, None),
                                                  'AUTH_MON_ID': ('pdbx_nonpoly_scheme', 'auth_mon_id', None, None),
                                                  'AUTH_SEQ_NUM': ('pdbx_nonpoly_scheme', 'auth_seq_num', None, None),
                                                  'ENTITY_ID': ('pdbx_nonpoly_scheme', 'entity_id', None, None),
                                                  'MON_ID': ('pdbx_nonpoly_scheme', 'mon_id', None, None),
                                                  'NDB_SEQ_NUM': ('pdbx_nonpoly_scheme', 'ndb_seq_num', None, None),
                                                  'PDB_INS_CODE': ('pdbx_nonpoly_scheme', 'pdb_ins_code', None, None),
                                                  'PDB_MON_ID': ('pdbx_nonpoly_scheme', 'pdb_mon_id', None, None),
                                                  'PDB_SEQ_NUM': ('pdbx_nonpoly_scheme', 'pdb_seq_num', None, None),
                                                  'PDB_STRAND_ID': ('pdbx_nonpoly_scheme', 'pdb_strand_id', None, None),
                                                  'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ASYM_ID', 'NDB_SEQ_NUM'), 'TYPE': 'UNIQUE'},
                                            's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                'MAP_MERGE_INDICES': {'pdbx_nonpoly_scheme': {'ATTRIBUTES': ('asym_id', 'ndb_seq_num'),
                                                                              'TYPE': 'EQUI-JOIN'}},
                                'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                'TABLE_ID': 'PDBX_NONPOLY_SCHEME',
                                'TABLE_NAME': 'pdbx_nonpoly_scheme',
                                'TABLE_TYPE': 'transactional'},
        'PDBX_PHASING_DM': {'ATTRIBUTES': {'DELTA_PHI_FINAL': 'delta_phi_final',
                                           'DELTA_PHI_INITIAL': 'delta_phi_initial',
                                           'ENTRY_ID': 'entry_id',
                                           'FOM': 'fom',
                                           'FOM_ACENTRIC': 'fom_acentric',
                                           'FOM_CENTRIC': 'fom_centric',
                                           'MASK_TYPE': 'mask_type',
                                           'METHOD': 'method',
                                           'REFLNS': 'reflns',
                                           'REFLNS_ACENTRIC': 'reflns_acentric',
                                           'REFLNS_CENTRIC': 'reflns_centric',
                                           'STRUCTURE_ID': 'Structure_ID'},
                            'ATTRIBUTE_INFO': {'DELTA_PHI_FINAL': {'NULLABLE': True,
                                                                   'ORDER': 12,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                               'DELTA_PHI_INITIAL': {'NULLABLE': True,
                                                                     'ORDER': 11,
                                                                     'PRECISION': 6,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'FLOAT',
                                                                     'WIDTH': 10},
                                               'ENTRY_ID': {'NULLABLE': False,
                                                            'ORDER': 2,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': True,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 10},
                                               'FOM': {'NULLABLE': True,
                                                       'ORDER': 7,
                                                       'PRECISION': 6,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'FLOAT',
                                                       'WIDTH': 10},
                                               'FOM_ACENTRIC': {'NULLABLE': True,
                                                                'ORDER': 5,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                               'FOM_CENTRIC': {'NULLABLE': True,
                                                               'ORDER': 6,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                               'MASK_TYPE': {'NULLABLE': True,
                                                             'ORDER': 4,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 80},
                                               'METHOD': {'NULLABLE': True,
                                                          'ORDER': 3,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 80},
                                               'REFLNS': {'NULLABLE': True,
                                                          'ORDER': 10,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'INT',
                                                          'WIDTH': 10},
                                               'REFLNS_ACENTRIC': {'NULLABLE': True,
                                                                   'ORDER': 8,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'INT',
                                                                   'WIDTH': 10},
                                               'REFLNS_CENTRIC': {'NULLABLE': True,
                                                                  'ORDER': 9,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'INT',
                                                                  'WIDTH': 10},
                                               'STRUCTURE_ID': {'NULLABLE': False,
                                                                'ORDER': 1,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10}},
                            'ATTRIBUTE_MAP': {'DELTA_PHI_FINAL': ('pdbx_phasing_dm', 'delta_phi_final', None, None),
                                              'DELTA_PHI_INITIAL': ('pdbx_phasing_dm', 'delta_phi_initial', None, None),
                                              'ENTRY_ID': ('pdbx_phasing_dm', 'entry_id', None, None),
                                              'FOM': ('pdbx_phasing_dm', 'fom', None, None),
                                              'FOM_ACENTRIC': ('pdbx_phasing_dm', 'fom_acentric', None, None),
                                              'FOM_CENTRIC': ('pdbx_phasing_dm', 'fom_centric', None, None),
                                              'MASK_TYPE': ('pdbx_phasing_dm', 'mask_type', None, None),
                                              'METHOD': ('pdbx_phasing_dm', 'method', None, None),
                                              'REFLNS': ('pdbx_phasing_dm', 'reflns', None, None),
                                              'REFLNS_ACENTRIC': ('pdbx_phasing_dm', 'reflns_acentric', None, None),
                                              'REFLNS_CENTRIC': ('pdbx_phasing_dm', 'reflns_centric', None, None),
                                              'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                            'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID'), 'TYPE': 'UNIQUE'},
                                        's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                            'MAP_MERGE_INDICES': {'pdbx_phasing_dm': {'ATTRIBUTES': ('entry_id',), 'TYPE': 'EQUI-JOIN'}},
                            'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                            'TABLE_ID': 'PDBX_PHASING_DM',
                            'TABLE_NAME': 'pdbx_phasing_dm',
                            'TABLE_TYPE': 'transactional'},
        'PDBX_PHASING_DM_SHELL': {'ATTRIBUTES': {'DELTA_PHI_FINAL': 'delta_phi_final',
                                                 'DELTA_PHI_INITIAL': 'delta_phi_initial',
                                                 'D_RES_HIGH': 'd_res_high',
                                                 'D_RES_LOW': 'd_res_low',
                                                 'FOM': 'fom',
                                                 'FOM_ACENTRIC': 'fom_acentric',
                                                 'FOM_CENTRIC': 'fom_centric',
                                                 'REFLNS': 'reflns',
                                                 'REFLNS_ACENTRIC': 'reflns_acentric',
                                                 'REFLNS_CENTRIC': 'reflns_centric',
                                                 'STRUCTURE_ID': 'Structure_ID'},
                                  'ATTRIBUTE_INFO': {'DELTA_PHI_FINAL': {'NULLABLE': True,
                                                                         'ORDER': 11,
                                                                         'PRECISION': 6,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'FLOAT',
                                                                         'WIDTH': 10},
                                                     'DELTA_PHI_INITIAL': {'NULLABLE': True,
                                                                           'ORDER': 10,
                                                                           'PRECISION': 6,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'FLOAT',
                                                                           'WIDTH': 10},
                                                     'D_RES_HIGH': {'NULLABLE': False,
                                                                    'ORDER': 2,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': True,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                                     'D_RES_LOW': {'NULLABLE': False,
                                                                   'ORDER': 3,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': True,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                                     'FOM': {'NULLABLE': True,
                                                             'ORDER': 6,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                                     'FOM_ACENTRIC': {'NULLABLE': True,
                                                                      'ORDER': 4,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                                     'FOM_CENTRIC': {'NULLABLE': True,
                                                                     'ORDER': 5,
                                                                     'PRECISION': 6,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'FLOAT',
                                                                     'WIDTH': 10},
                                                     'REFLNS': {'NULLABLE': True,
                                                                'ORDER': 9,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'INT',
                                                                'WIDTH': 10},
                                                     'REFLNS_ACENTRIC': {'NULLABLE': True,
                                                                         'ORDER': 7,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'INT',
                                                                         'WIDTH': 10},
                                                     'REFLNS_CENTRIC': {'NULLABLE': True,
                                                                        'ORDER': 8,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'INT',
                                                                        'WIDTH': 10},
                                                     'STRUCTURE_ID': {'NULLABLE': False,
                                                                      'ORDER': 1,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10}},
                                  'ATTRIBUTE_MAP': {'DELTA_PHI_FINAL': ('pdbx_phasing_dm_shell',
                                                                        'delta_phi_final',
                                                                        None,
                                                                        None),
                                                    'DELTA_PHI_INITIAL': ('pdbx_phasing_dm_shell',
                                                                          'delta_phi_initial',
                                                                          None,
                                                                          None),
                                                    'D_RES_HIGH': ('pdbx_phasing_dm_shell', 'd_res_high', None, None),
                                                    'D_RES_LOW': ('pdbx_phasing_dm_shell', 'd_res_low', None, None),
                                                    'FOM': ('pdbx_phasing_dm_shell', 'fom', None, None),
                                                    'FOM_ACENTRIC': ('pdbx_phasing_dm_shell', 'fom_acentric', None, None),
                                                    'FOM_CENTRIC': ('pdbx_phasing_dm_shell', 'fom_centric', None, None),
                                                    'REFLNS': ('pdbx_phasing_dm_shell', 'reflns', None, None),
                                                    'REFLNS_ACENTRIC': ('pdbx_phasing_dm_shell',
                                                                        'reflns_acentric',
                                                                        None,
                                                                        None),
                                                    'REFLNS_CENTRIC': ('pdbx_phasing_dm_shell', 'reflns_centric', None, None),
                                                    'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                  'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'D_RES_HIGH', 'D_RES_LOW'),
                                                     'TYPE': 'UNIQUE'},
                                              's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                  'MAP_MERGE_INDICES': {'pdbx_phasing_dm_shell': {'ATTRIBUTES': ('d_res_high', 'd_res_low'),
                                                                                  'TYPE': 'EQUI-JOIN'}},
                                  'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                  'TABLE_ID': 'PDBX_PHASING_DM_SHELL',
                                  'TABLE_NAME': 'pdbx_phasing_dm_shell',
                                  'TABLE_TYPE': 'transactional'},
        'PDBX_PHASING_MAD_SET': {'ATTRIBUTES': {'D_RES_HIGH': 'd_res_high',
                                                'D_RES_LOW': 'd_res_low',
                                                'FOM': 'fom',
                                                'FOM_ACENTRIC': 'fom_acentric',
                                                'FOM_CENTRIC': 'fom_centric',
                                                'ID': 'id',
                                                'LOC': 'loc',
                                                'LOC_ACENTRIC': 'loc_acentric',
                                                'LOC_CENTRIC': 'loc_centric',
                                                'NUMBER_OF_SITES': 'number_of_sites',
                                                'POWER': 'power',
                                                'POWER_ACENTRIC': 'power_acentric',
                                                'POWER_CENTRIC': 'power_centric',
                                                'REFLNS': 'reflns',
                                                'REFLNS_ACENTRIC': 'reflns_acentric',
                                                'REFLNS_CENTRIC': 'reflns_centric',
                                                'R_CULLIS': 'R_cullis',
                                                'R_CULLIS_ACENTRIC': 'R_cullis_acentric',
                                                'R_CULLIS_CENTRIC': 'R_cullis_centric',
                                                'R_KRAUT': 'R_kraut',
                                                'R_KRAUT_ACENTRIC': 'R_kraut_acentric',
                                                'R_KRAUT_CENTRIC': 'R_kraut_centric',
                                                'STRUCTURE_ID': 'Structure_ID'},
                                 'ATTRIBUTE_INFO': {'D_RES_HIGH': {'NULLABLE': True,
                                                                   'ORDER': 4,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                                    'D_RES_LOW': {'NULLABLE': True,
                                                                  'ORDER': 3,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10},
                                                    'FOM': {'NULLABLE': True,
                                                            'ORDER': 11,
                                                            'PRECISION': 6,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'FLOAT',
                                                            'WIDTH': 10},
                                                    'FOM_ACENTRIC': {'NULLABLE': True,
                                                                     'ORDER': 9,
                                                                     'PRECISION': 6,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'FLOAT',
                                                                     'WIDTH': 10},
                                                    'FOM_CENTRIC': {'NULLABLE': True,
                                                                    'ORDER': 10,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                                    'ID': {'NULLABLE': False,
                                                           'ORDER': 2,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': True,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 13},
                                                    'LOC': {'NULLABLE': True,
                                                            'ORDER': 20,
                                                            'PRECISION': 6,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'FLOAT',
                                                            'WIDTH': 10},
                                                    'LOC_ACENTRIC': {'NULLABLE': True,
                                                                     'ORDER': 19,
                                                                     'PRECISION': 6,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'FLOAT',
                                                                     'WIDTH': 10},
                                                    'LOC_CENTRIC': {'NULLABLE': True,
                                                                    'ORDER': 18,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                                    'NUMBER_OF_SITES': {'NULLABLE': True,
                                                                        'ORDER': 5,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'INT',
                                                                        'WIDTH': 10},
                                                    'POWER': {'NULLABLE': True,
                                                              'ORDER': 23,
                                                              'PRECISION': 6,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'FLOAT',
                                                              'WIDTH': 10},
                                                    'POWER_ACENTRIC': {'NULLABLE': True,
                                                                       'ORDER': 22,
                                                                       'PRECISION': 6,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'FLOAT',
                                                                       'WIDTH': 10},
                                                    'POWER_CENTRIC': {'NULLABLE': True,
                                                                      'ORDER': 21,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                                    'REFLNS': {'NULLABLE': True,
                                                               'ORDER': 8,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'INT',
                                                               'WIDTH': 10},
                                                    'REFLNS_ACENTRIC': {'NULLABLE': True,
                                                                        'ORDER': 6,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'INT',
                                                                        'WIDTH': 10},
                                                    'REFLNS_CENTRIC': {'NULLABLE': True,
                                                                       'ORDER': 7,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'INT',
                                                                       'WIDTH': 10},
                                                    'R_CULLIS': {'NULLABLE': True,
                                                                 'ORDER': 14,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                                    'R_CULLIS_ACENTRIC': {'NULLABLE': True,
                                                                          'ORDER': 13,
                                                                          'PRECISION': 6,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'FLOAT',
                                                                          'WIDTH': 10},
                                                    'R_CULLIS_CENTRIC': {'NULLABLE': True,
                                                                         'ORDER': 12,
                                                                         'PRECISION': 6,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'FLOAT',
                                                                         'WIDTH': 10},
                                                    'R_KRAUT': {'NULLABLE': True,
                                                                'ORDER': 17,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                                    'R_KRAUT_ACENTRIC': {'NULLABLE': True,
                                                                         'ORDER': 16,
                                                                         'PRECISION': 6,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'FLOAT',
                                                                         'WIDTH': 10},
                                                    'R_KRAUT_CENTRIC': {'NULLABLE': True,
                                                                        'ORDER': 15,
                                                                        'PRECISION': 6,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'FLOAT',
                                                                        'WIDTH': 10},
                                                    'STRUCTURE_ID': {'NULLABLE': False,
                                                                     'ORDER': 1,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': True,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10}},
                                 'ATTRIBUTE_MAP': {'D_RES_HIGH': ('pdbx_phasing_MAD_set', 'd_res_high', None, None),
                                                   'D_RES_LOW': ('pdbx_phasing_MAD_set', 'd_res_low', None, None),
                                                   'FOM': ('pdbx_phasing_MAD_set', 'fom', None, None),
                                                   'FOM_ACENTRIC': ('pdbx_phasing_MAD_set', 'fom_acentric', None, None),
                                                   'FOM_CENTRIC': ('pdbx_phasing_MAD_set', 'fom_centric', None, None),
                                                   'ID': ('pdbx_phasing_MAD_set', 'id', None, None),
                                                   'LOC': ('pdbx_phasing_MAD_set', 'loc', None, None),
                                                   'LOC_ACENTRIC': ('pdbx_phasing_MAD_set', 'loc_acentric', None, None),
                                                   'LOC_CENTRIC': ('pdbx_phasing_MAD_set', 'loc_centric', None, None),
                                                   'NUMBER_OF_SITES': ('pdbx_phasing_MAD_set', 'number_of_sites', None, None),
                                                   'POWER': ('pdbx_phasing_MAD_set', 'power', None, None),
                                                   'POWER_ACENTRIC': ('pdbx_phasing_MAD_set', 'power_acentric', None, None),
                                                   'POWER_CENTRIC': ('pdbx_phasing_MAD_set', 'power_centric', None, None),
                                                   'REFLNS': ('pdbx_phasing_MAD_set', 'reflns', None, None),
                                                   'REFLNS_ACENTRIC': ('pdbx_phasing_MAD_set', 'reflns_acentric', None, None),
                                                   'REFLNS_CENTRIC': ('pdbx_phasing_MAD_set', 'reflns_centric', None, None),
                                                   'R_CULLIS': ('pdbx_phasing_MAD_set', 'R_cullis', None, None),
                                                   'R_CULLIS_ACENTRIC': ('pdbx_phasing_MAD_set',
                                                                         'R_cullis_acentric',
                                                                         None,
                                                                         None),
                                                   'R_CULLIS_CENTRIC': ('pdbx_phasing_MAD_set',
                                                                        'R_cullis_centric',
                                                                        None,
                                                                        None),
                                                   'R_KRAUT': ('pdbx_phasing_MAD_set', 'R_kraut', None, None),
                                                   'R_KRAUT_ACENTRIC': ('pdbx_phasing_MAD_set',
                                                                        'R_kraut_acentric',
                                                                        None,
                                                                        None),
                                                   'R_KRAUT_CENTRIC': ('pdbx_phasing_MAD_set', 'R_kraut_centric', None, None),
                                                   'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                 'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                             's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                 'MAP_MERGE_INDICES': {'pdbx_phasing_MAD_set': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                                 'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                 'TABLE_ID': 'PDBX_PHASING_MAD_SET',
                                 'TABLE_NAME': 'pdbx_phasing_MAD_set',
                                 'TABLE_TYPE': 'transactional'},
        'PDBX_PHASING_MAD_SET_SHELL': {'ATTRIBUTES': {'D_RES_HIGH': 'd_res_high',
                                                      'D_RES_LOW': 'd_res_low',
                                                      'FOM': 'fom',
                                                      'FOM_ACENTRIC': 'fom_acentric',
                                                      'FOM_CENTRIC': 'fom_centric',
                                                      'ID': 'id',
                                                      'LOC': 'loc',
                                                      'LOC_ACENTRIC': 'loc_acentric',
                                                      'LOC_CENTRIC': 'loc_centric',
                                                      'POWER': 'power',
                                                      'POWER_ACENTRIC': 'power_acentric',
                                                      'POWER_CENTRIC': 'power_centric',
                                                      'REFLNS': 'reflns',
                                                      'REFLNS_ACENTRIC': 'reflns_acentric',
                                                      'REFLNS_CENTRIC': 'reflns_centric',
                                                      'R_CULLIS': 'R_cullis',
                                                      'R_CULLIS_ACENTRIC': 'R_cullis_acentric',
                                                      'R_CULLIS_CENTRIC': 'R_cullis_centric',
                                                      'R_KRAUT': 'R_kraut',
                                                      'R_KRAUT_ACENTRIC': 'R_kraut_acentric',
                                                      'R_KRAUT_CENTRIC': 'R_kraut_centric',
                                                      'STRUCTURE_ID': 'Structure_ID'},
                                       'ATTRIBUTE_INFO': {'D_RES_HIGH': {'NULLABLE': False,
                                                                         'ORDER': 4,
                                                                         'PRECISION': 6,
                                                                         'PRIMARY_KEY': True,
                                                                         'SQL_TYPE': 'FLOAT',
                                                                         'WIDTH': 10},
                                                          'D_RES_LOW': {'NULLABLE': False,
                                                                        'ORDER': 3,
                                                                        'PRECISION': 6,
                                                                        'PRIMARY_KEY': True,
                                                                        'SQL_TYPE': 'FLOAT',
                                                                        'WIDTH': 10},
                                                          'FOM': {'NULLABLE': True,
                                                                  'ORDER': 10,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10},
                                                          'FOM_ACENTRIC': {'NULLABLE': True,
                                                                           'ORDER': 8,
                                                                           'PRECISION': 6,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'FLOAT',
                                                                           'WIDTH': 10},
                                                          'FOM_CENTRIC': {'NULLABLE': True,
                                                                          'ORDER': 9,
                                                                          'PRECISION': 6,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'FLOAT',
                                                                          'WIDTH': 10},
                                                          'ID': {'NULLABLE': False,
                                                                 'ORDER': 2,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': True,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 13},
                                                          'LOC': {'NULLABLE': True,
                                                                  'ORDER': 19,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10},
                                                          'LOC_ACENTRIC': {'NULLABLE': True,
                                                                           'ORDER': 18,
                                                                           'PRECISION': 6,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'FLOAT',
                                                                           'WIDTH': 10},
                                                          'LOC_CENTRIC': {'NULLABLE': True,
                                                                          'ORDER': 17,
                                                                          'PRECISION': 6,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'FLOAT',
                                                                          'WIDTH': 10},
                                                          'POWER': {'NULLABLE': True,
                                                                    'ORDER': 22,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                                          'POWER_ACENTRIC': {'NULLABLE': True,
                                                                             'ORDER': 21,
                                                                             'PRECISION': 6,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'FLOAT',
                                                                             'WIDTH': 10},
                                                          'POWER_CENTRIC': {'NULLABLE': True,
                                                                            'ORDER': 20,
                                                                            'PRECISION': 6,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'FLOAT',
                                                                            'WIDTH': 10},
                                                          'REFLNS': {'NULLABLE': True,
                                                                     'ORDER': 7,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'INT',
                                                                     'WIDTH': 10},
                                                          'REFLNS_ACENTRIC': {'NULLABLE': True,
                                                                              'ORDER': 5,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'INT',
                                                                              'WIDTH': 10},
                                                          'REFLNS_CENTRIC': {'NULLABLE': True,
                                                                             'ORDER': 6,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'INT',
                                                                             'WIDTH': 10},
                                                          'R_CULLIS': {'NULLABLE': True,
                                                                       'ORDER': 13,
                                                                       'PRECISION': 6,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'FLOAT',
                                                                       'WIDTH': 10},
                                                          'R_CULLIS_ACENTRIC': {'NULLABLE': True,
                                                                                'ORDER': 12,
                                                                                'PRECISION': 6,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'FLOAT',
                                                                                'WIDTH': 10},
                                                          'R_CULLIS_CENTRIC': {'NULLABLE': True,
                                                                               'ORDER': 11,
                                                                               'PRECISION': 6,
                                                                               'PRIMARY_KEY': False,
                                                                               'SQL_TYPE': 'FLOAT',
                                                                               'WIDTH': 10},
                                                          'R_KRAUT': {'NULLABLE': True,
                                                                      'ORDER': 16,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                                          'R_KRAUT_ACENTRIC': {'NULLABLE': True,
                                                                               'ORDER': 15,
                                                                               'PRECISION': 6,
                                                                               'PRIMARY_KEY': False,
                                                                               'SQL_TYPE': 'FLOAT',
                                                                               'WIDTH': 10},
                                                          'R_KRAUT_CENTRIC': {'NULLABLE': True,
                                                                              'ORDER': 14,
                                                                              'PRECISION': 6,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'FLOAT',
                                                                              'WIDTH': 10},
                                                          'STRUCTURE_ID': {'NULLABLE': False,
                                                                           'ORDER': 1,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': True,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10}},
                                       'ATTRIBUTE_MAP': {'D_RES_HIGH': ('pdbx_phasing_MAD_set_shell',
                                                                        'd_res_high',
                                                                        None,
                                                                        None),
                                                         'D_RES_LOW': ('pdbx_phasing_MAD_set_shell', 'd_res_low', None, None),
                                                         'FOM': ('pdbx_phasing_MAD_set_shell', 'fom', None, None),
                                                         'FOM_ACENTRIC': ('pdbx_phasing_MAD_set_shell',
                                                                          'fom_acentric',
                                                                          None,
                                                                          None),
                                                         'FOM_CENTRIC': ('pdbx_phasing_MAD_set_shell',
                                                                         'fom_centric',
                                                                         None,
                                                                         None),
                                                         'ID': ('pdbx_phasing_MAD_set_shell', 'id', None, None),
                                                         'LOC': ('pdbx_phasing_MAD_set_shell', 'loc', None, None),
                                                         'LOC_ACENTRIC': ('pdbx_phasing_MAD_set_shell',
                                                                          'loc_acentric',
                                                                          None,
                                                                          None),
                                                         'LOC_CENTRIC': ('pdbx_phasing_MAD_set_shell',
                                                                         'loc_centric',
                                                                         None,
                                                                         None),
                                                         'POWER': ('pdbx_phasing_MAD_set_shell', 'power', None, None),
                                                         'POWER_ACENTRIC': ('pdbx_phasing_MAD_set_shell',
                                                                            'power_acentric',
                                                                            None,
                                                                            None),
                                                         'POWER_CENTRIC': ('pdbx_phasing_MAD_set_shell',
                                                                           'power_centric',
                                                                           None,
                                                                           None),
                                                         'REFLNS': ('pdbx_phasing_MAD_set_shell', 'reflns', None, None),
                                                         'REFLNS_ACENTRIC': ('pdbx_phasing_MAD_set_shell',
                                                                             'reflns_acentric',
                                                                             None,
                                                                             None),
                                                         'REFLNS_CENTRIC': ('pdbx_phasing_MAD_set_shell',
                                                                            'reflns_centric',
                                                                            None,
                                                                            None),
                                                         'R_CULLIS': ('pdbx_phasing_MAD_set_shell', 'R_cullis', None, None),
                                                         'R_CULLIS_ACENTRIC': ('pdbx_phasing_MAD_set_shell',
                                                                               'R_cullis_acentric',
                                                                               None,
                                                                               None),
                                                         'R_CULLIS_CENTRIC': ('pdbx_phasing_MAD_set_shell',
                                                                              'R_cullis_centric',
                                                                              None,
                                                                              None),
                                                         'R_KRAUT': ('pdbx_phasing_MAD_set_shell', 'R_kraut', None, None),
                                                         'R_KRAUT_ACENTRIC': ('pdbx_phasing_MAD_set_shell',
                                                                              'R_kraut_acentric',
                                                                              None,
                                                                              None),
                                                         'R_KRAUT_CENTRIC': ('pdbx_phasing_MAD_set_shell',
                                                                             'R_kraut_centric',
                                                                             None,
                                                                             None),
                                                         'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                       'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID', 'D_RES_LOW', 'D_RES_HIGH'),
                                                          'TYPE': 'UNIQUE'},
                                                   's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                       'MAP_MERGE_INDICES': {'pdbx_phasing_MAD_set_shell': {'ATTRIBUTES': ('id',
                                                                                                           'd_res_low',
                                                                                                           'd_res_high'),
                                                                                            'TYPE': 'EQUI-JOIN'}},
                                       'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                       'TABLE_ID': 'PDBX_PHASING_MAD_SET_SHELL',
                                       'TABLE_NAME': 'pdbx_phasing_MAD_set_shell',
                                       'TABLE_TYPE': 'transactional'},
        'PDBX_PHASING_MAD_SET_SITE': {'ATTRIBUTES': {'ATOM_TYPE_SYMBOL': 'atom_type_symbol',
                                                     'B_ISO': 'b_iso',
                                                     'B_ISO_ESD': 'b_iso_esd',
                                                     'CARTN_X': 'Cartn_x',
                                                     'CARTN_X_ESD': 'Cartn_x_esd',
                                                     'CARTN_Y': 'Cartn_y',
                                                     'CARTN_Y_ESD': 'Cartn_y_esd',
                                                     'CARTN_Z': 'Cartn_z',
                                                     'CARTN_Z_ESD': 'Cartn_z_esd',
                                                     'FRACT_X': 'fract_x',
                                                     'FRACT_X_ESD': 'fract_x_esd',
                                                     'FRACT_Y': 'fract_y',
                                                     'FRACT_Y_ESD': 'fract_y_esd',
                                                     'FRACT_Z': 'fract_z',
                                                     'FRACT_Z_ESD': 'fract_z_esd',
                                                     'ID': 'id',
                                                     'OCCUPANCY': 'occupancy',
                                                     'OCCUPANCY_ESD': 'occupancy_esd',
                                                     'OCCUPANCY_ISO': 'occupancy_iso',
                                                     'SET_ID': 'set_id',
                                                     'STRUCTURE_ID': 'Structure_ID'},
                                      'ATTRIBUTE_INFO': {'ATOM_TYPE_SYMBOL': {'NULLABLE': True,
                                                                              'ORDER': 3,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                                         'B_ISO': {'NULLABLE': True,
                                                                   'ORDER': 16,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                                         'B_ISO_ESD': {'NULLABLE': True,
                                                                       'ORDER': 17,
                                                                       'PRECISION': 6,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'FLOAT',
                                                                       'WIDTH': 10},
                                                         'CARTN_X': {'NULLABLE': True,
                                                                     'ORDER': 4,
                                                                     'PRECISION': 6,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'FLOAT',
                                                                     'WIDTH': 10},
                                                         'CARTN_X_ESD': {'NULLABLE': True,
                                                                         'ORDER': 7,
                                                                         'PRECISION': 6,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'FLOAT',
                                                                         'WIDTH': 10},
                                                         'CARTN_Y': {'NULLABLE': True,
                                                                     'ORDER': 5,
                                                                     'PRECISION': 6,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'FLOAT',
                                                                     'WIDTH': 10},
                                                         'CARTN_Y_ESD': {'NULLABLE': True,
                                                                         'ORDER': 8,
                                                                         'PRECISION': 6,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'FLOAT',
                                                                         'WIDTH': 10},
                                                         'CARTN_Z': {'NULLABLE': True,
                                                                     'ORDER': 6,
                                                                     'PRECISION': 6,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'FLOAT',
                                                                     'WIDTH': 10},
                                                         'CARTN_Z_ESD': {'NULLABLE': True,
                                                                         'ORDER': 9,
                                                                         'PRECISION': 6,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'FLOAT',
                                                                         'WIDTH': 10},
                                                         'FRACT_X': {'NULLABLE': True,
                                                                     'ORDER': 10,
                                                                     'PRECISION': 6,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'FLOAT',
                                                                     'WIDTH': 10},
                                                         'FRACT_X_ESD': {'NULLABLE': True,
                                                                         'ORDER': 13,
                                                                         'PRECISION': 6,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'FLOAT',
                                                                         'WIDTH': 10},
                                                         'FRACT_Y': {'NULLABLE': True,
                                                                     'ORDER': 11,
                                                                     'PRECISION': 6,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'FLOAT',
                                                                     'WIDTH': 10},
                                                         'FRACT_Y_ESD': {'NULLABLE': True,
                                                                         'ORDER': 14,
                                                                         'PRECISION': 6,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'FLOAT',
                                                                         'WIDTH': 10},
                                                         'FRACT_Z': {'NULLABLE': True,
                                                                     'ORDER': 12,
                                                                     'PRECISION': 6,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'FLOAT',
                                                                     'WIDTH': 10},
                                                         'FRACT_Z_ESD': {'NULLABLE': True,
                                                                         'ORDER': 15,
                                                                         'PRECISION': 6,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'FLOAT',
                                                                         'WIDTH': 10},
                                                         'ID': {'NULLABLE': False,
                                                                'ORDER': 2,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                                         'OCCUPANCY': {'NULLABLE': True,
                                                                       'ORDER': 18,
                                                                       'PRECISION': 6,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'FLOAT',
                                                                       'WIDTH': 10},
                                                         'OCCUPANCY_ESD': {'NULLABLE': True,
                                                                           'ORDER': 19,
                                                                           'PRECISION': 6,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'FLOAT',
                                                                           'WIDTH': 10},
                                                         'OCCUPANCY_ISO': {'NULLABLE': True,
                                                                           'ORDER': 21,
                                                                           'PRECISION': 6,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'FLOAT',
                                                                           'WIDTH': 10},
                                                         'SET_ID': {'NULLABLE': True,
                                                                    'ORDER': 20,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10},
                                                         'STRUCTURE_ID': {'NULLABLE': False,
                                                                          'ORDER': 1,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': True,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10}},
                                      'ATTRIBUTE_MAP': {'ATOM_TYPE_SYMBOL': ('pdbx_phasing_MAD_set_site',
                                                                             'atom_type_symbol',
                                                                             None,
                                                                             None),
                                                        'B_ISO': ('pdbx_phasing_MAD_set_site', 'b_iso', None, None),
                                                        'B_ISO_ESD': ('pdbx_phasing_MAD_set_site', 'b_iso_esd', None, None),
                                                        'CARTN_X': ('pdbx_phasing_MAD_set_site', 'Cartn_x', None, None),
                                                        'CARTN_X_ESD': ('pdbx_phasing_MAD_set_site',
                                                                        'Cartn_x_esd',
                                                                        None,
                                                                        None),
                                                        'CARTN_Y': ('pdbx_phasing_MAD_set_site', 'Cartn_y', None, None),
                                                        'CARTN_Y_ESD': ('pdbx_phasing_MAD_set_site',
                                                                        'Cartn_y_esd',
                                                                        None,
                                                                        None),
                                                        'CARTN_Z': ('pdbx_phasing_MAD_set_site', 'Cartn_z', None, None),
                                                        'CARTN_Z_ESD': ('pdbx_phasing_MAD_set_site',
                                                                        'Cartn_z_esd',
                                                                        None,
                                                                        None),
                                                        'FRACT_X': ('pdbx_phasing_MAD_set_site', 'fract_x', None, None),
                                                        'FRACT_X_ESD': ('pdbx_phasing_MAD_set_site',
                                                                        'fract_x_esd',
                                                                        None,
                                                                        None),
                                                        'FRACT_Y': ('pdbx_phasing_MAD_set_site', 'fract_y', None, None),
                                                        'FRACT_Y_ESD': ('pdbx_phasing_MAD_set_site',
                                                                        'fract_y_esd',
                                                                        None,
                                                                        None),
                                                        'FRACT_Z': ('pdbx_phasing_MAD_set_site', 'fract_z', None, None),
                                                        'FRACT_Z_ESD': ('pdbx_phasing_MAD_set_site',
                                                                        'fract_z_esd',
                                                                        None,
                                                                        None),
                                                        'ID': ('pdbx_phasing_MAD_set_site', 'id', None, None),
                                                        'OCCUPANCY': ('pdbx_phasing_MAD_set_site', 'occupancy', None, None),
                                                        'OCCUPANCY_ESD': ('pdbx_phasing_MAD_set_site',
                                                                          'occupancy_esd',
                                                                          None,
                                                                          None),
                                                        'OCCUPANCY_ISO': ('pdbx_phasing_MAD_set_site',
                                                                          'occupancy_iso',
                                                                          None,
                                                                          None),
                                                        'SET_ID': ('pdbx_phasing_MAD_set_site', 'set_id', None, None),
                                                        'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                      'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                                  's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                      'MAP_MERGE_INDICES': {'pdbx_phasing_MAD_set_site': {'ATTRIBUTES': ('id',),
                                                                                          'TYPE': 'EQUI-JOIN'}},
                                      'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                      'TABLE_ID': 'PDBX_PHASING_MAD_SET_SITE',
                                      'TABLE_NAME': 'pdbx_phasing_MAD_set_site',
                                      'TABLE_TYPE': 'transactional'},
        'PDBX_PHASING_MAD_SHELL': {'ATTRIBUTES': {'D_RES_HIGH': 'd_res_high',
                                                  'D_RES_LOW': 'd_res_low',
                                                  'FOM': 'fom',
                                                  'FOM_ACENTRIC': 'fom_acentric',
                                                  'FOM_CENTRIC': 'fom_centric',
                                                  'LOC': 'loc',
                                                  'LOC_ACENTRIC': 'loc_acentric',
                                                  'LOC_CENTRIC': 'loc_centric',
                                                  'POWER': 'power',
                                                  'POWER_ACENTRIC': 'power_acentric',
                                                  'POWER_CENTRIC': 'power_centric',
                                                  'REFLNS': 'reflns',
                                                  'REFLNS_ACENTRIC': 'reflns_acentric',
                                                  'REFLNS_CENTRIC': 'reflns_centric',
                                                  'R_CULLIS': 'R_cullis',
                                                  'R_CULLIS_ACENTRIC': 'R_cullis_acentric',
                                                  'R_CULLIS_CENTRIC': 'R_cullis_centric',
                                                  'R_KRAUT': 'R_kraut',
                                                  'R_KRAUT_ACENTRIC': 'R_kraut_acentric',
                                                  'R_KRAUT_CENTRIC': 'R_kraut_centric',
                                                  'STRUCTURE_ID': 'Structure_ID'},
                                   'ATTRIBUTE_INFO': {'D_RES_HIGH': {'NULLABLE': False,
                                                                     'ORDER': 3,
                                                                     'PRECISION': 6,
                                                                     'PRIMARY_KEY': True,
                                                                     'SQL_TYPE': 'FLOAT',
                                                                     'WIDTH': 10},
                                                      'D_RES_LOW': {'NULLABLE': False,
                                                                    'ORDER': 2,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': True,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                                      'FOM': {'NULLABLE': True,
                                                              'ORDER': 9,
                                                              'PRECISION': 6,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'FLOAT',
                                                              'WIDTH': 10},
                                                      'FOM_ACENTRIC': {'NULLABLE': True,
                                                                       'ORDER': 7,
                                                                       'PRECISION': 6,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'FLOAT',
                                                                       'WIDTH': 10},
                                                      'FOM_CENTRIC': {'NULLABLE': True,
                                                                      'ORDER': 8,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                                      'LOC': {'NULLABLE': True,
                                                              'ORDER': 18,
                                                              'PRECISION': 6,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'FLOAT',
                                                              'WIDTH': 10},
                                                      'LOC_ACENTRIC': {'NULLABLE': True,
                                                                       'ORDER': 17,
                                                                       'PRECISION': 6,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'FLOAT',
                                                                       'WIDTH': 10},
                                                      'LOC_CENTRIC': {'NULLABLE': True,
                                                                      'ORDER': 16,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                                      'POWER': {'NULLABLE': True,
                                                                'ORDER': 21,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                                      'POWER_ACENTRIC': {'NULLABLE': True,
                                                                         'ORDER': 20,
                                                                         'PRECISION': 6,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'FLOAT',
                                                                         'WIDTH': 10},
                                                      'POWER_CENTRIC': {'NULLABLE': True,
                                                                        'ORDER': 19,
                                                                        'PRECISION': 6,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'FLOAT',
                                                                        'WIDTH': 10},
                                                      'REFLNS': {'NULLABLE': True,
                                                                 'ORDER': 6,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'INT',
                                                                 'WIDTH': 10},
                                                      'REFLNS_ACENTRIC': {'NULLABLE': True,
                                                                          'ORDER': 4,
                                                                          'PRECISION': 6,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'FLOAT',
                                                                          'WIDTH': 10},
                                                      'REFLNS_CENTRIC': {'NULLABLE': True,
                                                                         'ORDER': 5,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'INT',
                                                                         'WIDTH': 10},
                                                      'R_CULLIS': {'NULLABLE': True,
                                                                   'ORDER': 12,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                                      'R_CULLIS_ACENTRIC': {'NULLABLE': True,
                                                                            'ORDER': 11,
                                                                            'PRECISION': 6,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'FLOAT',
                                                                            'WIDTH': 10},
                                                      'R_CULLIS_CENTRIC': {'NULLABLE': True,
                                                                           'ORDER': 10,
                                                                           'PRECISION': 6,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'FLOAT',
                                                                           'WIDTH': 10},
                                                      'R_KRAUT': {'NULLABLE': True,
                                                                  'ORDER': 15,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10},
                                                      'R_KRAUT_ACENTRIC': {'NULLABLE': True,
                                                                           'ORDER': 14,
                                                                           'PRECISION': 6,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'FLOAT',
                                                                           'WIDTH': 10},
                                                      'R_KRAUT_CENTRIC': {'NULLABLE': True,
                                                                          'ORDER': 13,
                                                                          'PRECISION': 6,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'FLOAT',
                                                                          'WIDTH': 10},
                                                      'STRUCTURE_ID': {'NULLABLE': False,
                                                                       'ORDER': 1,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': True,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10}},
                                   'ATTRIBUTE_MAP': {'D_RES_HIGH': ('pdbx_phasing_MAD_shell', 'd_res_high', None, None),
                                                     'D_RES_LOW': ('pdbx_phasing_MAD_shell', 'd_res_low', None, None),
                                                     'FOM': ('pdbx_phasing_MAD_shell', 'fom', None, None),
                                                     'FOM_ACENTRIC': ('pdbx_phasing_MAD_shell', 'fom_acentric', None, None),
                                                     'FOM_CENTRIC': ('pdbx_phasing_MAD_shell', 'fom_centric', None, None),
                                                     'LOC': ('pdbx_phasing_MAD_shell', 'loc', None, None),
                                                     'LOC_ACENTRIC': ('pdbx_phasing_MAD_shell', 'loc_acentric', None, None),
                                                     'LOC_CENTRIC': ('pdbx_phasing_MAD_shell', 'loc_centric', None, None),
                                                     'POWER': ('pdbx_phasing_MAD_shell', 'power', None, None),
                                                     'POWER_ACENTRIC': ('pdbx_phasing_MAD_shell',
                                                                        'power_acentric',
                                                                        None,
                                                                        None),
                                                     'POWER_CENTRIC': ('pdbx_phasing_MAD_shell', 'power_centric', None, None),
                                                     'REFLNS': ('pdbx_phasing_MAD_shell', 'reflns', None, None),
                                                     'REFLNS_ACENTRIC': ('pdbx_phasing_MAD_shell',
                                                                         'reflns_acentric',
                                                                         None,
                                                                         None),
                                                     'REFLNS_CENTRIC': ('pdbx_phasing_MAD_shell',
                                                                        'reflns_centric',
                                                                        None,
                                                                        None),
                                                     'R_CULLIS': ('pdbx_phasing_MAD_shell', 'R_cullis', None, None),
                                                     'R_CULLIS_ACENTRIC': ('pdbx_phasing_MAD_shell',
                                                                           'R_cullis_acentric',
                                                                           None,
                                                                           None),
                                                     'R_CULLIS_CENTRIC': ('pdbx_phasing_MAD_shell',
                                                                          'R_cullis_centric',
                                                                          None,
                                                                          None),
                                                     'R_KRAUT': ('pdbx_phasing_MAD_shell', 'R_kraut', None, None),
                                                     'R_KRAUT_ACENTRIC': ('pdbx_phasing_MAD_shell',
                                                                          'R_kraut_acentric',
                                                                          None,
                                                                          None),
                                                     'R_KRAUT_CENTRIC': ('pdbx_phasing_MAD_shell',
                                                                         'R_kraut_centric',
                                                                         None,
                                                                         None),
                                                     'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                   'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'D_RES_LOW', 'D_RES_HIGH'),
                                                      'TYPE': 'UNIQUE'},
                                               's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                   'MAP_MERGE_INDICES': {'pdbx_phasing_MAD_shell': {'ATTRIBUTES': ('d_res_low', 'd_res_high'),
                                                                                    'TYPE': 'EQUI-JOIN'}},
                                   'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                   'TABLE_ID': 'PDBX_PHASING_MAD_SHELL',
                                   'TABLE_NAME': 'pdbx_phasing_MAD_shell',
                                   'TABLE_TYPE': 'transactional'},
        'PDBX_PHASING_MR': {'ATTRIBUTES': {'CORRELATION_COEFF_FO_TO_FC': 'correlation_coeff_Fo_to_Fc',
                                           'CORRELATION_COEFF_IO_TO_IC': 'correlation_coeff_Io_to_Ic',
                                           'D_RES_HIGH_ROTATION': 'd_res_high_rotation',
                                           'D_RES_HIGH_TRANSLATION': 'd_res_high_translation',
                                           'D_RES_LOW_ROTATION': 'd_res_low_rotation',
                                           'D_RES_LOW_TRANSLATION': 'd_res_low_translation',
                                           'ENTRY_ID': 'entry_id',
                                           'METHOD_ROTATION': 'method_rotation',
                                           'METHOD_TRANSLATION': 'method_translation',
                                           'MODEL_DETAILS': 'model_details',
                                           'NATIVE_SET_ID': 'native_set_id',
                                           'PACKING': 'packing',
                                           'REFLNS_PERCENT_ROTATION': 'reflns_percent_rotation',
                                           'REFLNS_PERCENT_TRANSLATION': 'reflns_percent_translation',
                                           'R_FACTOR': 'R_factor',
                                           'R_RIGID_BODY': 'R_rigid_body',
                                           'SIGMA_F_ROTATION': 'sigma_F_rotation',
                                           'SIGMA_F_TRANSLATION': 'sigma_F_translation',
                                           'SIGMA_I_ROTATION': 'sigma_I_rotation',
                                           'SIGMA_I_TRANSLATION': 'sigma_I_translation',
                                           'STRUCTURE_ID': 'Structure_ID'},
                            'ATTRIBUTE_INFO': {'CORRELATION_COEFF_FO_TO_FC': {'NULLABLE': True,
                                                                              'ORDER': 16,
                                                                              'PRECISION': 6,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'FLOAT',
                                                                              'WIDTH': 10},
                                               'CORRELATION_COEFF_IO_TO_IC': {'NULLABLE': True,
                                                                              'ORDER': 15,
                                                                              'PRECISION': 6,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'FLOAT',
                                                                              'WIDTH': 10},
                                               'D_RES_HIGH_ROTATION': {'NULLABLE': True,
                                                                       'ORDER': 4,
                                                                       'PRECISION': 6,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'FLOAT',
                                                                       'WIDTH': 10},
                                               'D_RES_HIGH_TRANSLATION': {'NULLABLE': True,
                                                                          'ORDER': 10,
                                                                          'PRECISION': 6,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'FLOAT',
                                                                          'WIDTH': 10},
                                               'D_RES_LOW_ROTATION': {'NULLABLE': True,
                                                                      'ORDER': 5,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                               'D_RES_LOW_TRANSLATION': {'NULLABLE': True,
                                                                         'ORDER': 11,
                                                                         'PRECISION': 6,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'FLOAT',
                                                                         'WIDTH': 10},
                                               'ENTRY_ID': {'NULLABLE': False,
                                                            'ORDER': 2,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': True,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 10},
                                               'METHOD_ROTATION': {'NULLABLE': True,
                                                                   'ORDER': 3,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 80},
                                               'METHOD_TRANSLATION': {'NULLABLE': True,
                                                                      'ORDER': 9,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 80},
                                               'MODEL_DETAILS': {'NULLABLE': True,
                                                                 'ORDER': 20,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 200},
                                               'NATIVE_SET_ID': {'NULLABLE': True,
                                                                 'ORDER': 21,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 80},
                                               'PACKING': {'NULLABLE': True,
                                                           'ORDER': 19,
                                                           'PRECISION': 6,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'FLOAT',
                                                           'WIDTH': 10},
                                               'REFLNS_PERCENT_ROTATION': {'NULLABLE': True,
                                                                           'ORDER': 8,
                                                                           'PRECISION': 6,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'FLOAT',
                                                                           'WIDTH': 10},
                                               'REFLNS_PERCENT_TRANSLATION': {'NULLABLE': True,
                                                                              'ORDER': 14,
                                                                              'PRECISION': 6,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'FLOAT',
                                                                              'WIDTH': 10},
                                               'R_FACTOR': {'NULLABLE': True,
                                                            'ORDER': 17,
                                                            'PRECISION': 6,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'FLOAT',
                                                            'WIDTH': 10},
                                               'R_RIGID_BODY': {'NULLABLE': True,
                                                                'ORDER': 18,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                               'SIGMA_F_ROTATION': {'NULLABLE': True,
                                                                    'ORDER': 6,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                               'SIGMA_F_TRANSLATION': {'NULLABLE': True,
                                                                       'ORDER': 12,
                                                                       'PRECISION': 6,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'FLOAT',
                                                                       'WIDTH': 10},
                                               'SIGMA_I_ROTATION': {'NULLABLE': True,
                                                                    'ORDER': 7,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                               'SIGMA_I_TRANSLATION': {'NULLABLE': True,
                                                                       'ORDER': 13,
                                                                       'PRECISION': 6,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'FLOAT',
                                                                       'WIDTH': 10},
                                               'STRUCTURE_ID': {'NULLABLE': False,
                                                                'ORDER': 1,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10}},
                            'ATTRIBUTE_MAP': {'CORRELATION_COEFF_FO_TO_FC': ('pdbx_phasing_MR',
                                                                             'correlation_coeff_Fo_to_Fc',
                                                                             None,
                                                                             None),
                                              'CORRELATION_COEFF_IO_TO_IC': ('pdbx_phasing_MR',
                                                                             'correlation_coeff_Io_to_Ic',
                                                                             None,
                                                                             None),
                                              'D_RES_HIGH_ROTATION': ('pdbx_phasing_MR', 'd_res_high_rotation', None, None),
                                              'D_RES_HIGH_TRANSLATION': ('pdbx_phasing_MR',
                                                                         'd_res_high_translation',
                                                                         None,
                                                                         None),
                                              'D_RES_LOW_ROTATION': ('pdbx_phasing_MR', 'd_res_low_rotation', None, None),
                                              'D_RES_LOW_TRANSLATION': ('pdbx_phasing_MR',
                                                                        'd_res_low_translation',
                                                                        None,
                                                                        None),
                                              'ENTRY_ID': ('pdbx_phasing_MR', 'entry_id', None, None),
                                              'METHOD_ROTATION': ('pdbx_phasing_MR', 'method_rotation', None, None),
                                              'METHOD_TRANSLATION': ('pdbx_phasing_MR', 'method_translation', None, None),
                                              'MODEL_DETAILS': ('pdbx_phasing_MR', 'model_details', None, None),
                                              'NATIVE_SET_ID': ('pdbx_phasing_MR', 'native_set_id', None, None),
                                              'PACKING': ('pdbx_phasing_MR', 'packing', None, None),
                                              'REFLNS_PERCENT_ROTATION': ('pdbx_phasing_MR',
                                                                          'reflns_percent_rotation',
                                                                          None,
                                                                          None),
                                              'REFLNS_PERCENT_TRANSLATION': ('pdbx_phasing_MR',
                                                                             'reflns_percent_translation',
                                                                             None,
                                                                             None),
                                              'R_FACTOR': ('pdbx_phasing_MR', 'R_factor', None, None),
                                              'R_RIGID_BODY': ('pdbx_phasing_MR', 'R_rigid_body', None, None),
                                              'SIGMA_F_ROTATION': ('pdbx_phasing_MR', 'sigma_F_rotation', None, None),
                                              'SIGMA_F_TRANSLATION': ('pdbx_phasing_MR', 'sigma_F_translation', None, None),
                                              'SIGMA_I_ROTATION': ('pdbx_phasing_MR', 'sigma_I_rotation', None, None),
                                              'SIGMA_I_TRANSLATION': ('pdbx_phasing_MR', 'sigma_I_translation', None, None),
                                              'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                            'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID'), 'TYPE': 'UNIQUE'},
                                        's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                            'MAP_MERGE_INDICES': {'pdbx_phasing_MR': {'ATTRIBUTES': ('entry_id',), 'TYPE': 'EQUI-JOIN'}},
                            'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                            'TABLE_ID': 'PDBX_PHASING_MR',
                            'TABLE_NAME': 'pdbx_phasing_MR',
                            'TABLE_TYPE': 'transactional'},
        'PDBX_POINT_SYMMETRY': {'ATTRIBUTES': {'CIRCULAR_SYMMETRY': 'circular_symmetry',
                                               'ENTRY_ID': 'entry_id',
                                               'H_M_NOTATION': 'H_M_notation',
                                               'SCHOENFLIES_SYMBOL': 'Schoenflies_symbol',
                                               'STRUCTURE_ID': 'Structure_ID'},
                                'ATTRIBUTE_INFO': {'CIRCULAR_SYMMETRY': {'NULLABLE': True,
                                                                         'ORDER': 4,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'INT',
                                                                         'WIDTH': 10},
                                                   'ENTRY_ID': {'NULLABLE': False,
                                                                'ORDER': 2,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                                   'H_M_NOTATION': {'NULLABLE': True,
                                                                    'ORDER': 5,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10},
                                                   'SCHOENFLIES_SYMBOL': {'NULLABLE': True,
                                                                          'ORDER': 3,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                   'STRUCTURE_ID': {'NULLABLE': False,
                                                                    'ORDER': 1,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': True,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10}},
                                'ATTRIBUTE_MAP': {'CIRCULAR_SYMMETRY': ('pdbx_point_symmetry',
                                                                        'circular_symmetry',
                                                                        None,
                                                                        None),
                                                  'ENTRY_ID': ('pdbx_point_symmetry', 'entry_id', None, None),
                                                  'H_M_NOTATION': ('pdbx_point_symmetry', 'H-M_notation', None, None),
                                                  'SCHOENFLIES_SYMBOL': ('pdbx_point_symmetry',
                                                                         'Schoenflies_symbol',
                                                                         None,
                                                                         None),
                                                  'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID'), 'TYPE': 'UNIQUE'},
                                            's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                'MAP_MERGE_INDICES': {'pdbx_point_symmetry': {'ATTRIBUTES': ('entry_id',),
                                                                              'TYPE': 'EQUI-JOIN'}},
                                'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                'TABLE_ID': 'PDBX_POINT_SYMMETRY',
                                'TABLE_NAME': 'pdbx_point_symmetry',
                                'TABLE_TYPE': 'transactional'},
        'PDBX_POLY_SEQ_SCHEME': {'ATTRIBUTES': {'ASYM_ID': 'asym_id',
                                                'AUTH_MON_ID': 'auth_mon_id',
                                                'AUTH_SEQ_NUM': 'auth_seq_num',
                                                'ENTITY_ID': 'entity_id',
                                                'HETERO': 'hetero',
                                                'MON_ID': 'mon_id',
                                                'NDB_SEQ_NUM': 'ndb_seq_num',
                                                'PDB_INS_CODE': 'pdb_ins_code',
                                                'PDB_MON_ID': 'pdb_mon_id',
                                                'PDB_SEQ_NUM': 'pdb_seq_num',
                                                'PDB_STRAND_ID': 'pdb_strand_id',
                                                'SEQ_ID': 'seq_id',
                                                'STRUCTURE_ID': 'Structure_ID'},
                                 'ATTRIBUTE_INFO': {'ASYM_ID': {'NULLABLE': False,
                                                                'ORDER': 2,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                                    'AUTH_MON_ID': {'NULLABLE': True,
                                                                    'ORDER': 12,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10},
                                                    'AUTH_SEQ_NUM': {'NULLABLE': True,
                                                                     'ORDER': 10,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                                    'ENTITY_ID': {'NULLABLE': False,
                                                                  'ORDER': 3,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': True,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10},
                                                    'HETERO': {'NULLABLE': True,
                                                               'ORDER': 5,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                                    'MON_ID': {'NULLABLE': False,
                                                               'ORDER': 6,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                                    'NDB_SEQ_NUM': {'NULLABLE': True,
                                                                    'ORDER': 8,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'INT',
                                                                    'WIDTH': 10},
                                                    'PDB_INS_CODE': {'NULLABLE': True,
                                                                     'ORDER': 13,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                                    'PDB_MON_ID': {'NULLABLE': True,
                                                                   'ORDER': 11,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 10},
                                                    'PDB_SEQ_NUM': {'NULLABLE': True,
                                                                    'ORDER': 9,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10},
                                                    'PDB_STRAND_ID': {'NULLABLE': True,
                                                                      'ORDER': 7,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                                    'SEQ_ID': {'NULLABLE': False,
                                                               'ORDER': 4,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'INT',
                                                               'WIDTH': 10},
                                                    'STRUCTURE_ID': {'NULLABLE': False,
                                                                     'ORDER': 1,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': True,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10}},
                                 'ATTRIBUTE_MAP': {'ASYM_ID': ('pdbx_poly_seq_scheme', 'asym_id', None, None),
                                                   'AUTH_MON_ID': ('pdbx_poly_seq_scheme', 'auth_mon_id', None, None),
                                                   'AUTH_SEQ_NUM': ('pdbx_poly_seq_scheme', 'auth_seq_num', None, None),
                                                   'ENTITY_ID': ('pdbx_poly_seq_scheme', 'entity_id', None, None),
                                                   'HETERO': ('pdbx_poly_seq_scheme', 'hetero', None, None),
                                                   'MON_ID': ('pdbx_poly_seq_scheme', 'mon_id', None, None),
                                                   'NDB_SEQ_NUM': ('pdbx_poly_seq_scheme', 'ndb_seq_num', None, None),
                                                   'PDB_INS_CODE': ('pdbx_poly_seq_scheme', 'pdb_ins_code', None, None),
                                                   'PDB_MON_ID': ('pdbx_poly_seq_scheme', 'pdb_mon_id', None, None),
                                                   'PDB_SEQ_NUM': ('pdbx_poly_seq_scheme', 'pdb_seq_num', None, None),
                                                   'PDB_STRAND_ID': ('pdbx_poly_seq_scheme', 'pdb_strand_id', None, None),
                                                   'SEQ_ID': ('pdbx_poly_seq_scheme', 'seq_id', None, None),
                                                   'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                 'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ASYM_ID', 'ENTITY_ID', 'SEQ_ID', 'MON_ID'),
                                                    'TYPE': 'UNIQUE'},
                                             's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                 'MAP_MERGE_INDICES': {'pdbx_poly_seq_scheme': {'ATTRIBUTES': ('asym_id',
                                                                                               'entity_id',
                                                                                               'seq_id',
                                                                                               'mon_id'),
                                                                                'TYPE': 'EQUI-JOIN'}},
                                 'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                 'TABLE_ID': 'PDBX_POLY_SEQ_SCHEME',
                                 'TABLE_NAME': 'pdbx_poly_seq_scheme',
                                 'TABLE_TYPE': 'transactional'},
        'PDBX_PRD_AUDIT': {'ATTRIBUTES': {'ACTION_TYPE': 'action_type',
                                          'ANNOTATOR': 'annotator',
                                          'DATE': 'date',
                                          'DETAILS': 'details',
                                          'PRD_ID': 'prd_id',
                                          'PROCESSING_SITE': 'processing_site',
                                          'STRUCTURE_ID': 'Structure_ID'},
                           'ATTRIBUTE_INFO': {'ACTION_TYPE': {'NULLABLE': False,
                                                              'ORDER': 7,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 80},
                                              'ANNOTATOR': {'NULLABLE': True,
                                                            'ORDER': 4,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 10},
                                              'DATE': {'NULLABLE': False,
                                                       'ORDER': 3,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': True,
                                                       'SQL_TYPE': 'DATETIME',
                                                       'WIDTH': 15},
                                              'DETAILS': {'NULLABLE': True,
                                                          'ORDER': 6,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 200},
                                              'PRD_ID': {'NULLABLE': False,
                                                         'ORDER': 2,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': True,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 10},
                                              'PROCESSING_SITE': {'NULLABLE': True,
                                                                  'ORDER': 5,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10},
                                              'STRUCTURE_ID': {'NULLABLE': False,
                                                               'ORDER': 1,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10}},
                           'ATTRIBUTE_MAP': {'ACTION_TYPE': ('pdbx_prd_audit', 'action_type', None, None),
                                             'ANNOTATOR': ('pdbx_prd_audit', 'annotator', None, None),
                                             'DATE': ('pdbx_prd_audit', 'date', None, None),
                                             'DETAILS': ('pdbx_prd_audit', 'details', None, None),
                                             'PRD_ID': ('pdbx_prd_audit', 'prd_id', None, None),
                                             'PROCESSING_SITE': ('pdbx_prd_audit', 'processing_site', None, None),
                                             'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                           'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'PRD_ID', 'DATE', 'ACTION_TYPE'),
                                              'TYPE': 'UNIQUE'},
                                       's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                           'MAP_MERGE_INDICES': {'pdbx_prd_audit': {'ATTRIBUTES': ('prd_id', 'date', 'action_type'),
                                                                    'TYPE': 'EQUI-JOIN'}},
                           'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                           'TABLE_ID': 'PDBX_PRD_AUDIT',
                           'TABLE_NAME': 'pdbx_prd_audit',
                           'TABLE_TYPE': 'transactional'},
        'PDBX_PRERELEASE_SEQ': {'ATTRIBUTES': {'ENTITY_ID': 'entity_id',
                                               'SEQ_ONE_LETTER_CODE': 'seq_one_letter_code',
                                               'STRUCTURE_ID': 'Structure_ID'},
                                'ATTRIBUTE_INFO': {'ENTITY_ID': {'NULLABLE': False,
                                                                 'ORDER': 2,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': True,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                                   'SEQ_ONE_LETTER_CODE': {'NULLABLE': True,
                                                                           'ORDER': 3,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 16383},
                                                   'STRUCTURE_ID': {'NULLABLE': False,
                                                                    'ORDER': 1,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': True,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10}},
                                'ATTRIBUTE_MAP': {'ENTITY_ID': ('pdbx_prerelease_seq', 'entity_id', None, None),
                                                  'SEQ_ONE_LETTER_CODE': ('pdbx_prerelease_seq',
                                                                          'seq_one_letter_code',
                                                                          None,
                                                                          None),
                                                  'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTITY_ID'), 'TYPE': 'UNIQUE'},
                                            's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                'MAP_MERGE_INDICES': {'pdbx_prerelease_seq': {'ATTRIBUTES': ('entity_id',),
                                                                              'TYPE': 'EQUI-JOIN'}},
                                'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                'TABLE_ID': 'PDBX_PRERELEASE_SEQ',
                                'TABLE_NAME': 'pdbx_prerelease_seq',
                                'TABLE_TYPE': 'transactional'},
        'PDBX_REFERENCE_ENTITY_LINK': {'ATTRIBUTES': {'ATOM_ID_1': 'atom_id_1',
                                                      'ATOM_ID_2': 'atom_id_2',
                                                      'COMPONENT_1': 'component_1',
                                                      'COMPONENT_2': 'component_2',
                                                      'COMP_ID_1': 'comp_id_1',
                                                      'COMP_ID_2': 'comp_id_2',
                                                      'DETAILS': 'details',
                                                      'ENTITY_SEQ_NUM_1': 'entity_seq_num_1',
                                                      'ENTITY_SEQ_NUM_2': 'entity_seq_num_2',
                                                      'LINK_CLASS': 'link_class',
                                                      'LINK_ID': 'link_id',
                                                      'NONPOLY_RES_NUM_1': 'nonpoly_res_num_1',
                                                      'NONPOLY_RES_NUM_2': 'nonpoly_res_num_2',
                                                      'PRD_ID': 'prd_id',
                                                      'REF_ENTITY_ID_1': 'ref_entity_id_1',
                                                      'REF_ENTITY_ID_2': 'ref_entity_id_2',
                                                      'STRUCTURE_ID': 'Structure_ID',
                                                      'VALUE_ORDER': 'value_order'},
                                       'ATTRIBUTE_INFO': {'ATOM_ID_1': {'NULLABLE': True,
                                                                        'ORDER': 11,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 6},
                                                          'ATOM_ID_2': {'NULLABLE': True,
                                                                        'ORDER': 12,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                                          'COMPONENT_1': {'NULLABLE': True,
                                                                          'ORDER': 14,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'INT',
                                                                          'WIDTH': 10},
                                                          'COMPONENT_2': {'NULLABLE': True,
                                                                          'ORDER': 15,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'INT',
                                                                          'WIDTH': 10},
                                                          'COMP_ID_1': {'NULLABLE': True,
                                                                        'ORDER': 9,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                                          'COMP_ID_2': {'NULLABLE': True,
                                                                        'ORDER': 10,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                                          'DETAILS': {'NULLABLE': True,
                                                                      'ORDER': 4,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 200},
                                                          'ENTITY_SEQ_NUM_1': {'NULLABLE': True,
                                                                               'ORDER': 7,
                                                                               'PRECISION': 0,
                                                                               'PRIMARY_KEY': False,
                                                                               'SQL_TYPE': 'INT',
                                                                               'WIDTH': 10},
                                                          'ENTITY_SEQ_NUM_2': {'NULLABLE': True,
                                                                               'ORDER': 8,
                                                                               'PRECISION': 0,
                                                                               'PRIMARY_KEY': False,
                                                                               'SQL_TYPE': 'INT',
                                                                               'WIDTH': 10},
                                                          'LINK_CLASS': {'NULLABLE': True,
                                                                         'ORDER': 18,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                                          'LINK_ID': {'NULLABLE': False,
                                                                      'ORDER': 2,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'INT',
                                                                      'WIDTH': 10},
                                                          'NONPOLY_RES_NUM_1': {'NULLABLE': True,
                                                                                'ORDER': 16,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 10},
                                                          'NONPOLY_RES_NUM_2': {'NULLABLE': True,
                                                                                'ORDER': 17,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 10},
                                                          'PRD_ID': {'NULLABLE': False,
                                                                     'ORDER': 3,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': True,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                                          'REF_ENTITY_ID_1': {'NULLABLE': True,
                                                                              'ORDER': 5,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                                          'REF_ENTITY_ID_2': {'NULLABLE': True,
                                                                              'ORDER': 6,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                                          'STRUCTURE_ID': {'NULLABLE': False,
                                                                           'ORDER': 1,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': True,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10},
                                                          'VALUE_ORDER': {'NULLABLE': True,
                                                                          'ORDER': 13,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10}},
                                       'ATTRIBUTE_MAP': {'ATOM_ID_1': ('pdbx_reference_entity_link', 'atom_id_1', None, None),
                                                         'ATOM_ID_2': ('pdbx_reference_entity_link', 'atom_id_2', None, None),
                                                         'COMPONENT_1': ('pdbx_reference_entity_link',
                                                                         'component_1',
                                                                         None,
                                                                         None),
                                                         'COMPONENT_2': ('pdbx_reference_entity_link',
                                                                         'component_2',
                                                                         None,
                                                                         None),
                                                         'COMP_ID_1': ('pdbx_reference_entity_link', 'comp_id_1', None, None),
                                                         'COMP_ID_2': ('pdbx_reference_entity_link', 'comp_id_2', None, None),
                                                         'DETAILS': ('pdbx_reference_entity_link', 'details', None, None),
                                                         'ENTITY_SEQ_NUM_1': ('pdbx_reference_entity_link',
                                                                              'entity_seq_num_1',
                                                                              None,
                                                                              None),
                                                         'ENTITY_SEQ_NUM_2': ('pdbx_reference_entity_link',
                                                                              'entity_seq_num_2',
                                                                              None,
                                                                              None),
                                                         'LINK_CLASS': ('pdbx_reference_entity_link',
                                                                        'link_class',
                                                                        None,
                                                                        None),
                                                         'LINK_ID': ('pdbx_reference_entity_link', 'link_id', None, None),
                                                         'NONPOLY_RES_NUM_1': ('pdbx_reference_entity_link',
                                                                               'nonpoly_res_num_1',
                                                                               None,
                                                                               None),
                                                         'NONPOLY_RES_NUM_2': ('pdbx_reference_entity_link',
                                                                               'nonpoly_res_num_2',
                                                                               None,
                                                                               None),
                                                         'PRD_ID': ('pdbx_reference_entity_link', 'prd_id', None, None),
                                                         'REF_ENTITY_ID_1': ('pdbx_reference_entity_link',
                                                                             'ref_entity_id_1',
                                                                             None,
                                                                             None),
                                                         'REF_ENTITY_ID_2': ('pdbx_reference_entity_link',
                                                                             'ref_entity_id_2',
                                                                             None,
                                                                             None),
                                                         'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                         'VALUE_ORDER': ('pdbx_reference_entity_link',
                                                                         'value_order',
                                                                         None,
                                                                         None)},
                                       'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'LINK_ID', 'PRD_ID'),
                                                          'TYPE': 'UNIQUE'},
                                                   's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                       'MAP_MERGE_INDICES': {'pdbx_reference_entity_link': {'ATTRIBUTES': ('link_id',
                                                                                                           'prd_id'),
                                                                                            'TYPE': 'EQUI-JOIN'}},
                                       'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                       'TABLE_ID': 'PDBX_REFERENCE_ENTITY_LINK',
                                       'TABLE_NAME': 'pdbx_reference_entity_link',
                                       'TABLE_TYPE': 'transactional'},
        'PDBX_REFERENCE_ENTITY_LIST': {'ATTRIBUTES': {'COMPONENT_ID': 'component_id',
                                                      'DETAILS': 'details',
                                                      'PRD_ID': 'prd_id',
                                                      'REF_ENTITY_ID': 'ref_entity_id',
                                                      'STRUCTURE_ID': 'Structure_ID',
                                                      'TYPE': 'type'},
                                       'ATTRIBUTE_INFO': {'COMPONENT_ID': {'NULLABLE': False,
                                                                           'ORDER': 6,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': True,
                                                                           'SQL_TYPE': 'INT',
                                                                           'WIDTH': 10},
                                                          'DETAILS': {'NULLABLE': True,
                                                                      'ORDER': 5,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 200},
                                                          'PRD_ID': {'NULLABLE': False,
                                                                     'ORDER': 2,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': True,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                                          'REF_ENTITY_ID': {'NULLABLE': False,
                                                                            'ORDER': 3,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': True,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 10},
                                                          'STRUCTURE_ID': {'NULLABLE': False,
                                                                           'ORDER': 1,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': True,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10},
                                                          'TYPE': {'NULLABLE': True,
                                                                   'ORDER': 4,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 80}},
                                       'ATTRIBUTE_MAP': {'COMPONENT_ID': ('pdbx_reference_entity_list',
                                                                          'component_id',
                                                                          None,
                                                                          None),
                                                         'DETAILS': ('pdbx_reference_entity_list', 'details', None, None),
                                                         'PRD_ID': ('pdbx_reference_entity_list', 'prd_id', None, None),
                                                         'REF_ENTITY_ID': ('pdbx_reference_entity_list',
                                                                           'ref_entity_id',
                                                                           None,
                                                                           None),
                                                         'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                         'TYPE': ('pdbx_reference_entity_list', 'type', None, None)},
                                       'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID',
                                                                         'PRD_ID',
                                                                         'REF_ENTITY_ID',
                                                                         'COMPONENT_ID'),
                                                          'TYPE': 'UNIQUE'},
                                                   's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                       'MAP_MERGE_INDICES': {'pdbx_reference_entity_list': {'ATTRIBUTES': ('prd_id',
                                                                                                           'ref_entity_id',
                                                                                                           'component_id'),
                                                                                            'TYPE': 'EQUI-JOIN'}},
                                       'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                       'TABLE_ID': 'PDBX_REFERENCE_ENTITY_LIST',
                                       'TABLE_NAME': 'pdbx_reference_entity_list',
                                       'TABLE_TYPE': 'transactional'},
        'PDBX_REFERENCE_ENTITY_NONPOLY': {'ATTRIBUTES': {'CHEM_COMP_ID': 'chem_comp_id',
                                                         'DETAILS': 'details',
                                                         'NAME': 'name',
                                                         'PRD_ID': 'prd_id',
                                                         'REF_ENTITY_ID': 'ref_entity_id',
                                                         'STRUCTURE_ID': 'Structure_ID'},
                                          'ATTRIBUTE_INFO': {'CHEM_COMP_ID': {'NULLABLE': True,
                                                                              'ORDER': 6,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                                             'DETAILS': {'NULLABLE': True,
                                                                         'ORDER': 4,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 200},
                                                             'NAME': {'NULLABLE': True,
                                                                      'ORDER': 5,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 200},
                                                             'PRD_ID': {'NULLABLE': False,
                                                                        'ORDER': 2,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': True,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                                             'REF_ENTITY_ID': {'NULLABLE': False,
                                                                               'ORDER': 3,
                                                                               'PRECISION': 0,
                                                                               'PRIMARY_KEY': True,
                                                                               'SQL_TYPE': 'VARCHAR',
                                                                               'WIDTH': 10},
                                                             'STRUCTURE_ID': {'NULLABLE': False,
                                                                              'ORDER': 1,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': True,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10}},
                                          'ATTRIBUTE_MAP': {'CHEM_COMP_ID': ('pdbx_reference_entity_nonpoly',
                                                                             'chem_comp_id',
                                                                             None,
                                                                             None),
                                                            'DETAILS': ('pdbx_reference_entity_nonpoly',
                                                                        'details',
                                                                        None,
                                                                        None),
                                                            'NAME': ('pdbx_reference_entity_nonpoly', 'name', None, None),
                                                            'PRD_ID': ('pdbx_reference_entity_nonpoly', 'prd_id', None, None),
                                                            'REF_ENTITY_ID': ('pdbx_reference_entity_nonpoly',
                                                                              'ref_entity_id',
                                                                              None,
                                                                              None),
                                                            'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                          'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'PRD_ID', 'REF_ENTITY_ID'),
                                                             'TYPE': 'UNIQUE'},
                                                      's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                          'MAP_MERGE_INDICES': {'pdbx_reference_entity_nonpoly': {'ATTRIBUTES': ('prd_id',
                                                                                                                 'ref_entity_id'),
                                                                                                  'TYPE': 'EQUI-JOIN'}},
                                          'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                          'TABLE_ID': 'PDBX_REFERENCE_ENTITY_NONPOLY',
                                          'TABLE_NAME': 'pdbx_reference_entity_nonpoly',
                                          'TABLE_TYPE': 'transactional'},
        'PDBX_REFERENCE_ENTITY_POLY': {'ATTRIBUTES': {'DB_CODE': 'db_code',
                                                      'DB_NAME': 'db_name',
                                                      'PRD_ID': 'prd_id',
                                                      'REF_ENTITY_ID': 'ref_entity_id',
                                                      'STRUCTURE_ID': 'Structure_ID',
                                                      'TYPE': 'type'},
                                       'ATTRIBUTE_INFO': {'DB_CODE': {'NULLABLE': True,
                                                                      'ORDER': 5,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 200},
                                                          'DB_NAME': {'NULLABLE': True,
                                                                      'ORDER': 6,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 200},
                                                          'PRD_ID': {'NULLABLE': False,
                                                                     'ORDER': 2,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': True,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                                          'REF_ENTITY_ID': {'NULLABLE': False,
                                                                            'ORDER': 3,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': True,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 10},
                                                          'STRUCTURE_ID': {'NULLABLE': False,
                                                                           'ORDER': 1,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': True,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10},
                                                          'TYPE': {'NULLABLE': True,
                                                                   'ORDER': 4,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 80}},
                                       'ATTRIBUTE_MAP': {'DB_CODE': ('pdbx_reference_entity_poly', 'db_code', None, None),
                                                         'DB_NAME': ('pdbx_reference_entity_poly', 'db_name', None, None),
                                                         'PRD_ID': ('pdbx_reference_entity_poly', 'prd_id', None, None),
                                                         'REF_ENTITY_ID': ('pdbx_reference_entity_poly',
                                                                           'ref_entity_id',
                                                                           None,
                                                                           None),
                                                         'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                         'TYPE': ('pdbx_reference_entity_poly', 'type', None, None)},
                                       'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'PRD_ID', 'REF_ENTITY_ID'),
                                                          'TYPE': 'UNIQUE'},
                                                   's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                       'MAP_MERGE_INDICES': {'pdbx_reference_entity_poly': {'ATTRIBUTES': ('prd_id',
                                                                                                           'ref_entity_id'),
                                                                                            'TYPE': 'EQUI-JOIN'}},
                                       'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                       'TABLE_ID': 'PDBX_REFERENCE_ENTITY_POLY',
                                       'TABLE_NAME': 'pdbx_reference_entity_poly',
                                       'TABLE_TYPE': 'transactional'},
        'PDBX_REFERENCE_ENTITY_POLY_LINK': {'ATTRIBUTES': {'ATOM_ID_1': 'atom_id_1',
                                                           'ATOM_ID_2': 'atom_id_2',
                                                           'COMPONENT_ID': 'component_id',
                                                           'COMP_ID_1': 'comp_id_1',
                                                           'COMP_ID_2': 'comp_id_2',
                                                           'DETAILS': 'details',
                                                           'ENTITY_SEQ_NUM_1': 'entity_seq_num_1',
                                                           'ENTITY_SEQ_NUM_2': 'entity_seq_num_2',
                                                           'INSERT_CODE_1': 'insert_code_1',
                                                           'INSERT_CODE_2': 'insert_code_2',
                                                           'LINK_ID': 'link_id',
                                                           'PRD_ID': 'prd_id',
                                                           'REF_ENTITY_ID': 'ref_entity_id',
                                                           'STRUCTURE_ID': 'Structure_ID',
                                                           'VALUE_ORDER': 'value_order'},
                                            'ATTRIBUTE_INFO': {'ATOM_ID_1': {'NULLABLE': True,
                                                                             'ORDER': 11,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 6},
                                                               'ATOM_ID_2': {'NULLABLE': True,
                                                                             'ORDER': 12,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                               'COMPONENT_ID': {'NULLABLE': False,
                                                                                'ORDER': 6,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': True,
                                                                                'SQL_TYPE': 'INT',
                                                                                'WIDTH': 10},
                                                               'COMP_ID_1': {'NULLABLE': True,
                                                                             'ORDER': 9,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                               'COMP_ID_2': {'NULLABLE': True,
                                                                             'ORDER': 10,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                               'DETAILS': {'NULLABLE': True,
                                                                           'ORDER': 4,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 200},
                                                               'ENTITY_SEQ_NUM_1': {'NULLABLE': True,
                                                                                    'ORDER': 7,
                                                                                    'PRECISION': 0,
                                                                                    'PRIMARY_KEY': False,
                                                                                    'SQL_TYPE': 'INT',
                                                                                    'WIDTH': 10},
                                                               'ENTITY_SEQ_NUM_2': {'NULLABLE': True,
                                                                                    'ORDER': 8,
                                                                                    'PRECISION': 0,
                                                                                    'PRIMARY_KEY': False,
                                                                                    'SQL_TYPE': 'INT',
                                                                                    'WIDTH': 10},
                                                               'INSERT_CODE_1': {'NULLABLE': True,
                                                                                 'ORDER': 13,
                                                                                 'PRECISION': 0,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'VARCHAR',
                                                                                 'WIDTH': 10},
                                                               'INSERT_CODE_2': {'NULLABLE': True,
                                                                                 'ORDER': 14,
                                                                                 'PRECISION': 0,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'VARCHAR',
                                                                                 'WIDTH': 10},
                                                               'LINK_ID': {'NULLABLE': False,
                                                                           'ORDER': 2,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': True,
                                                                           'SQL_TYPE': 'INT',
                                                                           'WIDTH': 10},
                                                               'PRD_ID': {'NULLABLE': False,
                                                                          'ORDER': 3,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': True,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                               'REF_ENTITY_ID': {'NULLABLE': False,
                                                                                 'ORDER': 5,
                                                                                 'PRECISION': 0,
                                                                                 'PRIMARY_KEY': True,
                                                                                 'SQL_TYPE': 'VARCHAR',
                                                                                 'WIDTH': 10},
                                                               'STRUCTURE_ID': {'NULLABLE': False,
                                                                                'ORDER': 1,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': True,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 10},
                                                               'VALUE_ORDER': {'NULLABLE': True,
                                                                               'ORDER': 15,
                                                                               'PRECISION': 0,
                                                                               'PRIMARY_KEY': False,
                                                                               'SQL_TYPE': 'VARCHAR',
                                                                               'WIDTH': 10}},
                                            'ATTRIBUTE_MAP': {'ATOM_ID_1': ('pdbx_reference_entity_poly_link',
                                                                            'atom_id_1',
                                                                            None,
                                                                            None),
                                                              'ATOM_ID_2': ('pdbx_reference_entity_poly_link',
                                                                            'atom_id_2',
                                                                            None,
                                                                            None),
                                                              'COMPONENT_ID': ('pdbx_reference_entity_poly_link',
                                                                               'component_id',
                                                                               None,
                                                                               None),
                                                              'COMP_ID_1': ('pdbx_reference_entity_poly_link',
                                                                            'comp_id_1',
                                                                            None,
                                                                            None),
                                                              'COMP_ID_2': ('pdbx_reference_entity_poly_link',
                                                                            'comp_id_2',
                                                                            None,
                                                                            None),
                                                              'DETAILS': ('pdbx_reference_entity_poly_link',
                                                                          'details',
                                                                          None,
                                                                          None),
                                                              'ENTITY_SEQ_NUM_1': ('pdbx_reference_entity_poly_link',
                                                                                   'entity_seq_num_1',
                                                                                   None,
                                                                                   None),
                                                              'ENTITY_SEQ_NUM_2': ('pdbx_reference_entity_poly_link',
                                                                                   'entity_seq_num_2',
                                                                                   None,
                                                                                   None),
                                                              'INSERT_CODE_1': ('pdbx_reference_entity_poly_link',
                                                                                'insert_code_1',
                                                                                None,
                                                                                None),
                                                              'INSERT_CODE_2': ('pdbx_reference_entity_poly_link',
                                                                                'insert_code_2',
                                                                                None,
                                                                                None),
                                                              'LINK_ID': ('pdbx_reference_entity_poly_link',
                                                                          'link_id',
                                                                          None,
                                                                          None),
                                                              'PRD_ID': ('pdbx_reference_entity_poly_link',
                                                                         'prd_id',
                                                                         None,
                                                                         None),
                                                              'REF_ENTITY_ID': ('pdbx_reference_entity_poly_link',
                                                                                'ref_entity_id',
                                                                                None,
                                                                                None),
                                                              'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                              'VALUE_ORDER': ('pdbx_reference_entity_poly_link',
                                                                              'value_order',
                                                                              None,
                                                                              None)},
                                            'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID',
                                                                              'LINK_ID',
                                                                              'PRD_ID',
                                                                              'REF_ENTITY_ID',
                                                                              'COMPONENT_ID'),
                                                               'TYPE': 'UNIQUE'},
                                                        's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                            'MAP_MERGE_INDICES': {'pdbx_reference_entity_poly_link': {'ATTRIBUTES': ('link_id',
                                                                                                                     'prd_id',
                                                                                                                     'ref_entity_id',
                                                                                                                     'component_id'),
                                                                                                      'TYPE': 'EQUI-JOIN'}},
                                            'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                            'TABLE_ID': 'PDBX_REFERENCE_ENTITY_POLY_LINK',
                                            'TABLE_NAME': 'pdbx_reference_entity_poly_link',
                                            'TABLE_TYPE': 'transactional'},
        'PDBX_REFERENCE_ENTITY_POLY_SEQ': {'ATTRIBUTES': {'HETERO': 'hetero',
                                                          'MON_ID': 'mon_id',
                                                          'NUM': 'num',
                                                          'OBSERVED': 'observed',
                                                          'PARENT_MON_ID': 'parent_mon_id',
                                                          'PRD_ID': 'prd_id',
                                                          'REF_ENTITY_ID': 'ref_entity_id',
                                                          'STRUCTURE_ID': 'Structure_ID'},
                                           'ATTRIBUTE_INFO': {'HETERO': {'NULLABLE': False,
                                                                         'ORDER': 8,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': True,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                                              'MON_ID': {'NULLABLE': False,
                                                                         'ORDER': 4,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': True,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                                              'NUM': {'NULLABLE': False,
                                                                      'ORDER': 6,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'INT',
                                                                      'WIDTH': 10},
                                                              'OBSERVED': {'NULLABLE': True,
                                                                           'ORDER': 7,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10},
                                                              'PARENT_MON_ID': {'NULLABLE': True,
                                                                                'ORDER': 5,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 10},
                                                              'PRD_ID': {'NULLABLE': False,
                                                                         'ORDER': 2,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': True,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                                              'REF_ENTITY_ID': {'NULLABLE': False,
                                                                                'ORDER': 3,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': True,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 10},
                                                              'STRUCTURE_ID': {'NULLABLE': False,
                                                                               'ORDER': 1,
                                                                               'PRECISION': 0,
                                                                               'PRIMARY_KEY': True,
                                                                               'SQL_TYPE': 'VARCHAR',
                                                                               'WIDTH': 10}},
                                           'ATTRIBUTE_MAP': {'HETERO': ('pdbx_reference_entity_poly_seq',
                                                                        'hetero',
                                                                        None,
                                                                        None),
                                                             'MON_ID': ('pdbx_reference_entity_poly_seq',
                                                                        'mon_id',
                                                                        None,
                                                                        None),
                                                             'NUM': ('pdbx_reference_entity_poly_seq', 'num', None, None),
                                                             'OBSERVED': ('pdbx_reference_entity_poly_seq',
                                                                          'observed',
                                                                          None,
                                                                          None),
                                                             'PARENT_MON_ID': ('pdbx_reference_entity_poly_seq',
                                                                               'parent_mon_id',
                                                                               None,
                                                                               None),
                                                             'PRD_ID': ('pdbx_reference_entity_poly_seq',
                                                                        'prd_id',
                                                                        None,
                                                                        None),
                                                             'REF_ENTITY_ID': ('pdbx_reference_entity_poly_seq',
                                                                               'ref_entity_id',
                                                                               None,
                                                                               None),
                                                             'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                           'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID',
                                                                             'PRD_ID',
                                                                             'REF_ENTITY_ID',
                                                                             'MON_ID',
                                                                             'NUM',
                                                                             'HETERO'),
                                                              'TYPE': 'UNIQUE'},
                                                       's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                           'MAP_MERGE_INDICES': {'pdbx_reference_entity_poly_seq': {'ATTRIBUTES': ('prd_id',
                                                                                                                   'ref_entity_id',
                                                                                                                   'mon_id',
                                                                                                                   'num',
                                                                                                                   'hetero'),
                                                                                                    'TYPE': 'EQUI-JOIN'}},
                                           'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                           'TABLE_ID': 'PDBX_REFERENCE_ENTITY_POLY_SEQ',
                                           'TABLE_NAME': 'pdbx_reference_entity_poly_seq',
                                           'TABLE_TYPE': 'transactional'},
        'PDBX_REFERENCE_ENTITY_SEQUENCE': {'ATTRIBUTES': {'NRP_FLAG': 'NRP_flag',
                                                          'ONE_LETTER_CODES': 'one_letter_codes',
                                                          'PRD_ID': 'prd_id',
                                                          'REF_ENTITY_ID': 'ref_entity_id',
                                                          'STRUCTURE_ID': 'Structure_ID',
                                                          'TYPE': 'type'},
                                           'ATTRIBUTE_INFO': {'NRP_FLAG': {'NULLABLE': True,
                                                                           'ORDER': 5,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10},
                                                              'ONE_LETTER_CODES': {'NULLABLE': True,
                                                                                   'ORDER': 6,
                                                                                   'PRECISION': 0,
                                                                                   'PRIMARY_KEY': False,
                                                                                   'SQL_TYPE': 'VARCHAR',
                                                                                   'WIDTH': 80},
                                                              'PRD_ID': {'NULLABLE': False,
                                                                         'ORDER': 2,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': True,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                                              'REF_ENTITY_ID': {'NULLABLE': False,
                                                                                'ORDER': 3,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': True,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 10},
                                                              'STRUCTURE_ID': {'NULLABLE': False,
                                                                               'ORDER': 1,
                                                                               'PRECISION': 0,
                                                                               'PRIMARY_KEY': True,
                                                                               'SQL_TYPE': 'VARCHAR',
                                                                               'WIDTH': 10},
                                                              'TYPE': {'NULLABLE': True,
                                                                       'ORDER': 4,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 80}},
                                           'ATTRIBUTE_MAP': {'NRP_FLAG': ('pdbx_reference_entity_sequence',
                                                                          'NRP_flag',
                                                                          None,
                                                                          None),
                                                             'ONE_LETTER_CODES': ('pdbx_reference_entity_sequence',
                                                                                  'one_letter_codes',
                                                                                  None,
                                                                                  None),
                                                             'PRD_ID': ('pdbx_reference_entity_sequence',
                                                                        'prd_id',
                                                                        None,
                                                                        None),
                                                             'REF_ENTITY_ID': ('pdbx_reference_entity_sequence',
                                                                               'ref_entity_id',
                                                                               None,
                                                                               None),
                                                             'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                             'TYPE': ('pdbx_reference_entity_sequence', 'type', None, None)},
                                           'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'PRD_ID', 'REF_ENTITY_ID'),
                                                              'TYPE': 'UNIQUE'},
                                                       's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                           'MAP_MERGE_INDICES': {'pdbx_reference_entity_sequence': {'ATTRIBUTES': ('prd_id',
                                                                                                                   'ref_entity_id'),
                                                                                                    'TYPE': 'EQUI-JOIN'}},
                                           'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                           'TABLE_ID': 'PDBX_REFERENCE_ENTITY_SEQUENCE',
                                           'TABLE_NAME': 'pdbx_reference_entity_sequence',
                                           'TABLE_TYPE': 'transactional'},
        'PDBX_REFERENCE_ENTITY_SRC_NAT': {'ATTRIBUTES': {'ATCC': 'atcc',
                                                         'DB_CODE': 'db_code',
                                                         'DB_NAME': 'db_name',
                                                         'ORDINAL': 'ordinal',
                                                         'ORGANISM_SCIENTIFIC': 'organism_scientific',
                                                         'PRD_ID': 'prd_id',
                                                         'REF_ENTITY_ID': 'ref_entity_id',
                                                         'SOURCE': 'source',
                                                         'SOURCE_ID': 'source_id',
                                                         'STRAIN': 'strain',
                                                         'STRUCTURE_ID': 'Structure_ID',
                                                         'TAXID': 'taxid'},
                                          'ATTRIBUTE_INFO': {'ATCC': {'NULLABLE': True,
                                                                      'ORDER': 8,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 200},
                                                             'DB_CODE': {'NULLABLE': True,
                                                                         'ORDER': 9,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 200},
                                                             'DB_NAME': {'NULLABLE': True,
                                                                         'ORDER': 10,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 200},
                                                             'ORDINAL': {'NULLABLE': False,
                                                                         'ORDER': 4,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': True,
                                                                         'SQL_TYPE': 'INT',
                                                                         'WIDTH': 10},
                                                             'ORGANISM_SCIENTIFIC': {'NULLABLE': True,
                                                                                     'ORDER': 5,
                                                                                     'PRECISION': 0,
                                                                                     'PRIMARY_KEY': False,
                                                                                     'SQL_TYPE': 'VARCHAR',
                                                                                     'WIDTH': 200},
                                                             'PRD_ID': {'NULLABLE': False,
                                                                        'ORDER': 2,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': True,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                                             'REF_ENTITY_ID': {'NULLABLE': False,
                                                                               'ORDER': 3,
                                                                               'PRECISION': 0,
                                                                               'PRIMARY_KEY': True,
                                                                               'SQL_TYPE': 'VARCHAR',
                                                                               'WIDTH': 10},
                                                             'SOURCE': {'NULLABLE': True,
                                                                        'ORDER': 11,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 200},
                                                             'SOURCE_ID': {'NULLABLE': True,
                                                                           'ORDER': 12,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 200},
                                                             'STRAIN': {'NULLABLE': True,
                                                                        'ORDER': 6,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 200},
                                                             'STRUCTURE_ID': {'NULLABLE': False,
                                                                              'ORDER': 1,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': True,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                                             'TAXID': {'NULLABLE': True,
                                                                       'ORDER': 7,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 200}},
                                          'ATTRIBUTE_MAP': {'ATCC': ('pdbx_reference_entity_src_nat', 'atcc', None, None),
                                                            'DB_CODE': ('pdbx_reference_entity_src_nat',
                                                                        'db_code',
                                                                        None,
                                                                        None),
                                                            'DB_NAME': ('pdbx_reference_entity_src_nat',
                                                                        'db_name',
                                                                        None,
                                                                        None),
                                                            'ORDINAL': ('pdbx_reference_entity_src_nat',
                                                                        'ordinal',
                                                                        None,
                                                                        None),
                                                            'ORGANISM_SCIENTIFIC': ('pdbx_reference_entity_src_nat',
                                                                                    'organism_scientific',
                                                                                    None,
                                                                                    None),
                                                            'PRD_ID': ('pdbx_reference_entity_src_nat', 'prd_id', None, None),
                                                            'REF_ENTITY_ID': ('pdbx_reference_entity_src_nat',
                                                                              'ref_entity_id',
                                                                              None,
                                                                              None),
                                                            'SOURCE': ('pdbx_reference_entity_src_nat', 'source', None, None),
                                                            'SOURCE_ID': ('pdbx_reference_entity_src_nat',
                                                                          'source_id',
                                                                          None,
                                                                          None),
                                                            'STRAIN': ('pdbx_reference_entity_src_nat', 'strain', None, None),
                                                            'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                            'TAXID': ('pdbx_reference_entity_src_nat', 'taxid', None, None)},
                                          'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID',
                                                                            'PRD_ID',
                                                                            'REF_ENTITY_ID',
                                                                            'ORDINAL'),
                                                             'TYPE': 'UNIQUE'},
                                                      's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                          'MAP_MERGE_INDICES': {'pdbx_reference_entity_src_nat': {'ATTRIBUTES': ('prd_id',
                                                                                                                 'ref_entity_id',
                                                                                                                 'ordinal'),
                                                                                                  'TYPE': 'EQUI-JOIN'}},
                                          'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                          'TABLE_ID': 'PDBX_REFERENCE_ENTITY_SRC_NAT',
                                          'TABLE_NAME': 'pdbx_reference_entity_src_nat',
                                          'TABLE_TYPE': 'transactional'},
        'PDBX_REFERENCE_ENTITY_SUBCOMPONENTS': {'ATTRIBUTES': {'CHEM_COMP_ID': 'chem_comp_id',
                                                               'PRD_ID': 'prd_id',
                                                               'SEQ': 'seq',
                                                               'STRUCTURE_ID': 'Structure_ID'},
                                                'ATTRIBUTE_INFO': {'CHEM_COMP_ID': {'NULLABLE': True,
                                                                                    'ORDER': 4,
                                                                                    'PRECISION': 0,
                                                                                    'PRIMARY_KEY': False,
                                                                                    'SQL_TYPE': 'VARCHAR',
                                                                                    'WIDTH': 10},
                                                                   'PRD_ID': {'NULLABLE': False,
                                                                              'ORDER': 2,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': True,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                                                   'SEQ': {'NULLABLE': False,
                                                                           'ORDER': 3,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': True,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 200},
                                                                   'STRUCTURE_ID': {'NULLABLE': False,
                                                                                    'ORDER': 1,
                                                                                    'PRECISION': 0,
                                                                                    'PRIMARY_KEY': True,
                                                                                    'SQL_TYPE': 'VARCHAR',
                                                                                    'WIDTH': 10}},
                                                'ATTRIBUTE_MAP': {'CHEM_COMP_ID': ('pdbx_reference_entity_subcomponents',
                                                                                   'chem_comp_id',
                                                                                   None,
                                                                                   None),
                                                                  'PRD_ID': ('pdbx_reference_entity_subcomponents',
                                                                             'prd_id',
                                                                             None,
                                                                             None),
                                                                  'SEQ': ('pdbx_reference_entity_subcomponents',
                                                                          'seq',
                                                                          None,
                                                                          None),
                                                                  'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                                'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'PRD_ID', 'SEQ'),
                                                                   'TYPE': 'UNIQUE'},
                                                            's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                                'MAP_MERGE_INDICES': {'pdbx_reference_entity_subcomponents': {'ATTRIBUTES': ('prd_id',
                                                                                                                             'seq'),
                                                                                                              'TYPE': 'EQUI-JOIN'}},
                                                'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                                'TABLE_ID': 'PDBX_REFERENCE_ENTITY_SUBCOMPONENTS',
                                                'TABLE_NAME': 'pdbx_reference_entity_subcomponents',
                                                'TABLE_TYPE': 'transactional'},
        'PDBX_REFERENCE_MOLECULE': {'ATTRIBUTES': {'CHEM_COMP_ID': 'chem_comp_id',
                                                   'CLASS': 'class',
                                                   'CLASS_EVIDENCE_CODE': 'class_evidence_code',
                                                   'COMPOUND_DETAILS': 'compound_details',
                                                   'DESCRIPTION': 'description',
                                                   'FORMULA': 'formula',
                                                   'FORMULA_WEIGHT': 'formula_weight',
                                                   'NAME': 'name',
                                                   'PRD_ID': 'prd_id',
                                                   'RELEASE_STATUS': 'release_status',
                                                   'REPLACED_BY': 'replaced_by',
                                                   'REPLACES': 'replaces',
                                                   'REPRESENTATIVE_PDB_ID_CODE': 'representative_PDB_id_code',
                                                   'REPRESENT_AS': 'represent_as',
                                                   'STRUCTURE_ID': 'Structure_ID',
                                                   'TYPE': 'type',
                                                   'TYPE_EVIDENCE_CODE': 'type_evidence_code'},
                                    'ATTRIBUTE_INFO': {'CHEM_COMP_ID': {'NULLABLE': True,
                                                                        'ORDER': 11,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                                       'CLASS': {'NULLABLE': True,
                                                                 'ORDER': 7,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 200},
                                                       'CLASS_EVIDENCE_CODE': {'NULLABLE': True,
                                                                               'ORDER': 8,
                                                                               'PRECISION': 0,
                                                                               'PRIMARY_KEY': False,
                                                                               'SQL_TYPE': 'VARCHAR',
                                                                               'WIDTH': 200},
                                                       'COMPOUND_DETAILS': {'NULLABLE': True,
                                                                            'ORDER': 12,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 200},
                                                       'DESCRIPTION': {'NULLABLE': True,
                                                                       'ORDER': 13,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 200},
                                                       'FORMULA': {'NULLABLE': True,
                                                                   'ORDER': 4,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 200},
                                                       'FORMULA_WEIGHT': {'NULLABLE': True,
                                                                          'ORDER': 3,
                                                                          'PRECISION': 6,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'FLOAT',
                                                                          'WIDTH': 10},
                                                       'NAME': {'NULLABLE': True,
                                                                'ORDER': 9,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 200},
                                                       'PRD_ID': {'NULLABLE': False,
                                                                  'ORDER': 2,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': True,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10},
                                                       'RELEASE_STATUS': {'NULLABLE': True,
                                                                          'ORDER': 15,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 80},
                                                       'REPLACED_BY': {'NULLABLE': True,
                                                                       'ORDER': 17,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 80},
                                                       'REPLACES': {'NULLABLE': True,
                                                                    'ORDER': 16,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 80},
                                                       'REPRESENTATIVE_PDB_ID_CODE': {'NULLABLE': True,
                                                                                      'ORDER': 14,
                                                                                      'PRECISION': 0,
                                                                                      'PRIMARY_KEY': False,
                                                                                      'SQL_TYPE': 'VARCHAR',
                                                                                      'WIDTH': 10},
                                                       'REPRESENT_AS': {'NULLABLE': True,
                                                                        'ORDER': 10,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 80},
                                                       'STRUCTURE_ID': {'NULLABLE': False,
                                                                        'ORDER': 1,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': True,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                                       'TYPE': {'NULLABLE': True,
                                                                'ORDER': 5,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 80},
                                                       'TYPE_EVIDENCE_CODE': {'NULLABLE': True,
                                                                              'ORDER': 6,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 200}},
                                    'ATTRIBUTE_MAP': {'CHEM_COMP_ID': ('pdbx_reference_molecule', 'chem_comp_id', None, None),
                                                      'CLASS': ('pdbx_reference_molecule', 'class', None, None),
                                                      'CLASS_EVIDENCE_CODE': ('pdbx_reference_molecule',
                                                                              'class_evidence_code',
                                                                              None,
                                                                              None),
                                                      'COMPOUND_DETAILS': ('pdbx_reference_molecule',
                                                                           'compound_details',
                                                                           None,
                                                                           None),
                                                      'DESCRIPTION': ('pdbx_reference_molecule', 'description', None, None),
                                                      'FORMULA': ('pdbx_reference_molecule', 'formula', None, None),
                                                      'FORMULA_WEIGHT': ('pdbx_reference_molecule',
                                                                         'formula_weight',
                                                                         None,
                                                                         None),
                                                      'NAME': ('pdbx_reference_molecule', 'name', None, None),
                                                      'PRD_ID': ('pdbx_reference_molecule', 'prd_id', None, None),
                                                      'RELEASE_STATUS': ('pdbx_reference_molecule',
                                                                         'release_status',
                                                                         None,
                                                                         None),
                                                      'REPLACED_BY': ('pdbx_reference_molecule', 'replaced_by', None, None),
                                                      'REPLACES': ('pdbx_reference_molecule', 'replaces', None, None),
                                                      'REPRESENTATIVE_PDB_ID_CODE': ('pdbx_reference_molecule',
                                                                                     'representative_PDB_id_code',
                                                                                     None,
                                                                                     None),
                                                      'REPRESENT_AS': ('pdbx_reference_molecule', 'represent_as', None, None),
                                                      'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                      'TYPE': ('pdbx_reference_molecule', 'type', None, None),
                                                      'TYPE_EVIDENCE_CODE': ('pdbx_reference_molecule',
                                                                             'type_evidence_code',
                                                                             None,
                                                                             None)},
                                    'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'PRD_ID'), 'TYPE': 'UNIQUE'},
                                                's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                    'MAP_MERGE_INDICES': {'pdbx_reference_molecule': {'ATTRIBUTES': ('prd_id',),
                                                                                      'TYPE': 'EQUI-JOIN'}},
                                    'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                    'TABLE_ID': 'PDBX_REFERENCE_MOLECULE',
                                    'TABLE_NAME': 'pdbx_reference_molecule',
                                    'TABLE_TYPE': 'transactional'},
        'PDBX_REFERENCE_MOLECULE_ANNOTATION': {'ATTRIBUTES': {'CHEM_COMP_ID': 'chem_comp_id',
                                                              'FAMILY_PRD_ID': 'family_prd_id',
                                                              'ORDINAL': 'ordinal',
                                                              'PRD_ID': 'prd_id',
                                                              'SOURCE': 'source',
                                                              'STRUCTURE_ID': 'Structure_ID',
                                                              'SUPPORT': 'support',
                                                              'TEXT': 'text',
                                                              'TYPE': 'type'},
                                               'ATTRIBUTE_INFO': {'CHEM_COMP_ID': {'NULLABLE': True,
                                                                                   'ORDER': 9,
                                                                                   'PRECISION': 0,
                                                                                   'PRIMARY_KEY': False,
                                                                                   'SQL_TYPE': 'VARCHAR',
                                                                                   'WIDTH': 10},
                                                                  'FAMILY_PRD_ID': {'NULLABLE': False,
                                                                                    'ORDER': 2,
                                                                                    'PRECISION': 0,
                                                                                    'PRIMARY_KEY': True,
                                                                                    'SQL_TYPE': 'VARCHAR',
                                                                                    'WIDTH': 10},
                                                                  'ORDINAL': {'NULLABLE': False,
                                                                              'ORDER': 4,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': True,
                                                                              'SQL_TYPE': 'INT',
                                                                              'WIDTH': 10},
                                                                  'PRD_ID': {'NULLABLE': True,
                                                                             'ORDER': 3,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                                  'SOURCE': {'NULLABLE': True,
                                                                             'ORDER': 8,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 200},
                                                                  'STRUCTURE_ID': {'NULLABLE': False,
                                                                                   'ORDER': 1,
                                                                                   'PRECISION': 0,
                                                                                   'PRIMARY_KEY': True,
                                                                                   'SQL_TYPE': 'VARCHAR',
                                                                                   'WIDTH': 10},
                                                                  'SUPPORT': {'NULLABLE': True,
                                                                              'ORDER': 7,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 200},
                                                                  'TEXT': {'NULLABLE': True,
                                                                           'ORDER': 5,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 200},
                                                                  'TYPE': {'NULLABLE': True,
                                                                           'ORDER': 6,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 80}},
                                               'ATTRIBUTE_MAP': {'CHEM_COMP_ID': ('pdbx_reference_molecule_annotation',
                                                                                  'chem_comp_id',
                                                                                  None,
                                                                                  None),
                                                                 'FAMILY_PRD_ID': ('pdbx_reference_molecule_annotation',
                                                                                   'family_prd_id',
                                                                                   None,
                                                                                   None),
                                                                 'ORDINAL': ('pdbx_reference_molecule_annotation',
                                                                             'ordinal',
                                                                             None,
                                                                             None),
                                                                 'PRD_ID': ('pdbx_reference_molecule_annotation',
                                                                            'prd_id',
                                                                            None,
                                                                            None),
                                                                 'SOURCE': ('pdbx_reference_molecule_annotation',
                                                                            'source',
                                                                            None,
                                                                            None),
                                                                 'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                                 'SUPPORT': ('pdbx_reference_molecule_annotation',
                                                                             'support',
                                                                             None,
                                                                             None),
                                                                 'TEXT': ('pdbx_reference_molecule_annotation',
                                                                          'text',
                                                                          None,
                                                                          None),
                                                                 'TYPE': ('pdbx_reference_molecule_annotation',
                                                                          'type',
                                                                          None,
                                                                          None)},
                                               'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'FAMILY_PRD_ID', 'ORDINAL'),
                                                                  'TYPE': 'UNIQUE'},
                                                           's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                               'MAP_MERGE_INDICES': {'pdbx_reference_molecule_annotation': {'ATTRIBUTES': ('family_prd_id',
                                                                                                                           'ordinal'),
                                                                                                            'TYPE': 'EQUI-JOIN'}},
                                               'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                               'TABLE_ID': 'PDBX_REFERENCE_MOLECULE_ANNOTATION',
                                               'TABLE_NAME': 'pdbx_reference_molecule_annotation',
                                               'TABLE_TYPE': 'transactional'},
        'PDBX_REFERENCE_MOLECULE_DETAILS': {'ATTRIBUTES': {'FAMILY_PRD_ID': 'family_prd_id',
                                                           'ORDINAL': 'ordinal',
                                                           'PRD_ID': 'prd_id',
                                                           'SOURCE': 'source',
                                                           'SOURCE_ID': 'source_id',
                                                           'STRUCTURE_ID': 'Structure_ID',
                                                           'TEXT': 'text'},
                                            'ATTRIBUTE_INFO': {'FAMILY_PRD_ID': {'NULLABLE': False,
                                                                                 'ORDER': 2,
                                                                                 'PRECISION': 0,
                                                                                 'PRIMARY_KEY': True,
                                                                                 'SQL_TYPE': 'VARCHAR',
                                                                                 'WIDTH': 10},
                                                               'ORDINAL': {'NULLABLE': False,
                                                                           'ORDER': 4,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': True,
                                                                           'SQL_TYPE': 'INT',
                                                                           'WIDTH': 10},
                                                               'PRD_ID': {'NULLABLE': True,
                                                                          'ORDER': 3,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                               'SOURCE': {'NULLABLE': True,
                                                                          'ORDER': 5,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 200},
                                                               'SOURCE_ID': {'NULLABLE': True,
                                                                             'ORDER': 6,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 200},
                                                               'STRUCTURE_ID': {'NULLABLE': False,
                                                                                'ORDER': 1,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': True,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 10},
                                                               'TEXT': {'NULLABLE': True,
                                                                        'ORDER': 7,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 200}},
                                            'ATTRIBUTE_MAP': {'FAMILY_PRD_ID': ('pdbx_reference_molecule_details',
                                                                                'family_prd_id',
                                                                                None,
                                                                                None),
                                                              'ORDINAL': ('pdbx_reference_molecule_details',
                                                                          'ordinal',
                                                                          None,
                                                                          None),
                                                              'PRD_ID': ('pdbx_reference_molecule_details',
                                                                         'prd_id',
                                                                         None,
                                                                         None),
                                                              'SOURCE': ('pdbx_reference_molecule_details',
                                                                         'source',
                                                                         None,
                                                                         None),
                                                              'SOURCE_ID': ('pdbx_reference_molecule_details',
                                                                            'source_id',
                                                                            None,
                                                                            None),
                                                              'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                              'TEXT': ('pdbx_reference_molecule_details', 'text', None, None)},
                                            'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'FAMILY_PRD_ID', 'ORDINAL'),
                                                               'TYPE': 'UNIQUE'},
                                                        's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                            'MAP_MERGE_INDICES': {'pdbx_reference_molecule_details': {'ATTRIBUTES': ('family_prd_id',
                                                                                                                     'ordinal'),
                                                                                                      'TYPE': 'EQUI-JOIN'}},
                                            'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                            'TABLE_ID': 'PDBX_REFERENCE_MOLECULE_DETAILS',
                                            'TABLE_NAME': 'pdbx_reference_molecule_details',
                                            'TABLE_TYPE': 'transactional'},
        'PDBX_REFERENCE_MOLECULE_FAMILY': {'ATTRIBUTES': {'FAMILY_PRD_ID': 'family_prd_id',
                                                          'NAME': 'name',
                                                          'RELEASE_STATUS': 'release_status',
                                                          'REPLACED_BY': 'replaced_by',
                                                          'REPLACES': 'replaces',
                                                          'STRUCTURE_ID': 'Structure_ID'},
                                           'ATTRIBUTE_INFO': {'FAMILY_PRD_ID': {'NULLABLE': False,
                                                                                'ORDER': 2,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': True,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 10},
                                                              'NAME': {'NULLABLE': True,
                                                                       'ORDER': 3,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 200},
                                                              'RELEASE_STATUS': {'NULLABLE': True,
                                                                                 'ORDER': 4,
                                                                                 'PRECISION': 0,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'VARCHAR',
                                                                                 'WIDTH': 80},
                                                              'REPLACED_BY': {'NULLABLE': True,
                                                                              'ORDER': 6,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 80},
                                                              'REPLACES': {'NULLABLE': True,
                                                                           'ORDER': 5,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 80},
                                                              'STRUCTURE_ID': {'NULLABLE': False,
                                                                               'ORDER': 1,
                                                                               'PRECISION': 0,
                                                                               'PRIMARY_KEY': True,
                                                                               'SQL_TYPE': 'VARCHAR',
                                                                               'WIDTH': 10}},
                                           'ATTRIBUTE_MAP': {'FAMILY_PRD_ID': ('pdbx_reference_molecule_family',
                                                                               'family_prd_id',
                                                                               None,
                                                                               None),
                                                             'NAME': ('pdbx_reference_molecule_family', 'name', None, None),
                                                             'RELEASE_STATUS': ('pdbx_reference_molecule_family',
                                                                                'release_status',
                                                                                None,
                                                                                None),
                                                             'REPLACED_BY': ('pdbx_reference_molecule_family',
                                                                             'replaced_by',
                                                                             None,
                                                                             None),
                                                             'REPLACES': ('pdbx_reference_molecule_family',
                                                                          'replaces',
                                                                          None,
                                                                          None),
                                                             'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                           'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'FAMILY_PRD_ID'),
                                                              'TYPE': 'UNIQUE'},
                                                       's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                           'MAP_MERGE_INDICES': {'pdbx_reference_molecule_family': {'ATTRIBUTES': ('family_prd_id',),
                                                                                                    'TYPE': 'EQUI-JOIN'}},
                                           'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                           'TABLE_ID': 'PDBX_REFERENCE_MOLECULE_FAMILY',
                                           'TABLE_NAME': 'pdbx_reference_molecule_family',
                                           'TABLE_TYPE': 'transactional'},
        'PDBX_REFERENCE_MOLECULE_FEATURES': {'ATTRIBUTES': {'CHEM_COMP_ID': 'chem_comp_id',
                                                            'FAMILY_PRD_ID': 'family_prd_id',
                                                            'ORDINAL': 'ordinal',
                                                            'PRD_ID': 'prd_id',
                                                            'SOURCE': 'source',
                                                            'SOURCE_ORDINAL': 'source_ordinal',
                                                            'STRUCTURE_ID': 'Structure_ID',
                                                            'TYPE': 'type',
                                                            'VALUE': 'value'},
                                             'ATTRIBUTE_INFO': {'CHEM_COMP_ID': {'NULLABLE': True,
                                                                                 'ORDER': 9,
                                                                                 'PRECISION': 0,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'VARCHAR',
                                                                                 'WIDTH': 10},
                                                                'FAMILY_PRD_ID': {'NULLABLE': False,
                                                                                  'ORDER': 2,
                                                                                  'PRECISION': 0,
                                                                                  'PRIMARY_KEY': True,
                                                                                  'SQL_TYPE': 'VARCHAR',
                                                                                  'WIDTH': 10},
                                                                'ORDINAL': {'NULLABLE': False,
                                                                            'ORDER': 4,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': True,
                                                                            'SQL_TYPE': 'INT',
                                                                            'WIDTH': 10},
                                                                'PRD_ID': {'NULLABLE': False,
                                                                           'ORDER': 3,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': True,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10},
                                                                'SOURCE': {'NULLABLE': True,
                                                                           'ORDER': 8,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 80},
                                                                'SOURCE_ORDINAL': {'NULLABLE': True,
                                                                                   'ORDER': 5,
                                                                                   'PRECISION': 0,
                                                                                   'PRIMARY_KEY': False,
                                                                                   'SQL_TYPE': 'INT',
                                                                                   'WIDTH': 10},
                                                                'STRUCTURE_ID': {'NULLABLE': False,
                                                                                 'ORDER': 1,
                                                                                 'PRECISION': 0,
                                                                                 'PRIMARY_KEY': True,
                                                                                 'SQL_TYPE': 'VARCHAR',
                                                                                 'WIDTH': 10},
                                                                'TYPE': {'NULLABLE': True,
                                                                         'ORDER': 6,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 80},
                                                                'VALUE': {'NULLABLE': True,
                                                                          'ORDER': 7,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 200}},
                                             'ATTRIBUTE_MAP': {'CHEM_COMP_ID': ('pdbx_reference_molecule_features',
                                                                                'chem_comp_id',
                                                                                None,
                                                                                None),
                                                               'FAMILY_PRD_ID': ('pdbx_reference_molecule_features',
                                                                                 'family_prd_id',
                                                                                 None,
                                                                                 None),
                                                               'ORDINAL': ('pdbx_reference_molecule_features',
                                                                           'ordinal',
                                                                           None,
                                                                           None),
                                                               'PRD_ID': ('pdbx_reference_molecule_features',
                                                                          'prd_id',
                                                                          None,
                                                                          None),
                                                               'SOURCE': ('pdbx_reference_molecule_features',
                                                                          'source',
                                                                          None,
                                                                          None),
                                                               'SOURCE_ORDINAL': ('pdbx_reference_molecule_features',
                                                                                  'source_ordinal',
                                                                                  None,
                                                                                  None),
                                                               'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                               'TYPE': ('pdbx_reference_molecule_features',
                                                                        'type',
                                                                        None,
                                                                        None),
                                                               'VALUE': ('pdbx_reference_molecule_features',
                                                                         'value',
                                                                         None,
                                                                         None)},
                                             'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID',
                                                                               'FAMILY_PRD_ID',
                                                                               'PRD_ID',
                                                                               'ORDINAL'),
                                                                'TYPE': 'UNIQUE'},
                                                         's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                             'MAP_MERGE_INDICES': {'pdbx_reference_molecule_features': {'ATTRIBUTES': ('family_prd_id',
                                                                                                                       'prd_id',
                                                                                                                       'ordinal'),
                                                                                                        'TYPE': 'EQUI-JOIN'}},
                                             'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                             'TABLE_ID': 'PDBX_REFERENCE_MOLECULE_FEATURES',
                                             'TABLE_NAME': 'pdbx_reference_molecule_features',
                                             'TABLE_TYPE': 'transactional'},
        'PDBX_REFERENCE_MOLECULE_LIST': {'ATTRIBUTES': {'FAMILY_PRD_ID': 'family_prd_id',
                                                        'PRD_ID': 'prd_id',
                                                        'STRUCTURE_ID': 'Structure_ID'},
                                         'ATTRIBUTE_INFO': {'FAMILY_PRD_ID': {'NULLABLE': False,
                                                                              'ORDER': 3,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': True,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                                            'PRD_ID': {'NULLABLE': False,
                                                                       'ORDER': 2,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': True,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                            'STRUCTURE_ID': {'NULLABLE': False,
                                                                             'ORDER': 1,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': True,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10}},
                                         'ATTRIBUTE_MAP': {'FAMILY_PRD_ID': ('pdbx_reference_molecule_list',
                                                                             'family_prd_id',
                                                                             None,
                                                                             None),
                                                           'PRD_ID': ('pdbx_reference_molecule_list', 'prd_id', None, None),
                                                           'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                         'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'PRD_ID', 'FAMILY_PRD_ID'),
                                                            'TYPE': 'UNIQUE'},
                                                     's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                         'MAP_MERGE_INDICES': {'pdbx_reference_molecule_list': {'ATTRIBUTES': ('prd_id',
                                                                                                               'family_prd_id'),
                                                                                                'TYPE': 'EQUI-JOIN'}},
                                         'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                         'TABLE_ID': 'PDBX_REFERENCE_MOLECULE_LIST',
                                         'TABLE_NAME': 'pdbx_reference_molecule_list',
                                         'TABLE_TYPE': 'transactional'},
        'PDBX_REFERENCE_MOLECULE_RELATED_STRUCTURES': {'ATTRIBUTES': {'CITATION_ID': 'citation_id',
                                                                      'DB_ACCESSION': 'db_accession',
                                                                      'DB_CODE': 'db_code',
                                                                      'DB_NAME': 'db_name',
                                                                      'FAMILY_PRD_ID': 'family_prd_id',
                                                                      'FORMULA': 'formula',
                                                                      'NAME': 'name',
                                                                      'ORDINAL': 'ordinal',
                                                                      'STRUCTURE_ID': 'Structure_ID'},
                                                       'ATTRIBUTE_INFO': {'CITATION_ID': {'NULLABLE': True,
                                                                                          'ORDER': 9,
                                                                                          'PRECISION': 0,
                                                                                          'PRIMARY_KEY': False,
                                                                                          'SQL_TYPE': 'VARCHAR',
                                                                                          'WIDTH': 10},
                                                                          'DB_ACCESSION': {'NULLABLE': True,
                                                                                           'ORDER': 6,
                                                                                           'PRECISION': 0,
                                                                                           'PRIMARY_KEY': False,
                                                                                           'SQL_TYPE': 'VARCHAR',
                                                                                           'WIDTH': 200},
                                                                          'DB_CODE': {'NULLABLE': True,
                                                                                      'ORDER': 5,
                                                                                      'PRECISION': 0,
                                                                                      'PRIMARY_KEY': False,
                                                                                      'SQL_TYPE': 'VARCHAR',
                                                                                      'WIDTH': 200},
                                                                          'DB_NAME': {'NULLABLE': True,
                                                                                      'ORDER': 4,
                                                                                      'PRECISION': 0,
                                                                                      'PRIMARY_KEY': False,
                                                                                      'SQL_TYPE': 'VARCHAR',
                                                                                      'WIDTH': 200},
                                                                          'FAMILY_PRD_ID': {'NULLABLE': False,
                                                                                            'ORDER': 2,
                                                                                            'PRECISION': 0,
                                                                                            'PRIMARY_KEY': True,
                                                                                            'SQL_TYPE': 'VARCHAR',
                                                                                            'WIDTH': 10},
                                                                          'FORMULA': {'NULLABLE': True,
                                                                                      'ORDER': 8,
                                                                                      'PRECISION': 0,
                                                                                      'PRIMARY_KEY': False,
                                                                                      'SQL_TYPE': 'VARCHAR',
                                                                                      'WIDTH': 200},
                                                                          'NAME': {'NULLABLE': True,
                                                                                   'ORDER': 7,
                                                                                   'PRECISION': 0,
                                                                                   'PRIMARY_KEY': False,
                                                                                   'SQL_TYPE': 'VARCHAR',
                                                                                   'WIDTH': 200},
                                                                          'ORDINAL': {'NULLABLE': False,
                                                                                      'ORDER': 3,
                                                                                      'PRECISION': 0,
                                                                                      'PRIMARY_KEY': True,
                                                                                      'SQL_TYPE': 'INT',
                                                                                      'WIDTH': 10},
                                                                          'STRUCTURE_ID': {'NULLABLE': False,
                                                                                           'ORDER': 1,
                                                                                           'PRECISION': 0,
                                                                                           'PRIMARY_KEY': True,
                                                                                           'SQL_TYPE': 'VARCHAR',
                                                                                           'WIDTH': 10}},
                                                       'ATTRIBUTE_MAP': {'CITATION_ID': ('pdbx_reference_molecule_related_structures',
                                                                                         'citation_id',
                                                                                         None,
                                                                                         None),
                                                                         'DB_ACCESSION': ('pdbx_reference_molecule_related_structures',
                                                                                          'db_accession',
                                                                                          None,
                                                                                          None),
                                                                         'DB_CODE': ('pdbx_reference_molecule_related_structures',
                                                                                     'db_code',
                                                                                     None,
                                                                                     None),
                                                                         'DB_NAME': ('pdbx_reference_molecule_related_structures',
                                                                                     'db_name',
                                                                                     None,
                                                                                     None),
                                                                         'FAMILY_PRD_ID': ('pdbx_reference_molecule_related_structures',
                                                                                           'family_prd_id',
                                                                                           None,
                                                                                           None),
                                                                         'FORMULA': ('pdbx_reference_molecule_related_structures',
                                                                                     'formula',
                                                                                     None,
                                                                                     None),
                                                                         'NAME': ('pdbx_reference_molecule_related_structures',
                                                                                  'name',
                                                                                  None,
                                                                                  None),
                                                                         'ORDINAL': ('pdbx_reference_molecule_related_structures',
                                                                                     'ordinal',
                                                                                     None,
                                                                                     None),
                                                                         'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                                       'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID',
                                                                                         'FAMILY_PRD_ID',
                                                                                         'ORDINAL'),
                                                                          'TYPE': 'UNIQUE'},
                                                                   's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                                       'MAP_MERGE_INDICES': {'pdbx_reference_molecule_related_structures': {'ATTRIBUTES': ('family_prd_id',
                                                                                                                                           'ordinal'),
                                                                                                                            'TYPE': 'EQUI-JOIN'}},
                                                       'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                                       'TABLE_ID': 'PDBX_REFERENCE_MOLECULE_RELATED_STRUCTURES',
                                                       'TABLE_NAME': 'pdbx_reference_molecule_related_structures',
                                                       'TABLE_TYPE': 'transactional'},
        'PDBX_REFERENCE_MOLECULE_SYNONYMS': {'ATTRIBUTES': {'CHEM_COMP_ID': 'chem_comp_id',
                                                            'FAMILY_PRD_ID': 'family_prd_id',
                                                            'NAME': 'name',
                                                            'ORDINAL': 'ordinal',
                                                            'PRD_ID': 'prd_id',
                                                            'SOURCE': 'source',
                                                            'STRUCTURE_ID': 'Structure_ID'},
                                             'ATTRIBUTE_INFO': {'CHEM_COMP_ID': {'NULLABLE': True,
                                                                                 'ORDER': 7,
                                                                                 'PRECISION': 0,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'VARCHAR',
                                                                                 'WIDTH': 10},
                                                                'FAMILY_PRD_ID': {'NULLABLE': False,
                                                                                  'ORDER': 2,
                                                                                  'PRECISION': 0,
                                                                                  'PRIMARY_KEY': True,
                                                                                  'SQL_TYPE': 'VARCHAR',
                                                                                  'WIDTH': 10},
                                                                'NAME': {'NULLABLE': True,
                                                                         'ORDER': 5,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 200},
                                                                'ORDINAL': {'NULLABLE': False,
                                                                            'ORDER': 4,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': True,
                                                                            'SQL_TYPE': 'INT',
                                                                            'WIDTH': 10},
                                                                'PRD_ID': {'NULLABLE': False,
                                                                           'ORDER': 3,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': True,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10},
                                                                'SOURCE': {'NULLABLE': True,
                                                                           'ORDER': 6,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 200},
                                                                'STRUCTURE_ID': {'NULLABLE': False,
                                                                                 'ORDER': 1,
                                                                                 'PRECISION': 0,
                                                                                 'PRIMARY_KEY': True,
                                                                                 'SQL_TYPE': 'VARCHAR',
                                                                                 'WIDTH': 10}},
                                             'ATTRIBUTE_MAP': {'CHEM_COMP_ID': ('pdbx_reference_molecule_synonyms',
                                                                                'chem_comp_id',
                                                                                None,
                                                                                None),
                                                               'FAMILY_PRD_ID': ('pdbx_reference_molecule_synonyms',
                                                                                 'family_prd_id',
                                                                                 None,
                                                                                 None),
                                                               'NAME': ('pdbx_reference_molecule_synonyms',
                                                                        'name',
                                                                        None,
                                                                        None),
                                                               'ORDINAL': ('pdbx_reference_molecule_synonyms',
                                                                           'ordinal',
                                                                           None,
                                                                           None),
                                                               'PRD_ID': ('pdbx_reference_molecule_synonyms',
                                                                          'prd_id',
                                                                          None,
                                                                          None),
                                                               'SOURCE': ('pdbx_reference_molecule_synonyms',
                                                                          'source',
                                                                          None,
                                                                          None),
                                                               'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                             'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID',
                                                                               'FAMILY_PRD_ID',
                                                                               'PRD_ID',
                                                                               'ORDINAL'),
                                                                'TYPE': 'UNIQUE'},
                                                         's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                             'MAP_MERGE_INDICES': {'pdbx_reference_molecule_synonyms': {'ATTRIBUTES': ('family_prd_id',
                                                                                                                       'prd_id',
                                                                                                                       'ordinal'),
                                                                                                        'TYPE': 'EQUI-JOIN'}},
                                             'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                             'TABLE_ID': 'PDBX_REFERENCE_MOLECULE_SYNONYMS',
                                             'TABLE_NAME': 'pdbx_reference_molecule_synonyms',
                                             'TABLE_TYPE': 'transactional'},
        'PDBX_REFINE': {'ATTRIBUTES': {'ENTRY_ID': 'entry_id',
                                       'FREE_R_ERROR_NO_CUTOFF': 'free_R_error_no_cutoff',
                                       'FREE_R_FACTOR_4SIG_CUTOFF': 'free_R_factor_4sig_cutoff',
                                       'FREE_R_FACTOR_NO_CUTOFF': 'free_R_factor_no_cutoff',
                                       'FREE_R_VAL_4SIG_CUTOFF': 'free_R_val_4sig_cutoff',
                                       'FREE_R_VAL_TEST_SET_CT_4SIG_CUTOFF': 'free_R_val_test_set_ct_4sig_cutoff',
                                       'FREE_R_VAL_TEST_SET_CT_NO_CUTOFF': 'free_R_val_test_set_ct_no_cutoff',
                                       'FREE_R_VAL_TEST_SET_SIZE_PERC_4SIG_CUTOFF': 'free_R_val_test_set_size_perc_4sig_cutoff',
                                       'FREE_R_VAL_TEST_SET_SIZE_PERC_NO_CUTOFF': 'free_R_val_test_set_size_perc_no_cutoff',
                                       'NUMBER_REFLNS_OBS_4SIG_CUTOFF': 'number_reflns_obs_4sig_cutoff',
                                       'NUMBER_REFLNS_OBS_NO_CUTOFF': 'number_reflns_obs_no_cutoff',
                                       'PDBX_REFINE_ID': 'pdbx_refine_id',
                                       'R_FACTOR_ALL_4SIG_CUTOFF': 'R_factor_all_4sig_cutoff',
                                       'R_FACTOR_ALL_NO_CUTOFF': 'R_factor_all_no_cutoff',
                                       'R_FACTOR_OBS_4SIG_CUTOFF': 'R_factor_obs_4sig_cutoff',
                                       'R_FACTOR_OBS_NO_CUTOFF': 'R_factor_obs_no_cutoff',
                                       'STRUCTURE_ID': 'Structure_ID'},
                        'ATTRIBUTE_INFO': {'ENTRY_ID': {'NULLABLE': False,
                                                        'ORDER': 2,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': True,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 10},
                                           'FREE_R_ERROR_NO_CUTOFF': {'NULLABLE': True,
                                                                      'ORDER': 8,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                           'FREE_R_FACTOR_4SIG_CUTOFF': {'NULLABLE': True,
                                                                         'ORDER': 6,
                                                                         'PRECISION': 6,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'FLOAT',
                                                                         'WIDTH': 10},
                                           'FREE_R_FACTOR_NO_CUTOFF': {'NULLABLE': True,
                                                                       'ORDER': 7,
                                                                       'PRECISION': 6,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'FLOAT',
                                                                       'WIDTH': 10},
                                           'FREE_R_VAL_4SIG_CUTOFF': {'NULLABLE': True,
                                                                      'ORDER': 14,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                           'FREE_R_VAL_TEST_SET_CT_4SIG_CUTOFF': {'NULLABLE': True,
                                                                                  'ORDER': 16,
                                                                                  'PRECISION': 6,
                                                                                  'PRIMARY_KEY': False,
                                                                                  'SQL_TYPE': 'FLOAT',
                                                                                  'WIDTH': 10},
                                           'FREE_R_VAL_TEST_SET_CT_NO_CUTOFF': {'NULLABLE': True,
                                                                                'ORDER': 10,
                                                                                'PRECISION': 6,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'FLOAT',
                                                                                'WIDTH': 10},
                                           'FREE_R_VAL_TEST_SET_SIZE_PERC_4SIG_CUTOFF': {'NULLABLE': True,
                                                                                         'ORDER': 15,
                                                                                         'PRECISION': 6,
                                                                                         'PRIMARY_KEY': False,
                                                                                         'SQL_TYPE': 'FLOAT',
                                                                                         'WIDTH': 10},
                                           'FREE_R_VAL_TEST_SET_SIZE_PERC_NO_CUTOFF': {'NULLABLE': True,
                                                                                       'ORDER': 9,
                                                                                       'PRECISION': 6,
                                                                                       'PRIMARY_KEY': False,
                                                                                       'SQL_TYPE': 'FLOAT',
                                                                                       'WIDTH': 10},
                                           'NUMBER_REFLNS_OBS_4SIG_CUTOFF': {'NULLABLE': True,
                                                                             'ORDER': 17,
                                                                             'PRECISION': 6,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'FLOAT',
                                                                             'WIDTH': 10},
                                           'NUMBER_REFLNS_OBS_NO_CUTOFF': {'NULLABLE': True,
                                                                           'ORDER': 11,
                                                                           'PRECISION': 6,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'FLOAT',
                                                                           'WIDTH': 10},
                                           'PDBX_REFINE_ID': {'NULLABLE': False,
                                                              'ORDER': 3,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 80},
                                           'R_FACTOR_ALL_4SIG_CUTOFF': {'NULLABLE': True,
                                                                        'ORDER': 12,
                                                                        'PRECISION': 6,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'FLOAT',
                                                                        'WIDTH': 10},
                                           'R_FACTOR_ALL_NO_CUTOFF': {'NULLABLE': True,
                                                                      'ORDER': 4,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                           'R_FACTOR_OBS_4SIG_CUTOFF': {'NULLABLE': True,
                                                                        'ORDER': 13,
                                                                        'PRECISION': 6,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'FLOAT',
                                                                        'WIDTH': 10},
                                           'R_FACTOR_OBS_NO_CUTOFF': {'NULLABLE': True,
                                                                      'ORDER': 5,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                           'STRUCTURE_ID': {'NULLABLE': False,
                                                            'ORDER': 1,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': True,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 10}},
                        'ATTRIBUTE_MAP': {'ENTRY_ID': ('pdbx_refine', 'entry_id', None, None),
                                          'FREE_R_ERROR_NO_CUTOFF': ('pdbx_refine', 'free_R_error_no_cutoff', None, None),
                                          'FREE_R_FACTOR_4SIG_CUTOFF': ('pdbx_refine',
                                                                        'free_R_factor_4sig_cutoff',
                                                                        None,
                                                                        None),
                                          'FREE_R_FACTOR_NO_CUTOFF': ('pdbx_refine', 'free_R_factor_no_cutoff', None, None),
                                          'FREE_R_VAL_4SIG_CUTOFF': ('pdbx_refine', 'free_R_val_4sig_cutoff', None, None),
                                          'FREE_R_VAL_TEST_SET_CT_4SIG_CUTOFF': ('pdbx_refine',
                                                                                 'free_R_val_test_set_ct_4sig_cutoff',
                                                                                 None,
                                                                                 None),
                                          'FREE_R_VAL_TEST_SET_CT_NO_CUTOFF': ('pdbx_refine',
                                                                               'free_R_val_test_set_ct_no_cutoff',
                                                                               None,
                                                                               None),
                                          'FREE_R_VAL_TEST_SET_SIZE_PERC_4SIG_CUTOFF': ('pdbx_refine',
                                                                                        'free_R_val_test_set_size_perc_4sig_cutoff',
                                                                                        None,
                                                                                        None),
                                          'FREE_R_VAL_TEST_SET_SIZE_PERC_NO_CUTOFF': ('pdbx_refine',
                                                                                      'free_R_val_test_set_size_perc_no_cutoff',
                                                                                      None,
                                                                                      None),
                                          'NUMBER_REFLNS_OBS_4SIG_CUTOFF': ('pdbx_refine',
                                                                            'number_reflns_obs_4sig_cutoff',
                                                                            None,
                                                                            None),
                                          'NUMBER_REFLNS_OBS_NO_CUTOFF': ('pdbx_refine',
                                                                          'number_reflns_obs_no_cutoff',
                                                                          None,
                                                                          None),
                                          'PDBX_REFINE_ID': ('pdbx_refine', 'pdbx_refine_id', None, None),
                                          'R_FACTOR_ALL_4SIG_CUTOFF': ('pdbx_refine', 'R_factor_all_4sig_cutoff', None, None),
                                          'R_FACTOR_ALL_NO_CUTOFF': ('pdbx_refine', 'R_factor_all_no_cutoff', None, None),
                                          'R_FACTOR_OBS_4SIG_CUTOFF': ('pdbx_refine', 'R_factor_obs_4sig_cutoff', None, None),
                                          'R_FACTOR_OBS_NO_CUTOFF': ('pdbx_refine', 'R_factor_obs_no_cutoff', None, None),
                                          'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                        'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID', 'PDBX_REFINE_ID'), 'TYPE': 'UNIQUE'},
                                    's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                        'MAP_MERGE_INDICES': {'pdbx_refine': {'ATTRIBUTES': ('entry_id', 'pdbx_refine_id'),
                                                              'TYPE': 'EQUI-JOIN'}},
                        'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                        'TABLE_ID': 'PDBX_REFINE',
                        'TABLE_NAME': 'pdbx_refine',
                        'TABLE_TYPE': 'transactional'},
        'PDBX_REFINE_AUX_FILE': {'ATTRIBUTES': {'FILE_NAME': 'file_name',
                                                'FILE_TYPE': 'file_type',
                                                'PDBX_REFINE_ID': 'pdbx_refine_id',
                                                'SERIAL_NO': 'serial_no',
                                                'STRUCTURE_ID': 'Structure_ID'},
                                 'ATTRIBUTE_INFO': {'FILE_NAME': {'NULLABLE': True,
                                                                  'ORDER': 4,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 80},
                                                    'FILE_TYPE': {'NULLABLE': True,
                                                                  'ORDER': 5,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 80},
                                                    'PDBX_REFINE_ID': {'NULLABLE': False,
                                                                       'ORDER': 3,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': True,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 80},
                                                    'SERIAL_NO': {'NULLABLE': False,
                                                                  'ORDER': 2,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': True,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10},
                                                    'STRUCTURE_ID': {'NULLABLE': False,
                                                                     'ORDER': 1,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': True,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10}},
                                 'ATTRIBUTE_MAP': {'FILE_NAME': ('pdbx_refine_aux_file', 'file_name', None, None),
                                                   'FILE_TYPE': ('pdbx_refine_aux_file', 'file_type', None, None),
                                                   'PDBX_REFINE_ID': ('pdbx_refine_aux_file', 'pdbx_refine_id', None, None),
                                                   'SERIAL_NO': ('pdbx_refine_aux_file', 'serial_no', None, None),
                                                   'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                 'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'SERIAL_NO', 'PDBX_REFINE_ID'),
                                                    'TYPE': 'UNIQUE'},
                                             's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                 'MAP_MERGE_INDICES': {'pdbx_refine_aux_file': {'ATTRIBUTES': ('serial_no', 'pdbx_refine_id'),
                                                                                'TYPE': 'EQUI-JOIN'}},
                                 'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                 'TABLE_ID': 'PDBX_REFINE_AUX_FILE',
                                 'TABLE_NAME': 'pdbx_refine_aux_file',
                                 'TABLE_TYPE': 'transactional'},
        'PDBX_REFINE_COMPONENT': {'ATTRIBUTES': {'AUTH_ASYM_ID': 'auth_asym_id',
                                                 'AUTH_COMP_ID': 'auth_comp_id',
                                                 'AUTH_SEQ_ID': 'auth_seq_id',
                                                 'B_ISO': 'B_iso',
                                                 'B_ISO_MAIN_CHAIN': 'B_iso_main_chain',
                                                 'B_ISO_SIDE_CHAIN': 'B_iso_side_chain',
                                                 'CONNECT': 'connect',
                                                 'CORRELATION': 'correlation',
                                                 'CORRELATION_MAIN_CHAIN': 'correlation_main_chain',
                                                 'CORRELATION_SIDE_CHAIN': 'correlation_side_chain',
                                                 'DENSITY_INDEX': 'density_index',
                                                 'DENSITY_INDEX_MAIN_CHAIN': 'density_index_main_chain',
                                                 'DENSITY_INDEX_SIDE_CHAIN': 'density_index_side_chain',
                                                 'DENSITY_RATIO': 'density_ratio',
                                                 'DENSITY_RATIO_MAIN_CHAIN': 'density_ratio_main_chain',
                                                 'DENSITY_RATIO_SIDE_CHAIN': 'density_ratio_side_chain',
                                                 'LABEL_ALT_ID': 'label_alt_id',
                                                 'LABEL_ASYM_ID': 'label_asym_id',
                                                 'LABEL_COMP_ID': 'label_comp_id',
                                                 'LABEL_SEQ_ID': 'label_seq_id',
                                                 'PDB_INS_CODE': 'PDB_ins_code',
                                                 'REAL_SPACE_R': 'real_space_R',
                                                 'REAL_SPACE_R_MAIN_CHAIN': 'real_space_R_main_chain',
                                                 'REAL_SPACE_R_SIDE_CHAIN': 'real_space_R_side_chain',
                                                 'SHIFT': 'shift',
                                                 'SHIFT_MAIN_CHAIN': 'shift_main_chain',
                                                 'SHIFT_SIDE_CHAIN': 'shift_side_chain',
                                                 'STRUCTURE_ID': 'Structure_ID'},
                                  'ATTRIBUTE_INFO': {'AUTH_ASYM_ID': {'NULLABLE': True,
                                                                      'ORDER': 6,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                                     'AUTH_COMP_ID': {'NULLABLE': True,
                                                                      'ORDER': 7,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                                     'AUTH_SEQ_ID': {'NULLABLE': True,
                                                                     'ORDER': 8,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                                     'B_ISO': {'NULLABLE': True,
                                                               'ORDER': 10,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                                     'B_ISO_MAIN_CHAIN': {'NULLABLE': True,
                                                                          'ORDER': 11,
                                                                          'PRECISION': 6,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'FLOAT',
                                                                          'WIDTH': 10},
                                                     'B_ISO_SIDE_CHAIN': {'NULLABLE': True,
                                                                          'ORDER': 12,
                                                                          'PRECISION': 6,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'FLOAT',
                                                                          'WIDTH': 10},
                                                     'CONNECT': {'NULLABLE': True,
                                                                 'ORDER': 22,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                                     'CORRELATION': {'NULLABLE': True,
                                                                     'ORDER': 16,
                                                                     'PRECISION': 6,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'FLOAT',
                                                                     'WIDTH': 10},
                                                     'CORRELATION_MAIN_CHAIN': {'NULLABLE': True,
                                                                                'ORDER': 18,
                                                                                'PRECISION': 6,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'FLOAT',
                                                                                'WIDTH': 10},
                                                     'CORRELATION_SIDE_CHAIN': {'NULLABLE': True,
                                                                                'ORDER': 17,
                                                                                'PRECISION': 6,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'FLOAT',
                                                                                'WIDTH': 10},
                                                     'DENSITY_INDEX': {'NULLABLE': True,
                                                                       'ORDER': 23,
                                                                       'PRECISION': 6,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'FLOAT',
                                                                       'WIDTH': 10},
                                                     'DENSITY_INDEX_MAIN_CHAIN': {'NULLABLE': True,
                                                                                  'ORDER': 24,
                                                                                  'PRECISION': 6,
                                                                                  'PRIMARY_KEY': False,
                                                                                  'SQL_TYPE': 'FLOAT',
                                                                                  'WIDTH': 10},
                                                     'DENSITY_INDEX_SIDE_CHAIN': {'NULLABLE': True,
                                                                                  'ORDER': 25,
                                                                                  'PRECISION': 6,
                                                                                  'PRIMARY_KEY': False,
                                                                                  'SQL_TYPE': 'FLOAT',
                                                                                  'WIDTH': 10},
                                                     'DENSITY_RATIO': {'NULLABLE': True,
                                                                       'ORDER': 26,
                                                                       'PRECISION': 6,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'FLOAT',
                                                                       'WIDTH': 10},
                                                     'DENSITY_RATIO_MAIN_CHAIN': {'NULLABLE': True,
                                                                                  'ORDER': 27,
                                                                                  'PRECISION': 6,
                                                                                  'PRIMARY_KEY': False,
                                                                                  'SQL_TYPE': 'FLOAT',
                                                                                  'WIDTH': 10},
                                                     'DENSITY_RATIO_SIDE_CHAIN': {'NULLABLE': True,
                                                                                  'ORDER': 28,
                                                                                  'PRECISION': 6,
                                                                                  'PRIMARY_KEY': False,
                                                                                  'SQL_TYPE': 'FLOAT',
                                                                                  'WIDTH': 10},
                                                     'LABEL_ALT_ID': {'NULLABLE': False,
                                                                      'ORDER': 2,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                                     'LABEL_ASYM_ID': {'NULLABLE': False,
                                                                       'ORDER': 3,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': True,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                     'LABEL_COMP_ID': {'NULLABLE': False,
                                                                       'ORDER': 4,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': True,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                     'LABEL_SEQ_ID': {'NULLABLE': False,
                                                                      'ORDER': 5,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'INT',
                                                                      'WIDTH': 10},
                                                     'PDB_INS_CODE': {'NULLABLE': True,
                                                                      'ORDER': 9,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                                     'REAL_SPACE_R': {'NULLABLE': True,
                                                                      'ORDER': 19,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                                     'REAL_SPACE_R_MAIN_CHAIN': {'NULLABLE': True,
                                                                                 'ORDER': 21,
                                                                                 'PRECISION': 6,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'FLOAT',
                                                                                 'WIDTH': 10},
                                                     'REAL_SPACE_R_SIDE_CHAIN': {'NULLABLE': True,
                                                                                 'ORDER': 20,
                                                                                 'PRECISION': 6,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'FLOAT',
                                                                                 'WIDTH': 10},
                                                     'SHIFT': {'NULLABLE': True,
                                                               'ORDER': 13,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                                     'SHIFT_MAIN_CHAIN': {'NULLABLE': True,
                                                                          'ORDER': 15,
                                                                          'PRECISION': 6,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'FLOAT',
                                                                          'WIDTH': 10},
                                                     'SHIFT_SIDE_CHAIN': {'NULLABLE': True,
                                                                          'ORDER': 14,
                                                                          'PRECISION': 6,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'FLOAT',
                                                                          'WIDTH': 10},
                                                     'STRUCTURE_ID': {'NULLABLE': False,
                                                                      'ORDER': 1,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10}},
                                  'ATTRIBUTE_MAP': {'AUTH_ASYM_ID': ('pdbx_refine_component', 'auth_asym_id', None, None),
                                                    'AUTH_COMP_ID': ('pdbx_refine_component', 'auth_comp_id', None, None),
                                                    'AUTH_SEQ_ID': ('pdbx_refine_component', 'auth_seq_id', None, None),
                                                    'B_ISO': ('pdbx_refine_component', 'B_iso', None, None),
                                                    'B_ISO_MAIN_CHAIN': ('pdbx_refine_component',
                                                                         'B_iso_main_chain',
                                                                         None,
                                                                         None),
                                                    'B_ISO_SIDE_CHAIN': ('pdbx_refine_component',
                                                                         'B_iso_side_chain',
                                                                         None,
                                                                         None),
                                                    'CONNECT': ('pdbx_refine_component', 'connect', None, None),
                                                    'CORRELATION': ('pdbx_refine_component', 'correlation', None, None),
                                                    'CORRELATION_MAIN_CHAIN': ('pdbx_refine_component',
                                                                               'correlation_main_chain',
                                                                               None,
                                                                               None),
                                                    'CORRELATION_SIDE_CHAIN': ('pdbx_refine_component',
                                                                               'correlation_side_chain',
                                                                               None,
                                                                               None),
                                                    'DENSITY_INDEX': ('pdbx_refine_component', 'density_index', None, None),
                                                    'DENSITY_INDEX_MAIN_CHAIN': ('pdbx_refine_component',
                                                                                 'density_index_main_chain',
                                                                                 None,
                                                                                 None),
                                                    'DENSITY_INDEX_SIDE_CHAIN': ('pdbx_refine_component',
                                                                                 'density_index_side_chain',
                                                                                 None,
                                                                                 None),
                                                    'DENSITY_RATIO': ('pdbx_refine_component', 'density_ratio', None, None),
                                                    'DENSITY_RATIO_MAIN_CHAIN': ('pdbx_refine_component',
                                                                                 'density_ratio_main_chain',
                                                                                 None,
                                                                                 None),
                                                    'DENSITY_RATIO_SIDE_CHAIN': ('pdbx_refine_component',
                                                                                 'density_ratio_side_chain',
                                                                                 None,
                                                                                 None),
                                                    'LABEL_ALT_ID': ('pdbx_refine_component', 'label_alt_id', None, None),
                                                    'LABEL_ASYM_ID': ('pdbx_refine_component', 'label_asym_id', None, None),
                                                    'LABEL_COMP_ID': ('pdbx_refine_component', 'label_comp_id', None, None),
                                                    'LABEL_SEQ_ID': ('pdbx_refine_component', 'label_seq_id', None, None),
                                                    'PDB_INS_CODE': ('pdbx_refine_component', 'PDB_ins_code', None, None),
                                                    'REAL_SPACE_R': ('pdbx_refine_component', 'real_space_R', None, None),
                                                    'REAL_SPACE_R_MAIN_CHAIN': ('pdbx_refine_component',
                                                                                'real_space_R_main_chain',
                                                                                None,
                                                                                None),
                                                    'REAL_SPACE_R_SIDE_CHAIN': ('pdbx_refine_component',
                                                                                'real_space_R_side_chain',
                                                                                None,
                                                                                None),
                                                    'SHIFT': ('pdbx_refine_component', 'shift', None, None),
                                                    'SHIFT_MAIN_CHAIN': ('pdbx_refine_component',
                                                                         'shift_main_chain',
                                                                         None,
                                                                         None),
                                                    'SHIFT_SIDE_CHAIN': ('pdbx_refine_component',
                                                                         'shift_side_chain',
                                                                         None,
                                                                         None),
                                                    'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                  'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID',
                                                                    'LABEL_ALT_ID',
                                                                    'LABEL_ASYM_ID',
                                                                    'LABEL_COMP_ID',
                                                                    'LABEL_SEQ_ID'),
                                                     'TYPE': 'UNIQUE'},
                                              's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                  'MAP_MERGE_INDICES': {'pdbx_refine_component': {'ATTRIBUTES': ('label_alt_id',
                                                                                                 'label_asym_id',
                                                                                                 'label_comp_id',
                                                                                                 'label_seq_id'),
                                                                                  'TYPE': 'EQUI-JOIN'}},
                                  'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                  'TABLE_ID': 'PDBX_REFINE_COMPONENT',
                                  'TABLE_NAME': 'pdbx_refine_component',
                                  'TABLE_TYPE': 'transactional'},
        'PDBX_REFINE_TLS': {'ATTRIBUTES': {'DETAILS': 'details',
                                           'ID': 'id',
                                           'L_1_1': 'L_1_1',
                                           'L_1_1_ESD': 'L_1_1_esd',
                                           'L_1_2': 'L_1_2',
                                           'L_1_2_ESD': 'L_1_2_esd',
                                           'L_1_3': 'L_1_3',
                                           'L_1_3_ESD': 'L_1_3_esd',
                                           'L_2_2': 'L_2_2',
                                           'L_2_2_ESD': 'L_2_2_esd',
                                           'L_2_3': 'L_2_3',
                                           'L_2_3_ESD': 'L_2_3_esd',
                                           'L_3_3': 'L_3_3',
                                           'L_3_3_ESD': 'L_3_3_esd',
                                           'METHOD': 'method',
                                           'ORIGIN_X': 'origin_x',
                                           'ORIGIN_Y': 'origin_y',
                                           'ORIGIN_Z': 'origin_z',
                                           'PDBX_REFINE_ID': 'pdbx_refine_id',
                                           'STRUCTURE_ID': 'Structure_ID',
                                           'S_1_1': 'S_1_1',
                                           'S_1_1_ESD': 'S_1_1_esd',
                                           'S_1_2': 'S_1_2',
                                           'S_1_2_ESD': 'S_1_2_esd',
                                           'S_1_3': 'S_1_3',
                                           'S_1_3_ESD': 'S_1_3_esd',
                                           'S_2_1': 'S_2_1',
                                           'S_2_1_ESD': 'S_2_1_esd',
                                           'S_2_2': 'S_2_2',
                                           'S_2_2_ESD': 'S_2_2_esd',
                                           'S_2_3': 'S_2_3',
                                           'S_2_3_ESD': 'S_2_3_esd',
                                           'S_3_1': 'S_3_1',
                                           'S_3_1_ESD': 'S_3_1_esd',
                                           'S_3_2': 'S_3_2',
                                           'S_3_2_ESD': 'S_3_2_esd',
                                           'S_3_3': 'S_3_3',
                                           'S_3_3_ESD': 'S_3_3_esd',
                                           'T_1_1': 'T_1_1',
                                           'T_1_1_ESD': 'T_1_1_esd',
                                           'T_1_2': 'T_1_2',
                                           'T_1_2_ESD': 'T_1_2_esd',
                                           'T_1_3': 'T_1_3',
                                           'T_1_3_ESD': 'T_1_3_esd',
                                           'T_2_2': 'T_2_2',
                                           'T_2_2_ESD': 'T_2_2_esd',
                                           'T_2_3': 'T_2_3',
                                           'T_2_3_ESD': 'T_2_3_esd',
                                           'T_3_3': 'T_3_3',
                                           'T_3_3_ESD': 'T_3_3_esd'},
                            'ATTRIBUTE_INFO': {'DETAILS': {'NULLABLE': True,
                                                           'ORDER': 4,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 200},
                                               'ID': {'NULLABLE': False,
                                                      'ORDER': 2,
                                                      'PRECISION': 0,
                                                      'PRIMARY_KEY': True,
                                                      'SQL_TYPE': 'VARCHAR',
                                                      'WIDTH': 10},
                                               'L_1_1': {'NULLABLE': True,
                                                         'ORDER': 21,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                               'L_1_1_ESD': {'NULLABLE': True,
                                                             'ORDER': 22,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                               'L_1_2': {'NULLABLE': True,
                                                         'ORDER': 23,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                               'L_1_2_ESD': {'NULLABLE': True,
                                                             'ORDER': 24,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                               'L_1_3': {'NULLABLE': True,
                                                         'ORDER': 25,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                               'L_1_3_ESD': {'NULLABLE': True,
                                                             'ORDER': 26,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                               'L_2_2': {'NULLABLE': True,
                                                         'ORDER': 27,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                               'L_2_2_ESD': {'NULLABLE': True,
                                                             'ORDER': 28,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                               'L_2_3': {'NULLABLE': True,
                                                         'ORDER': 29,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                               'L_2_3_ESD': {'NULLABLE': True,
                                                             'ORDER': 30,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                               'L_3_3': {'NULLABLE': True,
                                                         'ORDER': 31,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                               'L_3_3_ESD': {'NULLABLE': True,
                                                             'ORDER': 32,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                               'METHOD': {'NULLABLE': True,
                                                          'ORDER': 5,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 10},
                                               'ORIGIN_X': {'NULLABLE': True,
                                                            'ORDER': 6,
                                                            'PRECISION': 6,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'FLOAT',
                                                            'WIDTH': 10},
                                               'ORIGIN_Y': {'NULLABLE': True,
                                                            'ORDER': 7,
                                                            'PRECISION': 6,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'FLOAT',
                                                            'WIDTH': 10},
                                               'ORIGIN_Z': {'NULLABLE': True,
                                                            'ORDER': 8,
                                                            'PRECISION': 6,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'FLOAT',
                                                            'WIDTH': 10},
                                               'PDBX_REFINE_ID': {'NULLABLE': True,
                                                                  'ORDER': 3,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 80},
                                               'STRUCTURE_ID': {'NULLABLE': False,
                                                                'ORDER': 1,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                               'S_1_1': {'NULLABLE': True,
                                                         'ORDER': 33,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                               'S_1_1_ESD': {'NULLABLE': True,
                                                             'ORDER': 34,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                               'S_1_2': {'NULLABLE': True,
                                                         'ORDER': 35,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                               'S_1_2_ESD': {'NULLABLE': True,
                                                             'ORDER': 36,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                               'S_1_3': {'NULLABLE': True,
                                                         'ORDER': 37,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                               'S_1_3_ESD': {'NULLABLE': True,
                                                             'ORDER': 38,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                               'S_2_1': {'NULLABLE': True,
                                                         'ORDER': 39,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                               'S_2_1_ESD': {'NULLABLE': True,
                                                             'ORDER': 40,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                               'S_2_2': {'NULLABLE': True,
                                                         'ORDER': 41,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                               'S_2_2_ESD': {'NULLABLE': True,
                                                             'ORDER': 42,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                               'S_2_3': {'NULLABLE': True,
                                                         'ORDER': 43,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                               'S_2_3_ESD': {'NULLABLE': True,
                                                             'ORDER': 44,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                               'S_3_1': {'NULLABLE': True,
                                                         'ORDER': 45,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                               'S_3_1_ESD': {'NULLABLE': True,
                                                             'ORDER': 46,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                               'S_3_2': {'NULLABLE': True,
                                                         'ORDER': 47,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                               'S_3_2_ESD': {'NULLABLE': True,
                                                             'ORDER': 48,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                               'S_3_3': {'NULLABLE': True,
                                                         'ORDER': 49,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                               'S_3_3_ESD': {'NULLABLE': True,
                                                             'ORDER': 50,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                               'T_1_1': {'NULLABLE': True,
                                                         'ORDER': 9,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                               'T_1_1_ESD': {'NULLABLE': True,
                                                             'ORDER': 10,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                               'T_1_2': {'NULLABLE': True,
                                                         'ORDER': 11,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                               'T_1_2_ESD': {'NULLABLE': True,
                                                             'ORDER': 12,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                               'T_1_3': {'NULLABLE': True,
                                                         'ORDER': 13,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                               'T_1_3_ESD': {'NULLABLE': True,
                                                             'ORDER': 14,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                               'T_2_2': {'NULLABLE': True,
                                                         'ORDER': 15,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                               'T_2_2_ESD': {'NULLABLE': True,
                                                             'ORDER': 16,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                               'T_2_3': {'NULLABLE': True,
                                                         'ORDER': 17,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                               'T_2_3_ESD': {'NULLABLE': True,
                                                             'ORDER': 18,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                               'T_3_3': {'NULLABLE': True,
                                                         'ORDER': 19,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                               'T_3_3_ESD': {'NULLABLE': True,
                                                             'ORDER': 20,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10}},
                            'ATTRIBUTE_MAP': {'DETAILS': ('pdbx_refine_tls', 'details', None, None),
                                              'ID': ('pdbx_refine_tls', 'id', None, None),
                                              'L_1_1': ('pdbx_refine_tls', 'L[1][1]', None, None),
                                              'L_1_1_ESD': ('pdbx_refine_tls', 'L[1][1]_esd', None, None),
                                              'L_1_2': ('pdbx_refine_tls', 'L[1][2]', None, None),
                                              'L_1_2_ESD': ('pdbx_refine_tls', 'L[1][2]_esd', None, None),
                                              'L_1_3': ('pdbx_refine_tls', 'L[1][3]', None, None),
                                              'L_1_3_ESD': ('pdbx_refine_tls', 'L[1][3]_esd', None, None),
                                              'L_2_2': ('pdbx_refine_tls', 'L[2][2]', None, None),
                                              'L_2_2_ESD': ('pdbx_refine_tls', 'L[2][2]_esd', None, None),
                                              'L_2_3': ('pdbx_refine_tls', 'L[2][3]', None, None),
                                              'L_2_3_ESD': ('pdbx_refine_tls', 'L[2][3]_esd', None, None),
                                              'L_3_3': ('pdbx_refine_tls', 'L[3][3]', None, None),
                                              'L_3_3_ESD': ('pdbx_refine_tls', 'L[3][3]_esd', None, None),
                                              'METHOD': ('pdbx_refine_tls', 'method', None, None),
                                              'ORIGIN_X': ('pdbx_refine_tls', 'origin_x', None, None),
                                              'ORIGIN_Y': ('pdbx_refine_tls', 'origin_y', None, None),
                                              'ORIGIN_Z': ('pdbx_refine_tls', 'origin_z', None, None),
                                              'PDBX_REFINE_ID': ('pdbx_refine_tls', 'pdbx_refine_id', None, None),
                                              'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                              'S_1_1': ('pdbx_refine_tls', 'S[1][1]', None, None),
                                              'S_1_1_ESD': ('pdbx_refine_tls', 'S[1][1]_esd', None, None),
                                              'S_1_2': ('pdbx_refine_tls', 'S[1][2]', None, None),
                                              'S_1_2_ESD': ('pdbx_refine_tls', 'S[1][2]_esd', None, None),
                                              'S_1_3': ('pdbx_refine_tls', 'S[1][3]', None, None),
                                              'S_1_3_ESD': ('pdbx_refine_tls', 'S[1][3]_esd', None, None),
                                              'S_2_1': ('pdbx_refine_tls', 'S[2][1]', None, None),
                                              'S_2_1_ESD': ('pdbx_refine_tls', 'S[2][1]_esd', None, None),
                                              'S_2_2': ('pdbx_refine_tls', 'S[2][2]', None, None),
                                              'S_2_2_ESD': ('pdbx_refine_tls', 'S[2][2]_esd', None, None),
                                              'S_2_3': ('pdbx_refine_tls', 'S[2][3]', None, None),
                                              'S_2_3_ESD': ('pdbx_refine_tls', 'S[2][3]_esd', None, None),
                                              'S_3_1': ('pdbx_refine_tls', 'S[3][1]', None, None),
                                              'S_3_1_ESD': ('pdbx_refine_tls', 'S[3][1]_esd', None, None),
                                              'S_3_2': ('pdbx_refine_tls', 'S[3][2]', None, None),
                                              'S_3_2_ESD': ('pdbx_refine_tls', 'S[3][2]_esd', None, None),
                                              'S_3_3': ('pdbx_refine_tls', 'S[3][3]', None, None),
                                              'S_3_3_ESD': ('pdbx_refine_tls', 'S[3][3]_esd', None, None),
                                              'T_1_1': ('pdbx_refine_tls', 'T[1][1]', None, None),
                                              'T_1_1_ESD': ('pdbx_refine_tls', 'T[1][1]_esd', None, None),
                                              'T_1_2': ('pdbx_refine_tls', 'T[1][2]', None, None),
                                              'T_1_2_ESD': ('pdbx_refine_tls', 'T[1][2]_esd', None, None),
                                              'T_1_3': ('pdbx_refine_tls', 'T[1][3]', None, None),
                                              'T_1_3_ESD': ('pdbx_refine_tls', 'T[1][3]_esd', None, None),
                                              'T_2_2': ('pdbx_refine_tls', 'T[2][2]', None, None),
                                              'T_2_2_ESD': ('pdbx_refine_tls', 'T[2][2]_esd', None, None),
                                              'T_2_3': ('pdbx_refine_tls', 'T[2][3]', None, None),
                                              'T_2_3_ESD': ('pdbx_refine_tls', 'T[2][3]_esd', None, None),
                                              'T_3_3': ('pdbx_refine_tls', 'T[3][3]', None, None),
                                              'T_3_3_ESD': ('pdbx_refine_tls', 'T[3][3]_esd', None, None)},
                            'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                        's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                            'MAP_MERGE_INDICES': {'pdbx_refine_tls': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                            'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                            'TABLE_ID': 'PDBX_REFINE_TLS',
                            'TABLE_NAME': 'pdbx_refine_tls',
                            'TABLE_TYPE': 'transactional'},
        'PDBX_REFINE_TLS_GROUP': {'ATTRIBUTES': {'BEG_AUTH_ASYM_ID': 'beg_auth_asym_id',
                                                 'BEG_AUTH_SEQ_ID': 'beg_auth_seq_id',
                                                 'BEG_LABEL_ASYM_ID': 'beg_label_asym_id',
                                                 'BEG_LABEL_SEQ_ID': 'beg_label_seq_id',
                                                 'END_AUTH_ASYM_ID': 'end_auth_asym_id',
                                                 'END_AUTH_SEQ_ID': 'end_auth_seq_id',
                                                 'END_LABEL_ASYM_ID': 'end_label_asym_id',
                                                 'END_LABEL_SEQ_ID': 'end_label_seq_id',
                                                 'ID': 'id',
                                                 'PDBX_REFINE_ID': 'pdbx_refine_id',
                                                 'REFINE_TLS_ID': 'refine_tls_id',
                                                 'SELECTION': 'selection',
                                                 'SELECTION_DETAILS': 'selection_details',
                                                 'STRUCTURE_ID': 'Structure_ID'},
                                  'ATTRIBUTE_INFO': {'BEG_AUTH_ASYM_ID': {'NULLABLE': True,
                                                                          'ORDER': 7,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                     'BEG_AUTH_SEQ_ID': {'NULLABLE': True,
                                                                         'ORDER': 8,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                                     'BEG_LABEL_ASYM_ID': {'NULLABLE': True,
                                                                           'ORDER': 5,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10},
                                                     'BEG_LABEL_SEQ_ID': {'NULLABLE': True,
                                                                          'ORDER': 6,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'INT',
                                                                          'WIDTH': 10},
                                                     'END_AUTH_ASYM_ID': {'NULLABLE': True,
                                                                          'ORDER': 11,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                     'END_AUTH_SEQ_ID': {'NULLABLE': True,
                                                                         'ORDER': 12,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                                     'END_LABEL_ASYM_ID': {'NULLABLE': True,
                                                                           'ORDER': 9,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10},
                                                     'END_LABEL_SEQ_ID': {'NULLABLE': True,
                                                                          'ORDER': 10,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'INT',
                                                                          'WIDTH': 10},
                                                     'ID': {'NULLABLE': False,
                                                            'ORDER': 2,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': True,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 10},
                                                     'PDBX_REFINE_ID': {'NULLABLE': True,
                                                                        'ORDER': 3,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 80},
                                                     'REFINE_TLS_ID': {'NULLABLE': True,
                                                                       'ORDER': 4,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                     'SELECTION': {'NULLABLE': True,
                                                                   'ORDER': 13,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 80},
                                                     'SELECTION_DETAILS': {'NULLABLE': True,
                                                                           'ORDER': 14,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 4095},
                                                     'STRUCTURE_ID': {'NULLABLE': False,
                                                                      'ORDER': 1,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10}},
                                  'ATTRIBUTE_MAP': {'BEG_AUTH_ASYM_ID': ('pdbx_refine_tls_group',
                                                                         'beg_auth_asym_id',
                                                                         None,
                                                                         None),
                                                    'BEG_AUTH_SEQ_ID': ('pdbx_refine_tls_group',
                                                                        'beg_auth_seq_id',
                                                                        None,
                                                                        None),
                                                    'BEG_LABEL_ASYM_ID': ('pdbx_refine_tls_group',
                                                                          'beg_label_asym_id',
                                                                          None,
                                                                          None),
                                                    'BEG_LABEL_SEQ_ID': ('pdbx_refine_tls_group',
                                                                         'beg_label_seq_id',
                                                                         None,
                                                                         None),
                                                    'END_AUTH_ASYM_ID': ('pdbx_refine_tls_group',
                                                                         'end_auth_asym_id',
                                                                         None,
                                                                         None),
                                                    'END_AUTH_SEQ_ID': ('pdbx_refine_tls_group',
                                                                        'end_auth_seq_id',
                                                                        None,
                                                                        None),
                                                    'END_LABEL_ASYM_ID': ('pdbx_refine_tls_group',
                                                                          'end_label_asym_id',
                                                                          None,
                                                                          None),
                                                    'END_LABEL_SEQ_ID': ('pdbx_refine_tls_group',
                                                                         'end_label_seq_id',
                                                                         None,
                                                                         None),
                                                    'ID': ('pdbx_refine_tls_group', 'id', None, None),
                                                    'PDBX_REFINE_ID': ('pdbx_refine_tls_group', 'pdbx_refine_id', None, None),
                                                    'REFINE_TLS_ID': ('pdbx_refine_tls_group', 'refine_tls_id', None, None),
                                                    'SELECTION': ('pdbx_refine_tls_group', 'selection', None, None),
                                                    'SELECTION_DETAILS': ('pdbx_refine_tls_group',
                                                                          'selection_details',
                                                                          None,
                                                                          None),
                                                    'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                  'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                              's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                  'MAP_MERGE_INDICES': {'pdbx_refine_tls_group': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                                  'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                  'TABLE_ID': 'PDBX_REFINE_TLS_GROUP',
                                  'TABLE_NAME': 'pdbx_refine_tls_group',
                                  'TABLE_TYPE': 'transactional'},
        'PDBX_REFLNS_TWIN': {'ATTRIBUTES': {'CRYSTAL_ID': 'crystal_id',
                                            'DIFFRN_ID': 'diffrn_id',
                                            'DOMAIN_ID': 'domain_id',
                                            'FRACTION': 'fraction',
                                            'MEAN_F_SQUARE_OVER_MEAN_F2': 'mean_F_square_over_mean_F2',
                                            'MEAN_I2_OVER_MEAN_I_SQUARE': 'mean_I2_over_mean_I_square',
                                            'OPERATOR': 'operator',
                                            'STRUCTURE_ID': 'Structure_ID',
                                            'TYPE': 'type'},
                             'ATTRIBUTE_INFO': {'CRYSTAL_ID': {'NULLABLE': False,
                                                               'ORDER': 3,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                                'DIFFRN_ID': {'NULLABLE': False,
                                                              'ORDER': 2,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10},
                                                'DOMAIN_ID': {'NULLABLE': True,
                                                              'ORDER': 4,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10},
                                                'FRACTION': {'NULLABLE': True,
                                                             'ORDER': 7,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                                'MEAN_F_SQUARE_OVER_MEAN_F2': {'NULLABLE': True,
                                                                               'ORDER': 9,
                                                                               'PRECISION': 6,
                                                                               'PRIMARY_KEY': False,
                                                                               'SQL_TYPE': 'FLOAT',
                                                                               'WIDTH': 10},
                                                'MEAN_I2_OVER_MEAN_I_SQUARE': {'NULLABLE': True,
                                                                               'ORDER': 8,
                                                                               'PRECISION': 6,
                                                                               'PRIMARY_KEY': False,
                                                                               'SQL_TYPE': 'FLOAT',
                                                                               'WIDTH': 10},
                                                'OPERATOR': {'NULLABLE': False,
                                                             'ORDER': 6,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 80},
                                                'STRUCTURE_ID': {'NULLABLE': False,
                                                                 'ORDER': 1,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': True,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                                'TYPE': {'NULLABLE': True,
                                                         'ORDER': 5,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 80}},
                             'ATTRIBUTE_MAP': {'CRYSTAL_ID': ('pdbx_reflns_twin', 'crystal_id', None, None),
                                               'DIFFRN_ID': ('pdbx_reflns_twin', 'diffrn_id', None, None),
                                               'DOMAIN_ID': ('pdbx_reflns_twin', 'domain_id', None, None),
                                               'FRACTION': ('pdbx_reflns_twin', 'fraction', None, None),
                                               'MEAN_F_SQUARE_OVER_MEAN_F2': ('pdbx_reflns_twin',
                                                                              'mean_F_square_over_mean_F2',
                                                                              None,
                                                                              None),
                                               'MEAN_I2_OVER_MEAN_I_SQUARE': ('pdbx_reflns_twin',
                                                                              'mean_I2_over_mean_I_square',
                                                                              None,
                                                                              None),
                                               'OPERATOR': ('pdbx_reflns_twin', 'operator', None, None),
                                               'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                               'TYPE': ('pdbx_reflns_twin', 'type', None, None)},
                             'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'DIFFRN_ID', 'CRYSTAL_ID', 'OPERATOR'),
                                                'TYPE': 'UNIQUE'},
                                         's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                             'MAP_MERGE_INDICES': {'pdbx_reflns_twin': {'ATTRIBUTES': ('diffrn_id', 'crystal_id', 'operator'),
                                                                        'TYPE': 'EQUI-JOIN'}},
                             'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                             'TABLE_ID': 'PDBX_REFLNS_TWIN',
                             'TABLE_NAME': 'pdbx_reflns_twin',
                             'TABLE_TYPE': 'transactional'},
        'PDBX_REMEDIATION_ATOM_SITE_MAPPING': {'ATTRIBUTES': {'AUTH_ALT_ID': 'auth_alt_id',
                                                              'AUTH_ASYM_ID': 'auth_asym_id',
                                                              'AUTH_ATOM_ID': 'auth_atom_id',
                                                              'AUTH_COMP_ID': 'auth_comp_id',
                                                              'AUTH_SEQ_ID': 'auth_seq_id',
                                                              'GROUP_PDB': 'group_PDB',
                                                              'ID': 'id',
                                                              'LABEL_ALT_ID': 'label_alt_id',
                                                              'LABEL_ASYM_ID': 'label_asym_id',
                                                              'LABEL_ATOM_ID': 'label_atom_id',
                                                              'LABEL_COMP_ID': 'label_comp_id',
                                                              'LABEL_SEQ_ID': 'label_seq_id',
                                                              'OCCUPANCY': 'occupancy',
                                                              'PDBX_ALIGN': 'pdbx_align',
                                                              'PDB_INS_CODE': 'PDB_ins_code',
                                                              'PRE_AUTH_ALT_ID': 'pre_auth_alt_id',
                                                              'PRE_AUTH_ASYM_ID': 'pre_auth_asym_id',
                                                              'PRE_AUTH_ATOM_ID': 'pre_auth_atom_id',
                                                              'PRE_AUTH_COMP_ID': 'pre_auth_comp_id',
                                                              'PRE_AUTH_SEQ_ID': 'pre_auth_seq_id',
                                                              'PRE_GROUP_PDB': 'pre_group_PDB',
                                                              'PRE_OCCUPANCY': 'pre_occupancy',
                                                              'PRE_PDBX_ALIGN': 'pre_pdbx_align',
                                                              'PRE_PDB_INS_CODE': 'pre_PDB_ins_code',
                                                              'STRUCTURE_ID': 'Structure_ID'},
                                               'ATTRIBUTE_INFO': {'AUTH_ALT_ID': {'NULLABLE': True,
                                                                                  'ORDER': 23,
                                                                                  'PRECISION': 0,
                                                                                  'PRIMARY_KEY': False,
                                                                                  'SQL_TYPE': 'VARCHAR',
                                                                                  'WIDTH': 10},
                                                                  'AUTH_ASYM_ID': {'NULLABLE': True,
                                                                                   'ORDER': 19,
                                                                                   'PRECISION': 0,
                                                                                   'PRIMARY_KEY': False,
                                                                                   'SQL_TYPE': 'VARCHAR',
                                                                                   'WIDTH': 10},
                                                                  'AUTH_ATOM_ID': {'NULLABLE': True,
                                                                                   'ORDER': 20,
                                                                                   'PRECISION': 0,
                                                                                   'PRIMARY_KEY': False,
                                                                                   'SQL_TYPE': 'VARCHAR',
                                                                                   'WIDTH': 6},
                                                                  'AUTH_COMP_ID': {'NULLABLE': True,
                                                                                   'ORDER': 21,
                                                                                   'PRECISION': 0,
                                                                                   'PRIMARY_KEY': False,
                                                                                   'SQL_TYPE': 'VARCHAR',
                                                                                   'WIDTH': 10},
                                                                  'AUTH_SEQ_ID': {'NULLABLE': True,
                                                                                  'ORDER': 22,
                                                                                  'PRECISION': 0,
                                                                                  'PRIMARY_KEY': False,
                                                                                  'SQL_TYPE': 'VARCHAR',
                                                                                  'WIDTH': 10},
                                                                  'GROUP_PDB': {'NULLABLE': True,
                                                                                'ORDER': 3,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 10},
                                                                  'ID': {'NULLABLE': False,
                                                                         'ORDER': 2,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': True,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                                                  'LABEL_ALT_ID': {'NULLABLE': True,
                                                                                   'ORDER': 4,
                                                                                   'PRECISION': 0,
                                                                                   'PRIMARY_KEY': False,
                                                                                   'SQL_TYPE': 'VARCHAR',
                                                                                   'WIDTH': 10},
                                                                  'LABEL_ASYM_ID': {'NULLABLE': True,
                                                                                    'ORDER': 5,
                                                                                    'PRECISION': 0,
                                                                                    'PRIMARY_KEY': False,
                                                                                    'SQL_TYPE': 'VARCHAR',
                                                                                    'WIDTH': 10},
                                                                  'LABEL_ATOM_ID': {'NULLABLE': True,
                                                                                    'ORDER': 6,
                                                                                    'PRECISION': 0,
                                                                                    'PRIMARY_KEY': False,
                                                                                    'SQL_TYPE': 'VARCHAR',
                                                                                    'WIDTH': 6},
                                                                  'LABEL_COMP_ID': {'NULLABLE': True,
                                                                                    'ORDER': 7,
                                                                                    'PRECISION': 0,
                                                                                    'PRIMARY_KEY': False,
                                                                                    'SQL_TYPE': 'VARCHAR',
                                                                                    'WIDTH': 10},
                                                                  'LABEL_SEQ_ID': {'NULLABLE': True,
                                                                                   'ORDER': 8,
                                                                                   'PRECISION': 0,
                                                                                   'PRIMARY_KEY': False,
                                                                                   'SQL_TYPE': 'INT',
                                                                                   'WIDTH': 10},
                                                                  'OCCUPANCY': {'NULLABLE': True,
                                                                                'ORDER': 24,
                                                                                'PRECISION': 6,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'FLOAT',
                                                                                'WIDTH': 10},
                                                                  'PDBX_ALIGN': {'NULLABLE': True,
                                                                                 'ORDER': 9,
                                                                                 'PRECISION': 0,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'INT',
                                                                                 'WIDTH': 10},
                                                                  'PDB_INS_CODE': {'NULLABLE': True,
                                                                                   'ORDER': 10,
                                                                                   'PRECISION': 0,
                                                                                   'PRIMARY_KEY': False,
                                                                                   'SQL_TYPE': 'VARCHAR',
                                                                                   'WIDTH': 10},
                                                                  'PRE_AUTH_ALT_ID': {'NULLABLE': True,
                                                                                      'ORDER': 17,
                                                                                      'PRECISION': 0,
                                                                                      'PRIMARY_KEY': False,
                                                                                      'SQL_TYPE': 'VARCHAR',
                                                                                      'WIDTH': 10},
                                                                  'PRE_AUTH_ASYM_ID': {'NULLABLE': True,
                                                                                       'ORDER': 11,
                                                                                       'PRECISION': 0,
                                                                                       'PRIMARY_KEY': False,
                                                                                       'SQL_TYPE': 'VARCHAR',
                                                                                       'WIDTH': 10},
                                                                  'PRE_AUTH_ATOM_ID': {'NULLABLE': True,
                                                                                       'ORDER': 12,
                                                                                       'PRECISION': 0,
                                                                                       'PRIMARY_KEY': False,
                                                                                       'SQL_TYPE': 'VARCHAR',
                                                                                       'WIDTH': 6},
                                                                  'PRE_AUTH_COMP_ID': {'NULLABLE': True,
                                                                                       'ORDER': 13,
                                                                                       'PRECISION': 0,
                                                                                       'PRIMARY_KEY': False,
                                                                                       'SQL_TYPE': 'VARCHAR',
                                                                                       'WIDTH': 10},
                                                                  'PRE_AUTH_SEQ_ID': {'NULLABLE': True,
                                                                                      'ORDER': 14,
                                                                                      'PRECISION': 0,
                                                                                      'PRIMARY_KEY': False,
                                                                                      'SQL_TYPE': 'VARCHAR',
                                                                                      'WIDTH': 10},
                                                                  'PRE_GROUP_PDB': {'NULLABLE': True,
                                                                                    'ORDER': 16,
                                                                                    'PRECISION': 0,
                                                                                    'PRIMARY_KEY': False,
                                                                                    'SQL_TYPE': 'VARCHAR',
                                                                                    'WIDTH': 10},
                                                                  'PRE_OCCUPANCY': {'NULLABLE': True,
                                                                                    'ORDER': 25,
                                                                                    'PRECISION': 6,
                                                                                    'PRIMARY_KEY': False,
                                                                                    'SQL_TYPE': 'FLOAT',
                                                                                    'WIDTH': 10},
                                                                  'PRE_PDBX_ALIGN': {'NULLABLE': True,
                                                                                     'ORDER': 18,
                                                                                     'PRECISION': 0,
                                                                                     'PRIMARY_KEY': False,
                                                                                     'SQL_TYPE': 'INT',
                                                                                     'WIDTH': 10},
                                                                  'PRE_PDB_INS_CODE': {'NULLABLE': True,
                                                                                       'ORDER': 15,
                                                                                       'PRECISION': 0,
                                                                                       'PRIMARY_KEY': False,
                                                                                       'SQL_TYPE': 'VARCHAR',
                                                                                       'WIDTH': 10},
                                                                  'STRUCTURE_ID': {'NULLABLE': False,
                                                                                   'ORDER': 1,
                                                                                   'PRECISION': 0,
                                                                                   'PRIMARY_KEY': True,
                                                                                   'SQL_TYPE': 'VARCHAR',
                                                                                   'WIDTH': 10}},
                                               'ATTRIBUTE_MAP': {'AUTH_ALT_ID': ('pdbx_remediation_atom_site_mapping',
                                                                                 'auth_alt_id',
                                                                                 None,
                                                                                 None),
                                                                 'AUTH_ASYM_ID': ('pdbx_remediation_atom_site_mapping',
                                                                                  'auth_asym_id',
                                                                                  None,
                                                                                  None),
                                                                 'AUTH_ATOM_ID': ('pdbx_remediation_atom_site_mapping',
                                                                                  'auth_atom_id',
                                                                                  None,
                                                                                  None),
                                                                 'AUTH_COMP_ID': ('pdbx_remediation_atom_site_mapping',
                                                                                  'auth_comp_id',
                                                                                  None,
                                                                                  None),
                                                                 'AUTH_SEQ_ID': ('pdbx_remediation_atom_site_mapping',
                                                                                 'auth_seq_id',
                                                                                 None,
                                                                                 None),
                                                                 'GROUP_PDB': ('pdbx_remediation_atom_site_mapping',
                                                                               'group_PDB',
                                                                               None,
                                                                               None),
                                                                 'ID': ('pdbx_remediation_atom_site_mapping',
                                                                        'id',
                                                                        None,
                                                                        None),
                                                                 'LABEL_ALT_ID': ('pdbx_remediation_atom_site_mapping',
                                                                                  'label_alt_id',
                                                                                  None,
                                                                                  None),
                                                                 'LABEL_ASYM_ID': ('pdbx_remediation_atom_site_mapping',
                                                                                   'label_asym_id',
                                                                                   None,
                                                                                   None),
                                                                 'LABEL_ATOM_ID': ('pdbx_remediation_atom_site_mapping',
                                                                                   'label_atom_id',
                                                                                   None,
                                                                                   None),
                                                                 'LABEL_COMP_ID': ('pdbx_remediation_atom_site_mapping',
                                                                                   'label_comp_id',
                                                                                   None,
                                                                                   None),
                                                                 'LABEL_SEQ_ID': ('pdbx_remediation_atom_site_mapping',
                                                                                  'label_seq_id',
                                                                                  None,
                                                                                  None),
                                                                 'OCCUPANCY': ('pdbx_remediation_atom_site_mapping',
                                                                               'occupancy',
                                                                               None,
                                                                               None),
                                                                 'PDBX_ALIGN': ('pdbx_remediation_atom_site_mapping',
                                                                                'pdbx_align',
                                                                                None,
                                                                                None),
                                                                 'PDB_INS_CODE': ('pdbx_remediation_atom_site_mapping',
                                                                                  'PDB_ins_code',
                                                                                  None,
                                                                                  None),
                                                                 'PRE_AUTH_ALT_ID': ('pdbx_remediation_atom_site_mapping',
                                                                                     'pre_auth_alt_id',
                                                                                     None,
                                                                                     None),
                                                                 'PRE_AUTH_ASYM_ID': ('pdbx_remediation_atom_site_mapping',
                                                                                      'pre_auth_asym_id',
                                                                                      None,
                                                                                      None),
                                                                 'PRE_AUTH_ATOM_ID': ('pdbx_remediation_atom_site_mapping',
                                                                                      'pre_auth_atom_id',
                                                                                      None,
                                                                                      None),
                                                                 'PRE_AUTH_COMP_ID': ('pdbx_remediation_atom_site_mapping',
                                                                                      'pre_auth_comp_id',
                                                                                      None,
                                                                                      None),
                                                                 'PRE_AUTH_SEQ_ID': ('pdbx_remediation_atom_site_mapping',
                                                                                     'pre_auth_seq_id',
                                                                                     None,
                                                                                     None),
                                                                 'PRE_GROUP_PDB': ('pdbx_remediation_atom_site_mapping',
                                                                                   'pre_group_PDB',
                                                                                   None,
                                                                                   None),
                                                                 'PRE_OCCUPANCY': ('pdbx_remediation_atom_site_mapping',
                                                                                   'pre_occupancy',
                                                                                   None,
                                                                                   None),
                                                                 'PRE_PDBX_ALIGN': ('pdbx_remediation_atom_site_mapping',
                                                                                    'pre_pdbx_align',
                                                                                    None,
                                                                                    None),
                                                                 'PRE_PDB_INS_CODE': ('pdbx_remediation_atom_site_mapping',
                                                                                      'pre_PDB_ins_code',
                                                                                      None,
                                                                                      None),
                                                                 'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                               'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                                           's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                               'MAP_MERGE_INDICES': {'pdbx_remediation_atom_site_mapping': {'ATTRIBUTES': ('id',),
                                                                                                            'TYPE': 'EQUI-JOIN'}},
                                               'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                               'TABLE_ID': 'PDBX_REMEDIATION_ATOM_SITE_MAPPING',
                                               'TABLE_NAME': 'pdbx_remediation_atom_site_mapping',
                                               'TABLE_TYPE': 'transactional'},
        'PDBX_RE_REFINEMENT': {'ATTRIBUTES': {'CITATION_ID': 'citation_id',
                                              'DETAILS': 'details',
                                              'ENTRY_ID': 'entry_id',
                                              'STRUCTURE_ID': 'Structure_ID'},
                               'ATTRIBUTE_INFO': {'CITATION_ID': {'NULLABLE': True,
                                                                  'ORDER': 3,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10},
                                                  'DETAILS': {'NULLABLE': True,
                                                              'ORDER': 4,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10},
                                                  'ENTRY_ID': {'NULLABLE': False,
                                                               'ORDER': 2,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                                  'STRUCTURE_ID': {'NULLABLE': False,
                                                                   'ORDER': 1,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': True,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 10}},
                               'ATTRIBUTE_MAP': {'CITATION_ID': ('pdbx_re_refinement', 'citation_id', None, None),
                                                 'DETAILS': ('pdbx_re_refinement', 'details', None, None),
                                                 'ENTRY_ID': ('pdbx_re_refinement', 'entry_id', None, None),
                                                 'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                               'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID'), 'TYPE': 'UNIQUE'},
                                           's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                               'MAP_MERGE_INDICES': {'pdbx_re_refinement': {'ATTRIBUTES': ('entry_id',), 'TYPE': 'EQUI-JOIN'}},
                               'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                               'TABLE_ID': 'PDBX_RE_REFINEMENT',
                               'TABLE_NAME': 'pdbx_re_refinement',
                               'TABLE_TYPE': 'transactional'},
        'PDBX_ROBOT_SYSTEM': {'ATTRIBUTES': {'ID': 'id',
                                             'MANUFACTURER': 'manufacturer',
                                             'MODEL': 'model',
                                             'STRUCTURE_ID': 'Structure_ID',
                                             'TYPE': 'type'},
                              'ATTRIBUTE_INFO': {'ID': {'NULLABLE': False,
                                                        'ORDER': 2,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': True,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 10},
                                                 'MANUFACTURER': {'NULLABLE': True,
                                                                  'ORDER': 5,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 80},
                                                 'MODEL': {'NULLABLE': True,
                                                           'ORDER': 3,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 80},
                                                 'STRUCTURE_ID': {'NULLABLE': False,
                                                                  'ORDER': 1,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': True,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10},
                                                 'TYPE': {'NULLABLE': True,
                                                          'ORDER': 4,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 80}},
                              'ATTRIBUTE_MAP': {'ID': ('pdbx_robot_system', 'id', None, None),
                                                'MANUFACTURER': ('pdbx_robot_system', 'manufacturer', None, None),
                                                'MODEL': ('pdbx_robot_system', 'model', None, None),
                                                'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                'TYPE': ('pdbx_robot_system', 'type', None, None)},
                              'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                          's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                              'MAP_MERGE_INDICES': {'pdbx_robot_system': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                              'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                              'TABLE_ID': 'PDBX_ROBOT_SYSTEM',
                              'TABLE_NAME': 'pdbx_robot_system',
                              'TABLE_TYPE': 'transactional'},
        'PDBX_SEQUENCE_RANGE': {'ATTRIBUTES': {'BEG_AUTH_ASYM_ID': 'beg_auth_asym_id',
                                               'BEG_AUTH_COMP_ID': 'beg_auth_comp_id',
                                               'BEG_AUTH_SEQ_ID': 'beg_auth_seq_id',
                                               'BEG_LABEL_ALT_ID': 'beg_label_alt_id',
                                               'BEG_LABEL_ASYM_ID': 'beg_label_asym_id',
                                               'BEG_LABEL_COMP_ID': 'beg_label_comp_id',
                                               'BEG_LABEL_SEQ_ID': 'beg_label_seq_id',
                                               'END_AUTH_ASYM_ID': 'end_auth_asym_id',
                                               'END_AUTH_COMP_ID': 'end_auth_comp_id',
                                               'END_AUTH_SEQ_ID': 'end_auth_seq_id',
                                               'END_LABEL_ALT_ID': 'end_label_alt_id',
                                               'END_LABEL_ASYM_ID': 'end_label_asym_id',
                                               'END_LABEL_COMP_ID': 'end_label_comp_id',
                                               'END_LABEL_SEQ_ID': 'end_label_seq_id',
                                               'SEQ_RANGE_ID': 'seq_range_id',
                                               'STRUCTURE_ID': 'Structure_ID'},
                                'ATTRIBUTE_INFO': {'BEG_AUTH_ASYM_ID': {'NULLABLE': True,
                                                                        'ORDER': 6,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                                   'BEG_AUTH_COMP_ID': {'NULLABLE': True,
                                                                        'ORDER': 7,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                                   'BEG_AUTH_SEQ_ID': {'NULLABLE': True,
                                                                       'ORDER': 8,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                   'BEG_LABEL_ALT_ID': {'NULLABLE': False,
                                                                        'ORDER': 2,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': True,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                                   'BEG_LABEL_ASYM_ID': {'NULLABLE': False,
                                                                         'ORDER': 3,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': True,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                                   'BEG_LABEL_COMP_ID': {'NULLABLE': False,
                                                                         'ORDER': 4,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': True,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                                   'BEG_LABEL_SEQ_ID': {'NULLABLE': False,
                                                                        'ORDER': 5,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': True,
                                                                        'SQL_TYPE': 'INT',
                                                                        'WIDTH': 10},
                                                   'END_AUTH_ASYM_ID': {'NULLABLE': True,
                                                                        'ORDER': 14,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                                   'END_AUTH_COMP_ID': {'NULLABLE': True,
                                                                        'ORDER': 15,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                                   'END_AUTH_SEQ_ID': {'NULLABLE': True,
                                                                       'ORDER': 16,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                   'END_LABEL_ALT_ID': {'NULLABLE': False,
                                                                        'ORDER': 10,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': True,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                                   'END_LABEL_ASYM_ID': {'NULLABLE': False,
                                                                         'ORDER': 11,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': True,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                                   'END_LABEL_COMP_ID': {'NULLABLE': False,
                                                                         'ORDER': 12,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': True,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                                   'END_LABEL_SEQ_ID': {'NULLABLE': False,
                                                                        'ORDER': 13,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': True,
                                                                        'SQL_TYPE': 'INT',
                                                                        'WIDTH': 10},
                                                   'SEQ_RANGE_ID': {'NULLABLE': False,
                                                                    'ORDER': 9,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': True,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10},
                                                   'STRUCTURE_ID': {'NULLABLE': False,
                                                                    'ORDER': 1,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': True,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10}},
                                'ATTRIBUTE_MAP': {'BEG_AUTH_ASYM_ID': ('pdbx_sequence_range', 'beg_auth_asym_id', None, None),
                                                  'BEG_AUTH_COMP_ID': ('pdbx_sequence_range', 'beg_auth_comp_id', None, None),
                                                  'BEG_AUTH_SEQ_ID': ('pdbx_sequence_range', 'beg_auth_seq_id', None, None),
                                                  'BEG_LABEL_ALT_ID': ('pdbx_sequence_range', 'beg_label_alt_id', None, None),
                                                  'BEG_LABEL_ASYM_ID': ('pdbx_sequence_range',
                                                                        'beg_label_asym_id',
                                                                        None,
                                                                        None),
                                                  'BEG_LABEL_COMP_ID': ('pdbx_sequence_range',
                                                                        'beg_label_comp_id',
                                                                        None,
                                                                        None),
                                                  'BEG_LABEL_SEQ_ID': ('pdbx_sequence_range', 'beg_label_seq_id', None, None),
                                                  'END_AUTH_ASYM_ID': ('pdbx_sequence_range', 'end_auth_asym_id', None, None),
                                                  'END_AUTH_COMP_ID': ('pdbx_sequence_range', 'end_auth_comp_id', None, None),
                                                  'END_AUTH_SEQ_ID': ('pdbx_sequence_range', 'end_auth_seq_id', None, None),
                                                  'END_LABEL_ALT_ID': ('pdbx_sequence_range', 'end_label_alt_id', None, None),
                                                  'END_LABEL_ASYM_ID': ('pdbx_sequence_range',
                                                                        'end_label_asym_id',
                                                                        None,
                                                                        None),
                                                  'END_LABEL_COMP_ID': ('pdbx_sequence_range',
                                                                        'end_label_comp_id',
                                                                        None,
                                                                        None),
                                                  'END_LABEL_SEQ_ID': ('pdbx_sequence_range', 'end_label_seq_id', None, None),
                                                  'SEQ_RANGE_ID': ('pdbx_sequence_range', 'seq_range_id', None, None),
                                                  'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID',
                                                                  'BEG_LABEL_ALT_ID',
                                                                  'BEG_LABEL_ASYM_ID',
                                                                  'BEG_LABEL_COMP_ID',
                                                                  'BEG_LABEL_SEQ_ID',
                                                                  'SEQ_RANGE_ID',
                                                                  'END_LABEL_ALT_ID',
                                                                  'END_LABEL_ASYM_ID',
                                                                  'END_LABEL_COMP_ID',
                                                                  'END_LABEL_SEQ_ID'),
                                                   'TYPE': 'UNIQUE'},
                                            's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                'MAP_MERGE_INDICES': {'pdbx_sequence_range': {'ATTRIBUTES': ('beg_label_alt_id',
                                                                                             'beg_label_asym_id',
                                                                                             'beg_label_comp_id',
                                                                                             'beg_label_seq_id',
                                                                                             'seq_range_id',
                                                                                             'end_label_alt_id',
                                                                                             'end_label_asym_id',
                                                                                             'end_label_comp_id',
                                                                                             'end_label_seq_id'),
                                                                              'TYPE': 'EQUI-JOIN'}},
                                'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                'TABLE_ID': 'PDBX_SEQUENCE_RANGE',
                                'TABLE_NAME': 'pdbx_sequence_range',
                                'TABLE_TYPE': 'transactional'},
        'PDBX_SG_PROJECT': {'ATTRIBUTES': {'FULL_NAME_OF_CENTER': 'full_name_of_center',
                                           'ID': 'id',
                                           'INITIAL_OF_CENTER': 'initial_of_center',
                                           'PROJECT_NAME': 'project_name',
                                           'STRUCTURE_ID': 'Structure_ID'},
                            'ATTRIBUTE_INFO': {'FULL_NAME_OF_CENTER': {'NULLABLE': True,
                                                                       'ORDER': 4,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 200},
                                               'ID': {'NULLABLE': False,
                                                      'ORDER': 2,
                                                      'PRECISION': 0,
                                                      'PRIMARY_KEY': True,
                                                      'SQL_TYPE': 'INT',
                                                      'WIDTH': 10},
                                               'INITIAL_OF_CENTER': {'NULLABLE': True,
                                                                     'ORDER': 5,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 200},
                                               'PROJECT_NAME': {'NULLABLE': True,
                                                                'ORDER': 3,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 200},
                                               'STRUCTURE_ID': {'NULLABLE': False,
                                                                'ORDER': 1,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10}},
                            'ATTRIBUTE_MAP': {'FULL_NAME_OF_CENTER': ('pdbx_SG_project', 'full_name_of_center', None, None),
                                              'ID': ('pdbx_SG_project', 'id', None, None),
                                              'INITIAL_OF_CENTER': ('pdbx_SG_project', 'initial_of_center', None, None),
                                              'PROJECT_NAME': ('pdbx_SG_project', 'project_name', None, None),
                                              'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                            'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                        's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                            'MAP_MERGE_INDICES': {'pdbx_SG_project': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                            'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                            'TABLE_ID': 'PDBX_SG_PROJECT',
                            'TABLE_NAME': 'pdbx_SG_project',
                            'TABLE_TYPE': 'transactional'},
        'PDBX_SOLN_SCATTER': {'ATTRIBUTES': {'BUFFER_NAME': 'buffer_name',
                                             'CONCENTRATION_RANGE': 'concentration_range',
                                             'DATA_ANALYSIS_SOFTWARE_LIST': 'data_analysis_software_list',
                                             'DATA_REDUCTION_SOFTWARE_LIST': 'data_reduction_software_list',
                                             'DETECTOR_SPECIFIC': 'detector_specific',
                                             'DETECTOR_TYPE': 'detector_type',
                                             'ENTRY_ID': 'entry_id',
                                             'ID': 'id',
                                             'MAX_MEAN_CROSS_SECTIONAL_RADII_GYRATION': 'max_mean_cross_sectional_radii_gyration',
                                             'MAX_MEAN_CROSS_SECTIONAL_RADII_GYRATION_ESD': 'max_mean_cross_sectional_radii_gyration_esd',
                                             'MEAN_GUINER_RADIUS': 'mean_guiner_radius',
                                             'MEAN_GUINER_RADIUS_ESD': 'mean_guiner_radius_esd',
                                             'MIN_MEAN_CROSS_SECTIONAL_RADII_GYRATION': 'min_mean_cross_sectional_radii_gyration',
                                             'MIN_MEAN_CROSS_SECTIONAL_RADII_GYRATION_ESD': 'min_mean_cross_sectional_radii_gyration_esd',
                                             'NUM_TIME_FRAMES': 'num_time_frames',
                                             'PROTEIN_LENGTH': 'protein_length',
                                             'SAMPLE_PH': 'sample_pH',
                                             'SOURCE_BEAMLINE': 'source_beamline',
                                             'SOURCE_BEAMLINE_INSTRUMENT': 'source_beamline_instrument',
                                             'SOURCE_CLASS': 'source_class',
                                             'SOURCE_TYPE': 'source_type',
                                             'STRUCTURE_ID': 'Structure_ID',
                                             'TEMPERATURE': 'temperature',
                                             'TYPE': 'type'},
                              'ATTRIBUTE_INFO': {'BUFFER_NAME': {'NULLABLE': True,
                                                                 'ORDER': 15,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 128},
                                                 'CONCENTRATION_RANGE': {'NULLABLE': True,
                                                                         'ORDER': 14,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 80},
                                                 'DATA_ANALYSIS_SOFTWARE_LIST': {'NULLABLE': True,
                                                                                 'ORDER': 24,
                                                                                 'PRECISION': 0,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'VARCHAR',
                                                                                 'WIDTH': 200},
                                                 'DATA_REDUCTION_SOFTWARE_LIST': {'NULLABLE': True,
                                                                                  'ORDER': 23,
                                                                                  'PRECISION': 0,
                                                                                  'PRIMARY_KEY': False,
                                                                                  'SQL_TYPE': 'VARCHAR',
                                                                                  'WIDTH': 200},
                                                 'DETECTOR_SPECIFIC': {'NULLABLE': True,
                                                                       'ORDER': 8,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 200},
                                                 'DETECTOR_TYPE': {'NULLABLE': True,
                                                                   'ORDER': 7,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 200},
                                                 'ENTRY_ID': {'NULLABLE': False,
                                                              'ORDER': 2,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10},
                                                 'ID': {'NULLABLE': False,
                                                        'ORDER': 3,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': True,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 10},
                                                 'MAX_MEAN_CROSS_SECTIONAL_RADII_GYRATION': {'NULLABLE': True,
                                                                                             'ORDER': 20,
                                                                                             'PRECISION': 6,
                                                                                             'PRIMARY_KEY': False,
                                                                                             'SQL_TYPE': 'FLOAT',
                                                                                             'WIDTH': 10},
                                                 'MAX_MEAN_CROSS_SECTIONAL_RADII_GYRATION_ESD': {'NULLABLE': True,
                                                                                                 'ORDER': 21,
                                                                                                 'PRECISION': 6,
                                                                                                 'PRIMARY_KEY': False,
                                                                                                 'SQL_TYPE': 'FLOAT',
                                                                                                 'WIDTH': 10},
                                                 'MEAN_GUINER_RADIUS': {'NULLABLE': True,
                                                                        'ORDER': 16,
                                                                        'PRECISION': 6,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'FLOAT',
                                                                        'WIDTH': 10},
                                                 'MEAN_GUINER_RADIUS_ESD': {'NULLABLE': True,
                                                                            'ORDER': 17,
                                                                            'PRECISION': 6,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'FLOAT',
                                                                            'WIDTH': 10},
                                                 'MIN_MEAN_CROSS_SECTIONAL_RADII_GYRATION': {'NULLABLE': True,
                                                                                             'ORDER': 18,
                                                                                             'PRECISION': 6,
                                                                                             'PRIMARY_KEY': False,
                                                                                             'SQL_TYPE': 'FLOAT',
                                                                                             'WIDTH': 10},
                                                 'MIN_MEAN_CROSS_SECTIONAL_RADII_GYRATION_ESD': {'NULLABLE': True,
                                                                                                 'ORDER': 19,
                                                                                                 'PRECISION': 6,
                                                                                                 'PRIMARY_KEY': False,
                                                                                                 'SQL_TYPE': 'FLOAT',
                                                                                                 'WIDTH': 10},
                                                 'NUM_TIME_FRAMES': {'NULLABLE': True,
                                                                     'ORDER': 11,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'INT',
                                                                     'WIDTH': 10},
                                                 'PROTEIN_LENGTH': {'NULLABLE': True,
                                                                    'ORDER': 22,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 80},
                                                 'SAMPLE_PH': {'NULLABLE': True,
                                                               'ORDER': 12,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                                 'SOURCE_BEAMLINE': {'NULLABLE': True,
                                                                     'ORDER': 5,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 200},
                                                 'SOURCE_BEAMLINE_INSTRUMENT': {'NULLABLE': True,
                                                                                'ORDER': 6,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 200},
                                                 'SOURCE_CLASS': {'NULLABLE': True,
                                                                  'ORDER': 10,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 200},
                                                 'SOURCE_TYPE': {'NULLABLE': True,
                                                                 'ORDER': 9,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 200},
                                                 'STRUCTURE_ID': {'NULLABLE': False,
                                                                  'ORDER': 1,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': True,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10},
                                                 'TEMPERATURE': {'NULLABLE': True,
                                                                 'ORDER': 13,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                                 'TYPE': {'NULLABLE': True,
                                                          'ORDER': 4,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 10}},
                              'ATTRIBUTE_MAP': {'BUFFER_NAME': ('pdbx_soln_scatter', 'buffer_name', None, None),
                                                'CONCENTRATION_RANGE': ('pdbx_soln_scatter',
                                                                        'concentration_range',
                                                                        None,
                                                                        None),
                                                'DATA_ANALYSIS_SOFTWARE_LIST': ('pdbx_soln_scatter',
                                                                                'data_analysis_software_list',
                                                                                None,
                                                                                None),
                                                'DATA_REDUCTION_SOFTWARE_LIST': ('pdbx_soln_scatter',
                                                                                 'data_reduction_software_list',
                                                                                 None,
                                                                                 None),
                                                'DETECTOR_SPECIFIC': ('pdbx_soln_scatter', 'detector_specific', None, None),
                                                'DETECTOR_TYPE': ('pdbx_soln_scatter', 'detector_type', None, None),
                                                'ENTRY_ID': ('pdbx_soln_scatter', 'entry_id', None, None),
                                                'ID': ('pdbx_soln_scatter', 'id', None, None),
                                                'MAX_MEAN_CROSS_SECTIONAL_RADII_GYRATION': ('pdbx_soln_scatter',
                                                                                            'max_mean_cross_sectional_radii_gyration',
                                                                                            None,
                                                                                            None),
                                                'MAX_MEAN_CROSS_SECTIONAL_RADII_GYRATION_ESD': ('pdbx_soln_scatter',
                                                                                                'max_mean_cross_sectional_radii_gyration_esd',
                                                                                                None,
                                                                                                None),
                                                'MEAN_GUINER_RADIUS': ('pdbx_soln_scatter', 'mean_guiner_radius', None, None),
                                                'MEAN_GUINER_RADIUS_ESD': ('pdbx_soln_scatter',
                                                                           'mean_guiner_radius_esd',
                                                                           None,
                                                                           None),
                                                'MIN_MEAN_CROSS_SECTIONAL_RADII_GYRATION': ('pdbx_soln_scatter',
                                                                                            'min_mean_cross_sectional_radii_gyration',
                                                                                            None,
                                                                                            None),
                                                'MIN_MEAN_CROSS_SECTIONAL_RADII_GYRATION_ESD': ('pdbx_soln_scatter',
                                                                                                'min_mean_cross_sectional_radii_gyration_esd',
                                                                                                None,
                                                                                                None),
                                                'NUM_TIME_FRAMES': ('pdbx_soln_scatter', 'num_time_frames', None, None),
                                                'PROTEIN_LENGTH': ('pdbx_soln_scatter', 'protein_length', None, None),
                                                'SAMPLE_PH': ('pdbx_soln_scatter', 'sample_pH', None, None),
                                                'SOURCE_BEAMLINE': ('pdbx_soln_scatter', 'source_beamline', None, None),
                                                'SOURCE_BEAMLINE_INSTRUMENT': ('pdbx_soln_scatter',
                                                                               'source_beamline_instrument',
                                                                               None,
                                                                               None),
                                                'SOURCE_CLASS': ('pdbx_soln_scatter', 'source_class', None, None),
                                                'SOURCE_TYPE': ('pdbx_soln_scatter', 'source_type', None, None),
                                                'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                'TEMPERATURE': ('pdbx_soln_scatter', 'temperature', None, None),
                                                'TYPE': ('pdbx_soln_scatter', 'type', None, None)},
                              'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                          's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                              'MAP_MERGE_INDICES': {'pdbx_soln_scatter': {'ATTRIBUTES': ('entry_id', 'id'),
                                                                          'TYPE': 'EQUI-JOIN'}},
                              'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                              'TABLE_ID': 'PDBX_SOLN_SCATTER',
                              'TABLE_NAME': 'pdbx_soln_scatter',
                              'TABLE_TYPE': 'transactional'},
        'PDBX_SOLN_SCATTER_MODEL': {'ATTRIBUTES': {'CONFORMER_SELECTION_CRITERIA': 'conformer_selection_criteria',
                                                   'DETAILS': 'details',
                                                   'ENTRY_FITTING_LIST': 'entry_fitting_list',
                                                   'ID': 'id',
                                                   'METHOD': 'method',
                                                   'NUM_CONFORMERS_CALCULATED': 'num_conformers_calculated',
                                                   'NUM_CONFORMERS_SUBMITTED': 'num_conformers_submitted',
                                                   'REPRESENTATIVE_CONFORMER': 'representative_conformer',
                                                   'SCATTER_ID': 'scatter_id',
                                                   'SOFTWARE_AUTHOR_LIST': 'software_author_list',
                                                   'SOFTWARE_LIST': 'software_list',
                                                   'STRUCTURE_ID': 'Structure_ID'},
                                    'ATTRIBUTE_INFO': {'CONFORMER_SELECTION_CRITERIA': {'NULLABLE': True,
                                                                                        'ORDER': 12,
                                                                                        'PRECISION': 0,
                                                                                        'PRIMARY_KEY': False,
                                                                                        'SQL_TYPE': 'VARCHAR',
                                                                                        'WIDTH': 1023},
                                                       'DETAILS': {'NULLABLE': True,
                                                                   'ORDER': 4,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 4095},
                                                       'ENTRY_FITTING_LIST': {'NULLABLE': True,
                                                                              'ORDER': 8,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 200},
                                                       'ID': {'NULLABLE': False,
                                                              'ORDER': 3,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10},
                                                       'METHOD': {'NULLABLE': True,
                                                                  'ORDER': 5,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 255},
                                                       'NUM_CONFORMERS_CALCULATED': {'NULLABLE': True,
                                                                                     'ORDER': 9,
                                                                                     'PRECISION': 0,
                                                                                     'PRIMARY_KEY': False,
                                                                                     'SQL_TYPE': 'INT',
                                                                                     'WIDTH': 10},
                                                       'NUM_CONFORMERS_SUBMITTED': {'NULLABLE': True,
                                                                                    'ORDER': 10,
                                                                                    'PRECISION': 0,
                                                                                    'PRIMARY_KEY': False,
                                                                                    'SQL_TYPE': 'INT',
                                                                                    'WIDTH': 10},
                                                       'REPRESENTATIVE_CONFORMER': {'NULLABLE': True,
                                                                                    'ORDER': 11,
                                                                                    'PRECISION': 0,
                                                                                    'PRIMARY_KEY': False,
                                                                                    'SQL_TYPE': 'INT',
                                                                                    'WIDTH': 10},
                                                       'SCATTER_ID': {'NULLABLE': False,
                                                                      'ORDER': 2,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                                       'SOFTWARE_AUTHOR_LIST': {'NULLABLE': True,
                                                                                'ORDER': 7,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 200},
                                                       'SOFTWARE_LIST': {'NULLABLE': True,
                                                                         'ORDER': 6,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 200},
                                                       'STRUCTURE_ID': {'NULLABLE': False,
                                                                        'ORDER': 1,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': True,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10}},
                                    'ATTRIBUTE_MAP': {'CONFORMER_SELECTION_CRITERIA': ('pdbx_soln_scatter_model',
                                                                                       'conformer_selection_criteria',
                                                                                       None,
                                                                                       None),
                                                      'DETAILS': ('pdbx_soln_scatter_model', 'details', None, None),
                                                      'ENTRY_FITTING_LIST': ('pdbx_soln_scatter_model',
                                                                             'entry_fitting_list',
                                                                             None,
                                                                             None),
                                                      'ID': ('pdbx_soln_scatter_model', 'id', None, None),
                                                      'METHOD': ('pdbx_soln_scatter_model', 'method', None, None),
                                                      'NUM_CONFORMERS_CALCULATED': ('pdbx_soln_scatter_model',
                                                                                    'num_conformers_calculated',
                                                                                    None,
                                                                                    None),
                                                      'NUM_CONFORMERS_SUBMITTED': ('pdbx_soln_scatter_model',
                                                                                   'num_conformers_submitted',
                                                                                   None,
                                                                                   None),
                                                      'REPRESENTATIVE_CONFORMER': ('pdbx_soln_scatter_model',
                                                                                   'representative_conformer',
                                                                                   None,
                                                                                   None),
                                                      'SCATTER_ID': ('pdbx_soln_scatter_model', 'scatter_id', None, None),
                                                      'SOFTWARE_AUTHOR_LIST': ('pdbx_soln_scatter_model',
                                                                               'software_author_list',
                                                                               None,
                                                                               None),
                                                      'SOFTWARE_LIST': ('pdbx_soln_scatter_model',
                                                                        'software_list',
                                                                        None,
                                                                        None),
                                                      'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                    'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'SCATTER_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                                's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                    'MAP_MERGE_INDICES': {'pdbx_soln_scatter_model': {'ATTRIBUTES': ('scatter_id', 'id'),
                                                                                      'TYPE': 'EQUI-JOIN'}},
                                    'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                    'TABLE_ID': 'PDBX_SOLN_SCATTER_MODEL',
                                    'TABLE_NAME': 'pdbx_soln_scatter_model',
                                    'TABLE_TYPE': 'transactional'},
        'PDBX_STRUCT_ASSEMBLY': {'ATTRIBUTES': {'DETAILS': 'details',
                                                'ID': 'id',
                                                'METHOD_DETAILS': 'method_details',
                                                'OLIGOMERIC_COUNT': 'oligomeric_count',
                                                'OLIGOMERIC_DETAILS': 'oligomeric_details',
                                                'STRUCTURE_ID': 'Structure_ID'},
                                 'ATTRIBUTE_INFO': {'DETAILS': {'NULLABLE': True,
                                                                'ORDER': 5,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 200},
                                                    'ID': {'NULLABLE': False,
                                                           'ORDER': 6,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': True,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 80},
                                                    'METHOD_DETAILS': {'NULLABLE': True,
                                                                       'ORDER': 2,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 200},
                                                    'OLIGOMERIC_COUNT': {'NULLABLE': True,
                                                                         'ORDER': 4,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'INT',
                                                                         'WIDTH': 10},
                                                    'OLIGOMERIC_DETAILS': {'NULLABLE': True,
                                                                           'ORDER': 3,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 80},
                                                    'STRUCTURE_ID': {'NULLABLE': False,
                                                                     'ORDER': 1,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': True,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10}},
                                 'ATTRIBUTE_MAP': {'DETAILS': ('pdbx_struct_assembly', 'details', None, None),
                                                   'ID': ('pdbx_struct_assembly', 'id', None, None),
                                                   'METHOD_DETAILS': ('pdbx_struct_assembly', 'method_details', None, None),
                                                   'OLIGOMERIC_COUNT': ('pdbx_struct_assembly',
                                                                        'oligomeric_count',
                                                                        None,
                                                                        None),
                                                   'OLIGOMERIC_DETAILS': ('pdbx_struct_assembly',
                                                                          'oligomeric_details',
                                                                          None,
                                                                          None),
                                                   'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                 'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                             's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                 'MAP_MERGE_INDICES': {'pdbx_struct_assembly': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                                 'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                 'TABLE_ID': 'PDBX_STRUCT_ASSEMBLY',
                                 'TABLE_NAME': 'pdbx_struct_assembly',
                                 'TABLE_TYPE': 'transactional'},
        'PDBX_STRUCT_ASSEMBLY_GEN': {'ATTRIBUTES': {'ASSEMBLY_ID': 'assembly_id',
                                                    'ASYM_ID_LIST': 'asym_id_list',
                                                    'AUTH_ASYM_ID_LIST': 'auth_asym_id_list',
                                                    'ENTITY_INST_ID': 'entity_inst_id',
                                                    'OPER_EXPRESSION': 'oper_expression',
                                                    'STRUCTURE_ID': 'Structure_ID'},
                                     'ATTRIBUTE_INFO': {'ASSEMBLY_ID': {'NULLABLE': False,
                                                                        'ORDER': 2,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': True,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 80},
                                                        'ASYM_ID_LIST': {'NULLABLE': False,
                                                                         'ORDER': 4,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': True,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 160},
                                                        'AUTH_ASYM_ID_LIST': {'NULLABLE': True,
                                                                              'ORDER': 5,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 80},
                                                        'ENTITY_INST_ID': {'NULLABLE': True,
                                                                           'ORDER': 3,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10},
                                                        'OPER_EXPRESSION': {'NULLABLE': False,
                                                                            'ORDER': 6,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': True,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 128},
                                                        'STRUCTURE_ID': {'NULLABLE': False,
                                                                         'ORDER': 1,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': True,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10}},
                                     'ATTRIBUTE_MAP': {'ASSEMBLY_ID': ('pdbx_struct_assembly_gen', 'assembly_id', None, None),
                                                       'ASYM_ID_LIST': ('pdbx_struct_assembly_gen',
                                                                        'asym_id_list',
                                                                        None,
                                                                        None),
                                                       'AUTH_ASYM_ID_LIST': ('pdbx_struct_assembly_gen',
                                                                             'auth_asym_id_list',
                                                                             None,
                                                                             None),
                                                       'ENTITY_INST_ID': ('pdbx_struct_assembly_gen',
                                                                          'entity_inst_id',
                                                                          None,
                                                                          None),
                                                       'OPER_EXPRESSION': ('pdbx_struct_assembly_gen',
                                                                           'oper_expression',
                                                                           None,
                                                                           None),
                                                       'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                     'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID',
                                                                       'ASSEMBLY_ID',
                                                                       'ASYM_ID_LIST',
                                                                       'OPER_EXPRESSION'),
                                                        'TYPE': 'UNIQUE'},
                                                 's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                     'MAP_MERGE_INDICES': {'pdbx_struct_assembly_gen': {'ATTRIBUTES': ('assembly_id',
                                                                                                       'asym_id_list',
                                                                                                       'oper_expression'),
                                                                                        'TYPE': 'EQUI-JOIN'}},
                                     'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                     'TABLE_ID': 'PDBX_STRUCT_ASSEMBLY_GEN',
                                     'TABLE_NAME': 'pdbx_struct_assembly_gen',
                                     'TABLE_TYPE': 'transactional'},
        'PDBX_STRUCT_ASSEMBLY_PROP': {'ATTRIBUTES': {'BIOL_ID': 'biol_id',
                                                     'DETAILS': 'details',
                                                     'STRUCTURE_ID': 'Structure_ID',
                                                     'TYPE': 'type',
                                                     'VALUE': 'value'},
                                      'ATTRIBUTE_INFO': {'BIOL_ID': {'NULLABLE': False,
                                                                     'ORDER': 2,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': True,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                                         'DETAILS': {'NULLABLE': True,
                                                                     'ORDER': 5,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 200},
                                                         'STRUCTURE_ID': {'NULLABLE': False,
                                                                          'ORDER': 1,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': True,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                         'TYPE': {'NULLABLE': False,
                                                                  'ORDER': 3,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': True,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 80},
                                                         'VALUE': {'NULLABLE': True,
                                                                   'ORDER': 4,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 200}},
                                      'ATTRIBUTE_MAP': {'BIOL_ID': ('pdbx_struct_assembly_prop', 'biol_id', None, None),
                                                        'DETAILS': ('pdbx_struct_assembly_prop', 'details', None, None),
                                                        'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                        'TYPE': ('pdbx_struct_assembly_prop', 'type', None, None),
                                                        'VALUE': ('pdbx_struct_assembly_prop', 'value', None, None)},
                                      'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'BIOL_ID', 'TYPE'), 'TYPE': 'UNIQUE'},
                                                  's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                      'MAP_MERGE_INDICES': {'pdbx_struct_assembly_prop': {'ATTRIBUTES': ('biol_id', 'type'),
                                                                                          'TYPE': 'EQUI-JOIN'}},
                                      'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                      'TABLE_ID': 'PDBX_STRUCT_ASSEMBLY_PROP',
                                      'TABLE_NAME': 'pdbx_struct_assembly_prop',
                                      'TABLE_TYPE': 'transactional'},
        'PDBX_STRUCT_ASYM_GEN': {'ATTRIBUTES': {'ASYM_ID': 'asym_id',
                                                'ENTITY_INST_ID': 'entity_inst_id',
                                                'OPER_EXPRESSION': 'oper_expression',
                                                'STRUCTURE_ID': 'Structure_ID'},
                                 'ATTRIBUTE_INFO': {'ASYM_ID': {'NULLABLE': True,
                                                                'ORDER': 3,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                                    'ENTITY_INST_ID': {'NULLABLE': False,
                                                                       'ORDER': 2,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': True,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                    'OPER_EXPRESSION': {'NULLABLE': False,
                                                                        'ORDER': 4,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': True,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 30},
                                                    'STRUCTURE_ID': {'NULLABLE': False,
                                                                     'ORDER': 1,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': True,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10}},
                                 'ATTRIBUTE_MAP': {'ASYM_ID': ('pdbx_struct_asym_gen', 'asym_id', None, None),
                                                   'ENTITY_INST_ID': ('pdbx_struct_asym_gen', 'entity_inst_id', None, None),
                                                   'OPER_EXPRESSION': ('pdbx_struct_asym_gen', 'oper_expression', None, None),
                                                   'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                 'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTITY_INST_ID', 'OPER_EXPRESSION'),
                                                    'TYPE': 'UNIQUE'},
                                             's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                 'MAP_MERGE_INDICES': {'pdbx_struct_asym_gen': {'ATTRIBUTES': ('entity_inst_id',
                                                                                               'oper_expression'),
                                                                                'TYPE': 'EQUI-JOIN'}},
                                 'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                 'TABLE_ID': 'PDBX_STRUCT_ASYM_GEN',
                                 'TABLE_NAME': 'pdbx_struct_asym_gen',
                                 'TABLE_TYPE': 'transactional'},
        'PDBX_STRUCT_CHEM_COMP_DIAGNOSTICS': {'ATTRIBUTES': {'ASYM_ID': 'asym_id',
                                                             'AUTH_COMP_ID': 'auth_comp_id',
                                                             'AUTH_SEQ_ID': 'auth_seq_id',
                                                             'DETAILS': 'details',
                                                             'ORDINAL': 'ordinal',
                                                             'PDB_INS_CODE': 'pdb_ins_code',
                                                             'PDB_STRAND_ID': 'pdb_strand_id',
                                                             'SEQ_NUM': 'seq_num',
                                                             'STRUCTURE_ID': 'Structure_ID',
                                                             'TYPE': 'type'},
                                              'ATTRIBUTE_INFO': {'ASYM_ID': {'NULLABLE': True,
                                                                             'ORDER': 5,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                                 'AUTH_COMP_ID': {'NULLABLE': True,
                                                                                  'ORDER': 8,
                                                                                  'PRECISION': 0,
                                                                                  'PRIMARY_KEY': False,
                                                                                  'SQL_TYPE': 'VARCHAR',
                                                                                  'WIDTH': 10},
                                                                 'AUTH_SEQ_ID': {'NULLABLE': True,
                                                                                 'ORDER': 6,
                                                                                 'PRECISION': 0,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'VARCHAR',
                                                                                 'WIDTH': 10},
                                                                 'DETAILS': {'NULLABLE': True,
                                                                             'ORDER': 2,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 200},
                                                                 'ORDINAL': {'NULLABLE': False,
                                                                             'ORDER': 10,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': True,
                                                                             'SQL_TYPE': 'INT',
                                                                             'WIDTH': 10},
                                                                 'PDB_INS_CODE': {'NULLABLE': True,
                                                                                  'ORDER': 9,
                                                                                  'PRECISION': 0,
                                                                                  'PRIMARY_KEY': False,
                                                                                  'SQL_TYPE': 'VARCHAR',
                                                                                  'WIDTH': 10},
                                                                 'PDB_STRAND_ID': {'NULLABLE': True,
                                                                                   'ORDER': 4,
                                                                                   'PRECISION': 0,
                                                                                   'PRIMARY_KEY': False,
                                                                                   'SQL_TYPE': 'VARCHAR',
                                                                                   'WIDTH': 10},
                                                                 'SEQ_NUM': {'NULLABLE': True,
                                                                             'ORDER': 7,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'INT',
                                                                             'WIDTH': 10},
                                                                 'STRUCTURE_ID': {'NULLABLE': False,
                                                                                  'ORDER': 1,
                                                                                  'PRECISION': 0,
                                                                                  'PRIMARY_KEY': True,
                                                                                  'SQL_TYPE': 'VARCHAR',
                                                                                  'WIDTH': 10},
                                                                 'TYPE': {'NULLABLE': True,
                                                                          'ORDER': 3,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 80}},
                                              'ATTRIBUTE_MAP': {'ASYM_ID': ('pdbx_struct_chem_comp_diagnostics',
                                                                            'asym_id',
                                                                            None,
                                                                            None),
                                                                'AUTH_COMP_ID': ('pdbx_struct_chem_comp_diagnostics',
                                                                                 'auth_comp_id',
                                                                                 None,
                                                                                 None),
                                                                'AUTH_SEQ_ID': ('pdbx_struct_chem_comp_diagnostics',
                                                                                'auth_seq_id',
                                                                                None,
                                                                                None),
                                                                'DETAILS': ('pdbx_struct_chem_comp_diagnostics',
                                                                            'details',
                                                                            None,
                                                                            None),
                                                                'ORDINAL': ('pdbx_struct_chem_comp_diagnostics',
                                                                            'ordinal',
                                                                            None,
                                                                            None),
                                                                'PDB_INS_CODE': ('pdbx_struct_chem_comp_diagnostics',
                                                                                 'pdb_ins_code',
                                                                                 None,
                                                                                 None),
                                                                'PDB_STRAND_ID': ('pdbx_struct_chem_comp_diagnostics',
                                                                                  'pdb_strand_id',
                                                                                  None,
                                                                                  None),
                                                                'SEQ_NUM': ('pdbx_struct_chem_comp_diagnostics',
                                                                            'seq_num',
                                                                            None,
                                                                            None),
                                                                'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                                'TYPE': ('pdbx_struct_chem_comp_diagnostics',
                                                                         'type',
                                                                         None,
                                                                         None)},
                                              'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ORDINAL'), 'TYPE': 'UNIQUE'},
                                                          's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                              'MAP_MERGE_INDICES': {'pdbx_struct_chem_comp_diagnostics': {'ATTRIBUTES': ('ordinal',),
                                                                                                          'TYPE': 'EQUI-JOIN'}},
                                              'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                              'TABLE_ID': 'PDBX_STRUCT_CHEM_COMP_DIAGNOSTICS',
                                              'TABLE_NAME': 'pdbx_struct_chem_comp_diagnostics',
                                              'TABLE_TYPE': 'transactional'},
        'PDBX_STRUCT_CHEM_COMP_FEATURE': {'ATTRIBUTES': {'ASYM_ID': 'asym_id',
                                                         'AUTH_COMP_ID': 'auth_comp_id',
                                                         'AUTH_SEQ_ID': 'auth_seq_id',
                                                         'DETAILS': 'details',
                                                         'ORDINAL': 'ordinal',
                                                         'PDB_INS_CODE': 'pdb_ins_code',
                                                         'PDB_STRAND_ID': 'pdb_strand_id',
                                                         'SEQ_NUM': 'seq_num',
                                                         'STRUCTURE_ID': 'Structure_ID',
                                                         'TYPE': 'type'},
                                          'ATTRIBUTE_INFO': {'ASYM_ID': {'NULLABLE': True,
                                                                         'ORDER': 5,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                                             'AUTH_COMP_ID': {'NULLABLE': True,
                                                                              'ORDER': 8,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                                             'AUTH_SEQ_ID': {'NULLABLE': True,
                                                                             'ORDER': 6,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                             'DETAILS': {'NULLABLE': True,
                                                                         'ORDER': 2,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 200},
                                                             'ORDINAL': {'NULLABLE': False,
                                                                         'ORDER': 10,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': True,
                                                                         'SQL_TYPE': 'INT',
                                                                         'WIDTH': 10},
                                                             'PDB_INS_CODE': {'NULLABLE': True,
                                                                              'ORDER': 9,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                                             'PDB_STRAND_ID': {'NULLABLE': True,
                                                                               'ORDER': 4,
                                                                               'PRECISION': 0,
                                                                               'PRIMARY_KEY': False,
                                                                               'SQL_TYPE': 'VARCHAR',
                                                                               'WIDTH': 10},
                                                             'SEQ_NUM': {'NULLABLE': True,
                                                                         'ORDER': 7,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'INT',
                                                                         'WIDTH': 10},
                                                             'STRUCTURE_ID': {'NULLABLE': False,
                                                                              'ORDER': 1,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': True,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                                             'TYPE': {'NULLABLE': True,
                                                                      'ORDER': 3,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 80}},
                                          'ATTRIBUTE_MAP': {'ASYM_ID': ('pdbx_struct_chem_comp_feature',
                                                                        'asym_id',
                                                                        None,
                                                                        None),
                                                            'AUTH_COMP_ID': ('pdbx_struct_chem_comp_feature',
                                                                             'auth_comp_id',
                                                                             None,
                                                                             None),
                                                            'AUTH_SEQ_ID': ('pdbx_struct_chem_comp_feature',
                                                                            'auth_seq_id',
                                                                            None,
                                                                            None),
                                                            'DETAILS': ('pdbx_struct_chem_comp_feature',
                                                                        'details',
                                                                        None,
                                                                        None),
                                                            'ORDINAL': ('pdbx_struct_chem_comp_feature',
                                                                        'ordinal',
                                                                        None,
                                                                        None),
                                                            'PDB_INS_CODE': ('pdbx_struct_chem_comp_feature',
                                                                             'pdb_ins_code',
                                                                             None,
                                                                             None),
                                                            'PDB_STRAND_ID': ('pdbx_struct_chem_comp_feature',
                                                                              'pdb_strand_id',
                                                                              None,
                                                                              None),
                                                            'SEQ_NUM': ('pdbx_struct_chem_comp_feature',
                                                                        'seq_num',
                                                                        None,
                                                                        None),
                                                            'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                            'TYPE': ('pdbx_struct_chem_comp_feature', 'type', None, None)},
                                          'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ORDINAL'), 'TYPE': 'UNIQUE'},
                                                      's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                          'MAP_MERGE_INDICES': {'pdbx_struct_chem_comp_feature': {'ATTRIBUTES': ('ordinal',),
                                                                                                  'TYPE': 'EQUI-JOIN'}},
                                          'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                          'TABLE_ID': 'PDBX_STRUCT_CHEM_COMP_FEATURE',
                                          'TABLE_NAME': 'pdbx_struct_chem_comp_feature',
                                          'TABLE_TYPE': 'transactional'},
        'PDBX_STRUCT_CONN_ANGLE': {'ATTRIBUTES': {'ID': 'id',
                                                  'PTNR1_AUTH_ALT_ID': 'ptnr1_auth_alt_id',
                                                  'PTNR1_AUTH_ASYM_ID': 'ptnr1_auth_asym_id',
                                                  'PTNR1_AUTH_ATOM_ID': 'ptnr1_auth_atom_id',
                                                  'PTNR1_AUTH_COMP_ID': 'ptnr1_auth_comp_id',
                                                  'PTNR1_AUTH_SEQ_ID': 'ptnr1_auth_seq_id',
                                                  'PTNR1_LABEL_ALT_ID': 'ptnr1_label_alt_id',
                                                  'PTNR1_LABEL_ASYM_ID': 'ptnr1_label_asym_id',
                                                  'PTNR1_LABEL_ATOM_ID': 'ptnr1_label_atom_id',
                                                  'PTNR1_LABEL_COMP_ID': 'ptnr1_label_comp_id',
                                                  'PTNR1_LABEL_SEQ_ID': 'ptnr1_label_seq_id',
                                                  'PTNR1_PDB_INS_CODE': 'ptnr1_PDB_ins_code',
                                                  'PTNR1_SYMMETRY': 'ptnr1_symmetry',
                                                  'PTNR2_AUTH_ALT_ID': 'ptnr2_auth_alt_id',
                                                  'PTNR2_AUTH_ASYM_ID': 'ptnr2_auth_asym_id',
                                                  'PTNR2_AUTH_ATOM_ID': 'ptnr2_auth_atom_id',
                                                  'PTNR2_AUTH_COMP_ID': 'ptnr2_auth_comp_id',
                                                  'PTNR2_AUTH_SEQ_ID': 'ptnr2_auth_seq_id',
                                                  'PTNR2_LABEL_ALT_ID': 'ptnr2_label_alt_id',
                                                  'PTNR2_LABEL_ASYM_ID': 'ptnr2_label_asym_id',
                                                  'PTNR2_LABEL_ATOM_ID': 'ptnr2_label_atom_id',
                                                  'PTNR2_LABEL_COMP_ID': 'ptnr2_label_comp_id',
                                                  'PTNR2_LABEL_SEQ_ID': 'ptnr2_label_seq_id',
                                                  'PTNR2_PDB_INS_CODE': 'ptnr2_PDB_ins_code',
                                                  'PTNR2_SYMMETRY': 'ptnr2_symmetry',
                                                  'PTNR3_AUTH_ALT_ID': 'ptnr3_auth_alt_id',
                                                  'PTNR3_AUTH_ASYM_ID': 'ptnr3_auth_asym_id',
                                                  'PTNR3_AUTH_ATOM_ID': 'ptnr3_auth_atom_id',
                                                  'PTNR3_AUTH_COMP_ID': 'ptnr3_auth_comp_id',
                                                  'PTNR3_AUTH_SEQ_ID': 'ptnr3_auth_seq_id',
                                                  'PTNR3_LABEL_ALT_ID': 'ptnr3_label_alt_id',
                                                  'PTNR3_LABEL_ASYM_ID': 'ptnr3_label_asym_id',
                                                  'PTNR3_LABEL_ATOM_ID': 'ptnr3_label_atom_id',
                                                  'PTNR3_LABEL_COMP_ID': 'ptnr3_label_comp_id',
                                                  'PTNR3_LABEL_SEQ_ID': 'ptnr3_label_seq_id',
                                                  'PTNR3_PDB_INS_CODE': 'ptnr3_PDB_ins_code',
                                                  'STRUCTURE_ID': 'Structure_ID',
                                                  'VALUE': 'value',
                                                  'VALUE_ESD': 'value_esd'},
                                   'ATTRIBUTE_INFO': {'ID': {'NULLABLE': False,
                                                             'ORDER': 2,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 10},
                                                      'PTNR1_AUTH_ALT_ID': {'NULLABLE': True,
                                                                            'ORDER': 24,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 10},
                                                      'PTNR1_AUTH_ASYM_ID': {'NULLABLE': True,
                                                                             'ORDER': 8,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                      'PTNR1_AUTH_ATOM_ID': {'NULLABLE': True,
                                                                             'ORDER': 9,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 6},
                                                      'PTNR1_AUTH_COMP_ID': {'NULLABLE': True,
                                                                             'ORDER': 10,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                      'PTNR1_AUTH_SEQ_ID': {'NULLABLE': True,
                                                                            'ORDER': 11,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 10},
                                                      'PTNR1_LABEL_ALT_ID': {'NULLABLE': True,
                                                                             'ORDER': 3,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                      'PTNR1_LABEL_ASYM_ID': {'NULLABLE': True,
                                                                              'ORDER': 4,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                                      'PTNR1_LABEL_ATOM_ID': {'NULLABLE': True,
                                                                              'ORDER': 5,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 6},
                                                      'PTNR1_LABEL_COMP_ID': {'NULLABLE': True,
                                                                              'ORDER': 6,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                                      'PTNR1_LABEL_SEQ_ID': {'NULLABLE': True,
                                                                             'ORDER': 7,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'INT',
                                                                             'WIDTH': 10},
                                                      'PTNR1_PDB_INS_CODE': {'NULLABLE': True,
                                                                             'ORDER': 23,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                      'PTNR1_SYMMETRY': {'NULLABLE': True,
                                                                         'ORDER': 12,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                                      'PTNR2_AUTH_ALT_ID': {'NULLABLE': True,
                                                                            'ORDER': 26,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 10},
                                                      'PTNR2_AUTH_ASYM_ID': {'NULLABLE': True,
                                                                             'ORDER': 18,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                      'PTNR2_AUTH_ATOM_ID': {'NULLABLE': True,
                                                                             'ORDER': 19,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 6},
                                                      'PTNR2_AUTH_COMP_ID': {'NULLABLE': True,
                                                                             'ORDER': 20,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                      'PTNR2_AUTH_SEQ_ID': {'NULLABLE': True,
                                                                            'ORDER': 21,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 10},
                                                      'PTNR2_LABEL_ALT_ID': {'NULLABLE': True,
                                                                             'ORDER': 13,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                      'PTNR2_LABEL_ASYM_ID': {'NULLABLE': True,
                                                                              'ORDER': 14,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                                      'PTNR2_LABEL_ATOM_ID': {'NULLABLE': True,
                                                                              'ORDER': 15,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 6},
                                                      'PTNR2_LABEL_COMP_ID': {'NULLABLE': True,
                                                                              'ORDER': 16,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                                      'PTNR2_LABEL_SEQ_ID': {'NULLABLE': True,
                                                                             'ORDER': 17,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'INT',
                                                                             'WIDTH': 10},
                                                      'PTNR2_PDB_INS_CODE': {'NULLABLE': True,
                                                                             'ORDER': 25,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                      'PTNR2_SYMMETRY': {'NULLABLE': True,
                                                                         'ORDER': 22,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                                      'PTNR3_AUTH_ALT_ID': {'NULLABLE': True,
                                                                            'ORDER': 27,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 10},
                                                      'PTNR3_AUTH_ASYM_ID': {'NULLABLE': True,
                                                                             'ORDER': 28,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                      'PTNR3_AUTH_ATOM_ID': {'NULLABLE': True,
                                                                             'ORDER': 29,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 6},
                                                      'PTNR3_AUTH_COMP_ID': {'NULLABLE': True,
                                                                             'ORDER': 30,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                      'PTNR3_AUTH_SEQ_ID': {'NULLABLE': True,
                                                                            'ORDER': 32,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 10},
                                                      'PTNR3_LABEL_ALT_ID': {'NULLABLE': True,
                                                                             'ORDER': 33,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                      'PTNR3_LABEL_ASYM_ID': {'NULLABLE': True,
                                                                              'ORDER': 34,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                                      'PTNR3_LABEL_ATOM_ID': {'NULLABLE': True,
                                                                              'ORDER': 35,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 6},
                                                      'PTNR3_LABEL_COMP_ID': {'NULLABLE': True,
                                                                              'ORDER': 36,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                                      'PTNR3_LABEL_SEQ_ID': {'NULLABLE': True,
                                                                             'ORDER': 37,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'INT',
                                                                             'WIDTH': 10},
                                                      'PTNR3_PDB_INS_CODE': {'NULLABLE': True,
                                                                             'ORDER': 31,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                      'STRUCTURE_ID': {'NULLABLE': False,
                                                                       'ORDER': 1,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': True,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                      'VALUE': {'NULLABLE': True,
                                                                'ORDER': 38,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                                      'VALUE_ESD': {'NULLABLE': True,
                                                                    'ORDER': 39,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10}},
                                   'ATTRIBUTE_MAP': {'ID': ('pdbx_struct_conn_angle', 'id', None, None),
                                                     'PTNR1_AUTH_ALT_ID': ('pdbx_struct_conn_angle',
                                                                           'ptnr1_auth_alt_id',
                                                                           None,
                                                                           None),
                                                     'PTNR1_AUTH_ASYM_ID': ('pdbx_struct_conn_angle',
                                                                            'ptnr1_auth_asym_id',
                                                                            None,
                                                                            None),
                                                     'PTNR1_AUTH_ATOM_ID': ('pdbx_struct_conn_angle',
                                                                            'ptnr1_auth_atom_id',
                                                                            None,
                                                                            None),
                                                     'PTNR1_AUTH_COMP_ID': ('pdbx_struct_conn_angle',
                                                                            'ptnr1_auth_comp_id',
                                                                            None,
                                                                            None),
                                                     'PTNR1_AUTH_SEQ_ID': ('pdbx_struct_conn_angle',
                                                                           'ptnr1_auth_seq_id',
                                                                           None,
                                                                           None),
                                                     'PTNR1_LABEL_ALT_ID': ('pdbx_struct_conn_angle',
                                                                            'ptnr1_label_alt_id',
                                                                            None,
                                                                            None),
                                                     'PTNR1_LABEL_ASYM_ID': ('pdbx_struct_conn_angle',
                                                                             'ptnr1_label_asym_id',
                                                                             None,
                                                                             None),
                                                     'PTNR1_LABEL_ATOM_ID': ('pdbx_struct_conn_angle',
                                                                             'ptnr1_label_atom_id',
                                                                             None,
                                                                             None),
                                                     'PTNR1_LABEL_COMP_ID': ('pdbx_struct_conn_angle',
                                                                             'ptnr1_label_comp_id',
                                                                             None,
                                                                             None),
                                                     'PTNR1_LABEL_SEQ_ID': ('pdbx_struct_conn_angle',
                                                                            'ptnr1_label_seq_id',
                                                                            None,
                                                                            None),
                                                     'PTNR1_PDB_INS_CODE': ('pdbx_struct_conn_angle',
                                                                            'ptnr1_PDB_ins_code',
                                                                            None,
                                                                            None),
                                                     'PTNR1_SYMMETRY': ('pdbx_struct_conn_angle',
                                                                        'ptnr1_symmetry',
                                                                        None,
                                                                        None),
                                                     'PTNR2_AUTH_ALT_ID': ('pdbx_struct_conn_angle',
                                                                           'ptnr2_auth_alt_id',
                                                                           None,
                                                                           None),
                                                     'PTNR2_AUTH_ASYM_ID': ('pdbx_struct_conn_angle',
                                                                            'ptnr2_auth_asym_id',
                                                                            None,
                                                                            None),
                                                     'PTNR2_AUTH_ATOM_ID': ('pdbx_struct_conn_angle',
                                                                            'ptnr2_auth_atom_id',
                                                                            None,
                                                                            None),
                                                     'PTNR2_AUTH_COMP_ID': ('pdbx_struct_conn_angle',
                                                                            'ptnr2_auth_comp_id',
                                                                            None,
                                                                            None),
                                                     'PTNR2_AUTH_SEQ_ID': ('pdbx_struct_conn_angle',
                                                                           'ptnr2_auth_seq_id',
                                                                           None,
                                                                           None),
                                                     'PTNR2_LABEL_ALT_ID': ('pdbx_struct_conn_angle',
                                                                            'ptnr2_label_alt_id',
                                                                            None,
                                                                            None),
                                                     'PTNR2_LABEL_ASYM_ID': ('pdbx_struct_conn_angle',
                                                                             'ptnr2_label_asym_id',
                                                                             None,
                                                                             None),
                                                     'PTNR2_LABEL_ATOM_ID': ('pdbx_struct_conn_angle',
                                                                             'ptnr2_label_atom_id',
                                                                             None,
                                                                             None),
                                                     'PTNR2_LABEL_COMP_ID': ('pdbx_struct_conn_angle',
                                                                             'ptnr2_label_comp_id',
                                                                             None,
                                                                             None),
                                                     'PTNR2_LABEL_SEQ_ID': ('pdbx_struct_conn_angle',
                                                                            'ptnr2_label_seq_id',
                                                                            None,
                                                                            None),
                                                     'PTNR2_PDB_INS_CODE': ('pdbx_struct_conn_angle',
                                                                            'ptnr2_PDB_ins_code',
                                                                            None,
                                                                            None),
                                                     'PTNR2_SYMMETRY': ('pdbx_struct_conn_angle',
                                                                        'ptnr2_symmetry',
                                                                        None,
                                                                        None),
                                                     'PTNR3_AUTH_ALT_ID': ('pdbx_struct_conn_angle',
                                                                           'ptnr3_auth_alt_id',
                                                                           None,
                                                                           None),
                                                     'PTNR3_AUTH_ASYM_ID': ('pdbx_struct_conn_angle',
                                                                            'ptnr3_auth_asym_id',
                                                                            None,
                                                                            None),
                                                     'PTNR3_AUTH_ATOM_ID': ('pdbx_struct_conn_angle',
                                                                            'ptnr3_auth_atom_id',
                                                                            None,
                                                                            None),
                                                     'PTNR3_AUTH_COMP_ID': ('pdbx_struct_conn_angle',
                                                                            'ptnr3_auth_comp_id',
                                                                            None,
                                                                            None),
                                                     'PTNR3_AUTH_SEQ_ID': ('pdbx_struct_conn_angle',
                                                                           'ptnr3_auth_seq_id',
                                                                           None,
                                                                           None),
                                                     'PTNR3_LABEL_ALT_ID': ('pdbx_struct_conn_angle',
                                                                            'ptnr3_label_alt_id',
                                                                            None,
                                                                            None),
                                                     'PTNR3_LABEL_ASYM_ID': ('pdbx_struct_conn_angle',
                                                                             'ptnr3_label_asym_id',
                                                                             None,
                                                                             None),
                                                     'PTNR3_LABEL_ATOM_ID': ('pdbx_struct_conn_angle',
                                                                             'ptnr3_label_atom_id',
                                                                             None,
                                                                             None),
                                                     'PTNR3_LABEL_COMP_ID': ('pdbx_struct_conn_angle',
                                                                             'ptnr3_label_comp_id',
                                                                             None,
                                                                             None),
                                                     'PTNR3_LABEL_SEQ_ID': ('pdbx_struct_conn_angle',
                                                                            'ptnr3_label_seq_id',
                                                                            None,
                                                                            None),
                                                     'PTNR3_PDB_INS_CODE': ('pdbx_struct_conn_angle',
                                                                            'ptnr3_PDB_ins_code',
                                                                            None,
                                                                            None),
                                                     'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                     'VALUE': ('pdbx_struct_conn_angle', 'value', None, None),
                                                     'VALUE_ESD': ('pdbx_struct_conn_angle', 'value_esd', None, None)},
                                   'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                               's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                   'MAP_MERGE_INDICES': {'pdbx_struct_conn_angle': {'ATTRIBUTES': ('id',),
                                                                                    'TYPE': 'EQUI-JOIN'}},
                                   'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                   'TABLE_ID': 'PDBX_STRUCT_CONN_ANGLE',
                                   'TABLE_NAME': 'pdbx_struct_conn_angle',
                                   'TABLE_TYPE': 'transactional'},
        'PDBX_STRUCT_ENTITY_INST': {'ATTRIBUTES': {'DETAILS': 'details',
                                                   'ENTITY_ID': 'entity_id',
                                                   'ID': 'id',
                                                   'STRUCTURE_ID': 'Structure_ID'},
                                    'ATTRIBUTE_INFO': {'DETAILS': {'NULLABLE': True,
                                                                   'ORDER': 2,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 200},
                                                       'ENTITY_ID': {'NULLABLE': True,
                                                                     'ORDER': 3,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                                       'ID': {'NULLABLE': False,
                                                              'ORDER': 4,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10},
                                                       'STRUCTURE_ID': {'NULLABLE': False,
                                                                        'ORDER': 1,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': True,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10}},
                                    'ATTRIBUTE_MAP': {'DETAILS': ('pdbx_struct_entity_inst', 'details', None, None),
                                                      'ENTITY_ID': ('pdbx_struct_entity_inst', 'entity_id', None, None),
                                                      'ID': ('pdbx_struct_entity_inst', 'id', None, None),
                                                      'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                    'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                                's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                    'MAP_MERGE_INDICES': {'pdbx_struct_entity_inst': {'ATTRIBUTES': ('id',),
                                                                                      'TYPE': 'EQUI-JOIN'}},
                                    'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                    'TABLE_ID': 'PDBX_STRUCT_ENTITY_INST',
                                    'TABLE_NAME': 'pdbx_struct_entity_inst',
                                    'TABLE_TYPE': 'transactional'},
        'PDBX_STRUCT_GROUP_COMPONENTS': {'ATTRIBUTES': {'AUTH_ASYM_ID': 'auth_asym_id',
                                                        'AUTH_COMP_ID': 'auth_comp_id',
                                                        'AUTH_SEQ_ID': 'auth_seq_id',
                                                        'LABEL_ALT_ID': 'label_alt_id',
                                                        'LABEL_ASYM_ID': 'label_asym_id',
                                                        'LABEL_COMP_ID': 'label_comp_id',
                                                        'LABEL_SEQ_ID': 'label_seq_id',
                                                        'ORDINAL': 'ordinal',
                                                        'PDB_INS_CODE': 'PDB_ins_code',
                                                        'PDB_MODEL_NUM': 'PDB_model_num',
                                                        'STRUCTURE_ID': 'Structure_ID',
                                                        'STRUCT_GROUP_ID': 'struct_group_id'},
                                         'ATTRIBUTE_INFO': {'AUTH_ASYM_ID': {'NULLABLE': True,
                                                                             'ORDER': 5,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                            'AUTH_COMP_ID': {'NULLABLE': True,
                                                                             'ORDER': 6,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                            'AUTH_SEQ_ID': {'NULLABLE': True,
                                                                            'ORDER': 7,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 10},
                                                            'LABEL_ALT_ID': {'NULLABLE': True,
                                                                             'ORDER': 12,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                            'LABEL_ASYM_ID': {'NULLABLE': True,
                                                                              'ORDER': 9,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                                            'LABEL_COMP_ID': {'NULLABLE': True,
                                                                              'ORDER': 10,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                                            'LABEL_SEQ_ID': {'NULLABLE': True,
                                                                             'ORDER': 11,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'INT',
                                                                             'WIDTH': 10},
                                                            'ORDINAL': {'NULLABLE': False,
                                                                        'ORDER': 2,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': True,
                                                                        'SQL_TYPE': 'INT',
                                                                        'WIDTH': 10},
                                                            'PDB_INS_CODE': {'NULLABLE': True,
                                                                             'ORDER': 8,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                            'PDB_MODEL_NUM': {'NULLABLE': True,
                                                                              'ORDER': 4,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'INT',
                                                                              'WIDTH': 10},
                                                            'STRUCTURE_ID': {'NULLABLE': False,
                                                                             'ORDER': 1,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': True,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                            'STRUCT_GROUP_ID': {'NULLABLE': True,
                                                                                'ORDER': 3,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 10}},
                                         'ATTRIBUTE_MAP': {'AUTH_ASYM_ID': ('pdbx_struct_group_components',
                                                                            'auth_asym_id',
                                                                            None,
                                                                            None),
                                                           'AUTH_COMP_ID': ('pdbx_struct_group_components',
                                                                            'auth_comp_id',
                                                                            None,
                                                                            None),
                                                           'AUTH_SEQ_ID': ('pdbx_struct_group_components',
                                                                           'auth_seq_id',
                                                                           None,
                                                                           None),
                                                           'LABEL_ALT_ID': ('pdbx_struct_group_components',
                                                                            'label_alt_id',
                                                                            None,
                                                                            None),
                                                           'LABEL_ASYM_ID': ('pdbx_struct_group_components',
                                                                             'label_asym_id',
                                                                             None,
                                                                             None),
                                                           'LABEL_COMP_ID': ('pdbx_struct_group_components',
                                                                             'label_comp_id',
                                                                             None,
                                                                             None),
                                                           'LABEL_SEQ_ID': ('pdbx_struct_group_components',
                                                                            'label_seq_id',
                                                                            None,
                                                                            None),
                                                           'ORDINAL': ('pdbx_struct_group_components', 'ordinal', None, None),
                                                           'PDB_INS_CODE': ('pdbx_struct_group_components',
                                                                            'PDB_ins_code',
                                                                            None,
                                                                            None),
                                                           'PDB_MODEL_NUM': ('pdbx_struct_group_components',
                                                                             'PDB_model_num',
                                                                             None,
                                                                             None),
                                                           'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                           'STRUCT_GROUP_ID': ('pdbx_struct_group_components',
                                                                               'struct_group_id',
                                                                               None,
                                                                               None)},
                                         'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ORDINAL'), 'TYPE': 'UNIQUE'},
                                                     's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                         'MAP_MERGE_INDICES': {'pdbx_struct_group_components': {'ATTRIBUTES': ('ordinal',),
                                                                                                'TYPE': 'EQUI-JOIN'}},
                                         'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                         'TABLE_ID': 'PDBX_STRUCT_GROUP_COMPONENTS',
                                         'TABLE_NAME': 'pdbx_struct_group_components',
                                         'TABLE_TYPE': 'transactional'},
        'PDBX_STRUCT_GROUP_COMPONENT_RANGE': {'ATTRIBUTES': {'BEG_AUTH_ASYM_ID': 'beg_auth_asym_id',
                                                             'BEG_AUTH_COMP_ID': 'beg_auth_comp_id',
                                                             'BEG_AUTH_SEQ_ID': 'beg_auth_seq_id',
                                                             'BEG_LABEL_ALT_ID': 'beg_label_alt_id',
                                                             'BEG_LABEL_ASYM_ID': 'beg_label_asym_id',
                                                             'BEG_LABEL_COMP_ID': 'beg_label_comp_id',
                                                             'BEG_LABEL_SEQ_ID': 'beg_label_seq_id',
                                                             'BEG_PDB_INS_CODE': 'beg_PDB_ins_code',
                                                             'END_AUTH_ASYM_ID': 'end_auth_asym_id',
                                                             'END_AUTH_COMP_ID': 'end_auth_comp_id',
                                                             'END_AUTH_SEQ_ID': 'end_auth_seq_id',
                                                             'END_LABEL_ALT_ID': 'end_label_alt_id',
                                                             'END_LABEL_ASYM_ID': 'end_label_asym_id',
                                                             'END_LABEL_COMP_ID': 'end_label_comp_id',
                                                             'END_LABEL_SEQ_ID': 'end_label_seq_id',
                                                             'END_PDB_INS_CODE': 'end_PDB_ins_code',
                                                             'ORDINAL': 'ordinal',
                                                             'PDB_MODEL_NUM': 'PDB_model_num',
                                                             'STRUCTURE_ID': 'Structure_ID',
                                                             'STRUCT_GROUP_ID': 'struct_group_id'},
                                              'ATTRIBUTE_INFO': {'BEG_AUTH_ASYM_ID': {'NULLABLE': True,
                                                                                      'ORDER': 5,
                                                                                      'PRECISION': 0,
                                                                                      'PRIMARY_KEY': False,
                                                                                      'SQL_TYPE': 'VARCHAR',
                                                                                      'WIDTH': 10},
                                                                 'BEG_AUTH_COMP_ID': {'NULLABLE': True,
                                                                                      'ORDER': 6,
                                                                                      'PRECISION': 0,
                                                                                      'PRIMARY_KEY': False,
                                                                                      'SQL_TYPE': 'VARCHAR',
                                                                                      'WIDTH': 10},
                                                                 'BEG_AUTH_SEQ_ID': {'NULLABLE': True,
                                                                                     'ORDER': 7,
                                                                                     'PRECISION': 0,
                                                                                     'PRIMARY_KEY': False,
                                                                                     'SQL_TYPE': 'VARCHAR',
                                                                                     'WIDTH': 10},
                                                                 'BEG_LABEL_ALT_ID': {'NULLABLE': True,
                                                                                      'ORDER': 12,
                                                                                      'PRECISION': 0,
                                                                                      'PRIMARY_KEY': False,
                                                                                      'SQL_TYPE': 'VARCHAR',
                                                                                      'WIDTH': 10},
                                                                 'BEG_LABEL_ASYM_ID': {'NULLABLE': True,
                                                                                       'ORDER': 9,
                                                                                       'PRECISION': 0,
                                                                                       'PRIMARY_KEY': False,
                                                                                       'SQL_TYPE': 'VARCHAR',
                                                                                       'WIDTH': 10},
                                                                 'BEG_LABEL_COMP_ID': {'NULLABLE': True,
                                                                                       'ORDER': 10,
                                                                                       'PRECISION': 0,
                                                                                       'PRIMARY_KEY': False,
                                                                                       'SQL_TYPE': 'VARCHAR',
                                                                                       'WIDTH': 10},
                                                                 'BEG_LABEL_SEQ_ID': {'NULLABLE': True,
                                                                                      'ORDER': 11,
                                                                                      'PRECISION': 0,
                                                                                      'PRIMARY_KEY': False,
                                                                                      'SQL_TYPE': 'INT',
                                                                                      'WIDTH': 10},
                                                                 'BEG_PDB_INS_CODE': {'NULLABLE': True,
                                                                                      'ORDER': 8,
                                                                                      'PRECISION': 0,
                                                                                      'PRIMARY_KEY': False,
                                                                                      'SQL_TYPE': 'VARCHAR',
                                                                                      'WIDTH': 10},
                                                                 'END_AUTH_ASYM_ID': {'NULLABLE': True,
                                                                                      'ORDER': 13,
                                                                                      'PRECISION': 0,
                                                                                      'PRIMARY_KEY': False,
                                                                                      'SQL_TYPE': 'VARCHAR',
                                                                                      'WIDTH': 10},
                                                                 'END_AUTH_COMP_ID': {'NULLABLE': True,
                                                                                      'ORDER': 14,
                                                                                      'PRECISION': 0,
                                                                                      'PRIMARY_KEY': False,
                                                                                      'SQL_TYPE': 'VARCHAR',
                                                                                      'WIDTH': 10},
                                                                 'END_AUTH_SEQ_ID': {'NULLABLE': True,
                                                                                     'ORDER': 15,
                                                                                     'PRECISION': 0,
                                                                                     'PRIMARY_KEY': False,
                                                                                     'SQL_TYPE': 'VARCHAR',
                                                                                     'WIDTH': 10},
                                                                 'END_LABEL_ALT_ID': {'NULLABLE': True,
                                                                                      'ORDER': 20,
                                                                                      'PRECISION': 0,
                                                                                      'PRIMARY_KEY': False,
                                                                                      'SQL_TYPE': 'VARCHAR',
                                                                                      'WIDTH': 10},
                                                                 'END_LABEL_ASYM_ID': {'NULLABLE': True,
                                                                                       'ORDER': 17,
                                                                                       'PRECISION': 0,
                                                                                       'PRIMARY_KEY': False,
                                                                                       'SQL_TYPE': 'VARCHAR',
                                                                                       'WIDTH': 10},
                                                                 'END_LABEL_COMP_ID': {'NULLABLE': True,
                                                                                       'ORDER': 18,
                                                                                       'PRECISION': 0,
                                                                                       'PRIMARY_KEY': False,
                                                                                       'SQL_TYPE': 'VARCHAR',
                                                                                       'WIDTH': 10},
                                                                 'END_LABEL_SEQ_ID': {'NULLABLE': True,
                                                                                      'ORDER': 19,
                                                                                      'PRECISION': 0,
                                                                                      'PRIMARY_KEY': False,
                                                                                      'SQL_TYPE': 'INT',
                                                                                      'WIDTH': 10},
                                                                 'END_PDB_INS_CODE': {'NULLABLE': True,
                                                                                      'ORDER': 16,
                                                                                      'PRECISION': 0,
                                                                                      'PRIMARY_KEY': False,
                                                                                      'SQL_TYPE': 'VARCHAR',
                                                                                      'WIDTH': 10},
                                                                 'ORDINAL': {'NULLABLE': False,
                                                                             'ORDER': 2,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': True,
                                                                             'SQL_TYPE': 'INT',
                                                                             'WIDTH': 10},
                                                                 'PDB_MODEL_NUM': {'NULLABLE': True,
                                                                                   'ORDER': 4,
                                                                                   'PRECISION': 0,
                                                                                   'PRIMARY_KEY': False,
                                                                                   'SQL_TYPE': 'INT',
                                                                                   'WIDTH': 10},
                                                                 'STRUCTURE_ID': {'NULLABLE': False,
                                                                                  'ORDER': 1,
                                                                                  'PRECISION': 0,
                                                                                  'PRIMARY_KEY': True,
                                                                                  'SQL_TYPE': 'VARCHAR',
                                                                                  'WIDTH': 10},
                                                                 'STRUCT_GROUP_ID': {'NULLABLE': True,
                                                                                     'ORDER': 3,
                                                                                     'PRECISION': 0,
                                                                                     'PRIMARY_KEY': False,
                                                                                     'SQL_TYPE': 'VARCHAR',
                                                                                     'WIDTH': 10}},
                                              'ATTRIBUTE_MAP': {'BEG_AUTH_ASYM_ID': ('pdbx_struct_group_component_range',
                                                                                     'beg_auth_asym_id',
                                                                                     None,
                                                                                     None),
                                                                'BEG_AUTH_COMP_ID': ('pdbx_struct_group_component_range',
                                                                                     'beg_auth_comp_id',
                                                                                     None,
                                                                                     None),
                                                                'BEG_AUTH_SEQ_ID': ('pdbx_struct_group_component_range',
                                                                                    'beg_auth_seq_id',
                                                                                    None,
                                                                                    None),
                                                                'BEG_LABEL_ALT_ID': ('pdbx_struct_group_component_range',
                                                                                     'beg_label_alt_id',
                                                                                     None,
                                                                                     None),
                                                                'BEG_LABEL_ASYM_ID': ('pdbx_struct_group_component_range',
                                                                                      'beg_label_asym_id',
                                                                                      None,
                                                                                      None),
                                                                'BEG_LABEL_COMP_ID': ('pdbx_struct_group_component_range',
                                                                                      'beg_label_comp_id',
                                                                                      None,
                                                                                      None),
                                                                'BEG_LABEL_SEQ_ID': ('pdbx_struct_group_component_range',
                                                                                     'beg_label_seq_id',
                                                                                     None,
                                                                                     None),
                                                                'BEG_PDB_INS_CODE': ('pdbx_struct_group_component_range',
                                                                                     'beg_PDB_ins_code',
                                                                                     None,
                                                                                     None),
                                                                'END_AUTH_ASYM_ID': ('pdbx_struct_group_component_range',
                                                                                     'end_auth_asym_id',
                                                                                     None,
                                                                                     None),
                                                                'END_AUTH_COMP_ID': ('pdbx_struct_group_component_range',
                                                                                     'end_auth_comp_id',
                                                                                     None,
                                                                                     None),
                                                                'END_AUTH_SEQ_ID': ('pdbx_struct_group_component_range',
                                                                                    'end_auth_seq_id',
                                                                                    None,
                                                                                    None),
                                                                'END_LABEL_ALT_ID': ('pdbx_struct_group_component_range',
                                                                                     'end_label_alt_id',
                                                                                     None,
                                                                                     None),
                                                                'END_LABEL_ASYM_ID': ('pdbx_struct_group_component_range',
                                                                                      'end_label_asym_id',
                                                                                      None,
                                                                                      None),
                                                                'END_LABEL_COMP_ID': ('pdbx_struct_group_component_range',
                                                                                      'end_label_comp_id',
                                                                                      None,
                                                                                      None),
                                                                'END_LABEL_SEQ_ID': ('pdbx_struct_group_component_range',
                                                                                     'end_label_seq_id',
                                                                                     None,
                                                                                     None),
                                                                'END_PDB_INS_CODE': ('pdbx_struct_group_component_range',
                                                                                     'end_PDB_ins_code',
                                                                                     None,
                                                                                     None),
                                                                'ORDINAL': ('pdbx_struct_group_component_range',
                                                                            'ordinal',
                                                                            None,
                                                                            None),
                                                                'PDB_MODEL_NUM': ('pdbx_struct_group_component_range',
                                                                                  'PDB_model_num',
                                                                                  None,
                                                                                  None),
                                                                'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                                'STRUCT_GROUP_ID': ('pdbx_struct_group_component_range',
                                                                                    'struct_group_id',
                                                                                    None,
                                                                                    None)},
                                              'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ORDINAL'), 'TYPE': 'UNIQUE'},
                                                          's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                              'MAP_MERGE_INDICES': {'pdbx_struct_group_component_range': {'ATTRIBUTES': ('ordinal',),
                                                                                                          'TYPE': 'EQUI-JOIN'}},
                                              'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                              'TABLE_ID': 'PDBX_STRUCT_GROUP_COMPONENT_RANGE',
                                              'TABLE_NAME': 'pdbx_struct_group_component_range',
                                              'TABLE_TYPE': 'transactional'},
        'PDBX_STRUCT_GROUP_LIST': {'ATTRIBUTES': {'DESCRIPTION': 'description',
                                                  'GROUP_ENUMERATION_TYPE': 'group_enumeration_type',
                                                  'NAME': 'name',
                                                  'SELECTION': 'selection',
                                                  'SELECTION_DETAILS': 'selection_details',
                                                  'STRUCTURE_ID': 'Structure_ID',
                                                  'STRUCT_GROUP_ID': 'struct_group_id',
                                                  'TYPE': 'type'},
                                   'ATTRIBUTE_INFO': {'DESCRIPTION': {'NULLABLE': True,
                                                                      'ORDER': 6,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 200},
                                                      'GROUP_ENUMERATION_TYPE': {'NULLABLE': True,
                                                                                 'ORDER': 5,
                                                                                 'PRECISION': 0,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'VARCHAR',
                                                                                 'WIDTH': 100},
                                                      'NAME': {'NULLABLE': True,
                                                               'ORDER': 3,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 80},
                                                      'SELECTION': {'NULLABLE': True,
                                                                    'ORDER': 7,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 80},
                                                      'SELECTION_DETAILS': {'NULLABLE': True,
                                                                            'ORDER': 8,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 200},
                                                      'STRUCTURE_ID': {'NULLABLE': False,
                                                                       'ORDER': 1,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': True,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                      'STRUCT_GROUP_ID': {'NULLABLE': False,
                                                                          'ORDER': 2,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': True,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                      'TYPE': {'NULLABLE': True,
                                                               'ORDER': 4,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 80}},
                                   'ATTRIBUTE_MAP': {'DESCRIPTION': ('pdbx_struct_group_list', 'description', None, None),
                                                     'GROUP_ENUMERATION_TYPE': ('pdbx_struct_group_list',
                                                                                'group_enumeration_type',
                                                                                None,
                                                                                None),
                                                     'NAME': ('pdbx_struct_group_list', 'name', None, None),
                                                     'SELECTION': ('pdbx_struct_group_list', 'selection', None, None),
                                                     'SELECTION_DETAILS': ('pdbx_struct_group_list',
                                                                           'selection_details',
                                                                           None,
                                                                           None),
                                                     'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                     'STRUCT_GROUP_ID': ('pdbx_struct_group_list',
                                                                         'struct_group_id',
                                                                         None,
                                                                         None),
                                                     'TYPE': ('pdbx_struct_group_list', 'type', None, None)},
                                   'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'STRUCT_GROUP_ID'), 'TYPE': 'UNIQUE'},
                                               's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                   'MAP_MERGE_INDICES': {'pdbx_struct_group_list': {'ATTRIBUTES': ('struct_group_id',),
                                                                                    'TYPE': 'EQUI-JOIN'}},
                                   'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                   'TABLE_ID': 'PDBX_STRUCT_GROUP_LIST',
                                   'TABLE_NAME': 'pdbx_struct_group_list',
                                   'TABLE_TYPE': 'transactional'},
        'PDBX_STRUCT_INFO': {'ATTRIBUTES': {'DETAILS': 'details',
                                            'STRUCTURE_ID': 'Structure_ID',
                                            'TYPE': 'type',
                                            'VALUE': 'value'},
                             'ATTRIBUTE_INFO': {'DETAILS': {'NULLABLE': True,
                                                            'ORDER': 4,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 200},
                                                'STRUCTURE_ID': {'NULLABLE': False,
                                                                 'ORDER': 1,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': True,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                                'TYPE': {'NULLABLE': False,
                                                         'ORDER': 2,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': True,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 80},
                                                'VALUE': {'NULLABLE': False,
                                                          'ORDER': 3,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': True,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 200}},
                             'ATTRIBUTE_MAP': {'DETAILS': ('pdbx_struct_info', 'details', None, None),
                                               'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                               'TYPE': ('pdbx_struct_info', 'type', None, None),
                                               'VALUE': ('pdbx_struct_info', 'value', None, None)},
                             'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'TYPE', 'VALUE'), 'TYPE': 'UNIQUE'},
                                         's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                             'MAP_MERGE_INDICES': {'pdbx_struct_info': {'ATTRIBUTES': ('type', 'value'), 'TYPE': 'EQUI-JOIN'}},
                             'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                             'TABLE_ID': 'PDBX_STRUCT_INFO',
                             'TABLE_NAME': 'pdbx_struct_info',
                             'TABLE_TYPE': 'transactional'},
        'PDBX_STRUCT_LEGACY_OPER_LIST': {'ATTRIBUTES': {'ID': 'id',
                                                        'MATRIX_1_1': 'matrix_1_1',
                                                        'MATRIX_1_2': 'matrix_1_2',
                                                        'MATRIX_1_3': 'matrix_1_3',
                                                        'MATRIX_2_1': 'matrix_2_1',
                                                        'MATRIX_2_2': 'matrix_2_2',
                                                        'MATRIX_2_3': 'matrix_2_3',
                                                        'MATRIX_3_1': 'matrix_3_1',
                                                        'MATRIX_3_2': 'matrix_3_2',
                                                        'MATRIX_3_3': 'matrix_3_3',
                                                        'NAME': 'name',
                                                        'STRUCTURE_ID': 'Structure_ID',
                                                        'VECTOR_1': 'vector_1',
                                                        'VECTOR_2': 'vector_2',
                                                        'VECTOR_3': 'vector_3'},
                                         'ATTRIBUTE_INFO': {'ID': {'NULLABLE': False,
                                                                   'ORDER': 2,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': True,
                                                                   'SQL_TYPE': 'INT',
                                                                   'WIDTH': 10},
                                                            'MATRIX_1_1': {'NULLABLE': True,
                                                                           'ORDER': 4,
                                                                           'PRECISION': 6,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'FLOAT',
                                                                           'WIDTH': 10},
                                                            'MATRIX_1_2': {'NULLABLE': True,
                                                                           'ORDER': 5,
                                                                           'PRECISION': 6,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'FLOAT',
                                                                           'WIDTH': 10},
                                                            'MATRIX_1_3': {'NULLABLE': True,
                                                                           'ORDER': 6,
                                                                           'PRECISION': 6,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'FLOAT',
                                                                           'WIDTH': 10},
                                                            'MATRIX_2_1': {'NULLABLE': True,
                                                                           'ORDER': 7,
                                                                           'PRECISION': 6,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'FLOAT',
                                                                           'WIDTH': 10},
                                                            'MATRIX_2_2': {'NULLABLE': True,
                                                                           'ORDER': 8,
                                                                           'PRECISION': 6,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'FLOAT',
                                                                           'WIDTH': 10},
                                                            'MATRIX_2_3': {'NULLABLE': True,
                                                                           'ORDER': 9,
                                                                           'PRECISION': 6,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'FLOAT',
                                                                           'WIDTH': 10},
                                                            'MATRIX_3_1': {'NULLABLE': True,
                                                                           'ORDER': 10,
                                                                           'PRECISION': 6,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'FLOAT',
                                                                           'WIDTH': 10},
                                                            'MATRIX_3_2': {'NULLABLE': True,
                                                                           'ORDER': 11,
                                                                           'PRECISION': 6,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'FLOAT',
                                                                           'WIDTH': 10},
                                                            'MATRIX_3_3': {'NULLABLE': True,
                                                                           'ORDER': 12,
                                                                           'PRECISION': 6,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'FLOAT',
                                                                           'WIDTH': 10},
                                                            'NAME': {'NULLABLE': True,
                                                                     'ORDER': 3,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 80},
                                                            'STRUCTURE_ID': {'NULLABLE': False,
                                                                             'ORDER': 1,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': True,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                            'VECTOR_1': {'NULLABLE': True,
                                                                         'ORDER': 13,
                                                                         'PRECISION': 6,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'FLOAT',
                                                                         'WIDTH': 10},
                                                            'VECTOR_2': {'NULLABLE': True,
                                                                         'ORDER': 14,
                                                                         'PRECISION': 6,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'FLOAT',
                                                                         'WIDTH': 10},
                                                            'VECTOR_3': {'NULLABLE': True,
                                                                         'ORDER': 15,
                                                                         'PRECISION': 6,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'FLOAT',
                                                                         'WIDTH': 10}},
                                         'ATTRIBUTE_MAP': {'ID': ('pdbx_struct_legacy_oper_list', 'id', None, None),
                                                           'MATRIX_1_1': ('pdbx_struct_legacy_oper_list',
                                                                          'matrix[1][1]',
                                                                          None,
                                                                          None),
                                                           'MATRIX_1_2': ('pdbx_struct_legacy_oper_list',
                                                                          'matrix[1][2]',
                                                                          None,
                                                                          None),
                                                           'MATRIX_1_3': ('pdbx_struct_legacy_oper_list',
                                                                          'matrix[1][3]',
                                                                          None,
                                                                          None),
                                                           'MATRIX_2_1': ('pdbx_struct_legacy_oper_list',
                                                                          'matrix[2][1]',
                                                                          None,
                                                                          None),
                                                           'MATRIX_2_2': ('pdbx_struct_legacy_oper_list',
                                                                          'matrix[2][2]',
                                                                          None,
                                                                          None),
                                                           'MATRIX_2_3': ('pdbx_struct_legacy_oper_list',
                                                                          'matrix[2][3]',
                                                                          None,
                                                                          None),
                                                           'MATRIX_3_1': ('pdbx_struct_legacy_oper_list',
                                                                          'matrix[3][1]',
                                                                          None,
                                                                          None),
                                                           'MATRIX_3_2': ('pdbx_struct_legacy_oper_list',
                                                                          'matrix[3][2]',
                                                                          None,
                                                                          None),
                                                           'MATRIX_3_3': ('pdbx_struct_legacy_oper_list',
                                                                          'matrix[3][3]',
                                                                          None,
                                                                          None),
                                                           'NAME': ('pdbx_struct_legacy_oper_list', 'name', None, None),
                                                           'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                           'VECTOR_1': ('pdbx_struct_legacy_oper_list',
                                                                        'vector[1]',
                                                                        None,
                                                                        None),
                                                           'VECTOR_2': ('pdbx_struct_legacy_oper_list',
                                                                        'vector[2]',
                                                                        None,
                                                                        None),
                                                           'VECTOR_3': ('pdbx_struct_legacy_oper_list',
                                                                        'vector[3]',
                                                                        None,
                                                                        None)},
                                         'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                                     's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                         'MAP_MERGE_INDICES': {'pdbx_struct_legacy_oper_list': {'ATTRIBUTES': ('id',),
                                                                                                'TYPE': 'EQUI-JOIN'}},
                                         'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                         'TABLE_ID': 'PDBX_STRUCT_LEGACY_OPER_LIST',
                                         'TABLE_NAME': 'pdbx_struct_legacy_oper_list',
                                         'TABLE_TYPE': 'transactional'},
        'PDBX_STRUCT_MOD_RESIDUE': {'ATTRIBUTES': {'AUTH_ASYM_ID': 'auth_asym_id',
                                                   'AUTH_COMP_ID': 'auth_comp_id',
                                                   'AUTH_SEQ_ID': 'auth_seq_id',
                                                   'DETAILS': 'details',
                                                   'ID': 'id',
                                                   'LABEL_ASYM_ID': 'label_asym_id',
                                                   'LABEL_COMP_ID': 'label_comp_id',
                                                   'LABEL_SEQ_ID': 'label_seq_id',
                                                   'PARENT_COMP_ID': 'parent_comp_id',
                                                   'PDB_INS_CODE': 'PDB_ins_code',
                                                   'PDB_MODEL_NUM': 'PDB_model_num',
                                                   'STRUCTURE_ID': 'Structure_ID'},
                                    'ATTRIBUTE_INFO': {'AUTH_ASYM_ID': {'NULLABLE': True,
                                                                        'ORDER': 4,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                                       'AUTH_COMP_ID': {'NULLABLE': True,
                                                                        'ORDER': 5,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                                       'AUTH_SEQ_ID': {'NULLABLE': True,
                                                                       'ORDER': 6,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                       'DETAILS': {'NULLABLE': True,
                                                                   'ORDER': 12,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 200},
                                                       'ID': {'NULLABLE': False,
                                                              'ORDER': 2,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'INT',
                                                              'WIDTH': 10},
                                                       'LABEL_ASYM_ID': {'NULLABLE': True,
                                                                         'ORDER': 8,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                                       'LABEL_COMP_ID': {'NULLABLE': True,
                                                                         'ORDER': 9,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                                       'LABEL_SEQ_ID': {'NULLABLE': True,
                                                                        'ORDER': 10,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'INT',
                                                                        'WIDTH': 10},
                                                       'PARENT_COMP_ID': {'NULLABLE': True,
                                                                          'ORDER': 11,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                       'PDB_INS_CODE': {'NULLABLE': True,
                                                                        'ORDER': 7,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                                       'PDB_MODEL_NUM': {'NULLABLE': True,
                                                                         'ORDER': 3,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'INT',
                                                                         'WIDTH': 10},
                                                       'STRUCTURE_ID': {'NULLABLE': False,
                                                                        'ORDER': 1,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': True,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10}},
                                    'ATTRIBUTE_MAP': {'AUTH_ASYM_ID': ('pdbx_struct_mod_residue', 'auth_asym_id', None, None),
                                                      'AUTH_COMP_ID': ('pdbx_struct_mod_residue', 'auth_comp_id', None, None),
                                                      'AUTH_SEQ_ID': ('pdbx_struct_mod_residue', 'auth_seq_id', None, None),
                                                      'DETAILS': ('pdbx_struct_mod_residue', 'details', None, None),
                                                      'ID': ('pdbx_struct_mod_residue', 'id', None, None),
                                                      'LABEL_ASYM_ID': ('pdbx_struct_mod_residue',
                                                                        'label_asym_id',
                                                                        None,
                                                                        None),
                                                      'LABEL_COMP_ID': ('pdbx_struct_mod_residue',
                                                                        'label_comp_id',
                                                                        None,
                                                                        None),
                                                      'LABEL_SEQ_ID': ('pdbx_struct_mod_residue', 'label_seq_id', None, None),
                                                      'PARENT_COMP_ID': ('pdbx_struct_mod_residue',
                                                                         'parent_comp_id',
                                                                         None,
                                                                         None),
                                                      'PDB_INS_CODE': ('pdbx_struct_mod_residue', 'PDB_ins_code', None, None),
                                                      'PDB_MODEL_NUM': ('pdbx_struct_mod_residue',
                                                                        'PDB_model_num',
                                                                        None,
                                                                        None),
                                                      'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                    'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                                's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                    'MAP_MERGE_INDICES': {'pdbx_struct_mod_residue': {'ATTRIBUTES': ('id',),
                                                                                      'TYPE': 'EQUI-JOIN'}},
                                    'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                    'TABLE_ID': 'PDBX_STRUCT_MOD_RESIDUE',
                                    'TABLE_NAME': 'pdbx_struct_mod_residue',
                                    'TABLE_TYPE': 'transactional'},
        'PDBX_STRUCT_MSYM_GEN': {'ATTRIBUTES': {'ENTITY_INST_ID': 'entity_inst_id',
                                                'MSYM_ID': 'msym_id',
                                                'OPER_EXPRESSION': 'oper_expression',
                                                'STRUCTURE_ID': 'Structure_ID'},
                                 'ATTRIBUTE_INFO': {'ENTITY_INST_ID': {'NULLABLE': False,
                                                                       'ORDER': 2,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': True,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                    'MSYM_ID': {'NULLABLE': False,
                                                                'ORDER': 3,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                                    'OPER_EXPRESSION': {'NULLABLE': False,
                                                                        'ORDER': 4,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': True,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 30},
                                                    'STRUCTURE_ID': {'NULLABLE': False,
                                                                     'ORDER': 1,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': True,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10}},
                                 'ATTRIBUTE_MAP': {'ENTITY_INST_ID': ('pdbx_struct_msym_gen', 'entity_inst_id', None, None),
                                                   'MSYM_ID': ('pdbx_struct_msym_gen', 'msym_id', None, None),
                                                   'OPER_EXPRESSION': ('pdbx_struct_msym_gen', 'oper_expression', None, None),
                                                   'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                 'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID',
                                                                   'ENTITY_INST_ID',
                                                                   'MSYM_ID',
                                                                   'OPER_EXPRESSION'),
                                                    'TYPE': 'UNIQUE'},
                                             's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                 'MAP_MERGE_INDICES': {'pdbx_struct_msym_gen': {'ATTRIBUTES': ('entity_inst_id',
                                                                                               'msym_id',
                                                                                               'oper_expression'),
                                                                                'TYPE': 'EQUI-JOIN'}},
                                 'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                 'TABLE_ID': 'PDBX_STRUCT_MSYM_GEN',
                                 'TABLE_NAME': 'pdbx_struct_msym_gen',
                                 'TABLE_TYPE': 'transactional'},
        'PDBX_STRUCT_OPER_LIST': {'ATTRIBUTES': {'ID': 'id',
                                                 'MATRIX_1_1': 'matrix_1_1',
                                                 'MATRIX_1_2': 'matrix_1_2',
                                                 'MATRIX_1_3': 'matrix_1_3',
                                                 'MATRIX_2_1': 'matrix_2_1',
                                                 'MATRIX_2_2': 'matrix_2_2',
                                                 'MATRIX_2_3': 'matrix_2_3',
                                                 'MATRIX_3_1': 'matrix_3_1',
                                                 'MATRIX_3_2': 'matrix_3_2',
                                                 'MATRIX_3_3': 'matrix_3_3',
                                                 'NAME': 'name',
                                                 'STRUCTURE_ID': 'Structure_ID',
                                                 'SYMMETRY_OPERATION': 'symmetry_operation',
                                                 'TYPE': 'type',
                                                 'VECTOR_1': 'vector_1',
                                                 'VECTOR_2': 'vector_2',
                                                 'VECTOR_3': 'vector_3'},
                                  'ATTRIBUTE_INFO': {'ID': {'NULLABLE': False,
                                                            'ORDER': 2,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': True,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 10},
                                                     'MATRIX_1_1': {'NULLABLE': True,
                                                                    'ORDER': 6,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                                     'MATRIX_1_2': {'NULLABLE': True,
                                                                    'ORDER': 7,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                                     'MATRIX_1_3': {'NULLABLE': True,
                                                                    'ORDER': 8,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                                     'MATRIX_2_1': {'NULLABLE': True,
                                                                    'ORDER': 9,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                                     'MATRIX_2_2': {'NULLABLE': True,
                                                                    'ORDER': 10,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                                     'MATRIX_2_3': {'NULLABLE': True,
                                                                    'ORDER': 11,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                                     'MATRIX_3_1': {'NULLABLE': True,
                                                                    'ORDER': 12,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                                     'MATRIX_3_2': {'NULLABLE': True,
                                                                    'ORDER': 13,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                                     'MATRIX_3_3': {'NULLABLE': True,
                                                                    'ORDER': 14,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                                     'NAME': {'NULLABLE': True,
                                                              'ORDER': 4,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 80},
                                                     'STRUCTURE_ID': {'NULLABLE': False,
                                                                      'ORDER': 1,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                                     'SYMMETRY_OPERATION': {'NULLABLE': True,
                                                                            'ORDER': 5,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 80},
                                                     'TYPE': {'NULLABLE': True,
                                                              'ORDER': 3,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 80},
                                                     'VECTOR_1': {'NULLABLE': True,
                                                                  'ORDER': 15,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10},
                                                     'VECTOR_2': {'NULLABLE': True,
                                                                  'ORDER': 16,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10},
                                                     'VECTOR_3': {'NULLABLE': True,
                                                                  'ORDER': 17,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10}},
                                  'ATTRIBUTE_MAP': {'ID': ('pdbx_struct_oper_list', 'id', None, None),
                                                    'MATRIX_1_1': ('pdbx_struct_oper_list', 'matrix[1][1]', None, None),
                                                    'MATRIX_1_2': ('pdbx_struct_oper_list', 'matrix[1][2]', None, None),
                                                    'MATRIX_1_3': ('pdbx_struct_oper_list', 'matrix[1][3]', None, None),
                                                    'MATRIX_2_1': ('pdbx_struct_oper_list', 'matrix[2][1]', None, None),
                                                    'MATRIX_2_2': ('pdbx_struct_oper_list', 'matrix[2][2]', None, None),
                                                    'MATRIX_2_3': ('pdbx_struct_oper_list', 'matrix[2][3]', None, None),
                                                    'MATRIX_3_1': ('pdbx_struct_oper_list', 'matrix[3][1]', None, None),
                                                    'MATRIX_3_2': ('pdbx_struct_oper_list', 'matrix[3][2]', None, None),
                                                    'MATRIX_3_3': ('pdbx_struct_oper_list', 'matrix[3][3]', None, None),
                                                    'NAME': ('pdbx_struct_oper_list', 'name', None, None),
                                                    'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                    'SYMMETRY_OPERATION': ('pdbx_struct_oper_list',
                                                                           'symmetry_operation',
                                                                           None,
                                                                           None),
                                                    'TYPE': ('pdbx_struct_oper_list', 'type', None, None),
                                                    'VECTOR_1': ('pdbx_struct_oper_list', 'vector[1]', None, None),
                                                    'VECTOR_2': ('pdbx_struct_oper_list', 'vector[2]', None, None),
                                                    'VECTOR_3': ('pdbx_struct_oper_list', 'vector[3]', None, None)},
                                  'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                              's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                  'MAP_MERGE_INDICES': {'pdbx_struct_oper_list': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                                  'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                  'TABLE_ID': 'PDBX_STRUCT_OPER_LIST',
                                  'TABLE_NAME': 'pdbx_struct_oper_list',
                                  'TABLE_TYPE': 'transactional'},
        'PDBX_STRUCT_REF_SEQ_DELETION': {'ATTRIBUTES': {'ASYM_ID': 'asym_id',
                                                        'COMP_ID': 'comp_id',
                                                        'DB_CODE': 'db_code',
                                                        'DB_NAME': 'db_name',
                                                        'DB_SEQ_ID': 'db_seq_id',
                                                        'DETAILS': 'details',
                                                        'ID': 'id',
                                                        'STRUCTURE_ID': 'Structure_ID'},
                                         'ATTRIBUTE_INFO': {'ASYM_ID': {'NULLABLE': True,
                                                                        'ORDER': 4,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                                            'COMP_ID': {'NULLABLE': True,
                                                                        'ORDER': 5,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                                            'DB_CODE': {'NULLABLE': True,
                                                                        'ORDER': 7,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 80},
                                                            'DB_NAME': {'NULLABLE': True,
                                                                        'ORDER': 8,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 80},
                                                            'DB_SEQ_ID': {'NULLABLE': True,
                                                                          'ORDER': 6,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'INT',
                                                                          'WIDTH': 10},
                                                            'DETAILS': {'NULLABLE': True,
                                                                        'ORDER': 3,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 200},
                                                            'ID': {'NULLABLE': False,
                                                                   'ORDER': 2,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': True,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 10},
                                                            'STRUCTURE_ID': {'NULLABLE': False,
                                                                             'ORDER': 1,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': True,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10}},
                                         'ATTRIBUTE_MAP': {'ASYM_ID': ('pdbx_struct_ref_seq_deletion', 'asym_id', None, None),
                                                           'COMP_ID': ('pdbx_struct_ref_seq_deletion', 'comp_id', None, None),
                                                           'DB_CODE': ('pdbx_struct_ref_seq_deletion', 'db_code', None, None),
                                                           'DB_NAME': ('pdbx_struct_ref_seq_deletion', 'db_name', None, None),
                                                           'DB_SEQ_ID': ('pdbx_struct_ref_seq_deletion',
                                                                         'db_seq_id',
                                                                         None,
                                                                         None),
                                                           'DETAILS': ('pdbx_struct_ref_seq_deletion', 'details', None, None),
                                                           'ID': ('pdbx_struct_ref_seq_deletion', 'id', None, None),
                                                           'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                         'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                                     's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                         'MAP_MERGE_INDICES': {'pdbx_struct_ref_seq_deletion': {'ATTRIBUTES': ('id',),
                                                                                                'TYPE': 'EQUI-JOIN'}},
                                         'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                         'TABLE_ID': 'PDBX_STRUCT_REF_SEQ_DELETION',
                                         'TABLE_NAME': 'pdbx_struct_ref_seq_deletion',
                                         'TABLE_TYPE': 'transactional'},
        'PDBX_STRUCT_REF_SEQ_FEATURE': {'ATTRIBUTES': {'ALIGN_ID': 'align_id',
                                                       'ASYM_ID': 'asym_id',
                                                       'BEG_AUTH_MON_ID': 'beg_auth_mon_id',
                                                       'BEG_AUTH_SEQ_ID': 'beg_auth_seq_id',
                                                       'BEG_PDB_INS_CODE': 'beg_pdb_ins_code',
                                                       'BEG_SEQ_NUM': 'beg_seq_num',
                                                       'DETAILS': 'details',
                                                       'END_AUTH_MON_ID': 'end_auth_mon_id',
                                                       'END_AUTH_SEQ_ID': 'end_auth_seq_id',
                                                       'END_PDB_INS_CODE': 'end_pdb_ins_code',
                                                       'END_SEQ_NUM': 'end_seq_num',
                                                       'FEATURE_ID': 'feature_id',
                                                       'PDB_STRAND_ID': 'pdb_strand_id',
                                                       'STRUCTURE_ID': 'Structure_ID',
                                                       'TYPE': 'type'},
                                        'ATTRIBUTE_INFO': {'ALIGN_ID': {'NULLABLE': True,
                                                                        'ORDER': 3,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                                           'ASYM_ID': {'NULLABLE': True,
                                                                       'ORDER': 7,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                           'BEG_AUTH_MON_ID': {'NULLABLE': True,
                                                                               'ORDER': 12,
                                                                               'PRECISION': 0,
                                                                               'PRIMARY_KEY': False,
                                                                               'SQL_TYPE': 'VARCHAR',
                                                                               'WIDTH': 10},
                                                           'BEG_AUTH_SEQ_ID': {'NULLABLE': True,
                                                                               'ORDER': 8,
                                                                               'PRECISION': 0,
                                                                               'PRIMARY_KEY': False,
                                                                               'SQL_TYPE': 'VARCHAR',
                                                                               'WIDTH': 10},
                                                           'BEG_PDB_INS_CODE': {'NULLABLE': True,
                                                                                'ORDER': 14,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 10},
                                                           'BEG_SEQ_NUM': {'NULLABLE': True,
                                                                           'ORDER': 10,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10},
                                                           'DETAILS': {'NULLABLE': True,
                                                                       'ORDER': 5,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 200},
                                                           'END_AUTH_MON_ID': {'NULLABLE': True,
                                                                               'ORDER': 13,
                                                                               'PRECISION': 0,
                                                                               'PRIMARY_KEY': False,
                                                                               'SQL_TYPE': 'VARCHAR',
                                                                               'WIDTH': 10},
                                                           'END_AUTH_SEQ_ID': {'NULLABLE': True,
                                                                               'ORDER': 9,
                                                                               'PRECISION': 0,
                                                                               'PRIMARY_KEY': False,
                                                                               'SQL_TYPE': 'VARCHAR',
                                                                               'WIDTH': 10},
                                                           'END_PDB_INS_CODE': {'NULLABLE': True,
                                                                                'ORDER': 15,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 10},
                                                           'END_SEQ_NUM': {'NULLABLE': True,
                                                                           'ORDER': 11,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10},
                                                           'FEATURE_ID': {'NULLABLE': False,
                                                                          'ORDER': 2,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': True,
                                                                          'SQL_TYPE': 'INT',
                                                                          'WIDTH': 10},
                                                           'PDB_STRAND_ID': {'NULLABLE': True,
                                                                             'ORDER': 6,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                           'STRUCTURE_ID': {'NULLABLE': False,
                                                                            'ORDER': 1,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': True,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 10},
                                                           'TYPE': {'NULLABLE': True,
                                                                    'ORDER': 4,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 200}},
                                        'ATTRIBUTE_MAP': {'ALIGN_ID': ('pdbx_struct_ref_seq_feature', 'align_id', None, None),
                                                          'ASYM_ID': ('pdbx_struct_ref_seq_feature', 'asym_id', None, None),
                                                          'BEG_AUTH_MON_ID': ('pdbx_struct_ref_seq_feature',
                                                                              'beg_auth_mon_id',
                                                                              None,
                                                                              None),
                                                          'BEG_AUTH_SEQ_ID': ('pdbx_struct_ref_seq_feature',
                                                                              'beg_auth_seq_id',
                                                                              None,
                                                                              None),
                                                          'BEG_PDB_INS_CODE': ('pdbx_struct_ref_seq_feature',
                                                                               'beg_pdb_ins_code',
                                                                               None,
                                                                               None),
                                                          'BEG_SEQ_NUM': ('pdbx_struct_ref_seq_feature',
                                                                          'beg_seq_num',
                                                                          None,
                                                                          None),
                                                          'DETAILS': ('pdbx_struct_ref_seq_feature', 'details', None, None),
                                                          'END_AUTH_MON_ID': ('pdbx_struct_ref_seq_feature',
                                                                              'end_auth_mon_id',
                                                                              None,
                                                                              None),
                                                          'END_AUTH_SEQ_ID': ('pdbx_struct_ref_seq_feature',
                                                                              'end_auth_seq_id',
                                                                              None,
                                                                              None),
                                                          'END_PDB_INS_CODE': ('pdbx_struct_ref_seq_feature',
                                                                               'end_pdb_ins_code',
                                                                               None,
                                                                               None),
                                                          'END_SEQ_NUM': ('pdbx_struct_ref_seq_feature',
                                                                          'end_seq_num',
                                                                          None,
                                                                          None),
                                                          'FEATURE_ID': ('pdbx_struct_ref_seq_feature',
                                                                         'feature_id',
                                                                         None,
                                                                         None),
                                                          'PDB_STRAND_ID': ('pdbx_struct_ref_seq_feature',
                                                                            'pdb_strand_id',
                                                                            None,
                                                                            None),
                                                          'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                          'TYPE': ('pdbx_struct_ref_seq_feature', 'type', None, None)},
                                        'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'FEATURE_ID'), 'TYPE': 'UNIQUE'},
                                                    's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                        'MAP_MERGE_INDICES': {'pdbx_struct_ref_seq_feature': {'ATTRIBUTES': ('feature_id',),
                                                                                              'TYPE': 'EQUI-JOIN'}},
                                        'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                        'TABLE_ID': 'PDBX_STRUCT_REF_SEQ_FEATURE',
                                        'TABLE_NAME': 'pdbx_struct_ref_seq_feature',
                                        'TABLE_TYPE': 'transactional'},
        'PDBX_STRUCT_REF_SEQ_FEATURE_PROP': {'ATTRIBUTES': {'BEG_DB_MON_ID': 'beg_db_mon_id',
                                                            'BEG_DB_SEQ_ID': 'beg_db_seq_id',
                                                            'DETAILS': 'details',
                                                            'END_DB_MON_ID': 'end_db_mon_id',
                                                            'END_DB_SEQ_ID': 'end_db_seq_id',
                                                            'FEATURE_ID': 'feature_id',
                                                            'PROPERTY_ID': 'property_id',
                                                            'STRUCTURE_ID': 'Structure_ID',
                                                            'TYPE': 'type',
                                                            'VALUE': 'value'},
                                             'ATTRIBUTE_INFO': {'BEG_DB_MON_ID': {'NULLABLE': True,
                                                                                  'ORDER': 7,
                                                                                  'PRECISION': 0,
                                                                                  'PRIMARY_KEY': False,
                                                                                  'SQL_TYPE': 'VARCHAR',
                                                                                  'WIDTH': 10},
                                                                'BEG_DB_SEQ_ID': {'NULLABLE': True,
                                                                                  'ORDER': 9,
                                                                                  'PRECISION': 0,
                                                                                  'PRIMARY_KEY': False,
                                                                                  'SQL_TYPE': 'INT',
                                                                                  'WIDTH': 10},
                                                                'DETAILS': {'NULLABLE': True,
                                                                            'ORDER': 6,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 200},
                                                                'END_DB_MON_ID': {'NULLABLE': True,
                                                                                  'ORDER': 8,
                                                                                  'PRECISION': 0,
                                                                                  'PRIMARY_KEY': False,
                                                                                  'SQL_TYPE': 'VARCHAR',
                                                                                  'WIDTH': 10},
                                                                'END_DB_SEQ_ID': {'NULLABLE': True,
                                                                                  'ORDER': 10,
                                                                                  'PRECISION': 0,
                                                                                  'PRIMARY_KEY': False,
                                                                                  'SQL_TYPE': 'INT',
                                                                                  'WIDTH': 10},
                                                                'FEATURE_ID': {'NULLABLE': False,
                                                                               'ORDER': 2,
                                                                               'PRECISION': 0,
                                                                               'PRIMARY_KEY': True,
                                                                               'SQL_TYPE': 'INT',
                                                                               'WIDTH': 10},
                                                                'PROPERTY_ID': {'NULLABLE': False,
                                                                                'ORDER': 3,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': True,
                                                                                'SQL_TYPE': 'INT',
                                                                                'WIDTH': 10},
                                                                'STRUCTURE_ID': {'NULLABLE': False,
                                                                                 'ORDER': 1,
                                                                                 'PRECISION': 0,
                                                                                 'PRIMARY_KEY': True,
                                                                                 'SQL_TYPE': 'VARCHAR',
                                                                                 'WIDTH': 10},
                                                                'TYPE': {'NULLABLE': True,
                                                                         'ORDER': 4,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 200},
                                                                'VALUE': {'NULLABLE': True,
                                                                          'ORDER': 5,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 200}},
                                             'ATTRIBUTE_MAP': {'BEG_DB_MON_ID': ('pdbx_struct_ref_seq_feature_prop',
                                                                                 'beg_db_mon_id',
                                                                                 None,
                                                                                 None),
                                                               'BEG_DB_SEQ_ID': ('pdbx_struct_ref_seq_feature_prop',
                                                                                 'beg_db_seq_id',
                                                                                 None,
                                                                                 None),
                                                               'DETAILS': ('pdbx_struct_ref_seq_feature_prop',
                                                                           'details',
                                                                           None,
                                                                           None),
                                                               'END_DB_MON_ID': ('pdbx_struct_ref_seq_feature_prop',
                                                                                 'end_db_mon_id',
                                                                                 None,
                                                                                 None),
                                                               'END_DB_SEQ_ID': ('pdbx_struct_ref_seq_feature_prop',
                                                                                 'end_db_seq_id',
                                                                                 None,
                                                                                 None),
                                                               'FEATURE_ID': ('pdbx_struct_ref_seq_feature_prop',
                                                                              'feature_id',
                                                                              None,
                                                                              None),
                                                               'PROPERTY_ID': ('pdbx_struct_ref_seq_feature_prop',
                                                                               'property_id',
                                                                               None,
                                                                               None),
                                                               'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                               'TYPE': ('pdbx_struct_ref_seq_feature_prop',
                                                                        'type',
                                                                        None,
                                                                        None),
                                                               'VALUE': ('pdbx_struct_ref_seq_feature_prop',
                                                                         'value',
                                                                         None,
                                                                         None)},
                                             'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'FEATURE_ID', 'PROPERTY_ID'),
                                                                'TYPE': 'UNIQUE'},
                                                         's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                             'MAP_MERGE_INDICES': {'pdbx_struct_ref_seq_feature_prop': {'ATTRIBUTES': ('feature_id',
                                                                                                                       'property_id'),
                                                                                                        'TYPE': 'EQUI-JOIN'}},
                                             'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                             'TABLE_ID': 'PDBX_STRUCT_REF_SEQ_FEATURE_PROP',
                                             'TABLE_NAME': 'pdbx_struct_ref_seq_feature_prop',
                                             'TABLE_TYPE': 'transactional'},
        'PDBX_STRUCT_REF_SEQ_INSERTION': {'ATTRIBUTES': {'ASYM_ID': 'asym_id',
                                                         'AUTH_ASYM_ID': 'auth_asym_id',
                                                         'AUTH_SEQ_ID': 'auth_seq_id',
                                                         'COMP_ID': 'comp_id',
                                                         'DB_CODE': 'db_code',
                                                         'DB_NAME': 'db_name',
                                                         'DETAILS': 'details',
                                                         'ID': 'id',
                                                         'PDB_INS_CODE': 'PDB_ins_code',
                                                         'SEQ_ID': 'seq_id',
                                                         'STRUCTURE_ID': 'Structure_ID'},
                                          'ATTRIBUTE_INFO': {'ASYM_ID': {'NULLABLE': True,
                                                                         'ORDER': 4,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                                             'AUTH_ASYM_ID': {'NULLABLE': True,
                                                                              'ORDER': 5,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                                             'AUTH_SEQ_ID': {'NULLABLE': True,
                                                                             'ORDER': 6,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                             'COMP_ID': {'NULLABLE': True,
                                                                         'ORDER': 3,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                                             'DB_CODE': {'NULLABLE': True,
                                                                         'ORDER': 10,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 80},
                                                             'DB_NAME': {'NULLABLE': True,
                                                                         'ORDER': 11,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 80},
                                                             'DETAILS': {'NULLABLE': True,
                                                                         'ORDER': 9,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 200},
                                                             'ID': {'NULLABLE': False,
                                                                    'ORDER': 2,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': True,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10},
                                                             'PDB_INS_CODE': {'NULLABLE': True,
                                                                              'ORDER': 8,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                                             'SEQ_ID': {'NULLABLE': True,
                                                                        'ORDER': 7,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'INT',
                                                                        'WIDTH': 10},
                                                             'STRUCTURE_ID': {'NULLABLE': False,
                                                                              'ORDER': 1,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': True,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10}},
                                          'ATTRIBUTE_MAP': {'ASYM_ID': ('pdbx_struct_ref_seq_insertion',
                                                                        'asym_id',
                                                                        None,
                                                                        None),
                                                            'AUTH_ASYM_ID': ('pdbx_struct_ref_seq_insertion',
                                                                             'auth_asym_id',
                                                                             None,
                                                                             None),
                                                            'AUTH_SEQ_ID': ('pdbx_struct_ref_seq_insertion',
                                                                            'auth_seq_id',
                                                                            None,
                                                                            None),
                                                            'COMP_ID': ('pdbx_struct_ref_seq_insertion',
                                                                        'comp_id',
                                                                        None,
                                                                        None),
                                                            'DB_CODE': ('pdbx_struct_ref_seq_insertion',
                                                                        'db_code',
                                                                        None,
                                                                        None),
                                                            'DB_NAME': ('pdbx_struct_ref_seq_insertion',
                                                                        'db_name',
                                                                        None,
                                                                        None),
                                                            'DETAILS': ('pdbx_struct_ref_seq_insertion',
                                                                        'details',
                                                                        None,
                                                                        None),
                                                            'ID': ('pdbx_struct_ref_seq_insertion', 'id', None, None),
                                                            'PDB_INS_CODE': ('pdbx_struct_ref_seq_insertion',
                                                                             'PDB_ins_code',
                                                                             None,
                                                                             None),
                                                            'SEQ_ID': ('pdbx_struct_ref_seq_insertion', 'seq_id', None, None),
                                                            'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                          'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                                      's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                          'MAP_MERGE_INDICES': {'pdbx_struct_ref_seq_insertion': {'ATTRIBUTES': ('id',),
                                                                                                  'TYPE': 'EQUI-JOIN'}},
                                          'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                          'TABLE_ID': 'PDBX_STRUCT_REF_SEQ_INSERTION',
                                          'TABLE_NAME': 'pdbx_struct_ref_seq_insertion',
                                          'TABLE_TYPE': 'transactional'},
        'PDBX_STRUCT_SHEET_HBOND': {'ATTRIBUTES': {'RANGE_1_AUTH_ASYM_ID': 'range_1_auth_asym_id',
                                                   'RANGE_1_AUTH_ATOM_ID': 'range_1_auth_atom_id',
                                                   'RANGE_1_AUTH_COMP_ID': 'range_1_auth_comp_id',
                                                   'RANGE_1_AUTH_SEQ_ID': 'range_1_auth_seq_id',
                                                   'RANGE_1_LABEL_ASYM_ID': 'range_1_label_asym_id',
                                                   'RANGE_1_LABEL_ATOM_ID': 'range_1_label_atom_id',
                                                   'RANGE_1_LABEL_COMP_ID': 'range_1_label_comp_id',
                                                   'RANGE_1_LABEL_SEQ_ID': 'range_1_label_seq_id',
                                                   'RANGE_1_PDB_INS_CODE': 'range_1_PDB_ins_code',
                                                   'RANGE_2_AUTH_ASYM_ID': 'range_2_auth_asym_id',
                                                   'RANGE_2_AUTH_ATOM_ID': 'range_2_auth_atom_id',
                                                   'RANGE_2_AUTH_COMP_ID': 'range_2_auth_comp_id',
                                                   'RANGE_2_AUTH_SEQ_ID': 'range_2_auth_seq_id',
                                                   'RANGE_2_LABEL_ASYM_ID': 'range_2_label_asym_id',
                                                   'RANGE_2_LABEL_ATOM_ID': 'range_2_label_atom_id',
                                                   'RANGE_2_LABEL_COMP_ID': 'range_2_label_comp_id',
                                                   'RANGE_2_LABEL_SEQ_ID': 'range_2_label_seq_id',
                                                   'RANGE_2_PDB_INS_CODE': 'range_2_PDB_ins_code',
                                                   'RANGE_ID_1': 'range_id_1',
                                                   'RANGE_ID_2': 'range_id_2',
                                                   'SHEET_ID': 'sheet_id',
                                                   'STRUCTURE_ID': 'Structure_ID'},
                                    'ATTRIBUTE_INFO': {'RANGE_1_AUTH_ASYM_ID': {'NULLABLE': True,
                                                                                'ORDER': 12,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 10},
                                                       'RANGE_1_AUTH_ATOM_ID': {'NULLABLE': True,
                                                                                'ORDER': 9,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 6},
                                                       'RANGE_1_AUTH_COMP_ID': {'NULLABLE': True,
                                                                                'ORDER': 11,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 10},
                                                       'RANGE_1_AUTH_SEQ_ID': {'NULLABLE': True,
                                                                               'ORDER': 10,
                                                                               'PRECISION': 0,
                                                                               'PRIMARY_KEY': False,
                                                                               'SQL_TYPE': 'VARCHAR',
                                                                               'WIDTH': 10},
                                                       'RANGE_1_LABEL_ASYM_ID': {'NULLABLE': True,
                                                                                 'ORDER': 8,
                                                                                 'PRECISION': 0,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'VARCHAR',
                                                                                 'WIDTH': 10},
                                                       'RANGE_1_LABEL_ATOM_ID': {'NULLABLE': True,
                                                                                 'ORDER': 5,
                                                                                 'PRECISION': 0,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'VARCHAR',
                                                                                 'WIDTH': 6},
                                                       'RANGE_1_LABEL_COMP_ID': {'NULLABLE': True,
                                                                                 'ORDER': 7,
                                                                                 'PRECISION': 0,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'VARCHAR',
                                                                                 'WIDTH': 10},
                                                       'RANGE_1_LABEL_SEQ_ID': {'NULLABLE': True,
                                                                                'ORDER': 6,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'INT',
                                                                                'WIDTH': 10},
                                                       'RANGE_1_PDB_INS_CODE': {'NULLABLE': True,
                                                                                'ORDER': 13,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 10},
                                                       'RANGE_2_AUTH_ASYM_ID': {'NULLABLE': True,
                                                                                'ORDER': 21,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 10},
                                                       'RANGE_2_AUTH_ATOM_ID': {'NULLABLE': True,
                                                                                'ORDER': 18,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 6},
                                                       'RANGE_2_AUTH_COMP_ID': {'NULLABLE': True,
                                                                                'ORDER': 20,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 10},
                                                       'RANGE_2_AUTH_SEQ_ID': {'NULLABLE': True,
                                                                               'ORDER': 19,
                                                                               'PRECISION': 0,
                                                                               'PRIMARY_KEY': False,
                                                                               'SQL_TYPE': 'VARCHAR',
                                                                               'WIDTH': 10},
                                                       'RANGE_2_LABEL_ASYM_ID': {'NULLABLE': True,
                                                                                 'ORDER': 17,
                                                                                 'PRECISION': 0,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'VARCHAR',
                                                                                 'WIDTH': 10},
                                                       'RANGE_2_LABEL_ATOM_ID': {'NULLABLE': True,
                                                                                 'ORDER': 14,
                                                                                 'PRECISION': 0,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'VARCHAR',
                                                                                 'WIDTH': 6},
                                                       'RANGE_2_LABEL_COMP_ID': {'NULLABLE': True,
                                                                                 'ORDER': 16,
                                                                                 'PRECISION': 0,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'VARCHAR',
                                                                                 'WIDTH': 10},
                                                       'RANGE_2_LABEL_SEQ_ID': {'NULLABLE': True,
                                                                                'ORDER': 15,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'INT',
                                                                                'WIDTH': 10},
                                                       'RANGE_2_PDB_INS_CODE': {'NULLABLE': True,
                                                                                'ORDER': 22,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 10},
                                                       'RANGE_ID_1': {'NULLABLE': False,
                                                                      'ORDER': 2,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                                       'RANGE_ID_2': {'NULLABLE': False,
                                                                      'ORDER': 3,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                                       'SHEET_ID': {'NULLABLE': False,
                                                                    'ORDER': 4,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': True,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10},
                                                       'STRUCTURE_ID': {'NULLABLE': False,
                                                                        'ORDER': 1,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': True,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10}},
                                    'ATTRIBUTE_MAP': {'RANGE_1_AUTH_ASYM_ID': ('pdbx_struct_sheet_hbond',
                                                                               'range_1_auth_asym_id',
                                                                               None,
                                                                               None),
                                                      'RANGE_1_AUTH_ATOM_ID': ('pdbx_struct_sheet_hbond',
                                                                               'range_1_auth_atom_id',
                                                                               None,
                                                                               None),
                                                      'RANGE_1_AUTH_COMP_ID': ('pdbx_struct_sheet_hbond',
                                                                               'range_1_auth_comp_id',
                                                                               None,
                                                                               None),
                                                      'RANGE_1_AUTH_SEQ_ID': ('pdbx_struct_sheet_hbond',
                                                                              'range_1_auth_seq_id',
                                                                              None,
                                                                              None),
                                                      'RANGE_1_LABEL_ASYM_ID': ('pdbx_struct_sheet_hbond',
                                                                                'range_1_label_asym_id',
                                                                                None,
                                                                                None),
                                                      'RANGE_1_LABEL_ATOM_ID': ('pdbx_struct_sheet_hbond',
                                                                                'range_1_label_atom_id',
                                                                                None,
                                                                                None),
                                                      'RANGE_1_LABEL_COMP_ID': ('pdbx_struct_sheet_hbond',
                                                                                'range_1_label_comp_id',
                                                                                None,
                                                                                None),
                                                      'RANGE_1_LABEL_SEQ_ID': ('pdbx_struct_sheet_hbond',
                                                                               'range_1_label_seq_id',
                                                                               None,
                                                                               None),
                                                      'RANGE_1_PDB_INS_CODE': ('pdbx_struct_sheet_hbond',
                                                                               'range_1_PDB_ins_code',
                                                                               None,
                                                                               None),
                                                      'RANGE_2_AUTH_ASYM_ID': ('pdbx_struct_sheet_hbond',
                                                                               'range_2_auth_asym_id',
                                                                               None,
                                                                               None),
                                                      'RANGE_2_AUTH_ATOM_ID': ('pdbx_struct_sheet_hbond',
                                                                               'range_2_auth_atom_id',
                                                                               None,
                                                                               None),
                                                      'RANGE_2_AUTH_COMP_ID': ('pdbx_struct_sheet_hbond',
                                                                               'range_2_auth_comp_id',
                                                                               None,
                                                                               None),
                                                      'RANGE_2_AUTH_SEQ_ID': ('pdbx_struct_sheet_hbond',
                                                                              'range_2_auth_seq_id',
                                                                              None,
                                                                              None),
                                                      'RANGE_2_LABEL_ASYM_ID': ('pdbx_struct_sheet_hbond',
                                                                                'range_2_label_asym_id',
                                                                                None,
                                                                                None),
                                                      'RANGE_2_LABEL_ATOM_ID': ('pdbx_struct_sheet_hbond',
                                                                                'range_2_label_atom_id',
                                                                                None,
                                                                                None),
                                                      'RANGE_2_LABEL_COMP_ID': ('pdbx_struct_sheet_hbond',
                                                                                'range_2_label_comp_id',
                                                                                None,
                                                                                None),
                                                      'RANGE_2_LABEL_SEQ_ID': ('pdbx_struct_sheet_hbond',
                                                                               'range_2_label_seq_id',
                                                                               None,
                                                                               None),
                                                      'RANGE_2_PDB_INS_CODE': ('pdbx_struct_sheet_hbond',
                                                                               'range_2_PDB_ins_code',
                                                                               None,
                                                                               None),
                                                      'RANGE_ID_1': ('pdbx_struct_sheet_hbond', 'range_id_1', None, None),
                                                      'RANGE_ID_2': ('pdbx_struct_sheet_hbond', 'range_id_2', None, None),
                                                      'SHEET_ID': ('pdbx_struct_sheet_hbond', 'sheet_id', None, None),
                                                      'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                    'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'RANGE_ID_1', 'RANGE_ID_2', 'SHEET_ID'),
                                                       'TYPE': 'UNIQUE'},
                                                's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                    'MAP_MERGE_INDICES': {'pdbx_struct_sheet_hbond': {'ATTRIBUTES': ('range_id_1',
                                                                                                     'range_id_2',
                                                                                                     'sheet_id'),
                                                                                      'TYPE': 'EQUI-JOIN'}},
                                    'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                    'TABLE_ID': 'PDBX_STRUCT_SHEET_HBOND',
                                    'TABLE_NAME': 'pdbx_struct_sheet_hbond',
                                    'TABLE_TYPE': 'transactional'},
        'PDBX_UNOBS_OR_ZERO_OCC_ATOMS': {'ATTRIBUTES': {'AUTH_ASYM_ID': 'auth_asym_id',
                                                        'AUTH_ATOM_ID': 'auth_atom_id',
                                                        'AUTH_COMP_ID': 'auth_comp_id',
                                                        'AUTH_SEQ_ID': 'auth_seq_id',
                                                        'ID': 'id',
                                                        'LABEL_ALT_ID': 'label_alt_id',
                                                        'LABEL_ASYM_ID': 'label_asym_id',
                                                        'LABEL_ATOM_ID': 'label_atom_id',
                                                        'LABEL_COMP_ID': 'label_comp_id',
                                                        'LABEL_SEQ_ID': 'label_seq_id',
                                                        'OCCUPANCY_FLAG': 'occupancy_flag',
                                                        'PDB_INS_CODE': 'PDB_ins_code',
                                                        'PDB_MODEL_NUM': 'PDB_model_num',
                                                        'POLYMER_FLAG': 'polymer_flag',
                                                        'STRUCTURE_ID': 'Structure_ID'},
                                         'ATTRIBUTE_INFO': {'AUTH_ASYM_ID': {'NULLABLE': True,
                                                                             'ORDER': 6,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                            'AUTH_ATOM_ID': {'NULLABLE': True,
                                                                             'ORDER': 7,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 6},
                                                            'AUTH_COMP_ID': {'NULLABLE': True,
                                                                             'ORDER': 8,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                            'AUTH_SEQ_ID': {'NULLABLE': True,
                                                                            'ORDER': 9,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 10},
                                                            'ID': {'NULLABLE': False,
                                                                   'ORDER': 2,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': True,
                                                                   'SQL_TYPE': 'INT',
                                                                   'WIDTH': 10},
                                                            'LABEL_ALT_ID': {'NULLABLE': True,
                                                                             'ORDER': 11,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                            'LABEL_ASYM_ID': {'NULLABLE': True,
                                                                              'ORDER': 13,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                                            'LABEL_ATOM_ID': {'NULLABLE': True,
                                                                              'ORDER': 12,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 6},
                                                            'LABEL_COMP_ID': {'NULLABLE': True,
                                                                              'ORDER': 14,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                                            'LABEL_SEQ_ID': {'NULLABLE': True,
                                                                             'ORDER': 15,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'INT',
                                                                             'WIDTH': 10},
                                                            'OCCUPANCY_FLAG': {'NULLABLE': True,
                                                                               'ORDER': 4,
                                                                               'PRECISION': 0,
                                                                               'PRIMARY_KEY': False,
                                                                               'SQL_TYPE': 'INT',
                                                                               'WIDTH': 10},
                                                            'PDB_INS_CODE': {'NULLABLE': True,
                                                                             'ORDER': 10,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                            'PDB_MODEL_NUM': {'NULLABLE': True,
                                                                              'ORDER': 5,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'INT',
                                                                              'WIDTH': 10},
                                                            'POLYMER_FLAG': {'NULLABLE': True,
                                                                             'ORDER': 3,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                            'STRUCTURE_ID': {'NULLABLE': False,
                                                                             'ORDER': 1,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': True,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10}},
                                         'ATTRIBUTE_MAP': {'AUTH_ASYM_ID': ('pdbx_unobs_or_zero_occ_atoms',
                                                                            'auth_asym_id',
                                                                            None,
                                                                            None),
                                                           'AUTH_ATOM_ID': ('pdbx_unobs_or_zero_occ_atoms',
                                                                            'auth_atom_id',
                                                                            None,
                                                                            None),
                                                           'AUTH_COMP_ID': ('pdbx_unobs_or_zero_occ_atoms',
                                                                            'auth_comp_id',
                                                                            None,
                                                                            None),
                                                           'AUTH_SEQ_ID': ('pdbx_unobs_or_zero_occ_atoms',
                                                                           'auth_seq_id',
                                                                           None,
                                                                           None),
                                                           'ID': ('pdbx_unobs_or_zero_occ_atoms', 'id', None, None),
                                                           'LABEL_ALT_ID': ('pdbx_unobs_or_zero_occ_atoms',
                                                                            'label_alt_id',
                                                                            None,
                                                                            None),
                                                           'LABEL_ASYM_ID': ('pdbx_unobs_or_zero_occ_atoms',
                                                                             'label_asym_id',
                                                                             None,
                                                                             None),
                                                           'LABEL_ATOM_ID': ('pdbx_unobs_or_zero_occ_atoms',
                                                                             'label_atom_id',
                                                                             None,
                                                                             None),
                                                           'LABEL_COMP_ID': ('pdbx_unobs_or_zero_occ_atoms',
                                                                             'label_comp_id',
                                                                             None,
                                                                             None),
                                                           'LABEL_SEQ_ID': ('pdbx_unobs_or_zero_occ_atoms',
                                                                            'label_seq_id',
                                                                            None,
                                                                            None),
                                                           'OCCUPANCY_FLAG': ('pdbx_unobs_or_zero_occ_atoms',
                                                                              'occupancy_flag',
                                                                              None,
                                                                              None),
                                                           'PDB_INS_CODE': ('pdbx_unobs_or_zero_occ_atoms',
                                                                            'PDB_ins_code',
                                                                            None,
                                                                            None),
                                                           'PDB_MODEL_NUM': ('pdbx_unobs_or_zero_occ_atoms',
                                                                             'PDB_model_num',
                                                                             None,
                                                                             None),
                                                           'POLYMER_FLAG': ('pdbx_unobs_or_zero_occ_atoms',
                                                                            'polymer_flag',
                                                                            None,
                                                                            None),
                                                           'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                         'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                                     's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                         'MAP_MERGE_INDICES': {'pdbx_unobs_or_zero_occ_atoms': {'ATTRIBUTES': ('id',),
                                                                                                'TYPE': 'EQUI-JOIN'}},
                                         'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                         'TABLE_ID': 'PDBX_UNOBS_OR_ZERO_OCC_ATOMS',
                                         'TABLE_NAME': 'pdbx_unobs_or_zero_occ_atoms',
                                         'TABLE_TYPE': 'transactional'},
        'PDBX_UNOBS_OR_ZERO_OCC_RESIDUES': {'ATTRIBUTES': {'AUTH_ASYM_ID': 'auth_asym_id',
                                                           'AUTH_COMP_ID': 'auth_comp_id',
                                                           'AUTH_SEQ_ID': 'auth_seq_id',
                                                           'ID': 'id',
                                                           'LABEL_ASYM_ID': 'label_asym_id',
                                                           'LABEL_COMP_ID': 'label_comp_id',
                                                           'LABEL_SEQ_ID': 'label_seq_id',
                                                           'OCCUPANCY_FLAG': 'occupancy_flag',
                                                           'PDB_INS_CODE': 'PDB_ins_code',
                                                           'PDB_MODEL_NUM': 'PDB_model_num',
                                                           'POLYMER_FLAG': 'polymer_flag',
                                                           'STRUCTURE_ID': 'Structure_ID'},
                                            'ATTRIBUTE_INFO': {'AUTH_ASYM_ID': {'NULLABLE': True,
                                                                                'ORDER': 6,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 10},
                                                               'AUTH_COMP_ID': {'NULLABLE': True,
                                                                                'ORDER': 7,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 10},
                                                               'AUTH_SEQ_ID': {'NULLABLE': True,
                                                                               'ORDER': 8,
                                                                               'PRECISION': 0,
                                                                               'PRIMARY_KEY': False,
                                                                               'SQL_TYPE': 'VARCHAR',
                                                                               'WIDTH': 10},
                                                               'ID': {'NULLABLE': False,
                                                                      'ORDER': 2,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'INT',
                                                                      'WIDTH': 10},
                                                               'LABEL_ASYM_ID': {'NULLABLE': True,
                                                                                 'ORDER': 10,
                                                                                 'PRECISION': 0,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'VARCHAR',
                                                                                 'WIDTH': 10},
                                                               'LABEL_COMP_ID': {'NULLABLE': True,
                                                                                 'ORDER': 11,
                                                                                 'PRECISION': 0,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'VARCHAR',
                                                                                 'WIDTH': 10},
                                                               'LABEL_SEQ_ID': {'NULLABLE': True,
                                                                                'ORDER': 12,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'INT',
                                                                                'WIDTH': 10},
                                                               'OCCUPANCY_FLAG': {'NULLABLE': True,
                                                                                  'ORDER': 4,
                                                                                  'PRECISION': 0,
                                                                                  'PRIMARY_KEY': False,
                                                                                  'SQL_TYPE': 'INT',
                                                                                  'WIDTH': 10},
                                                               'PDB_INS_CODE': {'NULLABLE': True,
                                                                                'ORDER': 9,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 10},
                                                               'PDB_MODEL_NUM': {'NULLABLE': True,
                                                                                 'ORDER': 5,
                                                                                 'PRECISION': 0,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'INT',
                                                                                 'WIDTH': 10},
                                                               'POLYMER_FLAG': {'NULLABLE': True,
                                                                                'ORDER': 3,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 10},
                                                               'STRUCTURE_ID': {'NULLABLE': False,
                                                                                'ORDER': 1,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': True,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 10}},
                                            'ATTRIBUTE_MAP': {'AUTH_ASYM_ID': ('pdbx_unobs_or_zero_occ_residues',
                                                                               'auth_asym_id',
                                                                               None,
                                                                               None),
                                                              'AUTH_COMP_ID': ('pdbx_unobs_or_zero_occ_residues',
                                                                               'auth_comp_id',
                                                                               None,
                                                                               None),
                                                              'AUTH_SEQ_ID': ('pdbx_unobs_or_zero_occ_residues',
                                                                              'auth_seq_id',
                                                                              None,
                                                                              None),
                                                              'ID': ('pdbx_unobs_or_zero_occ_residues', 'id', None, None),
                                                              'LABEL_ASYM_ID': ('pdbx_unobs_or_zero_occ_residues',
                                                                                'label_asym_id',
                                                                                None,
                                                                                None),
                                                              'LABEL_COMP_ID': ('pdbx_unobs_or_zero_occ_residues',
                                                                                'label_comp_id',
                                                                                None,
                                                                                None),
                                                              'LABEL_SEQ_ID': ('pdbx_unobs_or_zero_occ_residues',
                                                                               'label_seq_id',
                                                                               None,
                                                                               None),
                                                              'OCCUPANCY_FLAG': ('pdbx_unobs_or_zero_occ_residues',
                                                                                 'occupancy_flag',
                                                                                 None,
                                                                                 None),
                                                              'PDB_INS_CODE': ('pdbx_unobs_or_zero_occ_residues',
                                                                               'PDB_ins_code',
                                                                               None,
                                                                               None),
                                                              'PDB_MODEL_NUM': ('pdbx_unobs_or_zero_occ_residues',
                                                                                'PDB_model_num',
                                                                                None,
                                                                                None),
                                                              'POLYMER_FLAG': ('pdbx_unobs_or_zero_occ_residues',
                                                                               'polymer_flag',
                                                                               None,
                                                                               None),
                                                              'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                            'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                                        's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                            'MAP_MERGE_INDICES': {'pdbx_unobs_or_zero_occ_residues': {'ATTRIBUTES': ('id',),
                                                                                                      'TYPE': 'EQUI-JOIN'}},
                                            'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                            'TABLE_ID': 'PDBX_UNOBS_OR_ZERO_OCC_RESIDUES',
                                            'TABLE_NAME': 'pdbx_unobs_or_zero_occ_residues',
                                            'TABLE_TYPE': 'transactional'},
        'PDBX_VALIDATE_CHIRAL': {'ATTRIBUTES': {'AUTH_ASYM_ID': 'auth_asym_id',
                                                'AUTH_ATOM_ID': 'auth_atom_id',
                                                'AUTH_COMP_ID': 'auth_comp_id',
                                                'AUTH_SEQ_ID': 'auth_seq_id',
                                                'DETAILS': 'details',
                                                'ID': 'id',
                                                'LABEL_ALT_ID': 'label_alt_id',
                                                'OMEGA': 'omega',
                                                'PDB_INS_CODE': 'PDB_ins_code',
                                                'PDB_MODEL_NUM': 'PDB_model_num',
                                                'STRUCTURE_ID': 'Structure_ID'},
                                 'ATTRIBUTE_INFO': {'AUTH_ASYM_ID': {'NULLABLE': True,
                                                                     'ORDER': 4,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                                    'AUTH_ATOM_ID': {'NULLABLE': True,
                                                                     'ORDER': 5,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 6},
                                                    'AUTH_COMP_ID': {'NULLABLE': True,
                                                                     'ORDER': 7,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                                    'AUTH_SEQ_ID': {'NULLABLE': True,
                                                                    'ORDER': 8,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10},
                                                    'DETAILS': {'NULLABLE': True,
                                                                'ORDER': 11,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 80},
                                                    'ID': {'NULLABLE': False,
                                                           'ORDER': 2,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': True,
                                                           'SQL_TYPE': 'INT',
                                                           'WIDTH': 10},
                                                    'LABEL_ALT_ID': {'NULLABLE': True,
                                                                     'ORDER': 6,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                                    'OMEGA': {'NULLABLE': True,
                                                              'ORDER': 10,
                                                              'PRECISION': 6,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'FLOAT',
                                                              'WIDTH': 10},
                                                    'PDB_INS_CODE': {'NULLABLE': True,
                                                                     'ORDER': 9,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                                    'PDB_MODEL_NUM': {'NULLABLE': True,
                                                                      'ORDER': 3,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'INT',
                                                                      'WIDTH': 10},
                                                    'STRUCTURE_ID': {'NULLABLE': False,
                                                                     'ORDER': 1,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': True,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10}},
                                 'ATTRIBUTE_MAP': {'AUTH_ASYM_ID': ('pdbx_validate_chiral', 'auth_asym_id', None, None),
                                                   'AUTH_ATOM_ID': ('pdbx_validate_chiral', 'auth_atom_id', None, None),
                                                   'AUTH_COMP_ID': ('pdbx_validate_chiral', 'auth_comp_id', None, None),
                                                   'AUTH_SEQ_ID': ('pdbx_validate_chiral', 'auth_seq_id', None, None),
                                                   'DETAILS': ('pdbx_validate_chiral', 'details', None, None),
                                                   'ID': ('pdbx_validate_chiral', 'id', None, None),
                                                   'LABEL_ALT_ID': ('pdbx_validate_chiral', 'label_alt_id', None, None),
                                                   'OMEGA': ('pdbx_validate_chiral', 'omega', None, None),
                                                   'PDB_INS_CODE': ('pdbx_validate_chiral', 'PDB_ins_code', None, None),
                                                   'PDB_MODEL_NUM': ('pdbx_validate_chiral', 'PDB_model_num', None, None),
                                                   'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                 'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                             's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                 'MAP_MERGE_INDICES': {'pdbx_validate_chiral': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                                 'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                 'TABLE_ID': 'PDBX_VALIDATE_CHIRAL',
                                 'TABLE_NAME': 'pdbx_validate_chiral',
                                 'TABLE_TYPE': 'transactional'},
        'PDBX_VALIDATE_CLOSE_CONTACT': {'ATTRIBUTES': {'AUTH_ASYM_ID_1': 'auth_asym_id_1',
                                                       'AUTH_ASYM_ID_2': 'auth_asym_id_2',
                                                       'AUTH_ATOM_ID_1': 'auth_atom_id_1',
                                                       'AUTH_ATOM_ID_2': 'auth_atom_id_2',
                                                       'AUTH_COMP_ID_1': 'auth_comp_id_1',
                                                       'AUTH_COMP_ID_2': 'auth_comp_id_2',
                                                       'AUTH_SEQ_ID_1': 'auth_seq_id_1',
                                                       'AUTH_SEQ_ID_2': 'auth_seq_id_2',
                                                       'DIST': 'dist',
                                                       'ID': 'id',
                                                       'LABEL_ALT_ID_1': 'label_alt_id_1',
                                                       'LABEL_ALT_ID_2': 'label_alt_id_2',
                                                       'PDB_INS_CODE_1': 'PDB_ins_code_1',
                                                       'PDB_INS_CODE_2': 'PDB_ins_code_2',
                                                       'PDB_MODEL_NUM': 'PDB_model_num',
                                                       'STRUCTURE_ID': 'Structure_ID',
                                                       'SYMM_AS_XYZ_1': 'symm_as_xyz_1',
                                                       'SYMM_AS_XYZ_2': 'symm_as_xyz_2'},
                                        'ATTRIBUTE_INFO': {'AUTH_ASYM_ID_1': {'NULLABLE': True,
                                                                              'ORDER': 4,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                                           'AUTH_ASYM_ID_2': {'NULLABLE': True,
                                                                              'ORDER': 9,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                                           'AUTH_ATOM_ID_1': {'NULLABLE': True,
                                                                              'ORDER': 5,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 6},
                                                           'AUTH_ATOM_ID_2': {'NULLABLE': True,
                                                                              'ORDER': 8,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 6},
                                                           'AUTH_COMP_ID_1': {'NULLABLE': True,
                                                                              'ORDER': 6,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                                           'AUTH_COMP_ID_2': {'NULLABLE': True,
                                                                              'ORDER': 10,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                                           'AUTH_SEQ_ID_1': {'NULLABLE': True,
                                                                             'ORDER': 7,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                           'AUTH_SEQ_ID_2': {'NULLABLE': True,
                                                                             'ORDER': 11,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                           'DIST': {'NULLABLE': True,
                                                                    'ORDER': 18,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                                           'ID': {'NULLABLE': False,
                                                                  'ORDER': 2,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': True,
                                                                  'SQL_TYPE': 'INT',
                                                                  'WIDTH': 10},
                                                           'LABEL_ALT_ID_1': {'NULLABLE': True,
                                                                              'ORDER': 14,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                                           'LABEL_ALT_ID_2': {'NULLABLE': True,
                                                                              'ORDER': 15,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                                           'PDB_INS_CODE_1': {'NULLABLE': True,
                                                                              'ORDER': 12,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                                           'PDB_INS_CODE_2': {'NULLABLE': True,
                                                                              'ORDER': 13,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                                           'PDB_MODEL_NUM': {'NULLABLE': True,
                                                                             'ORDER': 3,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'INT',
                                                                             'WIDTH': 10},
                                                           'STRUCTURE_ID': {'NULLABLE': False,
                                                                            'ORDER': 1,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': True,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 10},
                                                           'SYMM_AS_XYZ_1': {'NULLABLE': True,
                                                                             'ORDER': 16,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 80},
                                                           'SYMM_AS_XYZ_2': {'NULLABLE': True,
                                                                             'ORDER': 17,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 80}},
                                        'ATTRIBUTE_MAP': {'AUTH_ASYM_ID_1': ('pdbx_validate_close_contact',
                                                                             'auth_asym_id_1',
                                                                             None,
                                                                             None),
                                                          'AUTH_ASYM_ID_2': ('pdbx_validate_close_contact',
                                                                             'auth_asym_id_2',
                                                                             None,
                                                                             None),
                                                          'AUTH_ATOM_ID_1': ('pdbx_validate_close_contact',
                                                                             'auth_atom_id_1',
                                                                             None,
                                                                             None),
                                                          'AUTH_ATOM_ID_2': ('pdbx_validate_close_contact',
                                                                             'auth_atom_id_2',
                                                                             None,
                                                                             None),
                                                          'AUTH_COMP_ID_1': ('pdbx_validate_close_contact',
                                                                             'auth_comp_id_1',
                                                                             None,
                                                                             None),
                                                          'AUTH_COMP_ID_2': ('pdbx_validate_close_contact',
                                                                             'auth_comp_id_2',
                                                                             None,
                                                                             None),
                                                          'AUTH_SEQ_ID_1': ('pdbx_validate_close_contact',
                                                                            'auth_seq_id_1',
                                                                            None,
                                                                            None),
                                                          'AUTH_SEQ_ID_2': ('pdbx_validate_close_contact',
                                                                            'auth_seq_id_2',
                                                                            None,
                                                                            None),
                                                          'DIST': ('pdbx_validate_close_contact', 'dist', None, None),
                                                          'ID': ('pdbx_validate_close_contact', 'id', None, None),
                                                          'LABEL_ALT_ID_1': ('pdbx_validate_close_contact',
                                                                             'label_alt_id_1',
                                                                             None,
                                                                             None),
                                                          'LABEL_ALT_ID_2': ('pdbx_validate_close_contact',
                                                                             'label_alt_id_2',
                                                                             None,
                                                                             None),
                                                          'PDB_INS_CODE_1': ('pdbx_validate_close_contact',
                                                                             'PDB_ins_code_1',
                                                                             None,
                                                                             None),
                                                          'PDB_INS_CODE_2': ('pdbx_validate_close_contact',
                                                                             'PDB_ins_code_2',
                                                                             None,
                                                                             None),
                                                          'PDB_MODEL_NUM': ('pdbx_validate_close_contact',
                                                                            'PDB_model_num',
                                                                            None,
                                                                            None),
                                                          'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                          'SYMM_AS_XYZ_1': ('pdbx_validate_close_contact',
                                                                            'symm_as_xyz_1',
                                                                            None,
                                                                            None),
                                                          'SYMM_AS_XYZ_2': ('pdbx_validate_close_contact',
                                                                            'symm_as_xyz_2',
                                                                            None,
                                                                            None)},
                                        'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                                    's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                        'MAP_MERGE_INDICES': {'pdbx_validate_close_contact': {'ATTRIBUTES': ('id',),
                                                                                              'TYPE': 'EQUI-JOIN'}},
                                        'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                        'TABLE_ID': 'PDBX_VALIDATE_CLOSE_CONTACT',
                                        'TABLE_NAME': 'pdbx_validate_close_contact',
                                        'TABLE_TYPE': 'transactional'},
        'PDBX_VALIDATE_MAIN_CHAIN_PLANE': {'ATTRIBUTES': {'AUTH_ASYM_ID': 'auth_asym_id',
                                                          'AUTH_COMP_ID': 'auth_comp_id',
                                                          'AUTH_SEQ_ID': 'auth_seq_id',
                                                          'ID': 'id',
                                                          'IMPROPER_TORSION_ANGLE': 'improper_torsion_angle',
                                                          'PDB_INS_CODE': 'PDB_ins_code',
                                                          'PDB_MODEL_NUM': 'PDB_model_num',
                                                          'STRUCTURE_ID': 'Structure_ID'},
                                           'ATTRIBUTE_INFO': {'AUTH_ASYM_ID': {'NULLABLE': True,
                                                                               'ORDER': 4,
                                                                               'PRECISION': 0,
                                                                               'PRIMARY_KEY': False,
                                                                               'SQL_TYPE': 'VARCHAR',
                                                                               'WIDTH': 10},
                                                              'AUTH_COMP_ID': {'NULLABLE': True,
                                                                               'ORDER': 5,
                                                                               'PRECISION': 0,
                                                                               'PRIMARY_KEY': False,
                                                                               'SQL_TYPE': 'VARCHAR',
                                                                               'WIDTH': 10},
                                                              'AUTH_SEQ_ID': {'NULLABLE': True,
                                                                              'ORDER': 6,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                                              'ID': {'NULLABLE': False,
                                                                     'ORDER': 2,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': True,
                                                                     'SQL_TYPE': 'INT',
                                                                     'WIDTH': 10},
                                                              'IMPROPER_TORSION_ANGLE': {'NULLABLE': True,
                                                                                         'ORDER': 8,
                                                                                         'PRECISION': 6,
                                                                                         'PRIMARY_KEY': False,
                                                                                         'SQL_TYPE': 'FLOAT',
                                                                                         'WIDTH': 10},
                                                              'PDB_INS_CODE': {'NULLABLE': True,
                                                                               'ORDER': 7,
                                                                               'PRECISION': 0,
                                                                               'PRIMARY_KEY': False,
                                                                               'SQL_TYPE': 'VARCHAR',
                                                                               'WIDTH': 10},
                                                              'PDB_MODEL_NUM': {'NULLABLE': True,
                                                                                'ORDER': 3,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'INT',
                                                                                'WIDTH': 10},
                                                              'STRUCTURE_ID': {'NULLABLE': False,
                                                                               'ORDER': 1,
                                                                               'PRECISION': 0,
                                                                               'PRIMARY_KEY': True,
                                                                               'SQL_TYPE': 'VARCHAR',
                                                                               'WIDTH': 10}},
                                           'ATTRIBUTE_MAP': {'AUTH_ASYM_ID': ('pdbx_validate_main_chain_plane',
                                                                              'auth_asym_id',
                                                                              None,
                                                                              None),
                                                             'AUTH_COMP_ID': ('pdbx_validate_main_chain_plane',
                                                                              'auth_comp_id',
                                                                              None,
                                                                              None),
                                                             'AUTH_SEQ_ID': ('pdbx_validate_main_chain_plane',
                                                                             'auth_seq_id',
                                                                             None,
                                                                             None),
                                                             'ID': ('pdbx_validate_main_chain_plane', 'id', None, None),
                                                             'IMPROPER_TORSION_ANGLE': ('pdbx_validate_main_chain_plane',
                                                                                        'improper_torsion_angle',
                                                                                        None,
                                                                                        None),
                                                             'PDB_INS_CODE': ('pdbx_validate_main_chain_plane',
                                                                              'PDB_ins_code',
                                                                              None,
                                                                              None),
                                                             'PDB_MODEL_NUM': ('pdbx_validate_main_chain_plane',
                                                                               'PDB_model_num',
                                                                               None,
                                                                               None),
                                                             'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                           'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                                       's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                           'MAP_MERGE_INDICES': {'pdbx_validate_main_chain_plane': {'ATTRIBUTES': ('id',),
                                                                                                    'TYPE': 'EQUI-JOIN'}},
                                           'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                           'TABLE_ID': 'PDBX_VALIDATE_MAIN_CHAIN_PLANE',
                                           'TABLE_NAME': 'pdbx_validate_main_chain_plane',
                                           'TABLE_TYPE': 'transactional'},
        'PDBX_VALIDATE_PEPTIDE_OMEGA': {'ATTRIBUTES': {'AUTH_ASYM_ID_1': 'auth_asym_id_1',
                                                       'AUTH_ASYM_ID_2': 'auth_asym_id_2',
                                                       'AUTH_COMP_ID_1': 'auth_comp_id_1',
                                                       'AUTH_COMP_ID_2': 'auth_comp_id_2',
                                                       'AUTH_SEQ_ID_1': 'auth_seq_id_1',
                                                       'AUTH_SEQ_ID_2': 'auth_seq_id_2',
                                                       'ID': 'id',
                                                       'LABEL_ALT_ID_1': 'label_alt_id_1',
                                                       'LABEL_ALT_ID_2': 'label_alt_id_2',
                                                       'OMEGA': 'omega',
                                                       'PDB_INS_CODE_1': 'PDB_ins_code_1',
                                                       'PDB_INS_CODE_2': 'PDB_ins_code_2',
                                                       'PDB_MODEL_NUM': 'PDB_model_num',
                                                       'STRUCTURE_ID': 'Structure_ID'},
                                        'ATTRIBUTE_INFO': {'AUTH_ASYM_ID_1': {'NULLABLE': True,
                                                                              'ORDER': 4,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                                           'AUTH_ASYM_ID_2': {'NULLABLE': True,
                                                                              'ORDER': 5,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                                           'AUTH_COMP_ID_1': {'NULLABLE': True,
                                                                              'ORDER': 6,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                                           'AUTH_COMP_ID_2': {'NULLABLE': True,
                                                                              'ORDER': 7,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                                           'AUTH_SEQ_ID_1': {'NULLABLE': True,
                                                                             'ORDER': 8,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                           'AUTH_SEQ_ID_2': {'NULLABLE': True,
                                                                             'ORDER': 9,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                           'ID': {'NULLABLE': False,
                                                                  'ORDER': 2,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': True,
                                                                  'SQL_TYPE': 'INT',
                                                                  'WIDTH': 10},
                                                           'LABEL_ALT_ID_1': {'NULLABLE': True,
                                                                              'ORDER': 12,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                                           'LABEL_ALT_ID_2': {'NULLABLE': True,
                                                                              'ORDER': 13,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                                           'OMEGA': {'NULLABLE': True,
                                                                     'ORDER': 14,
                                                                     'PRECISION': 6,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'FLOAT',
                                                                     'WIDTH': 10},
                                                           'PDB_INS_CODE_1': {'NULLABLE': True,
                                                                              'ORDER': 10,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                                           'PDB_INS_CODE_2': {'NULLABLE': True,
                                                                              'ORDER': 11,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                                           'PDB_MODEL_NUM': {'NULLABLE': True,
                                                                             'ORDER': 3,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'INT',
                                                                             'WIDTH': 10},
                                                           'STRUCTURE_ID': {'NULLABLE': False,
                                                                            'ORDER': 1,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': True,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 10}},
                                        'ATTRIBUTE_MAP': {'AUTH_ASYM_ID_1': ('pdbx_validate_peptide_omega',
                                                                             'auth_asym_id_1',
                                                                             None,
                                                                             None),
                                                          'AUTH_ASYM_ID_2': ('pdbx_validate_peptide_omega',
                                                                             'auth_asym_id_2',
                                                                             None,
                                                                             None),
                                                          'AUTH_COMP_ID_1': ('pdbx_validate_peptide_omega',
                                                                             'auth_comp_id_1',
                                                                             None,
                                                                             None),
                                                          'AUTH_COMP_ID_2': ('pdbx_validate_peptide_omega',
                                                                             'auth_comp_id_2',
                                                                             None,
                                                                             None),
                                                          'AUTH_SEQ_ID_1': ('pdbx_validate_peptide_omega',
                                                                            'auth_seq_id_1',
                                                                            None,
                                                                            None),
                                                          'AUTH_SEQ_ID_2': ('pdbx_validate_peptide_omega',
                                                                            'auth_seq_id_2',
                                                                            None,
                                                                            None),
                                                          'ID': ('pdbx_validate_peptide_omega', 'id', None, None),
                                                          'LABEL_ALT_ID_1': ('pdbx_validate_peptide_omega',
                                                                             'label_alt_id_1',
                                                                             None,
                                                                             None),
                                                          'LABEL_ALT_ID_2': ('pdbx_validate_peptide_omega',
                                                                             'label_alt_id_2',
                                                                             None,
                                                                             None),
                                                          'OMEGA': ('pdbx_validate_peptide_omega', 'omega', None, None),
                                                          'PDB_INS_CODE_1': ('pdbx_validate_peptide_omega',
                                                                             'PDB_ins_code_1',
                                                                             None,
                                                                             None),
                                                          'PDB_INS_CODE_2': ('pdbx_validate_peptide_omega',
                                                                             'PDB_ins_code_2',
                                                                             None,
                                                                             None),
                                                          'PDB_MODEL_NUM': ('pdbx_validate_peptide_omega',
                                                                            'PDB_model_num',
                                                                            None,
                                                                            None),
                                                          'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                        'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                                    's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                        'MAP_MERGE_INDICES': {'pdbx_validate_peptide_omega': {'ATTRIBUTES': ('id',),
                                                                                              'TYPE': 'EQUI-JOIN'}},
                                        'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                        'TABLE_ID': 'PDBX_VALIDATE_PEPTIDE_OMEGA',
                                        'TABLE_NAME': 'pdbx_validate_peptide_omega',
                                        'TABLE_TYPE': 'transactional'},
        'PDBX_VALIDATE_PLANES': {'ATTRIBUTES': {'AUTH_ASYM_ID': 'auth_asym_id',
                                                'AUTH_COMP_ID': 'auth_comp_id',
                                                'AUTH_SEQ_ID': 'auth_seq_id',
                                                'ID': 'id',
                                                'PDB_INS_CODE': 'PDB_ins_code',
                                                'PDB_MODEL_NUM': 'PDB_model_num',
                                                'RMSD': 'rmsd',
                                                'STRUCTURE_ID': 'Structure_ID',
                                                'TYPE': 'type'},
                                 'ATTRIBUTE_INFO': {'AUTH_ASYM_ID': {'NULLABLE': True,
                                                                     'ORDER': 4,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                                    'AUTH_COMP_ID': {'NULLABLE': True,
                                                                     'ORDER': 5,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                                    'AUTH_SEQ_ID': {'NULLABLE': True,
                                                                    'ORDER': 6,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10},
                                                    'ID': {'NULLABLE': False,
                                                           'ORDER': 2,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': True,
                                                           'SQL_TYPE': 'INT',
                                                           'WIDTH': 10},
                                                    'PDB_INS_CODE': {'NULLABLE': True,
                                                                     'ORDER': 7,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                                    'PDB_MODEL_NUM': {'NULLABLE': True,
                                                                      'ORDER': 3,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'INT',
                                                                      'WIDTH': 10},
                                                    'RMSD': {'NULLABLE': True,
                                                             'ORDER': 8,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                                    'STRUCTURE_ID': {'NULLABLE': False,
                                                                     'ORDER': 1,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': True,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                                    'TYPE': {'NULLABLE': True,
                                                             'ORDER': 9,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 80}},
                                 'ATTRIBUTE_MAP': {'AUTH_ASYM_ID': ('pdbx_validate_planes', 'auth_asym_id', None, None),
                                                   'AUTH_COMP_ID': ('pdbx_validate_planes', 'auth_comp_id', None, None),
                                                   'AUTH_SEQ_ID': ('pdbx_validate_planes', 'auth_seq_id', None, None),
                                                   'ID': ('pdbx_validate_planes', 'id', None, None),
                                                   'PDB_INS_CODE': ('pdbx_validate_planes', 'PDB_ins_code', None, None),
                                                   'PDB_MODEL_NUM': ('pdbx_validate_planes', 'PDB_model_num', None, None),
                                                   'RMSD': ('pdbx_validate_planes', 'rmsd', None, None),
                                                   'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                   'TYPE': ('pdbx_validate_planes', 'type', None, None)},
                                 'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                             's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                 'MAP_MERGE_INDICES': {'pdbx_validate_planes': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                                 'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                 'TABLE_ID': 'PDBX_VALIDATE_PLANES',
                                 'TABLE_NAME': 'pdbx_validate_planes',
                                 'TABLE_TYPE': 'transactional'},
        'PDBX_VALIDATE_PLANES_ATOM': {'ATTRIBUTES': {'ATOM_DEVIATION': 'atom_deviation',
                                                     'AUTH_ASYM_ID': 'auth_asym_id',
                                                     'AUTH_ATOM_ID': 'auth_atom_id',
                                                     'AUTH_COMP_ID': 'auth_comp_id',
                                                     'AUTH_SEQ_ID': 'auth_seq_id',
                                                     'ID': 'id',
                                                     'PDB_INS_CODE': 'PDB_ins_code',
                                                     'PDB_MODEL_NUM': 'PDB_model_num',
                                                     'PLANE_ID': 'plane_id',
                                                     'STRUCTURE_ID': 'Structure_ID'},
                                      'ATTRIBUTE_INFO': {'ATOM_DEVIATION': {'NULLABLE': True,
                                                                            'ORDER': 10,
                                                                            'PRECISION': 6,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'FLOAT',
                                                                            'WIDTH': 10},
                                                         'AUTH_ASYM_ID': {'NULLABLE': True,
                                                                          'ORDER': 5,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                         'AUTH_ATOM_ID': {'NULLABLE': True,
                                                                          'ORDER': 9,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 6},
                                                         'AUTH_COMP_ID': {'NULLABLE': True,
                                                                          'ORDER': 6,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                         'AUTH_SEQ_ID': {'NULLABLE': True,
                                                                         'ORDER': 7,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                                         'ID': {'NULLABLE': False,
                                                                'ORDER': 3,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'INT',
                                                                'WIDTH': 10},
                                                         'PDB_INS_CODE': {'NULLABLE': True,
                                                                          'ORDER': 8,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                         'PDB_MODEL_NUM': {'NULLABLE': True,
                                                                           'ORDER': 4,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'INT',
                                                                           'WIDTH': 10},
                                                         'PLANE_ID': {'NULLABLE': True,
                                                                      'ORDER': 2,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'INT',
                                                                      'WIDTH': 10},
                                                         'STRUCTURE_ID': {'NULLABLE': False,
                                                                          'ORDER': 1,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': True,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10}},
                                      'ATTRIBUTE_MAP': {'ATOM_DEVIATION': ('pdbx_validate_planes_atom',
                                                                           'atom_deviation',
                                                                           None,
                                                                           None),
                                                        'AUTH_ASYM_ID': ('pdbx_validate_planes_atom',
                                                                         'auth_asym_id',
                                                                         None,
                                                                         None),
                                                        'AUTH_ATOM_ID': ('pdbx_validate_planes_atom',
                                                                         'auth_atom_id',
                                                                         None,
                                                                         None),
                                                        'AUTH_COMP_ID': ('pdbx_validate_planes_atom',
                                                                         'auth_comp_id',
                                                                         None,
                                                                         None),
                                                        'AUTH_SEQ_ID': ('pdbx_validate_planes_atom',
                                                                        'auth_seq_id',
                                                                        None,
                                                                        None),
                                                        'ID': ('pdbx_validate_planes_atom', 'id', None, None),
                                                        'PDB_INS_CODE': ('pdbx_validate_planes_atom',
                                                                         'PDB_ins_code',
                                                                         None,
                                                                         None),
                                                        'PDB_MODEL_NUM': ('pdbx_validate_planes_atom',
                                                                          'PDB_model_num',
                                                                          None,
                                                                          None),
                                                        'PLANE_ID': ('pdbx_validate_planes_atom', 'plane_id', None, None),
                                                        'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                      'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                                  's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                      'MAP_MERGE_INDICES': {'pdbx_validate_planes_atom': {'ATTRIBUTES': ('id',),
                                                                                          'TYPE': 'EQUI-JOIN'}},
                                      'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                      'TABLE_ID': 'PDBX_VALIDATE_PLANES_ATOM',
                                      'TABLE_NAME': 'pdbx_validate_planes_atom',
                                      'TABLE_TYPE': 'transactional'},
        'PDBX_VALIDATE_RMSD_ANGLE': {'ATTRIBUTES': {'ANGLE_DEVIATION': 'angle_deviation',
                                                    'ANGLE_VALUE': 'angle_value',
                                                    'AUTH_ASYM_ID_1': 'auth_asym_id_1',
                                                    'AUTH_ASYM_ID_2': 'auth_asym_id_2',
                                                    'AUTH_ASYM_ID_3': 'auth_asym_id_3',
                                                    'AUTH_ATOM_ID_1': 'auth_atom_id_1',
                                                    'AUTH_ATOM_ID_2': 'auth_atom_id_2',
                                                    'AUTH_ATOM_ID_3': 'auth_atom_id_3',
                                                    'AUTH_COMP_ID_1': 'auth_comp_id_1',
                                                    'AUTH_COMP_ID_2': 'auth_comp_id_2',
                                                    'AUTH_COMP_ID_3': 'auth_comp_id_3',
                                                    'AUTH_SEQ_ID_1': 'auth_seq_id_1',
                                                    'AUTH_SEQ_ID_2': 'auth_seq_id_2',
                                                    'AUTH_SEQ_ID_3': 'auth_seq_id_3',
                                                    'ID': 'id',
                                                    'LABEL_ALT_ID_1': 'label_alt_id_1',
                                                    'LABEL_ALT_ID_2': 'label_alt_id_2',
                                                    'LABEL_ALT_ID_3': 'label_alt_id_3',
                                                    'LINKER_FLAG': 'linker_flag',
                                                    'PDB_INS_CODE_1': 'PDB_ins_code_1',
                                                    'PDB_INS_CODE_2': 'PDB_ins_code_2',
                                                    'PDB_INS_CODE_3': 'PDB_ins_code_3',
                                                    'PDB_MODEL_NUM': 'PDB_model_num',
                                                    'STRUCTURE_ID': 'Structure_ID'},
                                     'ATTRIBUTE_INFO': {'ANGLE_DEVIATION': {'NULLABLE': True,
                                                                            'ORDER': 22,
                                                                            'PRECISION': 6,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'FLOAT',
                                                                            'WIDTH': 10},
                                                        'ANGLE_VALUE': {'NULLABLE': True,
                                                                        'ORDER': 23,
                                                                        'PRECISION': 6,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'FLOAT',
                                                                        'WIDTH': 10},
                                                        'AUTH_ASYM_ID_1': {'NULLABLE': True,
                                                                           'ORDER': 4,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10},
                                                        'AUTH_ASYM_ID_2': {'NULLABLE': True,
                                                                           'ORDER': 9,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10},
                                                        'AUTH_ASYM_ID_3': {'NULLABLE': True,
                                                                           'ORDER': 13,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10},
                                                        'AUTH_ATOM_ID_1': {'NULLABLE': True,
                                                                           'ORDER': 5,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 6},
                                                        'AUTH_ATOM_ID_2': {'NULLABLE': True,
                                                                           'ORDER': 8,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 6},
                                                        'AUTH_ATOM_ID_3': {'NULLABLE': True,
                                                                           'ORDER': 12,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 6},
                                                        'AUTH_COMP_ID_1': {'NULLABLE': True,
                                                                           'ORDER': 6,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10},
                                                        'AUTH_COMP_ID_2': {'NULLABLE': True,
                                                                           'ORDER': 10,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10},
                                                        'AUTH_COMP_ID_3': {'NULLABLE': True,
                                                                           'ORDER': 14,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10},
                                                        'AUTH_SEQ_ID_1': {'NULLABLE': True,
                                                                          'ORDER': 7,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                        'AUTH_SEQ_ID_2': {'NULLABLE': True,
                                                                          'ORDER': 11,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                        'AUTH_SEQ_ID_3': {'NULLABLE': True,
                                                                          'ORDER': 15,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                        'ID': {'NULLABLE': False,
                                                               'ORDER': 2,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'INT',
                                                               'WIDTH': 10},
                                                        'LABEL_ALT_ID_1': {'NULLABLE': True,
                                                                           'ORDER': 19,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10},
                                                        'LABEL_ALT_ID_2': {'NULLABLE': True,
                                                                           'ORDER': 20,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10},
                                                        'LABEL_ALT_ID_3': {'NULLABLE': True,
                                                                           'ORDER': 21,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10},
                                                        'LINKER_FLAG': {'NULLABLE': True,
                                                                        'ORDER': 24,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 80},
                                                        'PDB_INS_CODE_1': {'NULLABLE': True,
                                                                           'ORDER': 16,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10},
                                                        'PDB_INS_CODE_2': {'NULLABLE': True,
                                                                           'ORDER': 17,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10},
                                                        'PDB_INS_CODE_3': {'NULLABLE': True,
                                                                           'ORDER': 18,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10},
                                                        'PDB_MODEL_NUM': {'NULLABLE': True,
                                                                          'ORDER': 3,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'INT',
                                                                          'WIDTH': 10},
                                                        'STRUCTURE_ID': {'NULLABLE': False,
                                                                         'ORDER': 1,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': True,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10}},
                                     'ATTRIBUTE_MAP': {'ANGLE_DEVIATION': ('pdbx_validate_rmsd_angle',
                                                                           'angle_deviation',
                                                                           None,
                                                                           None),
                                                       'ANGLE_VALUE': ('pdbx_validate_rmsd_angle', 'angle_value', None, None),
                                                       'AUTH_ASYM_ID_1': ('pdbx_validate_rmsd_angle',
                                                                          'auth_asym_id_1',
                                                                          None,
                                                                          None),
                                                       'AUTH_ASYM_ID_2': ('pdbx_validate_rmsd_angle',
                                                                          'auth_asym_id_2',
                                                                          None,
                                                                          None),
                                                       'AUTH_ASYM_ID_3': ('pdbx_validate_rmsd_angle',
                                                                          'auth_asym_id_3',
                                                                          None,
                                                                          None),
                                                       'AUTH_ATOM_ID_1': ('pdbx_validate_rmsd_angle',
                                                                          'auth_atom_id_1',
                                                                          None,
                                                                          None),
                                                       'AUTH_ATOM_ID_2': ('pdbx_validate_rmsd_angle',
                                                                          'auth_atom_id_2',
                                                                          None,
                                                                          None),
                                                       'AUTH_ATOM_ID_3': ('pdbx_validate_rmsd_angle',
                                                                          'auth_atom_id_3',
                                                                          None,
                                                                          None),
                                                       'AUTH_COMP_ID_1': ('pdbx_validate_rmsd_angle',
                                                                          'auth_comp_id_1',
                                                                          None,
                                                                          None),
                                                       'AUTH_COMP_ID_2': ('pdbx_validate_rmsd_angle',
                                                                          'auth_comp_id_2',
                                                                          None,
                                                                          None),
                                                       'AUTH_COMP_ID_3': ('pdbx_validate_rmsd_angle',
                                                                          'auth_comp_id_3',
                                                                          None,
                                                                          None),
                                                       'AUTH_SEQ_ID_1': ('pdbx_validate_rmsd_angle',
                                                                         'auth_seq_id_1',
                                                                         None,
                                                                         None),
                                                       'AUTH_SEQ_ID_2': ('pdbx_validate_rmsd_angle',
                                                                         'auth_seq_id_2',
                                                                         None,
                                                                         None),
                                                       'AUTH_SEQ_ID_3': ('pdbx_validate_rmsd_angle',
                                                                         'auth_seq_id_3',
                                                                         None,
                                                                         None),
                                                       'ID': ('pdbx_validate_rmsd_angle', 'id', None, None),
                                                       'LABEL_ALT_ID_1': ('pdbx_validate_rmsd_angle',
                                                                          'label_alt_id_1',
                                                                          None,
                                                                          None),
                                                       'LABEL_ALT_ID_2': ('pdbx_validate_rmsd_angle',
                                                                          'label_alt_id_2',
                                                                          None,
                                                                          None),
                                                       'LABEL_ALT_ID_3': ('pdbx_validate_rmsd_angle',
                                                                          'label_alt_id_3',
                                                                          None,
                                                                          None),
                                                       'LINKER_FLAG': ('pdbx_validate_rmsd_angle', 'linker_flag', None, None),
                                                       'PDB_INS_CODE_1': ('pdbx_validate_rmsd_angle',
                                                                          'PDB_ins_code_1',
                                                                          None,
                                                                          None),
                                                       'PDB_INS_CODE_2': ('pdbx_validate_rmsd_angle',
                                                                          'PDB_ins_code_2',
                                                                          None,
                                                                          None),
                                                       'PDB_INS_CODE_3': ('pdbx_validate_rmsd_angle',
                                                                          'PDB_ins_code_3',
                                                                          None,
                                                                          None),
                                                       'PDB_MODEL_NUM': ('pdbx_validate_rmsd_angle',
                                                                         'PDB_model_num',
                                                                         None,
                                                                         None),
                                                       'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                     'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                                 's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                     'MAP_MERGE_INDICES': {'pdbx_validate_rmsd_angle': {'ATTRIBUTES': ('id',),
                                                                                        'TYPE': 'EQUI-JOIN'}},
                                     'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                     'TABLE_ID': 'PDBX_VALIDATE_RMSD_ANGLE',
                                     'TABLE_NAME': 'pdbx_validate_rmsd_angle',
                                     'TABLE_TYPE': 'transactional'},
        'PDBX_VALIDATE_RMSD_BOND': {'ATTRIBUTES': {'AUTH_ASYM_ID_1': 'auth_asym_id_1',
                                                   'AUTH_ASYM_ID_2': 'auth_asym_id_2',
                                                   'AUTH_ATOM_ID_1': 'auth_atom_id_1',
                                                   'AUTH_ATOM_ID_2': 'auth_atom_id_2',
                                                   'AUTH_COMP_ID_1': 'auth_comp_id_1',
                                                   'AUTH_COMP_ID_2': 'auth_comp_id_2',
                                                   'AUTH_SEQ_ID_1': 'auth_seq_id_1',
                                                   'AUTH_SEQ_ID_2': 'auth_seq_id_2',
                                                   'BOND_DEVIATION': 'bond_deviation',
                                                   'BOND_VALUE': 'bond_value',
                                                   'ID': 'id',
                                                   'LABEL_ALT_ID_1': 'label_alt_id_1',
                                                   'LABEL_ALT_ID_2': 'label_alt_id_2',
                                                   'LINKER_FLAG': 'linker_flag',
                                                   'PDB_INS_CODE_1': 'PDB_ins_code_1',
                                                   'PDB_INS_CODE_2': 'PDB_ins_code_2',
                                                   'PDB_MODEL_NUM': 'PDB_model_num',
                                                   'STRUCTURE_ID': 'Structure_ID'},
                                    'ATTRIBUTE_INFO': {'AUTH_ASYM_ID_1': {'NULLABLE': True,
                                                                          'ORDER': 4,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                       'AUTH_ASYM_ID_2': {'NULLABLE': True,
                                                                          'ORDER': 9,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                       'AUTH_ATOM_ID_1': {'NULLABLE': True,
                                                                          'ORDER': 5,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 6},
                                                       'AUTH_ATOM_ID_2': {'NULLABLE': True,
                                                                          'ORDER': 8,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 6},
                                                       'AUTH_COMP_ID_1': {'NULLABLE': True,
                                                                          'ORDER': 6,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                       'AUTH_COMP_ID_2': {'NULLABLE': True,
                                                                          'ORDER': 10,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                       'AUTH_SEQ_ID_1': {'NULLABLE': True,
                                                                         'ORDER': 7,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                                       'AUTH_SEQ_ID_2': {'NULLABLE': True,
                                                                         'ORDER': 11,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                                       'BOND_DEVIATION': {'NULLABLE': True,
                                                                          'ORDER': 16,
                                                                          'PRECISION': 6,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'FLOAT',
                                                                          'WIDTH': 10},
                                                       'BOND_VALUE': {'NULLABLE': True,
                                                                      'ORDER': 17,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                                       'ID': {'NULLABLE': False,
                                                              'ORDER': 2,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'INT',
                                                              'WIDTH': 10},
                                                       'LABEL_ALT_ID_1': {'NULLABLE': True,
                                                                          'ORDER': 14,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                       'LABEL_ALT_ID_2': {'NULLABLE': True,
                                                                          'ORDER': 15,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                       'LINKER_FLAG': {'NULLABLE': True,
                                                                       'ORDER': 18,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 80},
                                                       'PDB_INS_CODE_1': {'NULLABLE': True,
                                                                          'ORDER': 12,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                       'PDB_INS_CODE_2': {'NULLABLE': True,
                                                                          'ORDER': 13,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                       'PDB_MODEL_NUM': {'NULLABLE': True,
                                                                         'ORDER': 3,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'INT',
                                                                         'WIDTH': 10},
                                                       'STRUCTURE_ID': {'NULLABLE': False,
                                                                        'ORDER': 1,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': True,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10}},
                                    'ATTRIBUTE_MAP': {'AUTH_ASYM_ID_1': ('pdbx_validate_rmsd_bond',
                                                                         'auth_asym_id_1',
                                                                         None,
                                                                         None),
                                                      'AUTH_ASYM_ID_2': ('pdbx_validate_rmsd_bond',
                                                                         'auth_asym_id_2',
                                                                         None,
                                                                         None),
                                                      'AUTH_ATOM_ID_1': ('pdbx_validate_rmsd_bond',
                                                                         'auth_atom_id_1',
                                                                         None,
                                                                         None),
                                                      'AUTH_ATOM_ID_2': ('pdbx_validate_rmsd_bond',
                                                                         'auth_atom_id_2',
                                                                         None,
                                                                         None),
                                                      'AUTH_COMP_ID_1': ('pdbx_validate_rmsd_bond',
                                                                         'auth_comp_id_1',
                                                                         None,
                                                                         None),
                                                      'AUTH_COMP_ID_2': ('pdbx_validate_rmsd_bond',
                                                                         'auth_comp_id_2',
                                                                         None,
                                                                         None),
                                                      'AUTH_SEQ_ID_1': ('pdbx_validate_rmsd_bond',
                                                                        'auth_seq_id_1',
                                                                        None,
                                                                        None),
                                                      'AUTH_SEQ_ID_2': ('pdbx_validate_rmsd_bond',
                                                                        'auth_seq_id_2',
                                                                        None,
                                                                        None),
                                                      'BOND_DEVIATION': ('pdbx_validate_rmsd_bond',
                                                                         'bond_deviation',
                                                                         None,
                                                                         None),
                                                      'BOND_VALUE': ('pdbx_validate_rmsd_bond', 'bond_value', None, None),
                                                      'ID': ('pdbx_validate_rmsd_bond', 'id', None, None),
                                                      'LABEL_ALT_ID_1': ('pdbx_validate_rmsd_bond',
                                                                         'label_alt_id_1',
                                                                         None,
                                                                         None),
                                                      'LABEL_ALT_ID_2': ('pdbx_validate_rmsd_bond',
                                                                         'label_alt_id_2',
                                                                         None,
                                                                         None),
                                                      'LINKER_FLAG': ('pdbx_validate_rmsd_bond', 'linker_flag', None, None),
                                                      'PDB_INS_CODE_1': ('pdbx_validate_rmsd_bond',
                                                                         'PDB_ins_code_1',
                                                                         None,
                                                                         None),
                                                      'PDB_INS_CODE_2': ('pdbx_validate_rmsd_bond',
                                                                         'PDB_ins_code_2',
                                                                         None,
                                                                         None),
                                                      'PDB_MODEL_NUM': ('pdbx_validate_rmsd_bond',
                                                                        'PDB_model_num',
                                                                        None,
                                                                        None),
                                                      'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                    'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                                's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                    'MAP_MERGE_INDICES': {'pdbx_validate_rmsd_bond': {'ATTRIBUTES': ('id',),
                                                                                      'TYPE': 'EQUI-JOIN'}},
                                    'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                    'TABLE_ID': 'PDBX_VALIDATE_RMSD_BOND',
                                    'TABLE_NAME': 'pdbx_validate_rmsd_bond',
                                    'TABLE_TYPE': 'transactional'},
        'PDBX_VALIDATE_SYMM_CONTACT': {'ATTRIBUTES': {'AUTH_ASYM_ID_1': 'auth_asym_id_1',
                                                      'AUTH_ASYM_ID_2': 'auth_asym_id_2',
                                                      'AUTH_ATOM_ID_1': 'auth_atom_id_1',
                                                      'AUTH_ATOM_ID_2': 'auth_atom_id_2',
                                                      'AUTH_COMP_ID_1': 'auth_comp_id_1',
                                                      'AUTH_COMP_ID_2': 'auth_comp_id_2',
                                                      'AUTH_SEQ_ID_1': 'auth_seq_id_1',
                                                      'AUTH_SEQ_ID_2': 'auth_seq_id_2',
                                                      'DIST': 'dist',
                                                      'ID': 'id',
                                                      'LABEL_ALT_ID_1': 'label_alt_id_1',
                                                      'LABEL_ALT_ID_2': 'label_alt_id_2',
                                                      'PDB_INS_CODE_1': 'PDB_ins_code_1',
                                                      'PDB_INS_CODE_2': 'PDB_ins_code_2',
                                                      'PDB_MODEL_NUM': 'PDB_model_num',
                                                      'SITE_SYMMETRY_1': 'site_symmetry_1',
                                                      'SITE_SYMMETRY_2': 'site_symmetry_2',
                                                      'STRUCTURE_ID': 'Structure_ID'},
                                       'ATTRIBUTE_INFO': {'AUTH_ASYM_ID_1': {'NULLABLE': True,
                                                                             'ORDER': 4,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                          'AUTH_ASYM_ID_2': {'NULLABLE': True,
                                                                             'ORDER': 9,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                          'AUTH_ATOM_ID_1': {'NULLABLE': True,
                                                                             'ORDER': 5,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 6},
                                                          'AUTH_ATOM_ID_2': {'NULLABLE': True,
                                                                             'ORDER': 8,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 6},
                                                          'AUTH_COMP_ID_1': {'NULLABLE': True,
                                                                             'ORDER': 6,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                          'AUTH_COMP_ID_2': {'NULLABLE': True,
                                                                             'ORDER': 10,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                          'AUTH_SEQ_ID_1': {'NULLABLE': True,
                                                                            'ORDER': 7,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 10},
                                                          'AUTH_SEQ_ID_2': {'NULLABLE': True,
                                                                            'ORDER': 11,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 10},
                                                          'DIST': {'NULLABLE': True,
                                                                   'ORDER': 18,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                                          'ID': {'NULLABLE': False,
                                                                 'ORDER': 2,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': True,
                                                                 'SQL_TYPE': 'INT',
                                                                 'WIDTH': 10},
                                                          'LABEL_ALT_ID_1': {'NULLABLE': True,
                                                                             'ORDER': 14,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                          'LABEL_ALT_ID_2': {'NULLABLE': True,
                                                                             'ORDER': 15,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                          'PDB_INS_CODE_1': {'NULLABLE': True,
                                                                             'ORDER': 12,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                          'PDB_INS_CODE_2': {'NULLABLE': True,
                                                                             'ORDER': 13,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                                          'PDB_MODEL_NUM': {'NULLABLE': True,
                                                                            'ORDER': 3,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'INT',
                                                                            'WIDTH': 10},
                                                          'SITE_SYMMETRY_1': {'NULLABLE': True,
                                                                              'ORDER': 16,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 80},
                                                          'SITE_SYMMETRY_2': {'NULLABLE': True,
                                                                              'ORDER': 17,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 80},
                                                          'STRUCTURE_ID': {'NULLABLE': False,
                                                                           'ORDER': 1,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': True,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10}},
                                       'ATTRIBUTE_MAP': {'AUTH_ASYM_ID_1': ('pdbx_validate_symm_contact',
                                                                            'auth_asym_id_1',
                                                                            None,
                                                                            None),
                                                         'AUTH_ASYM_ID_2': ('pdbx_validate_symm_contact',
                                                                            'auth_asym_id_2',
                                                                            None,
                                                                            None),
                                                         'AUTH_ATOM_ID_1': ('pdbx_validate_symm_contact',
                                                                            'auth_atom_id_1',
                                                                            None,
                                                                            None),
                                                         'AUTH_ATOM_ID_2': ('pdbx_validate_symm_contact',
                                                                            'auth_atom_id_2',
                                                                            None,
                                                                            None),
                                                         'AUTH_COMP_ID_1': ('pdbx_validate_symm_contact',
                                                                            'auth_comp_id_1',
                                                                            None,
                                                                            None),
                                                         'AUTH_COMP_ID_2': ('pdbx_validate_symm_contact',
                                                                            'auth_comp_id_2',
                                                                            None,
                                                                            None),
                                                         'AUTH_SEQ_ID_1': ('pdbx_validate_symm_contact',
                                                                           'auth_seq_id_1',
                                                                           None,
                                                                           None),
                                                         'AUTH_SEQ_ID_2': ('pdbx_validate_symm_contact',
                                                                           'auth_seq_id_2',
                                                                           None,
                                                                           None),
                                                         'DIST': ('pdbx_validate_symm_contact', 'dist', None, None),
                                                         'ID': ('pdbx_validate_symm_contact', 'id', None, None),
                                                         'LABEL_ALT_ID_1': ('pdbx_validate_symm_contact',
                                                                            'label_alt_id_1',
                                                                            None,
                                                                            None),
                                                         'LABEL_ALT_ID_2': ('pdbx_validate_symm_contact',
                                                                            'label_alt_id_2',
                                                                            None,
                                                                            None),
                                                         'PDB_INS_CODE_1': ('pdbx_validate_symm_contact',
                                                                            'PDB_ins_code_1',
                                                                            None,
                                                                            None),
                                                         'PDB_INS_CODE_2': ('pdbx_validate_symm_contact',
                                                                            'PDB_ins_code_2',
                                                                            None,
                                                                            None),
                                                         'PDB_MODEL_NUM': ('pdbx_validate_symm_contact',
                                                                           'PDB_model_num',
                                                                           None,
                                                                           None),
                                                         'SITE_SYMMETRY_1': ('pdbx_validate_symm_contact',
                                                                             'site_symmetry_1',
                                                                             None,
                                                                             None),
                                                         'SITE_SYMMETRY_2': ('pdbx_validate_symm_contact',
                                                                             'site_symmetry_2',
                                                                             None,
                                                                             None),
                                                         'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                       'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                                   's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                       'MAP_MERGE_INDICES': {'pdbx_validate_symm_contact': {'ATTRIBUTES': ('id',),
                                                                                            'TYPE': 'EQUI-JOIN'}},
                                       'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                       'TABLE_ID': 'PDBX_VALIDATE_SYMM_CONTACT',
                                       'TABLE_NAME': 'pdbx_validate_symm_contact',
                                       'TABLE_TYPE': 'transactional'},
        'PDBX_VALIDATE_TORSION': {'ATTRIBUTES': {'AUTH_ASYM_ID': 'auth_asym_id',
                                                 'AUTH_COMP_ID': 'auth_comp_id',
                                                 'AUTH_SEQ_ID': 'auth_seq_id',
                                                 'ID': 'id',
                                                 'PDB_INS_CODE': 'PDB_ins_code',
                                                 'PDB_MODEL_NUM': 'PDB_model_num',
                                                 'PHI': 'phi',
                                                 'PSI': 'psi',
                                                 'STRUCTURE_ID': 'Structure_ID'},
                                  'ATTRIBUTE_INFO': {'AUTH_ASYM_ID': {'NULLABLE': True,
                                                                      'ORDER': 4,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                                     'AUTH_COMP_ID': {'NULLABLE': True,
                                                                      'ORDER': 5,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                                     'AUTH_SEQ_ID': {'NULLABLE': True,
                                                                     'ORDER': 6,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                                     'ID': {'NULLABLE': False,
                                                            'ORDER': 2,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': True,
                                                            'SQL_TYPE': 'INT',
                                                            'WIDTH': 10},
                                                     'PDB_INS_CODE': {'NULLABLE': True,
                                                                      'ORDER': 7,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                                     'PDB_MODEL_NUM': {'NULLABLE': True,
                                                                       'ORDER': 3,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'INT',
                                                                       'WIDTH': 10},
                                                     'PHI': {'NULLABLE': True,
                                                             'ORDER': 8,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                                     'PSI': {'NULLABLE': True,
                                                             'ORDER': 9,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                                     'STRUCTURE_ID': {'NULLABLE': False,
                                                                      'ORDER': 1,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10}},
                                  'ATTRIBUTE_MAP': {'AUTH_ASYM_ID': ('pdbx_validate_torsion', 'auth_asym_id', None, None),
                                                    'AUTH_COMP_ID': ('pdbx_validate_torsion', 'auth_comp_id', None, None),
                                                    'AUTH_SEQ_ID': ('pdbx_validate_torsion', 'auth_seq_id', None, None),
                                                    'ID': ('pdbx_validate_torsion', 'id', None, None),
                                                    'PDB_INS_CODE': ('pdbx_validate_torsion', 'PDB_ins_code', None, None),
                                                    'PDB_MODEL_NUM': ('pdbx_validate_torsion', 'PDB_model_num', None, None),
                                                    'PHI': ('pdbx_validate_torsion', 'phi', None, None),
                                                    'PSI': ('pdbx_validate_torsion', 'psi', None, None),
                                                    'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                  'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                              's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                  'MAP_MERGE_INDICES': {'pdbx_validate_torsion': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                                  'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                  'TABLE_ID': 'PDBX_VALIDATE_TORSION',
                                  'TABLE_NAME': 'pdbx_validate_torsion',
                                  'TABLE_TYPE': 'transactional'},
        'PDBX_VERSION': {'ATTRIBUTES': {'DETAILS': 'details',
                                        'ENTRY_ID': 'entry_id',
                                        'MAJOR_VERSION': 'major_version',
                                        'MINOR_VERSION': 'minor_version',
                                        'REVISION_DATE': 'revision_date',
                                        'REVISION_TYPE': 'revision_type',
                                        'STRUCTURE_ID': 'Structure_ID'},
                         'ATTRIBUTE_INFO': {'DETAILS': {'NULLABLE': True,
                                                        'ORDER': 6,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 200},
                                            'ENTRY_ID': {'NULLABLE': False,
                                                         'ORDER': 2,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': True,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 10},
                                            'MAJOR_VERSION': {'NULLABLE': False,
                                                              'ORDER': 4,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'INT',
                                                              'WIDTH': 10},
                                            'MINOR_VERSION': {'NULLABLE': False,
                                                              'ORDER': 5,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10},
                                            'REVISION_DATE': {'NULLABLE': True,
                                                              'ORDER': 3,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'DATETIME',
                                                              'WIDTH': 15},
                                            'REVISION_TYPE': {'NULLABLE': False,
                                                              'ORDER': 7,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 80},
                                            'STRUCTURE_ID': {'NULLABLE': False,
                                                             'ORDER': 1,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 10}},
                         'ATTRIBUTE_MAP': {'DETAILS': ('pdbx_version', 'details', None, None),
                                           'ENTRY_ID': ('pdbx_version', 'entry_id', None, None),
                                           'MAJOR_VERSION': ('pdbx_version', 'major_version', None, None),
                                           'MINOR_VERSION': ('pdbx_version', 'minor_version', None, None),
                                           'REVISION_DATE': ('pdbx_version', 'revision_date', None, None),
                                           'REVISION_TYPE': ('pdbx_version', 'revision_type', None, None),
                                           'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                         'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID',
                                                           'ENTRY_ID',
                                                           'MAJOR_VERSION',
                                                           'MINOR_VERSION',
                                                           'REVISION_TYPE'),
                                            'TYPE': 'UNIQUE'},
                                     's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                         'MAP_MERGE_INDICES': {'pdbx_version': {'ATTRIBUTES': ('entry_id',
                                                                               'major_version',
                                                                               'minor_version',
                                                                               'revision_type'),
                                                                'TYPE': 'EQUI-JOIN'}},
                         'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                         'TABLE_ID': 'PDBX_VERSION',
                         'TABLE_NAME': 'pdbx_version',
                         'TABLE_TYPE': 'transactional'},
        'PDBX_XPLOR_FILE': {'ATTRIBUTES': {'PARAM_FILE': 'param_file',
                                           'PDBX_REFINE_ID': 'pdbx_refine_id',
                                           'SERIAL_NO': 'serial_no',
                                           'STRUCTURE_ID': 'Structure_ID',
                                           'TOPOL_FILE': 'topol_file'},
                            'ATTRIBUTE_INFO': {'PARAM_FILE': {'NULLABLE': True,
                                                              'ORDER': 4,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 80},
                                               'PDBX_REFINE_ID': {'NULLABLE': False,
                                                                  'ORDER': 3,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': True,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 80},
                                               'SERIAL_NO': {'NULLABLE': False,
                                                             'ORDER': 2,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 18},
                                               'STRUCTURE_ID': {'NULLABLE': False,
                                                                'ORDER': 1,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                               'TOPOL_FILE': {'NULLABLE': True,
                                                              'ORDER': 5,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 80}},
                            'ATTRIBUTE_MAP': {'PARAM_FILE': ('pdbx_xplor_file', 'param_file', None, None),
                                              'PDBX_REFINE_ID': ('pdbx_xplor_file', 'pdbx_refine_id', None, None),
                                              'SERIAL_NO': ('pdbx_xplor_file', 'serial_no', None, None),
                                              'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                              'TOPOL_FILE': ('pdbx_xplor_file', 'topol_file', None, None)},
                            'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'SERIAL_NO', 'PDBX_REFINE_ID'),
                                               'TYPE': 'UNIQUE'},
                                        's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                            'MAP_MERGE_INDICES': {'pdbx_xplor_file': {'ATTRIBUTES': ('serial_no', 'pdbx_refine_id'),
                                                                      'TYPE': 'EQUI-JOIN'}},
                            'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                            'TABLE_ID': 'PDBX_XPLOR_FILE',
                            'TABLE_NAME': 'pdbx_xplor_file',
                            'TABLE_TYPE': 'transactional'},
        'PHASING': {'ATTRIBUTES': {'METHOD': 'method', 'STRUCTURE_ID': 'Structure_ID'},
                    'ATTRIBUTE_INFO': {'METHOD': {'NULLABLE': False,
                                                  'ORDER': 2,
                                                  'PRECISION': 0,
                                                  'PRIMARY_KEY': True,
                                                  'SQL_TYPE': 'VARCHAR',
                                                  'WIDTH': 10},
                                       'STRUCTURE_ID': {'NULLABLE': False,
                                                        'ORDER': 1,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': True,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 10}},
                    'ATTRIBUTE_MAP': {'METHOD': ('phasing', 'method', None, None),
                                      'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                    'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'METHOD'), 'TYPE': 'UNIQUE'},
                                's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                    'MAP_MERGE_INDICES': {'phasing': {'ATTRIBUTES': ('method',), 'TYPE': 'EQUI-JOIN'}},
                    'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                    'TABLE_ID': 'PHASING',
                    'TABLE_NAME': 'phasing',
                    'TABLE_TYPE': 'transactional'},
        'PHASING_AVERAGING': {'ATTRIBUTES': {'DETAILS': 'details',
                                             'ENTRY_ID': 'entry_id',
                                             'METHOD': 'method',
                                             'STRUCTURE_ID': 'Structure_ID'},
                              'ATTRIBUTE_INFO': {'DETAILS': {'NULLABLE': True,
                                                             'ORDER': 3,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 200},
                                                 'ENTRY_ID': {'NULLABLE': False,
                                                              'ORDER': 2,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10},
                                                 'METHOD': {'NULLABLE': True,
                                                            'ORDER': 4,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 200},
                                                 'STRUCTURE_ID': {'NULLABLE': False,
                                                                  'ORDER': 1,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': True,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10}},
                              'ATTRIBUTE_MAP': {'DETAILS': ('phasing_averaging', 'details', None, None),
                                                'ENTRY_ID': ('phasing_averaging', 'entry_id', None, None),
                                                'METHOD': ('phasing_averaging', 'method', None, None),
                                                'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                              'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID'), 'TYPE': 'UNIQUE'},
                                          's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                              'MAP_MERGE_INDICES': {'phasing_averaging': {'ATTRIBUTES': ('entry_id',), 'TYPE': 'EQUI-JOIN'}},
                              'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                              'TABLE_ID': 'PHASING_AVERAGING',
                              'TABLE_NAME': 'phasing_averaging',
                              'TABLE_TYPE': 'transactional'},
        'PHASING_ISOMORPHOUS': {'ATTRIBUTES': {'DETAILS': 'details',
                                               'ENTRY_ID': 'entry_id',
                                               'METHOD': 'method',
                                               'PARENT': 'parent',
                                               'STRUCTURE_ID': 'Structure_ID'},
                                'ATTRIBUTE_INFO': {'DETAILS': {'NULLABLE': True,
                                                               'ORDER': 3,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 200},
                                                   'ENTRY_ID': {'NULLABLE': False,
                                                                'ORDER': 2,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                                   'METHOD': {'NULLABLE': True,
                                                              'ORDER': 4,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 200},
                                                   'PARENT': {'NULLABLE': True,
                                                              'ORDER': 5,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 200},
                                                   'STRUCTURE_ID': {'NULLABLE': False,
                                                                    'ORDER': 1,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': True,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10}},
                                'ATTRIBUTE_MAP': {'DETAILS': ('phasing_isomorphous', 'details', None, None),
                                                  'ENTRY_ID': ('phasing_isomorphous', 'entry_id', None, None),
                                                  'METHOD': ('phasing_isomorphous', 'method', None, None),
                                                  'PARENT': ('phasing_isomorphous', 'parent', None, None),
                                                  'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID'), 'TYPE': 'UNIQUE'},
                                            's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                'MAP_MERGE_INDICES': {'phasing_isomorphous': {'ATTRIBUTES': ('entry_id',),
                                                                              'TYPE': 'EQUI-JOIN'}},
                                'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                'TABLE_ID': 'PHASING_ISOMORPHOUS',
                                'TABLE_NAME': 'phasing_isomorphous',
                                'TABLE_TYPE': 'transactional'},
        'PHASING_MAD': {'ATTRIBUTES': {'DETAILS': 'details',
                                       'ENTRY_ID': 'entry_id',
                                       'METHOD': 'method',
                                       'PDBX_ANOM_SCAT_METHOD': 'pdbx_anom_scat_method',
                                       'PDBX_D_RES_HIGH': 'pdbx_d_res_high',
                                       'PDBX_D_RES_LOW': 'pdbx_d_res_low',
                                       'PDBX_FOM': 'pdbx_fom',
                                       'PDBX_FOM_ACENTRIC': 'pdbx_fom_acentric',
                                       'PDBX_FOM_CENTRIC': 'pdbx_fom_centric',
                                       'PDBX_LOC': 'pdbx_loc',
                                       'PDBX_LOC_ACENTRIC': 'pdbx_loc_acentric',
                                       'PDBX_LOC_CENTRIC': 'pdbx_loc_centric',
                                       'PDBX_NUMBER_DATA_SETS': 'pdbx_number_data_sets',
                                       'PDBX_POWER': 'pdbx_power',
                                       'PDBX_POWER_ACENTRIC': 'pdbx_power_acentric',
                                       'PDBX_POWER_CENTRIC': 'pdbx_power_centric',
                                       'PDBX_REFLNS': 'pdbx_reflns',
                                       'PDBX_REFLNS_ACENTRIC': 'pdbx_reflns_acentric',
                                       'PDBX_REFLNS_CENTRIC': 'pdbx_reflns_centric',
                                       'PDBX_R_CULLIS': 'pdbx_R_cullis',
                                       'PDBX_R_CULLIS_ACENTRIC': 'pdbx_R_cullis_acentric',
                                       'PDBX_R_CULLIS_CENTRIC': 'pdbx_R_cullis_centric',
                                       'PDBX_R_KRAUT': 'pdbx_R_kraut',
                                       'PDBX_R_KRAUT_ACENTRIC': 'pdbx_R_kraut_acentric',
                                       'PDBX_R_KRAUT_CENTRIC': 'pdbx_R_kraut_centric',
                                       'STRUCTURE_ID': 'Structure_ID'},
                        'ATTRIBUTE_INFO': {'DETAILS': {'NULLABLE': True,
                                                       'ORDER': 3,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'VARCHAR',
                                                       'WIDTH': 200},
                                           'ENTRY_ID': {'NULLABLE': False,
                                                        'ORDER': 2,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': True,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 10},
                                           'METHOD': {'NULLABLE': True,
                                                      'ORDER': 4,
                                                      'PRECISION': 0,
                                                      'PRIMARY_KEY': False,
                                                      'SQL_TYPE': 'VARCHAR',
                                                      'WIDTH': 200},
                                           'PDBX_ANOM_SCAT_METHOD': {'NULLABLE': True,
                                                                     'ORDER': 26,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 200},
                                           'PDBX_D_RES_HIGH': {'NULLABLE': True,
                                                               'ORDER': 6,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                           'PDBX_D_RES_LOW': {'NULLABLE': True,
                                                              'ORDER': 5,
                                                              'PRECISION': 6,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'FLOAT',
                                                              'WIDTH': 10},
                                           'PDBX_FOM': {'NULLABLE': True,
                                                        'ORDER': 12,
                                                        'PRECISION': 6,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'FLOAT',
                                                        'WIDTH': 10},
                                           'PDBX_FOM_ACENTRIC': {'NULLABLE': True,
                                                                 'ORDER': 10,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                           'PDBX_FOM_CENTRIC': {'NULLABLE': True,
                                                                'ORDER': 11,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                           'PDBX_LOC': {'NULLABLE': True,
                                                        'ORDER': 21,
                                                        'PRECISION': 6,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'FLOAT',
                                                        'WIDTH': 10},
                                           'PDBX_LOC_ACENTRIC': {'NULLABLE': True,
                                                                 'ORDER': 20,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                           'PDBX_LOC_CENTRIC': {'NULLABLE': True,
                                                                'ORDER': 19,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                           'PDBX_NUMBER_DATA_SETS': {'NULLABLE': True,
                                                                     'ORDER': 25,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'INT',
                                                                     'WIDTH': 10},
                                           'PDBX_POWER': {'NULLABLE': True,
                                                          'ORDER': 24,
                                                          'PRECISION': 6,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'FLOAT',
                                                          'WIDTH': 10},
                                           'PDBX_POWER_ACENTRIC': {'NULLABLE': True,
                                                                   'ORDER': 23,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                           'PDBX_POWER_CENTRIC': {'NULLABLE': True,
                                                                  'ORDER': 22,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10},
                                           'PDBX_REFLNS': {'NULLABLE': True,
                                                           'ORDER': 9,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'INT',
                                                           'WIDTH': 10},
                                           'PDBX_REFLNS_ACENTRIC': {'NULLABLE': True,
                                                                    'ORDER': 7,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'INT',
                                                                    'WIDTH': 10},
                                           'PDBX_REFLNS_CENTRIC': {'NULLABLE': True,
                                                                   'ORDER': 8,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'INT',
                                                                   'WIDTH': 10},
                                           'PDBX_R_CULLIS': {'NULLABLE': True,
                                                             'ORDER': 15,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                           'PDBX_R_CULLIS_ACENTRIC': {'NULLABLE': True,
                                                                      'ORDER': 14,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                           'PDBX_R_CULLIS_CENTRIC': {'NULLABLE': True,
                                                                     'ORDER': 13,
                                                                     'PRECISION': 6,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'FLOAT',
                                                                     'WIDTH': 10},
                                           'PDBX_R_KRAUT': {'NULLABLE': True,
                                                            'ORDER': 18,
                                                            'PRECISION': 6,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'FLOAT',
                                                            'WIDTH': 10},
                                           'PDBX_R_KRAUT_ACENTRIC': {'NULLABLE': True,
                                                                     'ORDER': 17,
                                                                     'PRECISION': 6,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'FLOAT',
                                                                     'WIDTH': 10},
                                           'PDBX_R_KRAUT_CENTRIC': {'NULLABLE': True,
                                                                    'ORDER': 16,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                           'STRUCTURE_ID': {'NULLABLE': False,
                                                            'ORDER': 1,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': True,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 10}},
                        'ATTRIBUTE_MAP': {'DETAILS': ('phasing_MAD', 'details', None, None),
                                          'ENTRY_ID': ('phasing_MAD', 'entry_id', None, None),
                                          'METHOD': ('phasing_MAD', 'method', None, None),
                                          'PDBX_ANOM_SCAT_METHOD': ('phasing_MAD', 'pdbx_anom_scat_method', None, None),
                                          'PDBX_D_RES_HIGH': ('phasing_MAD', 'pdbx_d_res_high', None, None),
                                          'PDBX_D_RES_LOW': ('phasing_MAD', 'pdbx_d_res_low', None, None),
                                          'PDBX_FOM': ('phasing_MAD', 'pdbx_fom', None, None),
                                          'PDBX_FOM_ACENTRIC': ('phasing_MAD', 'pdbx_fom_acentric', None, None),
                                          'PDBX_FOM_CENTRIC': ('phasing_MAD', 'pdbx_fom_centric', None, None),
                                          'PDBX_LOC': ('phasing_MAD', 'pdbx_loc', None, None),
                                          'PDBX_LOC_ACENTRIC': ('phasing_MAD', 'pdbx_loc_acentric', None, None),
                                          'PDBX_LOC_CENTRIC': ('phasing_MAD', 'pdbx_loc_centric', None, None),
                                          'PDBX_NUMBER_DATA_SETS': ('phasing_MAD', 'pdbx_number_data_sets', None, None),
                                          'PDBX_POWER': ('phasing_MAD', 'pdbx_power', None, None),
                                          'PDBX_POWER_ACENTRIC': ('phasing_MAD', 'pdbx_power_acentric', None, None),
                                          'PDBX_POWER_CENTRIC': ('phasing_MAD', 'pdbx_power_centric', None, None),
                                          'PDBX_REFLNS': ('phasing_MAD', 'pdbx_reflns', None, None),
                                          'PDBX_REFLNS_ACENTRIC': ('phasing_MAD', 'pdbx_reflns_acentric', None, None),
                                          'PDBX_REFLNS_CENTRIC': ('phasing_MAD', 'pdbx_reflns_centric', None, None),
                                          'PDBX_R_CULLIS': ('phasing_MAD', 'pdbx_R_cullis', None, None),
                                          'PDBX_R_CULLIS_ACENTRIC': ('phasing_MAD', 'pdbx_R_cullis_acentric', None, None),
                                          'PDBX_R_CULLIS_CENTRIC': ('phasing_MAD', 'pdbx_R_cullis_centric', None, None),
                                          'PDBX_R_KRAUT': ('phasing_MAD', 'pdbx_R_kraut', None, None),
                                          'PDBX_R_KRAUT_ACENTRIC': ('phasing_MAD', 'pdbx_R_kraut_acentric', None, None),
                                          'PDBX_R_KRAUT_CENTRIC': ('phasing_MAD', 'pdbx_R_kraut_centric', None, None),
                                          'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                        'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID'), 'TYPE': 'UNIQUE'},
                                    's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                        'MAP_MERGE_INDICES': {'phasing_MAD': {'ATTRIBUTES': ('entry_id',), 'TYPE': 'EQUI-JOIN'}},
                        'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                        'TABLE_ID': 'PHASING_MAD',
                        'TABLE_NAME': 'phasing_MAD',
                        'TABLE_TYPE': 'transactional'},
        'PHASING_MAD_CLUST': {'ATTRIBUTES': {'EXPT_ID': 'expt_id',
                                             'ID': 'id',
                                             'NUMBER_SET': 'number_set',
                                             'STRUCTURE_ID': 'Structure_ID'},
                              'ATTRIBUTE_INFO': {'EXPT_ID': {'NULLABLE': False,
                                                             'ORDER': 2,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 80},
                                                 'ID': {'NULLABLE': False,
                                                        'ORDER': 3,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': True,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 80},
                                                 'NUMBER_SET': {'NULLABLE': True,
                                                                'ORDER': 4,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'INT',
                                                                'WIDTH': 10},
                                                 'STRUCTURE_ID': {'NULLABLE': False,
                                                                  'ORDER': 1,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': True,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10}},
                              'ATTRIBUTE_MAP': {'EXPT_ID': ('phasing_MAD_clust', 'expt_id', None, None),
                                                'ID': ('phasing_MAD_clust', 'id', None, None),
                                                'NUMBER_SET': ('phasing_MAD_clust', 'number_set', None, None),
                                                'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                              'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'EXPT_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                          's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                              'MAP_MERGE_INDICES': {'phasing_MAD_clust': {'ATTRIBUTES': ('expt_id', 'id'),
                                                                          'TYPE': 'EQUI-JOIN'}},
                              'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                              'TABLE_ID': 'PHASING_MAD_CLUST',
                              'TABLE_NAME': 'phasing_MAD_clust',
                              'TABLE_TYPE': 'transactional'},
        'PHASING_MAD_EXPT': {'ATTRIBUTES': {'DELTA_DELTA_PHI': 'delta_delta_phi',
                                            'DELTA_PHI': 'delta_phi',
                                            'DELTA_PHI_SIGMA': 'delta_phi_sigma',
                                            'ID': 'id',
                                            'MEAN_FOM': 'mean_fom',
                                            'NUMBER_CLUST': 'number_clust',
                                            'R_NORMAL_ALL': 'R_normal_all',
                                            'R_NORMAL_ANOM_SCAT': 'R_normal_anom_scat',
                                            'STRUCTURE_ID': 'Structure_ID'},
                             'ATTRIBUTE_INFO': {'DELTA_DELTA_PHI': {'NULLABLE': True,
                                                                    'ORDER': 2,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                                'DELTA_PHI': {'NULLABLE': True,
                                                              'ORDER': 3,
                                                              'PRECISION': 6,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'FLOAT',
                                                              'WIDTH': 10},
                                                'DELTA_PHI_SIGMA': {'NULLABLE': True,
                                                                    'ORDER': 4,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                                'ID': {'NULLABLE': False,
                                                       'ORDER': 5,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': True,
                                                       'SQL_TYPE': 'VARCHAR',
                                                       'WIDTH': 80},
                                                'MEAN_FOM': {'NULLABLE': True,
                                                             'ORDER': 6,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                                'NUMBER_CLUST': {'NULLABLE': True,
                                                                 'ORDER': 7,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'INT',
                                                                 'WIDTH': 10},
                                                'R_NORMAL_ALL': {'NULLABLE': True,
                                                                 'ORDER': 8,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                                'R_NORMAL_ANOM_SCAT': {'NULLABLE': True,
                                                                       'ORDER': 9,
                                                                       'PRECISION': 6,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'FLOAT',
                                                                       'WIDTH': 10},
                                                'STRUCTURE_ID': {'NULLABLE': False,
                                                                 'ORDER': 1,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': True,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10}},
                             'ATTRIBUTE_MAP': {'DELTA_DELTA_PHI': ('phasing_MAD_expt', 'delta_delta_phi', None, None),
                                               'DELTA_PHI': ('phasing_MAD_expt', 'delta_phi', None, None),
                                               'DELTA_PHI_SIGMA': ('phasing_MAD_expt', 'delta_phi_sigma', None, None),
                                               'ID': ('phasing_MAD_expt', 'id', None, None),
                                               'MEAN_FOM': ('phasing_MAD_expt', 'mean_fom', None, None),
                                               'NUMBER_CLUST': ('phasing_MAD_expt', 'number_clust', None, None),
                                               'R_NORMAL_ALL': ('phasing_MAD_expt', 'R_normal_all', None, None),
                                               'R_NORMAL_ANOM_SCAT': ('phasing_MAD_expt', 'R_normal_anom_scat', None, None),
                                               'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                             'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                         's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                             'MAP_MERGE_INDICES': {'phasing_MAD_expt': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                             'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                             'TABLE_ID': 'PHASING_MAD_EXPT',
                             'TABLE_NAME': 'phasing_MAD_expt',
                             'TABLE_TYPE': 'transactional'},
        'PHASING_MAD_RATIO': {'ATTRIBUTES': {'CLUST_ID': 'clust_id',
                                             'D_RES_HIGH': 'd_res_high',
                                             'D_RES_LOW': 'd_res_low',
                                             'EXPT_ID': 'expt_id',
                                             'RATIO_ONE_WL': 'ratio_one_wl',
                                             'RATIO_ONE_WL_CENTRIC': 'ratio_one_wl_centric',
                                             'RATIO_TWO_WL': 'ratio_two_wl',
                                             'STRUCTURE_ID': 'Structure_ID',
                                             'WAVELENGTH_1': 'wavelength_1',
                                             'WAVELENGTH_2': 'wavelength_2'},
                              'ATTRIBUTE_INFO': {'CLUST_ID': {'NULLABLE': False,
                                                              'ORDER': 2,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 80},
                                                 'D_RES_HIGH': {'NULLABLE': True,
                                                                'ORDER': 4,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                                 'D_RES_LOW': {'NULLABLE': True,
                                                               'ORDER': 5,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                                 'EXPT_ID': {'NULLABLE': False,
                                                             'ORDER': 3,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 80},
                                                 'RATIO_ONE_WL': {'NULLABLE': True,
                                                                  'ORDER': 6,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10},
                                                 'RATIO_ONE_WL_CENTRIC': {'NULLABLE': True,
                                                                          'ORDER': 7,
                                                                          'PRECISION': 6,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'FLOAT',
                                                                          'WIDTH': 10},
                                                 'RATIO_TWO_WL': {'NULLABLE': True,
                                                                  'ORDER': 8,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10},
                                                 'STRUCTURE_ID': {'NULLABLE': False,
                                                                  'ORDER': 1,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': True,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10},
                                                 'WAVELENGTH_1': {'NULLABLE': False,
                                                                  'ORDER': 9,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': True,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10},
                                                 'WAVELENGTH_2': {'NULLABLE': False,
                                                                  'ORDER': 10,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': True,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10}},
                              'ATTRIBUTE_MAP': {'CLUST_ID': ('phasing_MAD_ratio', 'clust_id', None, None),
                                                'D_RES_HIGH': ('phasing_MAD_ratio', 'd_res_high', None, None),
                                                'D_RES_LOW': ('phasing_MAD_ratio', 'd_res_low', None, None),
                                                'EXPT_ID': ('phasing_MAD_ratio', 'expt_id', None, None),
                                                'RATIO_ONE_WL': ('phasing_MAD_ratio', 'ratio_one_wl', None, None),
                                                'RATIO_ONE_WL_CENTRIC': ('phasing_MAD_ratio',
                                                                         'ratio_one_wl_centric',
                                                                         None,
                                                                         None),
                                                'RATIO_TWO_WL': ('phasing_MAD_ratio', 'ratio_two_wl', None, None),
                                                'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                'WAVELENGTH_1': ('phasing_MAD_ratio', 'wavelength_1', None, None),
                                                'WAVELENGTH_2': ('phasing_MAD_ratio', 'wavelength_2', None, None)},
                              'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID',
                                                                'CLUST_ID',
                                                                'EXPT_ID',
                                                                'WAVELENGTH_1',
                                                                'WAVELENGTH_2'),
                                                 'TYPE': 'UNIQUE'},
                                          's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                              'MAP_MERGE_INDICES': {'phasing_MAD_ratio': {'ATTRIBUTES': ('clust_id',
                                                                                         'expt_id',
                                                                                         'wavelength_1',
                                                                                         'wavelength_2'),
                                                                          'TYPE': 'EQUI-JOIN'}},
                              'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                              'TABLE_ID': 'PHASING_MAD_RATIO',
                              'TABLE_NAME': 'phasing_MAD_ratio',
                              'TABLE_TYPE': 'transactional'},
        'PHASING_MAD_SET': {'ATTRIBUTES': {'CLUST_ID': 'clust_id',
                                           'D_RES_HIGH': 'd_res_high',
                                           'D_RES_LOW': 'd_res_low',
                                           'EXPT_ID': 'expt_id',
                                           'F_DOUBLE_PRIME': 'f_double_prime',
                                           'F_PRIME': 'f_prime',
                                           'PDBX_ATOM_TYPE': 'pdbx_atom_type',
                                           'PDBX_F_DOUBLE_PRIME_REFINED': 'pdbx_f_double_prime_refined',
                                           'PDBX_F_PRIME_REFINED': 'pdbx_f_prime_refined',
                                           'SET_ID': 'set_id',
                                           'STRUCTURE_ID': 'Structure_ID',
                                           'WAVELENGTH': 'wavelength',
                                           'WAVELENGTH_DETAILS': 'wavelength_details'},
                            'ATTRIBUTE_INFO': {'CLUST_ID': {'NULLABLE': False,
                                                            'ORDER': 2,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': True,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 80},
                                               'D_RES_HIGH': {'NULLABLE': True,
                                                              'ORDER': 4,
                                                              'PRECISION': 6,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'FLOAT',
                                                              'WIDTH': 10},
                                               'D_RES_LOW': {'NULLABLE': True,
                                                             'ORDER': 5,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                               'EXPT_ID': {'NULLABLE': False,
                                                           'ORDER': 3,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': True,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 80},
                                               'F_DOUBLE_PRIME': {'NULLABLE': True,
                                                                  'ORDER': 6,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10},
                                               'F_PRIME': {'NULLABLE': True,
                                                           'ORDER': 7,
                                                           'PRECISION': 6,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'FLOAT',
                                                           'WIDTH': 10},
                                               'PDBX_ATOM_TYPE': {'NULLABLE': True,
                                                                  'ORDER': 11,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10},
                                               'PDBX_F_DOUBLE_PRIME_REFINED': {'NULLABLE': True,
                                                                               'ORDER': 13,
                                                                               'PRECISION': 6,
                                                                               'PRIMARY_KEY': False,
                                                                               'SQL_TYPE': 'FLOAT',
                                                                               'WIDTH': 10},
                                               'PDBX_F_PRIME_REFINED': {'NULLABLE': True,
                                                                        'ORDER': 12,
                                                                        'PRECISION': 6,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'FLOAT',
                                                                        'WIDTH': 10},
                                               'SET_ID': {'NULLABLE': False,
                                                          'ORDER': 8,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': True,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 80},
                                               'STRUCTURE_ID': {'NULLABLE': False,
                                                                'ORDER': 1,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                               'WAVELENGTH': {'NULLABLE': False,
                                                              'ORDER': 9,
                                                              'PRECISION': 6,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'FLOAT',
                                                              'WIDTH': 10},
                                               'WAVELENGTH_DETAILS': {'NULLABLE': True,
                                                                      'ORDER': 10,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 200}},
                            'ATTRIBUTE_MAP': {'CLUST_ID': ('phasing_MAD_set', 'clust_id', None, None),
                                              'D_RES_HIGH': ('phasing_MAD_set', 'd_res_high', None, None),
                                              'D_RES_LOW': ('phasing_MAD_set', 'd_res_low', None, None),
                                              'EXPT_ID': ('phasing_MAD_set', 'expt_id', None, None),
                                              'F_DOUBLE_PRIME': ('phasing_MAD_set', 'f_double_prime', None, None),
                                              'F_PRIME': ('phasing_MAD_set', 'f_prime', None, None),
                                              'PDBX_ATOM_TYPE': ('phasing_MAD_set', 'pdbx_atom_type', None, None),
                                              'PDBX_F_DOUBLE_PRIME_REFINED': ('phasing_MAD_set',
                                                                              'pdbx_f_double_prime_refined',
                                                                              None,
                                                                              None),
                                              'PDBX_F_PRIME_REFINED': ('phasing_MAD_set', 'pdbx_f_prime_refined', None, None),
                                              'SET_ID': ('phasing_MAD_set', 'set_id', None, None),
                                              'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                              'WAVELENGTH': ('phasing_MAD_set', 'wavelength', None, None),
                                              'WAVELENGTH_DETAILS': ('phasing_MAD_set', 'wavelength_details', None, None)},
                            'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'CLUST_ID', 'EXPT_ID', 'SET_ID', 'WAVELENGTH'),
                                               'TYPE': 'UNIQUE'},
                                        's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                            'MAP_MERGE_INDICES': {'phasing_MAD_set': {'ATTRIBUTES': ('clust_id',
                                                                                     'expt_id',
                                                                                     'set_id',
                                                                                     'wavelength'),
                                                                      'TYPE': 'EQUI-JOIN'}},
                            'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                            'TABLE_ID': 'PHASING_MAD_SET',
                            'TABLE_NAME': 'phasing_MAD_set',
                            'TABLE_TYPE': 'transactional'},
        'PHASING_MIR': {'ATTRIBUTES': {'DETAILS': 'details',
                                       'D_RES_HIGH': 'd_res_high',
                                       'D_RES_LOW': 'd_res_low',
                                       'ENTRY_ID': 'entry_id',
                                       'FOM': 'FOM',
                                       'FOM_ACENTRIC': 'FOM_acentric',
                                       'FOM_CENTRIC': 'FOM_centric',
                                       'METHOD': 'method',
                                       'PDBX_NUMBER_DERIVATIVES': 'pdbx_number_derivatives',
                                       'REFLNS': 'reflns',
                                       'REFLNS_ACENTRIC': 'reflns_acentric',
                                       'REFLNS_CENTRIC': 'reflns_centric',
                                       'REFLNS_CRITERION': 'reflns_criterion',
                                       'STRUCTURE_ID': 'Structure_ID'},
                        'ATTRIBUTE_INFO': {'DETAILS': {'NULLABLE': True,
                                                       'ORDER': 3,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'VARCHAR',
                                                       'WIDTH': 200},
                                           'D_RES_HIGH': {'NULLABLE': True,
                                                          'ORDER': 4,
                                                          'PRECISION': 6,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'FLOAT',
                                                          'WIDTH': 10},
                                           'D_RES_LOW': {'NULLABLE': True,
                                                         'ORDER': 5,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                           'ENTRY_ID': {'NULLABLE': False,
                                                        'ORDER': 2,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': True,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 10},
                                           'FOM': {'NULLABLE': True,
                                                   'ORDER': 6,
                                                   'PRECISION': 6,
                                                   'PRIMARY_KEY': False,
                                                   'SQL_TYPE': 'FLOAT',
                                                   'WIDTH': 10},
                                           'FOM_ACENTRIC': {'NULLABLE': True,
                                                            'ORDER': 7,
                                                            'PRECISION': 6,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'FLOAT',
                                                            'WIDTH': 10},
                                           'FOM_CENTRIC': {'NULLABLE': True,
                                                           'ORDER': 8,
                                                           'PRECISION': 6,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'FLOAT',
                                                           'WIDTH': 10},
                                           'METHOD': {'NULLABLE': True,
                                                      'ORDER': 9,
                                                      'PRECISION': 0,
                                                      'PRIMARY_KEY': False,
                                                      'SQL_TYPE': 'VARCHAR',
                                                      'WIDTH': 200},
                                           'PDBX_NUMBER_DERIVATIVES': {'NULLABLE': True,
                                                                       'ORDER': 14,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'INT',
                                                                       'WIDTH': 10},
                                           'REFLNS': {'NULLABLE': True,
                                                      'ORDER': 10,
                                                      'PRECISION': 0,
                                                      'PRIMARY_KEY': False,
                                                      'SQL_TYPE': 'INT',
                                                      'WIDTH': 10},
                                           'REFLNS_ACENTRIC': {'NULLABLE': True,
                                                               'ORDER': 11,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'INT',
                                                               'WIDTH': 10},
                                           'REFLNS_CENTRIC': {'NULLABLE': True,
                                                              'ORDER': 12,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'INT',
                                                              'WIDTH': 10},
                                           'REFLNS_CRITERION': {'NULLABLE': True,
                                                                'ORDER': 13,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 200},
                                           'STRUCTURE_ID': {'NULLABLE': False,
                                                            'ORDER': 1,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': True,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 10}},
                        'ATTRIBUTE_MAP': {'DETAILS': ('phasing_MIR', 'details', None, None),
                                          'D_RES_HIGH': ('phasing_MIR', 'd_res_high', None, None),
                                          'D_RES_LOW': ('phasing_MIR', 'd_res_low', None, None),
                                          'ENTRY_ID': ('phasing_MIR', 'entry_id', None, None),
                                          'FOM': ('phasing_MIR', 'FOM', None, None),
                                          'FOM_ACENTRIC': ('phasing_MIR', 'FOM_acentric', None, None),
                                          'FOM_CENTRIC': ('phasing_MIR', 'FOM_centric', None, None),
                                          'METHOD': ('phasing_MIR', 'method', None, None),
                                          'PDBX_NUMBER_DERIVATIVES': ('phasing_MIR', 'pdbx_number_derivatives', None, None),
                                          'REFLNS': ('phasing_MIR', 'reflns', None, None),
                                          'REFLNS_ACENTRIC': ('phasing_MIR', 'reflns_acentric', None, None),
                                          'REFLNS_CENTRIC': ('phasing_MIR', 'reflns_centric', None, None),
                                          'REFLNS_CRITERION': ('phasing_MIR', 'reflns_criterion', None, None),
                                          'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                        'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID'), 'TYPE': 'UNIQUE'},
                                    's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                        'MAP_MERGE_INDICES': {'phasing_MIR': {'ATTRIBUTES': ('entry_id',), 'TYPE': 'EQUI-JOIN'}},
                        'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                        'TABLE_ID': 'PHASING_MIR',
                        'TABLE_NAME': 'phasing_MIR',
                        'TABLE_TYPE': 'transactional'},
        'PHASING_MIR_DER': {'ATTRIBUTES': {'DER_SET_ID': 'der_set_id',
                                           'DETAILS': 'details',
                                           'D_RES_HIGH': 'd_res_high',
                                           'D_RES_LOW': 'd_res_low',
                                           'ID': 'id',
                                           'NATIVE_SET_ID': 'native_set_id',
                                           'NUMBER_OF_SITES': 'number_of_sites',
                                           'PDBX_FOM': 'pdbx_fom',
                                           'PDBX_FOM_ACENTRIC': 'pdbx_fom_acentric',
                                           'PDBX_FOM_CENTRIC': 'pdbx_fom_centric',
                                           'PDBX_LOC': 'pdbx_loc',
                                           'PDBX_LOC_ACENTRIC': 'pdbx_loc_acentric',
                                           'PDBX_LOC_CENTRIC': 'pdbx_loc_centric',
                                           'PDBX_POWER': 'pdbx_power',
                                           'PDBX_REFLNS': 'pdbx_reflns',
                                           'PDBX_R_CULLIS': 'pdbx_R_cullis',
                                           'PDBX_R_KRAUT': 'pdbx_R_kraut',
                                           'PDBX_R_KRAUT_ACENTRIC': 'pdbx_R_kraut_acentric',
                                           'PDBX_R_KRAUT_CENTRIC': 'pdbx_R_kraut_centric',
                                           'POWER_ACENTRIC': 'power_acentric',
                                           'POWER_CENTRIC': 'power_centric',
                                           'REFLNS_ACENTRIC': 'reflns_acentric',
                                           'REFLNS_ANOMALOUS': 'reflns_anomalous',
                                           'REFLNS_CENTRIC': 'reflns_centric',
                                           'REFLNS_CRITERIA': 'reflns_criteria',
                                           'R_CULLIS_ACENTRIC': 'R_cullis_acentric',
                                           'R_CULLIS_ANOMALOUS': 'R_cullis_anomalous',
                                           'R_CULLIS_CENTRIC': 'R_cullis_centric',
                                           'STRUCTURE_ID': 'Structure_ID'},
                            'ATTRIBUTE_INFO': {'DER_SET_ID': {'NULLABLE': True,
                                                              'ORDER': 4,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 80},
                                               'DETAILS': {'NULLABLE': True,
                                                           'ORDER': 5,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 200},
                                               'D_RES_HIGH': {'NULLABLE': True,
                                                              'ORDER': 2,
                                                              'PRECISION': 6,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'FLOAT',
                                                              'WIDTH': 10},
                                               'D_RES_LOW': {'NULLABLE': True,
                                                             'ORDER': 3,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                               'ID': {'NULLABLE': False,
                                                      'ORDER': 6,
                                                      'PRECISION': 0,
                                                      'PRIMARY_KEY': True,
                                                      'SQL_TYPE': 'VARCHAR',
                                                      'WIDTH': 80},
                                               'NATIVE_SET_ID': {'NULLABLE': True,
                                                                 'ORDER': 7,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 80},
                                               'NUMBER_OF_SITES': {'NULLABLE': True,
                                                                   'ORDER': 8,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'INT',
                                                                   'WIDTH': 10},
                                               'PDBX_FOM': {'NULLABLE': True,
                                                            'ORDER': 26,
                                                            'PRECISION': 6,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'FLOAT',
                                                            'WIDTH': 10},
                                               'PDBX_FOM_ACENTRIC': {'NULLABLE': True,
                                                                     'ORDER': 25,
                                                                     'PRECISION': 6,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'FLOAT',
                                                                     'WIDTH': 10},
                                               'PDBX_FOM_CENTRIC': {'NULLABLE': True,
                                                                    'ORDER': 24,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                               'PDBX_LOC': {'NULLABLE': True,
                                                            'ORDER': 23,
                                                            'PRECISION': 6,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'FLOAT',
                                                            'WIDTH': 10},
                                               'PDBX_LOC_ACENTRIC': {'NULLABLE': True,
                                                                     'ORDER': 22,
                                                                     'PRECISION': 6,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'FLOAT',
                                                                     'WIDTH': 10},
                                               'PDBX_LOC_CENTRIC': {'NULLABLE': True,
                                                                    'ORDER': 21,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                               'PDBX_POWER': {'NULLABLE': True,
                                                              'ORDER': 27,
                                                              'PRECISION': 6,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'FLOAT',
                                                              'WIDTH': 10},
                                               'PDBX_REFLNS': {'NULLABLE': True,
                                                               'ORDER': 29,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'INT',
                                                               'WIDTH': 10},
                                               'PDBX_R_CULLIS': {'NULLABLE': True,
                                                                 'ORDER': 28,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                               'PDBX_R_KRAUT': {'NULLABLE': True,
                                                                'ORDER': 20,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                               'PDBX_R_KRAUT_ACENTRIC': {'NULLABLE': True,
                                                                         'ORDER': 19,
                                                                         'PRECISION': 6,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'FLOAT',
                                                                         'WIDTH': 10},
                                               'PDBX_R_KRAUT_CENTRIC': {'NULLABLE': True,
                                                                        'ORDER': 18,
                                                                        'PRECISION': 6,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'FLOAT',
                                                                        'WIDTH': 10},
                                               'POWER_ACENTRIC': {'NULLABLE': True,
                                                                  'ORDER': 9,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10},
                                               'POWER_CENTRIC': {'NULLABLE': True,
                                                                 'ORDER': 10,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                               'REFLNS_ACENTRIC': {'NULLABLE': True,
                                                                   'ORDER': 14,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'INT',
                                                                   'WIDTH': 10},
                                               'REFLNS_ANOMALOUS': {'NULLABLE': True,
                                                                    'ORDER': 15,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'INT',
                                                                    'WIDTH': 10},
                                               'REFLNS_CENTRIC': {'NULLABLE': True,
                                                                  'ORDER': 16,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'INT',
                                                                  'WIDTH': 10},
                                               'REFLNS_CRITERIA': {'NULLABLE': True,
                                                                   'ORDER': 17,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 200},
                                               'R_CULLIS_ACENTRIC': {'NULLABLE': True,
                                                                     'ORDER': 11,
                                                                     'PRECISION': 6,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'FLOAT',
                                                                     'WIDTH': 10},
                                               'R_CULLIS_ANOMALOUS': {'NULLABLE': True,
                                                                      'ORDER': 12,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                               'R_CULLIS_CENTRIC': {'NULLABLE': True,
                                                                    'ORDER': 13,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                               'STRUCTURE_ID': {'NULLABLE': False,
                                                                'ORDER': 1,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10}},
                            'ATTRIBUTE_MAP': {'DER_SET_ID': ('phasing_MIR_der', 'der_set_id', None, None),
                                              'DETAILS': ('phasing_MIR_der', 'details', None, None),
                                              'D_RES_HIGH': ('phasing_MIR_der', 'd_res_high', None, None),
                                              'D_RES_LOW': ('phasing_MIR_der', 'd_res_low', None, None),
                                              'ID': ('phasing_MIR_der', 'id', None, None),
                                              'NATIVE_SET_ID': ('phasing_MIR_der', 'native_set_id', None, None),
                                              'NUMBER_OF_SITES': ('phasing_MIR_der', 'number_of_sites', None, None),
                                              'PDBX_FOM': ('phasing_MIR_der', 'pdbx_fom', None, None),
                                              'PDBX_FOM_ACENTRIC': ('phasing_MIR_der', 'pdbx_fom_acentric', None, None),
                                              'PDBX_FOM_CENTRIC': ('phasing_MIR_der', 'pdbx_fom_centric', None, None),
                                              'PDBX_LOC': ('phasing_MIR_der', 'pdbx_loc', None, None),
                                              'PDBX_LOC_ACENTRIC': ('phasing_MIR_der', 'pdbx_loc_acentric', None, None),
                                              'PDBX_LOC_CENTRIC': ('phasing_MIR_der', 'pdbx_loc_centric', None, None),
                                              'PDBX_POWER': ('phasing_MIR_der', 'pdbx_power', None, None),
                                              'PDBX_REFLNS': ('phasing_MIR_der', 'pdbx_reflns', None, None),
                                              'PDBX_R_CULLIS': ('phasing_MIR_der', 'pdbx_R_cullis', None, None),
                                              'PDBX_R_KRAUT': ('phasing_MIR_der', 'pdbx_R_kraut', None, None),
                                              'PDBX_R_KRAUT_ACENTRIC': ('phasing_MIR_der',
                                                                        'pdbx_R_kraut_acentric',
                                                                        None,
                                                                        None),
                                              'PDBX_R_KRAUT_CENTRIC': ('phasing_MIR_der', 'pdbx_R_kraut_centric', None, None),
                                              'POWER_ACENTRIC': ('phasing_MIR_der', 'power_acentric', None, None),
                                              'POWER_CENTRIC': ('phasing_MIR_der', 'power_centric', None, None),
                                              'REFLNS_ACENTRIC': ('phasing_MIR_der', 'reflns_acentric', None, None),
                                              'REFLNS_ANOMALOUS': ('phasing_MIR_der', 'reflns_anomalous', None, None),
                                              'REFLNS_CENTRIC': ('phasing_MIR_der', 'reflns_centric', None, None),
                                              'REFLNS_CRITERIA': ('phasing_MIR_der', 'reflns_criteria', None, None),
                                              'R_CULLIS_ACENTRIC': ('phasing_MIR_der', 'R_cullis_acentric', None, None),
                                              'R_CULLIS_ANOMALOUS': ('phasing_MIR_der', 'R_cullis_anomalous', None, None),
                                              'R_CULLIS_CENTRIC': ('phasing_MIR_der', 'R_cullis_centric', None, None),
                                              'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                            'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                        's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                            'MAP_MERGE_INDICES': {'phasing_MIR_der': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                            'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                            'TABLE_ID': 'PHASING_MIR_DER',
                            'TABLE_NAME': 'phasing_MIR_der',
                            'TABLE_TYPE': 'transactional'},
        'PHASING_MIR_DER_REFLN': {'ATTRIBUTES': {'DER_ID': 'der_id',
                                                 'F_CALC': 'F_calc',
                                                 'F_CALC_AU': 'F_calc_au',
                                                 'F_MEAS': 'F_meas',
                                                 'F_MEAS_AU': 'F_meas_au',
                                                 'F_MEAS_SIGMA': 'F_meas_sigma',
                                                 'F_MEAS_SIGMA_AU': 'F_meas_sigma_au',
                                                 'HL_A_ISO': 'HL_A_iso',
                                                 'HL_B_ISO': 'HL_B_iso',
                                                 'HL_C_ISO': 'HL_C_iso',
                                                 'HL_D_ISO': 'HL_D_iso',
                                                 'INDEX_H': 'index_h',
                                                 'INDEX_K': 'index_k',
                                                 'INDEX_L': 'index_l',
                                                 'PHASE_CALC': 'phase_calc',
                                                 'SET_ID': 'set_id',
                                                 'STRUCTURE_ID': 'Structure_ID'},
                                  'ATTRIBUTE_INFO': {'DER_ID': {'NULLABLE': False,
                                                                'ORDER': 2,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 80},
                                                     'F_CALC': {'NULLABLE': True,
                                                                'ORDER': 3,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                                     'F_CALC_AU': {'NULLABLE': True,
                                                                   'ORDER': 4,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                                     'F_MEAS': {'NULLABLE': True,
                                                                'ORDER': 5,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                                     'F_MEAS_AU': {'NULLABLE': True,
                                                                   'ORDER': 6,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                                     'F_MEAS_SIGMA': {'NULLABLE': True,
                                                                      'ORDER': 7,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                                     'F_MEAS_SIGMA_AU': {'NULLABLE': True,
                                                                         'ORDER': 8,
                                                                         'PRECISION': 6,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'FLOAT',
                                                                         'WIDTH': 10},
                                                     'HL_A_ISO': {'NULLABLE': True,
                                                                  'ORDER': 9,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10},
                                                     'HL_B_ISO': {'NULLABLE': True,
                                                                  'ORDER': 10,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10},
                                                     'HL_C_ISO': {'NULLABLE': True,
                                                                  'ORDER': 11,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10},
                                                     'HL_D_ISO': {'NULLABLE': True,
                                                                  'ORDER': 12,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10},
                                                     'INDEX_H': {'NULLABLE': False,
                                                                 'ORDER': 13,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': True,
                                                                 'SQL_TYPE': 'INT',
                                                                 'WIDTH': 10},
                                                     'INDEX_K': {'NULLABLE': False,
                                                                 'ORDER': 14,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': True,
                                                                 'SQL_TYPE': 'INT',
                                                                 'WIDTH': 10},
                                                     'INDEX_L': {'NULLABLE': False,
                                                                 'ORDER': 15,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': True,
                                                                 'SQL_TYPE': 'INT',
                                                                 'WIDTH': 10},
                                                     'PHASE_CALC': {'NULLABLE': True,
                                                                    'ORDER': 16,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                                     'SET_ID': {'NULLABLE': False,
                                                                'ORDER': 17,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 80},
                                                     'STRUCTURE_ID': {'NULLABLE': False,
                                                                      'ORDER': 1,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10}},
                                  'ATTRIBUTE_MAP': {'DER_ID': ('phasing_MIR_der_refln', 'der_id', None, None),
                                                    'F_CALC': ('phasing_MIR_der_refln', 'F_calc', None, None),
                                                    'F_CALC_AU': ('phasing_MIR_der_refln', 'F_calc_au', None, None),
                                                    'F_MEAS': ('phasing_MIR_der_refln', 'F_meas', None, None),
                                                    'F_MEAS_AU': ('phasing_MIR_der_refln', 'F_meas_au', None, None),
                                                    'F_MEAS_SIGMA': ('phasing_MIR_der_refln', 'F_meas_sigma', None, None),
                                                    'F_MEAS_SIGMA_AU': ('phasing_MIR_der_refln',
                                                                        'F_meas_sigma_au',
                                                                        None,
                                                                        None),
                                                    'HL_A_ISO': ('phasing_MIR_der_refln', 'HL_A_iso', None, None),
                                                    'HL_B_ISO': ('phasing_MIR_der_refln', 'HL_B_iso', None, None),
                                                    'HL_C_ISO': ('phasing_MIR_der_refln', 'HL_C_iso', None, None),
                                                    'HL_D_ISO': ('phasing_MIR_der_refln', 'HL_D_iso', None, None),
                                                    'INDEX_H': ('phasing_MIR_der_refln', 'index_h', None, None),
                                                    'INDEX_K': ('phasing_MIR_der_refln', 'index_k', None, None),
                                                    'INDEX_L': ('phasing_MIR_der_refln', 'index_l', None, None),
                                                    'PHASE_CALC': ('phasing_MIR_der_refln', 'phase_calc', None, None),
                                                    'SET_ID': ('phasing_MIR_der_refln', 'set_id', None, None),
                                                    'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                  'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID',
                                                                    'DER_ID',
                                                                    'INDEX_H',
                                                                    'INDEX_K',
                                                                    'INDEX_L',
                                                                    'SET_ID'),
                                                     'TYPE': 'UNIQUE'},
                                              's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                  'MAP_MERGE_INDICES': {'phasing_MIR_der_refln': {'ATTRIBUTES': ('der_id',
                                                                                                 'index_h',
                                                                                                 'index_k',
                                                                                                 'index_l',
                                                                                                 'set_id'),
                                                                                  'TYPE': 'EQUI-JOIN'}},
                                  'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                  'TABLE_ID': 'PHASING_MIR_DER_REFLN',
                                  'TABLE_NAME': 'phasing_MIR_der_refln',
                                  'TABLE_TYPE': 'transactional'},
        'PHASING_MIR_DER_SHELL': {'ATTRIBUTES': {'DER_ID': 'der_id',
                                                 'D_RES_HIGH': 'd_res_high',
                                                 'D_RES_LOW': 'd_res_low',
                                                 'FOM': 'fom',
                                                 'HA_AMPL': 'ha_ampl',
                                                 'LOC': 'loc',
                                                 'PDBX_FOM_ACENTRIC': 'pdbx_fom_acentric',
                                                 'PDBX_FOM_CENTRIC': 'pdbx_fom_centric',
                                                 'PDBX_LOC_ACENTRIC': 'pdbx_loc_acentric',
                                                 'PDBX_LOC_CENTRIC': 'pdbx_loc_centric',
                                                 'PDBX_POWER_ACENTRIC': 'pdbx_power_acentric',
                                                 'PDBX_POWER_CENTRIC': 'pdbx_power_centric',
                                                 'PDBX_REFLNS_ACENTRIC': 'pdbx_reflns_acentric',
                                                 'PDBX_REFLNS_CENTRIC': 'pdbx_reflns_centric',
                                                 'PDBX_R_CULLIS_ACENTRIC': 'pdbx_R_cullis_acentric',
                                                 'PDBX_R_CULLIS_CENTRIC': 'pdbx_R_cullis_centric',
                                                 'PDBX_R_KRAUT_ACENTRIC': 'pdbx_R_kraut_acentric',
                                                 'PDBX_R_KRAUT_CENTRIC': 'pdbx_R_kraut_centric',
                                                 'PHASE': 'phase',
                                                 'POWER': 'power',
                                                 'REFLNS': 'reflns',
                                                 'R_CULLIS': 'R_cullis',
                                                 'R_KRAUT': 'R_kraut',
                                                 'STRUCTURE_ID': 'Structure_ID'},
                                  'ATTRIBUTE_INFO': {'DER_ID': {'NULLABLE': False,
                                                                'ORDER': 2,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 80},
                                                     'D_RES_HIGH': {'NULLABLE': False,
                                                                    'ORDER': 3,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': True,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                                     'D_RES_LOW': {'NULLABLE': False,
                                                                   'ORDER': 4,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': True,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                                     'FOM': {'NULLABLE': True,
                                                             'ORDER': 5,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                                     'HA_AMPL': {'NULLABLE': True,
                                                                 'ORDER': 6,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                                     'LOC': {'NULLABLE': True,
                                                             'ORDER': 7,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                                     'PDBX_FOM_ACENTRIC': {'NULLABLE': True,
                                                                           'ORDER': 22,
                                                                           'PRECISION': 6,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'FLOAT',
                                                                           'WIDTH': 10},
                                                     'PDBX_FOM_CENTRIC': {'NULLABLE': True,
                                                                          'ORDER': 21,
                                                                          'PRECISION': 6,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'FLOAT',
                                                                          'WIDTH': 10},
                                                     'PDBX_LOC_ACENTRIC': {'NULLABLE': True,
                                                                           'ORDER': 18,
                                                                           'PRECISION': 6,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'FLOAT',
                                                                           'WIDTH': 10},
                                                     'PDBX_LOC_CENTRIC': {'NULLABLE': True,
                                                                          'ORDER': 17,
                                                                          'PRECISION': 6,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'FLOAT',
                                                                          'WIDTH': 10},
                                                     'PDBX_POWER_ACENTRIC': {'NULLABLE': True,
                                                                             'ORDER': 20,
                                                                             'PRECISION': 6,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'FLOAT',
                                                                             'WIDTH': 10},
                                                     'PDBX_POWER_CENTRIC': {'NULLABLE': True,
                                                                            'ORDER': 19,
                                                                            'PRECISION': 6,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'FLOAT',
                                                                            'WIDTH': 10},
                                                     'PDBX_REFLNS_ACENTRIC': {'NULLABLE': True,
                                                                              'ORDER': 24,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'INT',
                                                                              'WIDTH': 10},
                                                     'PDBX_REFLNS_CENTRIC': {'NULLABLE': True,
                                                                             'ORDER': 23,
                                                                             'PRECISION': 6,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'FLOAT',
                                                                             'WIDTH': 10},
                                                     'PDBX_R_CULLIS_ACENTRIC': {'NULLABLE': True,
                                                                                'ORDER': 14,
                                                                                'PRECISION': 6,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'FLOAT',
                                                                                'WIDTH': 10},
                                                     'PDBX_R_CULLIS_CENTRIC': {'NULLABLE': True,
                                                                               'ORDER': 13,
                                                                               'PRECISION': 6,
                                                                               'PRIMARY_KEY': False,
                                                                               'SQL_TYPE': 'FLOAT',
                                                                               'WIDTH': 10},
                                                     'PDBX_R_KRAUT_ACENTRIC': {'NULLABLE': True,
                                                                               'ORDER': 16,
                                                                               'PRECISION': 6,
                                                                               'PRIMARY_KEY': False,
                                                                               'SQL_TYPE': 'FLOAT',
                                                                               'WIDTH': 10},
                                                     'PDBX_R_KRAUT_CENTRIC': {'NULLABLE': True,
                                                                              'ORDER': 15,
                                                                              'PRECISION': 6,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'FLOAT',
                                                                              'WIDTH': 10},
                                                     'PHASE': {'NULLABLE': True,
                                                               'ORDER': 8,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                                     'POWER': {'NULLABLE': True,
                                                               'ORDER': 9,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                                     'REFLNS': {'NULLABLE': True,
                                                                'ORDER': 12,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'INT',
                                                                'WIDTH': 10},
                                                     'R_CULLIS': {'NULLABLE': True,
                                                                  'ORDER': 10,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10},
                                                     'R_KRAUT': {'NULLABLE': True,
                                                                 'ORDER': 11,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                                     'STRUCTURE_ID': {'NULLABLE': False,
                                                                      'ORDER': 1,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10}},
                                  'ATTRIBUTE_MAP': {'DER_ID': ('phasing_MIR_der_shell', 'der_id', None, None),
                                                    'D_RES_HIGH': ('phasing_MIR_der_shell', 'd_res_high', None, None),
                                                    'D_RES_LOW': ('phasing_MIR_der_shell', 'd_res_low', None, None),
                                                    'FOM': ('phasing_MIR_der_shell', 'fom', None, None),
                                                    'HA_AMPL': ('phasing_MIR_der_shell', 'ha_ampl', None, None),
                                                    'LOC': ('phasing_MIR_der_shell', 'loc', None, None),
                                                    'PDBX_FOM_ACENTRIC': ('phasing_MIR_der_shell',
                                                                          'pdbx_fom_acentric',
                                                                          None,
                                                                          None),
                                                    'PDBX_FOM_CENTRIC': ('phasing_MIR_der_shell',
                                                                         'pdbx_fom_centric',
                                                                         None,
                                                                         None),
                                                    'PDBX_LOC_ACENTRIC': ('phasing_MIR_der_shell',
                                                                          'pdbx_loc_acentric',
                                                                          None,
                                                                          None),
                                                    'PDBX_LOC_CENTRIC': ('phasing_MIR_der_shell',
                                                                         'pdbx_loc_centric',
                                                                         None,
                                                                         None),
                                                    'PDBX_POWER_ACENTRIC': ('phasing_MIR_der_shell',
                                                                            'pdbx_power_acentric',
                                                                            None,
                                                                            None),
                                                    'PDBX_POWER_CENTRIC': ('phasing_MIR_der_shell',
                                                                           'pdbx_power_centric',
                                                                           None,
                                                                           None),
                                                    'PDBX_REFLNS_ACENTRIC': ('phasing_MIR_der_shell',
                                                                             'pdbx_reflns_acentric',
                                                                             None,
                                                                             None),
                                                    'PDBX_REFLNS_CENTRIC': ('phasing_MIR_der_shell',
                                                                            'pdbx_reflns_centric',
                                                                            None,
                                                                            None),
                                                    'PDBX_R_CULLIS_ACENTRIC': ('phasing_MIR_der_shell',
                                                                               'pdbx_R_cullis_acentric',
                                                                               None,
                                                                               None),
                                                    'PDBX_R_CULLIS_CENTRIC': ('phasing_MIR_der_shell',
                                                                              'pdbx_R_cullis_centric',
                                                                              None,
                                                                              None),
                                                    'PDBX_R_KRAUT_ACENTRIC': ('phasing_MIR_der_shell',
                                                                              'pdbx_R_kraut_acentric',
                                                                              None,
                                                                              None),
                                                    'PDBX_R_KRAUT_CENTRIC': ('phasing_MIR_der_shell',
                                                                             'pdbx_R_kraut_centric',
                                                                             None,
                                                                             None),
                                                    'PHASE': ('phasing_MIR_der_shell', 'phase', None, None),
                                                    'POWER': ('phasing_MIR_der_shell', 'power', None, None),
                                                    'REFLNS': ('phasing_MIR_der_shell', 'reflns', None, None),
                                                    'R_CULLIS': ('phasing_MIR_der_shell', 'R_cullis', None, None),
                                                    'R_KRAUT': ('phasing_MIR_der_shell', 'R_kraut', None, None),
                                                    'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                  'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'DER_ID', 'D_RES_HIGH', 'D_RES_LOW'),
                                                     'TYPE': 'UNIQUE'},
                                              's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                  'MAP_MERGE_INDICES': {'phasing_MIR_der_shell': {'ATTRIBUTES': ('der_id',
                                                                                                 'd_res_high',
                                                                                                 'd_res_low'),
                                                                                  'TYPE': 'EQUI-JOIN'}},
                                  'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                  'TABLE_ID': 'PHASING_MIR_DER_SHELL',
                                  'TABLE_NAME': 'phasing_MIR_der_shell',
                                  'TABLE_TYPE': 'transactional'},
        'PHASING_MIR_DER_SITE': {'ATTRIBUTES': {'ATOM_TYPE_SYMBOL': 'atom_type_symbol',
                                                'B_ISO': 'B_iso',
                                                'B_ISO_ESD': 'B_iso_esd',
                                                'CARTN_X': 'Cartn_x',
                                                'CARTN_X_ESD': 'Cartn_x_esd',
                                                'CARTN_Y': 'Cartn_y',
                                                'CARTN_Y_ESD': 'Cartn_y_esd',
                                                'CARTN_Z': 'Cartn_z',
                                                'CARTN_Z_ESD': 'Cartn_z_esd',
                                                'DER_ID': 'der_id',
                                                'DETAILS': 'details',
                                                'FRACT_X': 'fract_x',
                                                'FRACT_X_ESD': 'fract_x_esd',
                                                'FRACT_Y': 'fract_y',
                                                'FRACT_Y_ESD': 'fract_y_esd',
                                                'FRACT_Z': 'fract_z',
                                                'FRACT_Z_ESD': 'fract_z_esd',
                                                'ID': 'id',
                                                'OCCUPANCY': 'occupancy',
                                                'OCCUPANCY_ANOM': 'occupancy_anom',
                                                'OCCUPANCY_ANOM_SU': 'occupancy_anom_su',
                                                'OCCUPANCY_ISO': 'occupancy_iso',
                                                'OCCUPANCY_ISO_SU': 'occupancy_iso_su',
                                                'STRUCTURE_ID': 'Structure_ID'},
                                 'ATTRIBUTE_INFO': {'ATOM_TYPE_SYMBOL': {'NULLABLE': True,
                                                                         'ORDER': 3,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                                    'B_ISO': {'NULLABLE': True,
                                                              'ORDER': 4,
                                                              'PRECISION': 6,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'FLOAT',
                                                              'WIDTH': 10},
                                                    'B_ISO_ESD': {'NULLABLE': True,
                                                                  'ORDER': 5,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10},
                                                    'CARTN_X': {'NULLABLE': True,
                                                                'ORDER': 6,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                                    'CARTN_X_ESD': {'NULLABLE': True,
                                                                    'ORDER': 7,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                                    'CARTN_Y': {'NULLABLE': True,
                                                                'ORDER': 8,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                                    'CARTN_Y_ESD': {'NULLABLE': True,
                                                                    'ORDER': 9,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                                    'CARTN_Z': {'NULLABLE': True,
                                                                'ORDER': 10,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                                    'CARTN_Z_ESD': {'NULLABLE': True,
                                                                    'ORDER': 11,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                                    'DER_ID': {'NULLABLE': False,
                                                               'ORDER': 2,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 80},
                                                    'DETAILS': {'NULLABLE': True,
                                                                'ORDER': 12,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 200},
                                                    'FRACT_X': {'NULLABLE': True,
                                                                'ORDER': 13,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                                    'FRACT_X_ESD': {'NULLABLE': True,
                                                                    'ORDER': 14,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                                    'FRACT_Y': {'NULLABLE': True,
                                                                'ORDER': 15,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                                    'FRACT_Y_ESD': {'NULLABLE': True,
                                                                    'ORDER': 16,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                                    'FRACT_Z': {'NULLABLE': True,
                                                                'ORDER': 17,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                                    'FRACT_Z_ESD': {'NULLABLE': True,
                                                                    'ORDER': 18,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                                    'ID': {'NULLABLE': False,
                                                           'ORDER': 19,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': True,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 10},
                                                    'OCCUPANCY': {'NULLABLE': True,
                                                                  'ORDER': 20,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10},
                                                    'OCCUPANCY_ANOM': {'NULLABLE': True,
                                                                       'ORDER': 21,
                                                                       'PRECISION': 6,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'FLOAT',
                                                                       'WIDTH': 10},
                                                    'OCCUPANCY_ANOM_SU': {'NULLABLE': True,
                                                                          'ORDER': 22,
                                                                          'PRECISION': 6,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'FLOAT',
                                                                          'WIDTH': 10},
                                                    'OCCUPANCY_ISO': {'NULLABLE': True,
                                                                      'ORDER': 23,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                                    'OCCUPANCY_ISO_SU': {'NULLABLE': True,
                                                                         'ORDER': 24,
                                                                         'PRECISION': 6,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'FLOAT',
                                                                         'WIDTH': 10},
                                                    'STRUCTURE_ID': {'NULLABLE': False,
                                                                     'ORDER': 1,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': True,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10}},
                                 'ATTRIBUTE_MAP': {'ATOM_TYPE_SYMBOL': ('phasing_MIR_der_site',
                                                                        'atom_type_symbol',
                                                                        None,
                                                                        None),
                                                   'B_ISO': ('phasing_MIR_der_site', 'B_iso', None, None),
                                                   'B_ISO_ESD': ('phasing_MIR_der_site', 'B_iso_esd', None, None),
                                                   'CARTN_X': ('phasing_MIR_der_site', 'Cartn_x', None, None),
                                                   'CARTN_X_ESD': ('phasing_MIR_der_site', 'Cartn_x_esd', None, None),
                                                   'CARTN_Y': ('phasing_MIR_der_site', 'Cartn_y', None, None),
                                                   'CARTN_Y_ESD': ('phasing_MIR_der_site', 'Cartn_y_esd', None, None),
                                                   'CARTN_Z': ('phasing_MIR_der_site', 'Cartn_z', None, None),
                                                   'CARTN_Z_ESD': ('phasing_MIR_der_site', 'Cartn_z_esd', None, None),
                                                   'DER_ID': ('phasing_MIR_der_site', 'der_id', None, None),
                                                   'DETAILS': ('phasing_MIR_der_site', 'details', None, None),
                                                   'FRACT_X': ('phasing_MIR_der_site', 'fract_x', None, None),
                                                   'FRACT_X_ESD': ('phasing_MIR_der_site', 'fract_x_esd', None, None),
                                                   'FRACT_Y': ('phasing_MIR_der_site', 'fract_y', None, None),
                                                   'FRACT_Y_ESD': ('phasing_MIR_der_site', 'fract_y_esd', None, None),
                                                   'FRACT_Z': ('phasing_MIR_der_site', 'fract_z', None, None),
                                                   'FRACT_Z_ESD': ('phasing_MIR_der_site', 'fract_z_esd', None, None),
                                                   'ID': ('phasing_MIR_der_site', 'id', None, None),
                                                   'OCCUPANCY': ('phasing_MIR_der_site', 'occupancy', None, None),
                                                   'OCCUPANCY_ANOM': ('phasing_MIR_der_site', 'occupancy_anom', None, None),
                                                   'OCCUPANCY_ANOM_SU': ('phasing_MIR_der_site',
                                                                         'occupancy_anom_su',
                                                                         None,
                                                                         None),
                                                   'OCCUPANCY_ISO': ('phasing_MIR_der_site', 'occupancy_iso', None, None),
                                                   'OCCUPANCY_ISO_SU': ('phasing_MIR_der_site',
                                                                        'occupancy_iso_su',
                                                                        None,
                                                                        None),
                                                   'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                 'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'DER_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                             's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                 'MAP_MERGE_INDICES': {'phasing_MIR_der_site': {'ATTRIBUTES': ('der_id', 'id'),
                                                                                'TYPE': 'EQUI-JOIN'}},
                                 'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                 'TABLE_ID': 'PHASING_MIR_DER_SITE',
                                 'TABLE_NAME': 'phasing_MIR_der_site',
                                 'TABLE_TYPE': 'transactional'},
        'PHASING_MIR_SHELL': {'ATTRIBUTES': {'D_RES_HIGH': 'd_res_high',
                                             'D_RES_LOW': 'd_res_low',
                                             'FOM': 'FOM',
                                             'FOM_ACENTRIC': 'FOM_acentric',
                                             'FOM_CENTRIC': 'FOM_centric',
                                             'LOC': 'loc',
                                             'MEAN_PHASE': 'mean_phase',
                                             'PDBX_LOC_ACENTRIC': 'pdbx_loc_acentric',
                                             'PDBX_LOC_CENTRIC': 'pdbx_loc_centric',
                                             'PDBX_POWER_ACENTRIC': 'pdbx_power_acentric',
                                             'PDBX_POWER_CENTRIC': 'pdbx_power_centric',
                                             'PDBX_R_CULLIS_ACENTRIC': 'pdbx_R_cullis_acentric',
                                             'PDBX_R_CULLIS_CENTRIC': 'pdbx_R_cullis_centric',
                                             'PDBX_R_KRAUT_ACENTRIC': 'pdbx_R_kraut_acentric',
                                             'PDBX_R_KRAUT_CENTRIC': 'pdbx_R_kraut_centric',
                                             'POWER': 'power',
                                             'REFLNS': 'reflns',
                                             'REFLNS_ACENTRIC': 'reflns_acentric',
                                             'REFLNS_ANOMALOUS': 'reflns_anomalous',
                                             'REFLNS_CENTRIC': 'reflns_centric',
                                             'R_CULLIS': 'R_cullis',
                                             'R_KRAUT': 'R_kraut',
                                             'STRUCTURE_ID': 'Structure_ID'},
                              'ATTRIBUTE_INFO': {'D_RES_HIGH': {'NULLABLE': False,
                                                                'ORDER': 2,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                                 'D_RES_LOW': {'NULLABLE': False,
                                                               'ORDER': 3,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                                 'FOM': {'NULLABLE': True,
                                                         'ORDER': 4,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                                 'FOM_ACENTRIC': {'NULLABLE': True,
                                                                  'ORDER': 5,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10},
                                                 'FOM_CENTRIC': {'NULLABLE': True,
                                                                 'ORDER': 6,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                                 'LOC': {'NULLABLE': True,
                                                         'ORDER': 7,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                                 'MEAN_PHASE': {'NULLABLE': True,
                                                                'ORDER': 8,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                                 'PDBX_LOC_ACENTRIC': {'NULLABLE': True,
                                                                       'ORDER': 17,
                                                                       'PRECISION': 6,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'FLOAT',
                                                                       'WIDTH': 10},
                                                 'PDBX_LOC_CENTRIC': {'NULLABLE': True,
                                                                      'ORDER': 16,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                                 'PDBX_POWER_ACENTRIC': {'NULLABLE': True,
                                                                         'ORDER': 19,
                                                                         'PRECISION': 6,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'FLOAT',
                                                                         'WIDTH': 10},
                                                 'PDBX_POWER_CENTRIC': {'NULLABLE': True,
                                                                        'ORDER': 18,
                                                                        'PRECISION': 6,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'FLOAT',
                                                                        'WIDTH': 10},
                                                 'PDBX_R_CULLIS_ACENTRIC': {'NULLABLE': True,
                                                                            'ORDER': 23,
                                                                            'PRECISION': 6,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'FLOAT',
                                                                            'WIDTH': 10},
                                                 'PDBX_R_CULLIS_CENTRIC': {'NULLABLE': True,
                                                                           'ORDER': 22,
                                                                           'PRECISION': 6,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'FLOAT',
                                                                           'WIDTH': 10},
                                                 'PDBX_R_KRAUT_ACENTRIC': {'NULLABLE': True,
                                                                           'ORDER': 21,
                                                                           'PRECISION': 6,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'FLOAT',
                                                                           'WIDTH': 10},
                                                 'PDBX_R_KRAUT_CENTRIC': {'NULLABLE': True,
                                                                          'ORDER': 20,
                                                                          'PRECISION': 6,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'FLOAT',
                                                                          'WIDTH': 10},
                                                 'POWER': {'NULLABLE': True,
                                                           'ORDER': 9,
                                                           'PRECISION': 6,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'FLOAT',
                                                           'WIDTH': 10},
                                                 'REFLNS': {'NULLABLE': True,
                                                            'ORDER': 12,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'INT',
                                                            'WIDTH': 10},
                                                 'REFLNS_ACENTRIC': {'NULLABLE': True,
                                                                     'ORDER': 13,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'INT',
                                                                     'WIDTH': 10},
                                                 'REFLNS_ANOMALOUS': {'NULLABLE': True,
                                                                      'ORDER': 14,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'INT',
                                                                      'WIDTH': 10},
                                                 'REFLNS_CENTRIC': {'NULLABLE': True,
                                                                    'ORDER': 15,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'INT',
                                                                    'WIDTH': 10},
                                                 'R_CULLIS': {'NULLABLE': True,
                                                              'ORDER': 10,
                                                              'PRECISION': 6,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'FLOAT',
                                                              'WIDTH': 10},
                                                 'R_KRAUT': {'NULLABLE': True,
                                                             'ORDER': 11,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                                 'STRUCTURE_ID': {'NULLABLE': False,
                                                                  'ORDER': 1,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': True,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10}},
                              'ATTRIBUTE_MAP': {'D_RES_HIGH': ('phasing_MIR_shell', 'd_res_high', None, None),
                                                'D_RES_LOW': ('phasing_MIR_shell', 'd_res_low', None, None),
                                                'FOM': ('phasing_MIR_shell', 'FOM', None, None),
                                                'FOM_ACENTRIC': ('phasing_MIR_shell', 'FOM_acentric', None, None),
                                                'FOM_CENTRIC': ('phasing_MIR_shell', 'FOM_centric', None, None),
                                                'LOC': ('phasing_MIR_shell', 'loc', None, None),
                                                'MEAN_PHASE': ('phasing_MIR_shell', 'mean_phase', None, None),
                                                'PDBX_LOC_ACENTRIC': ('phasing_MIR_shell', 'pdbx_loc_acentric', None, None),
                                                'PDBX_LOC_CENTRIC': ('phasing_MIR_shell', 'pdbx_loc_centric', None, None),
                                                'PDBX_POWER_ACENTRIC': ('phasing_MIR_shell',
                                                                        'pdbx_power_acentric',
                                                                        None,
                                                                        None),
                                                'PDBX_POWER_CENTRIC': ('phasing_MIR_shell', 'pdbx_power_centric', None, None),
                                                'PDBX_R_CULLIS_ACENTRIC': ('phasing_MIR_shell',
                                                                           'pdbx_R_cullis_acentric',
                                                                           None,
                                                                           None),
                                                'PDBX_R_CULLIS_CENTRIC': ('phasing_MIR_shell',
                                                                          'pdbx_R_cullis_centric',
                                                                          None,
                                                                          None),
                                                'PDBX_R_KRAUT_ACENTRIC': ('phasing_MIR_shell',
                                                                          'pdbx_R_kraut_acentric',
                                                                          None,
                                                                          None),
                                                'PDBX_R_KRAUT_CENTRIC': ('phasing_MIR_shell',
                                                                         'pdbx_R_kraut_centric',
                                                                         None,
                                                                         None),
                                                'POWER': ('phasing_MIR_shell', 'power', None, None),
                                                'REFLNS': ('phasing_MIR_shell', 'reflns', None, None),
                                                'REFLNS_ACENTRIC': ('phasing_MIR_shell', 'reflns_acentric', None, None),
                                                'REFLNS_ANOMALOUS': ('phasing_MIR_shell', 'reflns_anomalous', None, None),
                                                'REFLNS_CENTRIC': ('phasing_MIR_shell', 'reflns_centric', None, None),
                                                'R_CULLIS': ('phasing_MIR_shell', 'R_cullis', None, None),
                                                'R_KRAUT': ('phasing_MIR_shell', 'R_kraut', None, None),
                                                'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                              'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'D_RES_HIGH', 'D_RES_LOW'), 'TYPE': 'UNIQUE'},
                                          's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                              'MAP_MERGE_INDICES': {'phasing_MIR_shell': {'ATTRIBUTES': ('d_res_high', 'd_res_low'),
                                                                          'TYPE': 'EQUI-JOIN'}},
                              'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                              'TABLE_ID': 'PHASING_MIR_SHELL',
                              'TABLE_NAME': 'phasing_MIR_shell',
                              'TABLE_TYPE': 'transactional'},
        'PHASING_SET': {'ATTRIBUTES': {'CELL_ANGLE_ALPHA': 'cell_angle_alpha',
                                       'CELL_ANGLE_BETA': 'cell_angle_beta',
                                       'CELL_ANGLE_GAMMA': 'cell_angle_gamma',
                                       'CELL_LENGTH_A': 'cell_length_a',
                                       'CELL_LENGTH_B': 'cell_length_b',
                                       'CELL_LENGTH_C': 'cell_length_c',
                                       'DETECTOR_SPECIFIC': 'detector_specific',
                                       'DETECTOR_TYPE': 'detector_type',
                                       'ID': 'id',
                                       'PDBX_D_RES_HIGH': 'pdbx_d_res_high',
                                       'PDBX_D_RES_LOW': 'pdbx_d_res_low',
                                       'PDBX_TEMP_DETAILS': 'pdbx_temp_details',
                                       'RADIATION_SOURCE_SPECIFIC': 'radiation_source_specific',
                                       'RADIATION_WAVELENGTH': 'radiation_wavelength',
                                       'STRUCTURE_ID': 'Structure_ID',
                                       'TEMP': 'temp'},
                        'ATTRIBUTE_INFO': {'CELL_ANGLE_ALPHA': {'NULLABLE': True,
                                                                'ORDER': 2,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                           'CELL_ANGLE_BETA': {'NULLABLE': True,
                                                               'ORDER': 3,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                           'CELL_ANGLE_GAMMA': {'NULLABLE': True,
                                                                'ORDER': 4,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                           'CELL_LENGTH_A': {'NULLABLE': True,
                                                             'ORDER': 5,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                           'CELL_LENGTH_B': {'NULLABLE': True,
                                                             'ORDER': 6,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                           'CELL_LENGTH_C': {'NULLABLE': True,
                                                             'ORDER': 7,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                           'DETECTOR_SPECIFIC': {'NULLABLE': True,
                                                                 'ORDER': 8,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 200},
                                           'DETECTOR_TYPE': {'NULLABLE': True,
                                                             'ORDER': 9,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 200},
                                           'ID': {'NULLABLE': False,
                                                  'ORDER': 10,
                                                  'PRECISION': 0,
                                                  'PRIMARY_KEY': True,
                                                  'SQL_TYPE': 'VARCHAR',
                                                  'WIDTH': 80},
                                           'PDBX_D_RES_HIGH': {'NULLABLE': True,
                                                               'ORDER': 15,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                           'PDBX_D_RES_LOW': {'NULLABLE': True,
                                                              'ORDER': 16,
                                                              'PRECISION': 6,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'FLOAT',
                                                              'WIDTH': 10},
                                           'PDBX_TEMP_DETAILS': {'NULLABLE': True,
                                                                 'ORDER': 14,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 200},
                                           'RADIATION_SOURCE_SPECIFIC': {'NULLABLE': True,
                                                                         'ORDER': 11,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 200},
                                           'RADIATION_WAVELENGTH': {'NULLABLE': True,
                                                                    'ORDER': 12,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                           'STRUCTURE_ID': {'NULLABLE': False,
                                                            'ORDER': 1,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': True,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 10},
                                           'TEMP': {'NULLABLE': True,
                                                    'ORDER': 13,
                                                    'PRECISION': 6,
                                                    'PRIMARY_KEY': False,
                                                    'SQL_TYPE': 'FLOAT',
                                                    'WIDTH': 10}},
                        'ATTRIBUTE_MAP': {'CELL_ANGLE_ALPHA': ('phasing_set', 'cell_angle_alpha', None, None),
                                          'CELL_ANGLE_BETA': ('phasing_set', 'cell_angle_beta', None, None),
                                          'CELL_ANGLE_GAMMA': ('phasing_set', 'cell_angle_gamma', None, None),
                                          'CELL_LENGTH_A': ('phasing_set', 'cell_length_a', None, None),
                                          'CELL_LENGTH_B': ('phasing_set', 'cell_length_b', None, None),
                                          'CELL_LENGTH_C': ('phasing_set', 'cell_length_c', None, None),
                                          'DETECTOR_SPECIFIC': ('phasing_set', 'detector_specific', None, None),
                                          'DETECTOR_TYPE': ('phasing_set', 'detector_type', None, None),
                                          'ID': ('phasing_set', 'id', None, None),
                                          'PDBX_D_RES_HIGH': ('phasing_set', 'pdbx_d_res_high', None, None),
                                          'PDBX_D_RES_LOW': ('phasing_set', 'pdbx_d_res_low', None, None),
                                          'PDBX_TEMP_DETAILS': ('phasing_set', 'pdbx_temp_details', None, None),
                                          'RADIATION_SOURCE_SPECIFIC': ('phasing_set',
                                                                        'radiation_source_specific',
                                                                        None,
                                                                        None),
                                          'RADIATION_WAVELENGTH': ('phasing_set', 'radiation_wavelength', None, None),
                                          'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                          'TEMP': ('phasing_set', 'temp', None, None)},
                        'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                    's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                        'MAP_MERGE_INDICES': {'phasing_set': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                        'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                        'TABLE_ID': 'PHASING_SET',
                        'TABLE_NAME': 'phasing_set',
                        'TABLE_TYPE': 'transactional'},
        'PHASING_SET_REFLN': {'ATTRIBUTES': {'F_MEAS': 'F_meas',
                                             'F_MEAS_AU': 'F_meas_au',
                                             'F_MEAS_SIGMA': 'F_meas_sigma',
                                             'F_MEAS_SIGMA_AU': 'F_meas_sigma_au',
                                             'INDEX_H': 'index_h',
                                             'INDEX_K': 'index_k',
                                             'INDEX_L': 'index_l',
                                             'SET_ID': 'set_id',
                                             'STRUCTURE_ID': 'Structure_ID'},
                              'ATTRIBUTE_INFO': {'F_MEAS': {'NULLABLE': True,
                                                            'ORDER': 3,
                                                            'PRECISION': 6,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'FLOAT',
                                                            'WIDTH': 10},
                                                 'F_MEAS_AU': {'NULLABLE': True,
                                                               'ORDER': 4,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                                 'F_MEAS_SIGMA': {'NULLABLE': True,
                                                                  'ORDER': 5,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10},
                                                 'F_MEAS_SIGMA_AU': {'NULLABLE': True,
                                                                     'ORDER': 6,
                                                                     'PRECISION': 6,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'FLOAT',
                                                                     'WIDTH': 10},
                                                 'INDEX_H': {'NULLABLE': False,
                                                             'ORDER': 7,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'INT',
                                                             'WIDTH': 10},
                                                 'INDEX_K': {'NULLABLE': False,
                                                             'ORDER': 8,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'INT',
                                                             'WIDTH': 10},
                                                 'INDEX_L': {'NULLABLE': False,
                                                             'ORDER': 9,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'INT',
                                                             'WIDTH': 10},
                                                 'SET_ID': {'NULLABLE': False,
                                                            'ORDER': 2,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': True,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 80},
                                                 'STRUCTURE_ID': {'NULLABLE': False,
                                                                  'ORDER': 1,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': True,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10}},
                              'ATTRIBUTE_MAP': {'F_MEAS': ('phasing_set_refln', 'F_meas', None, None),
                                                'F_MEAS_AU': ('phasing_set_refln', 'F_meas_au', None, None),
                                                'F_MEAS_SIGMA': ('phasing_set_refln', 'F_meas_sigma', None, None),
                                                'F_MEAS_SIGMA_AU': ('phasing_set_refln', 'F_meas_sigma_au', None, None),
                                                'INDEX_H': ('phasing_set_refln', 'index_h', None, None),
                                                'INDEX_K': ('phasing_set_refln', 'index_k', None, None),
                                                'INDEX_L': ('phasing_set_refln', 'index_l', None, None),
                                                'SET_ID': ('phasing_set_refln', 'set_id', None, None),
                                                'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                              'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'SET_ID', 'INDEX_H', 'INDEX_K', 'INDEX_L'),
                                                 'TYPE': 'UNIQUE'},
                                          's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                              'MAP_MERGE_INDICES': {'phasing_set_refln': {'ATTRIBUTES': ('set_id',
                                                                                         'index_h',
                                                                                         'index_k',
                                                                                         'index_l'),
                                                                          'TYPE': 'EQUI-JOIN'}},
                              'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                              'TABLE_ID': 'PHASING_SET_REFLN',
                              'TABLE_NAME': 'phasing_set_refln',
                              'TABLE_TYPE': 'transactional'},
        'PUBL': {'ATTRIBUTES': {'CONTACT_AUTHOR': 'contact_author',
                                'CONTACT_AUTHOR_ADDRESS': 'contact_author_address',
                                'CONTACT_AUTHOR_EMAIL': 'contact_author_email',
                                'CONTACT_AUTHOR_FAX': 'contact_author_fax',
                                'CONTACT_AUTHOR_NAME': 'contact_author_name',
                                'CONTACT_AUTHOR_PHONE': 'contact_author_phone',
                                'CONTACT_LETTER': 'contact_letter',
                                'ENTRY_ID': 'entry_id',
                                'MANUSCRIPT_CREATION': 'manuscript_creation',
                                'MANUSCRIPT_PROCESSED': 'manuscript_processed',
                                'MANUSCRIPT_TEXT': 'manuscript_text',
                                'REQUESTED_CATEGORY': 'requested_category',
                                'REQUESTED_COEDITOR_NAME': 'requested_coeditor_name',
                                'REQUESTED_JOURNAL': 'requested_journal',
                                'SECTION_ABSTRACT': 'section_abstract',
                                'SECTION_ACKNOWLEDGEMENTS': 'section_acknowledgements',
                                'SECTION_COMMENT': 'section_comment',
                                'SECTION_DISCUSSION': 'section_discussion',
                                'SECTION_EXPERIMENTAL': 'section_experimental',
                                'SECTION_EXPTL_PREP': 'section_exptl_prep',
                                'SECTION_EXPTL_REFINEMENT': 'section_exptl_refinement',
                                'SECTION_EXPTL_SOLUTION': 'section_exptl_solution',
                                'SECTION_FIGURE_CAPTIONS': 'section_figure_captions',
                                'SECTION_INTRODUCTION': 'section_introduction',
                                'SECTION_REFERENCES': 'section_references',
                                'SECTION_SYNOPSIS': 'section_synopsis',
                                'SECTION_TABLE_LEGENDS': 'section_table_legends',
                                'SECTION_TITLE': 'section_title',
                                'SECTION_TITLE_FOOTNOTE': 'section_title_footnote',
                                'STRUCTURE_ID': 'Structure_ID'},
                 'ATTRIBUTE_INFO': {'CONTACT_AUTHOR': {'NULLABLE': True,
                                                       'ORDER': 3,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'VARCHAR',
                                                       'WIDTH': 200},
                                    'CONTACT_AUTHOR_ADDRESS': {'NULLABLE': True,
                                                               'ORDER': 4,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 200},
                                    'CONTACT_AUTHOR_EMAIL': {'NULLABLE': True,
                                                             'ORDER': 5,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 80},
                                    'CONTACT_AUTHOR_FAX': {'NULLABLE': True,
                                                           'ORDER': 6,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 80},
                                    'CONTACT_AUTHOR_NAME': {'NULLABLE': True,
                                                            'ORDER': 7,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 200},
                                    'CONTACT_AUTHOR_PHONE': {'NULLABLE': True,
                                                             'ORDER': 8,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 80},
                                    'CONTACT_LETTER': {'NULLABLE': True,
                                                       'ORDER': 9,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'VARCHAR',
                                                       'WIDTH': 200},
                                    'ENTRY_ID': {'NULLABLE': False,
                                                 'ORDER': 2,
                                                 'PRECISION': 0,
                                                 'PRIMARY_KEY': True,
                                                 'SQL_TYPE': 'VARCHAR',
                                                 'WIDTH': 10},
                                    'MANUSCRIPT_CREATION': {'NULLABLE': True,
                                                            'ORDER': 10,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 200},
                                    'MANUSCRIPT_PROCESSED': {'NULLABLE': True,
                                                             'ORDER': 11,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 200},
                                    'MANUSCRIPT_TEXT': {'NULLABLE': True,
                                                        'ORDER': 12,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 200},
                                    'REQUESTED_CATEGORY': {'NULLABLE': True,
                                                           'ORDER': 13,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 80},
                                    'REQUESTED_COEDITOR_NAME': {'NULLABLE': True,
                                                                'ORDER': 14,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 80},
                                    'REQUESTED_JOURNAL': {'NULLABLE': True,
                                                          'ORDER': 15,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 80},
                                    'SECTION_ABSTRACT': {'NULLABLE': True,
                                                         'ORDER': 16,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 200},
                                    'SECTION_ACKNOWLEDGEMENTS': {'NULLABLE': True,
                                                                 'ORDER': 17,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 200},
                                    'SECTION_COMMENT': {'NULLABLE': True,
                                                        'ORDER': 18,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 200},
                                    'SECTION_DISCUSSION': {'NULLABLE': True,
                                                           'ORDER': 19,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 200},
                                    'SECTION_EXPERIMENTAL': {'NULLABLE': True,
                                                             'ORDER': 20,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 200},
                                    'SECTION_EXPTL_PREP': {'NULLABLE': True,
                                                           'ORDER': 21,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 200},
                                    'SECTION_EXPTL_REFINEMENT': {'NULLABLE': True,
                                                                 'ORDER': 22,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 200},
                                    'SECTION_EXPTL_SOLUTION': {'NULLABLE': True,
                                                               'ORDER': 23,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 200},
                                    'SECTION_FIGURE_CAPTIONS': {'NULLABLE': True,
                                                                'ORDER': 24,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 200},
                                    'SECTION_INTRODUCTION': {'NULLABLE': True,
                                                             'ORDER': 25,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 200},
                                    'SECTION_REFERENCES': {'NULLABLE': True,
                                                           'ORDER': 26,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 200},
                                    'SECTION_SYNOPSIS': {'NULLABLE': True,
                                                         'ORDER': 27,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 200},
                                    'SECTION_TABLE_LEGENDS': {'NULLABLE': True,
                                                              'ORDER': 28,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 200},
                                    'SECTION_TITLE': {'NULLABLE': True,
                                                      'ORDER': 29,
                                                      'PRECISION': 0,
                                                      'PRIMARY_KEY': False,
                                                      'SQL_TYPE': 'VARCHAR',
                                                      'WIDTH': 200},
                                    'SECTION_TITLE_FOOTNOTE': {'NULLABLE': True,
                                                               'ORDER': 30,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 200},
                                    'STRUCTURE_ID': {'NULLABLE': False,
                                                     'ORDER': 1,
                                                     'PRECISION': 0,
                                                     'PRIMARY_KEY': True,
                                                     'SQL_TYPE': 'VARCHAR',
                                                     'WIDTH': 10}},
                 'ATTRIBUTE_MAP': {'CONTACT_AUTHOR': ('publ', 'contact_author', None, None),
                                   'CONTACT_AUTHOR_ADDRESS': ('publ', 'contact_author_address', None, None),
                                   'CONTACT_AUTHOR_EMAIL': ('publ', 'contact_author_email', None, None),
                                   'CONTACT_AUTHOR_FAX': ('publ', 'contact_author_fax', None, None),
                                   'CONTACT_AUTHOR_NAME': ('publ', 'contact_author_name', None, None),
                                   'CONTACT_AUTHOR_PHONE': ('publ', 'contact_author_phone', None, None),
                                   'CONTACT_LETTER': ('publ', 'contact_letter', None, None),
                                   'ENTRY_ID': ('publ', 'entry_id', None, None),
                                   'MANUSCRIPT_CREATION': ('publ', 'manuscript_creation', None, None),
                                   'MANUSCRIPT_PROCESSED': ('publ', 'manuscript_processed', None, None),
                                   'MANUSCRIPT_TEXT': ('publ', 'manuscript_text', None, None),
                                   'REQUESTED_CATEGORY': ('publ', 'requested_category', None, None),
                                   'REQUESTED_COEDITOR_NAME': ('publ', 'requested_coeditor_name', None, None),
                                   'REQUESTED_JOURNAL': ('publ', 'requested_journal', None, None),
                                   'SECTION_ABSTRACT': ('publ', 'section_abstract', None, None),
                                   'SECTION_ACKNOWLEDGEMENTS': ('publ', 'section_acknowledgements', None, None),
                                   'SECTION_COMMENT': ('publ', 'section_comment', None, None),
                                   'SECTION_DISCUSSION': ('publ', 'section_discussion', None, None),
                                   'SECTION_EXPERIMENTAL': ('publ', 'section_experimental', None, None),
                                   'SECTION_EXPTL_PREP': ('publ', 'section_exptl_prep', None, None),
                                   'SECTION_EXPTL_REFINEMENT': ('publ', 'section_exptl_refinement', None, None),
                                   'SECTION_EXPTL_SOLUTION': ('publ', 'section_exptl_solution', None, None),
                                   'SECTION_FIGURE_CAPTIONS': ('publ', 'section_figure_captions', None, None),
                                   'SECTION_INTRODUCTION': ('publ', 'section_introduction', None, None),
                                   'SECTION_REFERENCES': ('publ', 'section_references', None, None),
                                   'SECTION_SYNOPSIS': ('publ', 'section_synopsis', None, None),
                                   'SECTION_TABLE_LEGENDS': ('publ', 'section_table_legends', None, None),
                                   'SECTION_TITLE': ('publ', 'section_title', None, None),
                                   'SECTION_TITLE_FOOTNOTE': ('publ', 'section_title_footnote', None, None),
                                   'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                 'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID'), 'TYPE': 'UNIQUE'},
                             's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                 'MAP_MERGE_INDICES': {'publ': {'ATTRIBUTES': ('entry_id',), 'TYPE': 'EQUI-JOIN'}},
                 'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                 'TABLE_ID': 'PUBL',
                 'TABLE_NAME': 'publ',
                 'TABLE_TYPE': 'transactional'},
        'PUBL_AUTHOR': {'ATTRIBUTES': {'ADDRESS': 'address',
                                       'EMAIL': 'email',
                                       'FOOTNOTE': 'footnote',
                                       'ID_IUCR': 'id_iucr',
                                       'NAME': 'name',
                                       'STRUCTURE_ID': 'Structure_ID'},
                        'ATTRIBUTE_INFO': {'ADDRESS': {'NULLABLE': True,
                                                       'ORDER': 2,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'VARCHAR',
                                                       'WIDTH': 200},
                                           'EMAIL': {'NULLABLE': True,
                                                     'ORDER': 3,
                                                     'PRECISION': 0,
                                                     'PRIMARY_KEY': False,
                                                     'SQL_TYPE': 'VARCHAR',
                                                     'WIDTH': 200},
                                           'FOOTNOTE': {'NULLABLE': True,
                                                        'ORDER': 4,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 80},
                                           'ID_IUCR': {'NULLABLE': True,
                                                       'ORDER': 6,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'VARCHAR',
                                                       'WIDTH': 10},
                                           'NAME': {'NULLABLE': False,
                                                    'ORDER': 5,
                                                    'PRECISION': 0,
                                                    'PRIMARY_KEY': True,
                                                    'SQL_TYPE': 'VARCHAR',
                                                    'WIDTH': 80},
                                           'STRUCTURE_ID': {'NULLABLE': False,
                                                            'ORDER': 1,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': True,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 10}},
                        'ATTRIBUTE_MAP': {'ADDRESS': ('publ_author', 'address', None, None),
                                          'EMAIL': ('publ_author', 'email', None, None),
                                          'FOOTNOTE': ('publ_author', 'footnote', None, None),
                                          'ID_IUCR': ('publ_author', 'id_iucr', None, None),
                                          'NAME': ('publ_author', 'name', None, None),
                                          'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                        'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'NAME'), 'TYPE': 'UNIQUE'},
                                    's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                        'MAP_MERGE_INDICES': {'publ_author': {'ATTRIBUTES': ('name',), 'TYPE': 'EQUI-JOIN'}},
                        'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                        'TABLE_ID': 'PUBL_AUTHOR',
                        'TABLE_NAME': 'publ_author',
                        'TABLE_TYPE': 'transactional'},
        'PUBL_BODY': {'ATTRIBUTES': {'CONTENTS': 'contents',
                                     'ELEMENT': 'element',
                                     'FORMAT': 'format',
                                     'LABEL': 'label',
                                     'STRUCTURE_ID': 'Structure_ID',
                                     'TITLE': 'title'},
                      'ATTRIBUTE_INFO': {'CONTENTS': {'NULLABLE': True,
                                                      'ORDER': 2,
                                                      'PRECISION': 0,
                                                      'PRIMARY_KEY': False,
                                                      'SQL_TYPE': 'VARCHAR',
                                                      'WIDTH': 200},
                                         'ELEMENT': {'NULLABLE': False,
                                                     'ORDER': 3,
                                                     'PRECISION': 0,
                                                     'PRIMARY_KEY': True,
                                                     'SQL_TYPE': 'VARCHAR',
                                                     'WIDTH': 10},
                                         'FORMAT': {'NULLABLE': True,
                                                    'ORDER': 4,
                                                    'PRECISION': 0,
                                                    'PRIMARY_KEY': False,
                                                    'SQL_TYPE': 'VARCHAR',
                                                    'WIDTH': 10},
                                         'LABEL': {'NULLABLE': False,
                                                   'ORDER': 5,
                                                   'PRECISION': 0,
                                                   'PRIMARY_KEY': True,
                                                   'SQL_TYPE': 'VARCHAR',
                                                   'WIDTH': 10},
                                         'STRUCTURE_ID': {'NULLABLE': False,
                                                          'ORDER': 1,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': True,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 10},
                                         'TITLE': {'NULLABLE': True,
                                                   'ORDER': 6,
                                                   'PRECISION': 0,
                                                   'PRIMARY_KEY': False,
                                                   'SQL_TYPE': 'VARCHAR',
                                                   'WIDTH': 200}},
                      'ATTRIBUTE_MAP': {'CONTENTS': ('publ_body', 'contents', None, None),
                                        'ELEMENT': ('publ_body', 'element', None, None),
                                        'FORMAT': ('publ_body', 'format', None, None),
                                        'LABEL': ('publ_body', 'label', None, None),
                                        'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                        'TITLE': ('publ_body', 'title', None, None)},
                      'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ELEMENT', 'LABEL'), 'TYPE': 'UNIQUE'},
                                  's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                      'MAP_MERGE_INDICES': {'publ_body': {'ATTRIBUTES': ('element', 'label'), 'TYPE': 'EQUI-JOIN'}},
                      'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                      'TABLE_ID': 'PUBL_BODY',
                      'TABLE_NAME': 'publ_body',
                      'TABLE_TYPE': 'transactional'},
        'PUBL_MANUSCRIPT_INCL': {'ATTRIBUTES': {'ENTRY_ID': 'entry_id',
                                                'EXTRA_DEFN': 'extra_defn',
                                                'EXTRA_INFO': 'extra_info',
                                                'EXTRA_ITEM': 'extra_item',
                                                'STRUCTURE_ID': 'Structure_ID'},
                                 'ATTRIBUTE_INFO': {'ENTRY_ID': {'NULLABLE': False,
                                                                 'ORDER': 2,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': True,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                                    'EXTRA_DEFN': {'NULLABLE': True,
                                                                   'ORDER': 3,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 80},
                                                    'EXTRA_INFO': {'NULLABLE': True,
                                                                   'ORDER': 4,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 200},
                                                    'EXTRA_ITEM': {'NULLABLE': True,
                                                                   'ORDER': 5,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 80},
                                                    'STRUCTURE_ID': {'NULLABLE': False,
                                                                     'ORDER': 1,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': True,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10}},
                                 'ATTRIBUTE_MAP': {'ENTRY_ID': ('publ_manuscript_incl', 'entry_id', None, None),
                                                   'EXTRA_DEFN': ('publ_manuscript_incl', 'extra_defn', None, None),
                                                   'EXTRA_INFO': ('publ_manuscript_incl', 'extra_info', None, None),
                                                   'EXTRA_ITEM': ('publ_manuscript_incl', 'extra_item', None, None),
                                                   'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                 'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID'), 'TYPE': 'UNIQUE'},
                                             's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                 'MAP_MERGE_INDICES': {'publ_manuscript_incl': {'ATTRIBUTES': ('entry_id',),
                                                                                'TYPE': 'EQUI-JOIN'}},
                                 'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                 'TABLE_ID': 'PUBL_MANUSCRIPT_INCL',
                                 'TABLE_NAME': 'publ_manuscript_incl',
                                 'TABLE_TYPE': 'transactional'},
        'REFINE': {'ATTRIBUTES': {'ANISO_B_1_1': 'aniso_B_1_1',
                                  'ANISO_B_1_2': 'aniso_B_1_2',
                                  'ANISO_B_1_3': 'aniso_B_1_3',
                                  'ANISO_B_2_2': 'aniso_B_2_2',
                                  'ANISO_B_2_3': 'aniso_B_2_3',
                                  'ANISO_B_3_3': 'aniso_B_3_3',
                                  'B_ISO_MAX': 'B_iso_max',
                                  'B_ISO_MEAN': 'B_iso_mean',
                                  'B_ISO_MIN': 'B_iso_min',
                                  'CORRELATION_COEFF_FO_TO_FC': 'correlation_coeff_Fo_to_Fc',
                                  'CORRELATION_COEFF_FO_TO_FC_FREE': 'correlation_coeff_Fo_to_Fc_free',
                                  'DETAILS': 'details',
                                  'DIFF_DENSITY_MAX': 'diff_density_max',
                                  'DIFF_DENSITY_MAX_ESD': 'diff_density_max_esd',
                                  'DIFF_DENSITY_MIN': 'diff_density_min',
                                  'DIFF_DENSITY_MIN_ESD': 'diff_density_min_esd',
                                  'DIFF_DENSITY_RMS': 'diff_density_rms',
                                  'DIFF_DENSITY_RMS_ESD': 'diff_density_rms_esd',
                                  'ENTRY_ID': 'entry_id',
                                  'LS_ABS_STRUCTURE_DETAILS': 'ls_abs_structure_details',
                                  'LS_ABS_STRUCTURE_FLACK': 'ls_abs_structure_Flack',
                                  'LS_ABS_STRUCTURE_FLACK_ESD': 'ls_abs_structure_Flack_esd',
                                  'LS_ABS_STRUCTURE_ROGERS': 'ls_abs_structure_Rogers',
                                  'LS_ABS_STRUCTURE_ROGERS_ESD': 'ls_abs_structure_Rogers_esd',
                                  'LS_D_RES_HIGH': 'ls_d_res_high',
                                  'LS_D_RES_LOW': 'ls_d_res_low',
                                  'LS_EXTINCTION_COEF': 'ls_extinction_coef',
                                  'LS_EXTINCTION_COEF_ESD': 'ls_extinction_coef_esd',
                                  'LS_EXTINCTION_EXPRESSION': 'ls_extinction_expression',
                                  'LS_EXTINCTION_METHOD': 'ls_extinction_method',
                                  'LS_GOODNESS_OF_FIT_ALL': 'ls_goodness_of_fit_all',
                                  'LS_GOODNESS_OF_FIT_ALL_ESD': 'ls_goodness_of_fit_all_esd',
                                  'LS_GOODNESS_OF_FIT_GT': 'ls_goodness_of_fit_gt',
                                  'LS_GOODNESS_OF_FIT_OBS': 'ls_goodness_of_fit_obs',
                                  'LS_GOODNESS_OF_FIT_OBS_ESD': 'ls_goodness_of_fit_obs_esd',
                                  'LS_GOODNESS_OF_FIT_REF': 'ls_goodness_of_fit_ref',
                                  'LS_HYDROGEN_TREATMENT': 'ls_hydrogen_treatment',
                                  'LS_MATRIX_TYPE': 'ls_matrix_type',
                                  'LS_NUMBER_CONSTRAINTS': 'ls_number_constraints',
                                  'LS_NUMBER_PARAMETERS': 'ls_number_parameters',
                                  'LS_NUMBER_REFLNS_ALL': 'ls_number_reflns_all',
                                  'LS_NUMBER_REFLNS_OBS': 'ls_number_reflns_obs',
                                  'LS_NUMBER_REFLNS_R_FREE': 'ls_number_reflns_R_free',
                                  'LS_NUMBER_REFLNS_R_WORK': 'ls_number_reflns_R_work',
                                  'LS_NUMBER_RESTRAINTS': 'ls_number_restraints',
                                  'LS_PERCENT_REFLNS_OBS': 'ls_percent_reflns_obs',
                                  'LS_PERCENT_REFLNS_R_FREE': 'ls_percent_reflns_R_free',
                                  'LS_REDUNDANCY_REFLNS_ALL': 'ls_redundancy_reflns_all',
                                  'LS_REDUNDANCY_REFLNS_OBS': 'ls_redundancy_reflns_obs',
                                  'LS_RESTRAINED_S_ALL': 'ls_restrained_S_all',
                                  'LS_RESTRAINED_S_OBS': 'ls_restrained_S_obs',
                                  'LS_R_FACTOR_ALL': 'ls_R_factor_all',
                                  'LS_R_FACTOR_GT': 'ls_R_factor_gt',
                                  'LS_R_FACTOR_OBS': 'ls_R_factor_obs',
                                  'LS_R_FACTOR_R_FREE': 'ls_R_factor_R_free',
                                  'LS_R_FACTOR_R_FREE_ERROR': 'ls_R_factor_R_free_error',
                                  'LS_R_FACTOR_R_FREE_ERROR_DETAILS': 'ls_R_factor_R_free_error_details',
                                  'LS_R_FACTOR_R_WORK': 'ls_R_factor_R_work',
                                  'LS_R_FSQD_FACTOR_OBS': 'ls_R_Fsqd_factor_obs',
                                  'LS_R_I_FACTOR_OBS': 'ls_R_I_factor_obs',
                                  'LS_SHIFT_OVER_ESD_MAX': 'ls_shift_over_esd_max',
                                  'LS_SHIFT_OVER_ESD_MEAN': 'ls_shift_over_esd_mean',
                                  'LS_SHIFT_OVER_SU_MAX': 'ls_shift_over_su_max',
                                  'LS_SHIFT_OVER_SU_MAX_LT': 'ls_shift_over_su_max_lt',
                                  'LS_SHIFT_OVER_SU_MEAN': 'ls_shift_over_su_mean',
                                  'LS_SHIFT_OVER_SU_MEAN_LT': 'ls_shift_over_su_mean_lt',
                                  'LS_STRUCTURE_FACTOR_COEF': 'ls_structure_factor_coef',
                                  'LS_WEIGHTING_DETAILS': 'ls_weighting_details',
                                  'LS_WEIGHTING_SCHEME': 'ls_weighting_scheme',
                                  'LS_WR_FACTOR_ALL': 'ls_wR_factor_all',
                                  'LS_WR_FACTOR_OBS': 'ls_wR_factor_obs',
                                  'LS_WR_FACTOR_R_FREE': 'ls_wR_factor_R_free',
                                  'LS_WR_FACTOR_R_WORK': 'ls_wR_factor_R_work',
                                  'OCCUPANCY_MAX': 'occupancy_max',
                                  'OCCUPANCY_MIN': 'occupancy_min',
                                  'OVERALL_FOM_FREE_R_SET': 'overall_FOM_free_R_set',
                                  'OVERALL_FOM_WORK_R_SET': 'overall_FOM_work_R_set',
                                  'OVERALL_SU_B': 'overall_SU_B',
                                  'OVERALL_SU_ML': 'overall_SU_ML',
                                  'OVERALL_SU_R_CRUICKSHANK_DPI': 'overall_SU_R_Cruickshank_DPI',
                                  'OVERALL_SU_R_FREE': 'overall_SU_R_free',
                                  'PDBX_DATA_CUTOFF_HIGH_ABSF': 'pdbx_data_cutoff_high_absF',
                                  'PDBX_DATA_CUTOFF_HIGH_RMS_ABSF': 'pdbx_data_cutoff_high_rms_absF',
                                  'PDBX_DATA_CUTOFF_LOW_ABSF': 'pdbx_data_cutoff_low_absF',
                                  'PDBX_DENSITY_CORRELATION': 'pdbx_density_correlation',
                                  'PDBX_DIFFRN_ID': 'pdbx_diffrn_id',
                                  'PDBX_ISOTROPIC_THERMAL_MODEL': 'pdbx_isotropic_thermal_model',
                                  'PDBX_LS_CROSS_VALID_METHOD': 'pdbx_ls_cross_valid_method',
                                  'PDBX_LS_SIGMA_F': 'pdbx_ls_sigma_F',
                                  'PDBX_LS_SIGMA_FSQD': 'pdbx_ls_sigma_Fsqd',
                                  'PDBX_LS_SIGMA_I': 'pdbx_ls_sigma_I',
                                  'PDBX_METHOD_TO_DETERMINE_STRUCT': 'pdbx_method_to_determine_struct',
                                  'PDBX_OVERALL_ESU_R': 'pdbx_overall_ESU_R',
                                  'PDBX_OVERALL_ESU_R_FREE': 'pdbx_overall_ESU_R_Free',
                                  'PDBX_OVERALL_PHASE_ERROR': 'pdbx_overall_phase_error',
                                  'PDBX_OVERALL_SU_R_BLOW_DPI': 'pdbx_overall_SU_R_Blow_DPI',
                                  'PDBX_OVERALL_SU_R_FREE_BLOW_DPI': 'pdbx_overall_SU_R_free_Blow_DPI',
                                  'PDBX_OVERALL_SU_R_FREE_CRUICKSHANK_DPI': 'pdbx_overall_SU_R_free_Cruickshank_DPI',
                                  'PDBX_PD_FSQRD_R_FACTOR': 'pdbx_pd_Fsqrd_R_factor',
                                  'PDBX_PD_LS_MATRIX_BAND_WIDTH': 'pdbx_pd_ls_matrix_band_width',
                                  'PDBX_PD_MARQUARDT_CORRELATION_COEFF': 'pdbx_pd_Marquardt_correlation_coeff',
                                  'PDBX_PD_MEAS_NUMBER_OF_POINTS': 'pdbx_pd_meas_number_of_points',
                                  'PDBX_PD_NUMBER_OF_POINTS': 'pdbx_pd_number_of_points',
                                  'PDBX_PD_NUMBER_OF_POWDER_PATTERNS': 'pdbx_pd_number_of_powder_patterns',
                                  'PDBX_PD_PROC_LS_PROF_R_FACTOR': 'pdbx_pd_proc_ls_prof_R_factor',
                                  'PDBX_PD_PROC_LS_PROF_WR_FACTOR': 'pdbx_pd_proc_ls_prof_wR_factor',
                                  'PDBX_REAL_SPACE_R': 'pdbx_real_space_R',
                                  'PDBX_REFINE_ID': 'pdbx_refine_id',
                                  'PDBX_R_FREE_SELECTION_DETAILS': 'pdbx_R_Free_selection_details',
                                  'PDBX_SOLVENT_ION_PROBE_RADII': 'pdbx_solvent_ion_probe_radii',
                                  'PDBX_SOLVENT_SHRINKAGE_RADII': 'pdbx_solvent_shrinkage_radii',
                                  'PDBX_SOLVENT_VDW_PROBE_RADII': 'pdbx_solvent_vdw_probe_radii',
                                  'PDBX_STARTING_MODEL': 'pdbx_starting_model',
                                  'PDBX_STEREOCHEMISTRY_TARGET_VALUES': 'pdbx_stereochemistry_target_values',
                                  'PDBX_STEREOCHEM_TARGET_VAL_SPEC_CASE': 'pdbx_stereochem_target_val_spec_case',
                                  'PDBX_TLS_RESIDUAL_ADP_FLAG': 'pdbx_TLS_residual_ADP_flag',
                                  'SOLVENT_MODEL_DETAILS': 'solvent_model_details',
                                  'SOLVENT_MODEL_PARAM_BSOL': 'solvent_model_param_bsol',
                                  'SOLVENT_MODEL_PARAM_KSOL': 'solvent_model_param_ksol',
                                  'STRUCTURE_ID': 'Structure_ID'},
                   'ATTRIBUTE_INFO': {'ANISO_B_1_1': {'NULLABLE': True,
                                                      'ORDER': 3,
                                                      'PRECISION': 6,
                                                      'PRIMARY_KEY': False,
                                                      'SQL_TYPE': 'FLOAT',
                                                      'WIDTH': 10},
                                      'ANISO_B_1_2': {'NULLABLE': True,
                                                      'ORDER': 4,
                                                      'PRECISION': 6,
                                                      'PRIMARY_KEY': False,
                                                      'SQL_TYPE': 'FLOAT',
                                                      'WIDTH': 10},
                                      'ANISO_B_1_3': {'NULLABLE': True,
                                                      'ORDER': 5,
                                                      'PRECISION': 6,
                                                      'PRIMARY_KEY': False,
                                                      'SQL_TYPE': 'FLOAT',
                                                      'WIDTH': 10},
                                      'ANISO_B_2_2': {'NULLABLE': True,
                                                      'ORDER': 6,
                                                      'PRECISION': 6,
                                                      'PRIMARY_KEY': False,
                                                      'SQL_TYPE': 'FLOAT',
                                                      'WIDTH': 10},
                                      'ANISO_B_2_3': {'NULLABLE': True,
                                                      'ORDER': 7,
                                                      'PRECISION': 6,
                                                      'PRIMARY_KEY': False,
                                                      'SQL_TYPE': 'FLOAT',
                                                      'WIDTH': 10},
                                      'ANISO_B_3_3': {'NULLABLE': True,
                                                      'ORDER': 8,
                                                      'PRECISION': 6,
                                                      'PRIMARY_KEY': False,
                                                      'SQL_TYPE': 'FLOAT',
                                                      'WIDTH': 10},
                                      'B_ISO_MAX': {'NULLABLE': True,
                                                    'ORDER': 9,
                                                    'PRECISION': 6,
                                                    'PRIMARY_KEY': False,
                                                    'SQL_TYPE': 'FLOAT',
                                                    'WIDTH': 10},
                                      'B_ISO_MEAN': {'NULLABLE': True,
                                                     'ORDER': 10,
                                                     'PRECISION': 6,
                                                     'PRIMARY_KEY': False,
                                                     'SQL_TYPE': 'FLOAT',
                                                     'WIDTH': 10},
                                      'B_ISO_MIN': {'NULLABLE': True,
                                                    'ORDER': 11,
                                                    'PRECISION': 6,
                                                    'PRIMARY_KEY': False,
                                                    'SQL_TYPE': 'FLOAT',
                                                    'WIDTH': 10},
                                      'CORRELATION_COEFF_FO_TO_FC': {'NULLABLE': True,
                                                                     'ORDER': 12,
                                                                     'PRECISION': 6,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'FLOAT',
                                                                     'WIDTH': 10},
                                      'CORRELATION_COEFF_FO_TO_FC_FREE': {'NULLABLE': True,
                                                                          'ORDER': 13,
                                                                          'PRECISION': 6,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'FLOAT',
                                                                          'WIDTH': 10},
                                      'DETAILS': {'NULLABLE': True,
                                                  'ORDER': 14,
                                                  'PRECISION': 0,
                                                  'PRIMARY_KEY': False,
                                                  'SQL_TYPE': 'VARCHAR',
                                                  'WIDTH': 16383},
                                      'DIFF_DENSITY_MAX': {'NULLABLE': True,
                                                           'ORDER': 15,
                                                           'PRECISION': 6,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'FLOAT',
                                                           'WIDTH': 10},
                                      'DIFF_DENSITY_MAX_ESD': {'NULLABLE': True,
                                                               'ORDER': 16,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                      'DIFF_DENSITY_MIN': {'NULLABLE': True,
                                                           'ORDER': 17,
                                                           'PRECISION': 6,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'FLOAT',
                                                           'WIDTH': 10},
                                      'DIFF_DENSITY_MIN_ESD': {'NULLABLE': True,
                                                               'ORDER': 18,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                      'DIFF_DENSITY_RMS': {'NULLABLE': True,
                                                           'ORDER': 19,
                                                           'PRECISION': 6,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'FLOAT',
                                                           'WIDTH': 10},
                                      'DIFF_DENSITY_RMS_ESD': {'NULLABLE': True,
                                                               'ORDER': 20,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                      'ENTRY_ID': {'NULLABLE': False,
                                                   'ORDER': 2,
                                                   'PRECISION': 0,
                                                   'PRIMARY_KEY': True,
                                                   'SQL_TYPE': 'VARCHAR',
                                                   'WIDTH': 10},
                                      'LS_ABS_STRUCTURE_DETAILS': {'NULLABLE': True,
                                                                   'ORDER': 22,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 200},
                                      'LS_ABS_STRUCTURE_FLACK': {'NULLABLE': True,
                                                                 'ORDER': 23,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                      'LS_ABS_STRUCTURE_FLACK_ESD': {'NULLABLE': True,
                                                                     'ORDER': 24,
                                                                     'PRECISION': 6,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'FLOAT',
                                                                     'WIDTH': 10},
                                      'LS_ABS_STRUCTURE_ROGERS': {'NULLABLE': True,
                                                                  'ORDER': 25,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10},
                                      'LS_ABS_STRUCTURE_ROGERS_ESD': {'NULLABLE': True,
                                                                      'ORDER': 26,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                      'LS_D_RES_HIGH': {'NULLABLE': True,
                                                        'ORDER': 27,
                                                        'PRECISION': 6,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'FLOAT',
                                                        'WIDTH': 10},
                                      'LS_D_RES_LOW': {'NULLABLE': True,
                                                       'ORDER': 28,
                                                       'PRECISION': 6,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'FLOAT',
                                                       'WIDTH': 10},
                                      'LS_EXTINCTION_COEF': {'NULLABLE': True,
                                                             'ORDER': 29,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                      'LS_EXTINCTION_COEF_ESD': {'NULLABLE': True,
                                                                 'ORDER': 30,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                      'LS_EXTINCTION_EXPRESSION': {'NULLABLE': True,
                                                                   'ORDER': 31,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 200},
                                      'LS_EXTINCTION_METHOD': {'NULLABLE': True,
                                                               'ORDER': 32,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 200},
                                      'LS_GOODNESS_OF_FIT_ALL': {'NULLABLE': True,
                                                                 'ORDER': 33,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                      'LS_GOODNESS_OF_FIT_ALL_ESD': {'NULLABLE': True,
                                                                     'ORDER': 34,
                                                                     'PRECISION': 6,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'FLOAT',
                                                                     'WIDTH': 10},
                                      'LS_GOODNESS_OF_FIT_GT': {'NULLABLE': True,
                                                                'ORDER': 81,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                      'LS_GOODNESS_OF_FIT_OBS': {'NULLABLE': True,
                                                                 'ORDER': 35,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                      'LS_GOODNESS_OF_FIT_OBS_ESD': {'NULLABLE': True,
                                                                     'ORDER': 36,
                                                                     'PRECISION': 6,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'FLOAT',
                                                                     'WIDTH': 10},
                                      'LS_GOODNESS_OF_FIT_REF': {'NULLABLE': True,
                                                                 'ORDER': 82,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                      'LS_HYDROGEN_TREATMENT': {'NULLABLE': True,
                                                                'ORDER': 37,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                      'LS_MATRIX_TYPE': {'NULLABLE': True,
                                                         'ORDER': 38,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 10},
                                      'LS_NUMBER_CONSTRAINTS': {'NULLABLE': True,
                                                                'ORDER': 39,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'INT',
                                                                'WIDTH': 10},
                                      'LS_NUMBER_PARAMETERS': {'NULLABLE': True,
                                                               'ORDER': 40,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'INT',
                                                               'WIDTH': 10},
                                      'LS_NUMBER_REFLNS_ALL': {'NULLABLE': True,
                                                               'ORDER': 41,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'INT',
                                                               'WIDTH': 10},
                                      'LS_NUMBER_REFLNS_OBS': {'NULLABLE': True,
                                                               'ORDER': 42,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'INT',
                                                               'WIDTH': 10},
                                      'LS_NUMBER_REFLNS_R_FREE': {'NULLABLE': True,
                                                                  'ORDER': 43,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'INT',
                                                                  'WIDTH': 10},
                                      'LS_NUMBER_REFLNS_R_WORK': {'NULLABLE': True,
                                                                  'ORDER': 44,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'INT',
                                                                  'WIDTH': 10},
                                      'LS_NUMBER_RESTRAINTS': {'NULLABLE': True,
                                                               'ORDER': 45,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'INT',
                                                               'WIDTH': 10},
                                      'LS_PERCENT_REFLNS_OBS': {'NULLABLE': True,
                                                                'ORDER': 46,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                      'LS_PERCENT_REFLNS_R_FREE': {'NULLABLE': True,
                                                                   'ORDER': 47,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                      'LS_REDUNDANCY_REFLNS_ALL': {'NULLABLE': True,
                                                                   'ORDER': 56,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                      'LS_REDUNDANCY_REFLNS_OBS': {'NULLABLE': True,
                                                                   'ORDER': 57,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                      'LS_RESTRAINED_S_ALL': {'NULLABLE': True,
                                                              'ORDER': 58,
                                                              'PRECISION': 6,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'FLOAT',
                                                              'WIDTH': 10},
                                      'LS_RESTRAINED_S_OBS': {'NULLABLE': True,
                                                              'ORDER': 59,
                                                              'PRECISION': 6,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'FLOAT',
                                                              'WIDTH': 10},
                                      'LS_R_FACTOR_ALL': {'NULLABLE': True,
                                                          'ORDER': 48,
                                                          'PRECISION': 6,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'FLOAT',
                                                          'WIDTH': 10},
                                      'LS_R_FACTOR_GT': {'NULLABLE': True,
                                                         'ORDER': 80,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                      'LS_R_FACTOR_OBS': {'NULLABLE': True,
                                                          'ORDER': 49,
                                                          'PRECISION': 6,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'FLOAT',
                                                          'WIDTH': 10},
                                      'LS_R_FACTOR_R_FREE': {'NULLABLE': True,
                                                             'ORDER': 50,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                      'LS_R_FACTOR_R_FREE_ERROR': {'NULLABLE': True,
                                                                   'ORDER': 51,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                      'LS_R_FACTOR_R_FREE_ERROR_DETAILS': {'NULLABLE': True,
                                                                           'ORDER': 52,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 200},
                                      'LS_R_FACTOR_R_WORK': {'NULLABLE': True,
                                                             'ORDER': 53,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                      'LS_R_FSQD_FACTOR_OBS': {'NULLABLE': True,
                                                               'ORDER': 54,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                      'LS_R_I_FACTOR_OBS': {'NULLABLE': True,
                                                            'ORDER': 55,
                                                            'PRECISION': 6,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'FLOAT',
                                                            'WIDTH': 10},
                                      'LS_SHIFT_OVER_ESD_MAX': {'NULLABLE': True,
                                                                'ORDER': 60,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                      'LS_SHIFT_OVER_ESD_MEAN': {'NULLABLE': True,
                                                                 'ORDER': 61,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                      'LS_SHIFT_OVER_SU_MAX': {'NULLABLE': True,
                                                               'ORDER': 83,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                      'LS_SHIFT_OVER_SU_MAX_LT': {'NULLABLE': True,
                                                                  'ORDER': 84,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10},
                                      'LS_SHIFT_OVER_SU_MEAN': {'NULLABLE': True,
                                                                'ORDER': 85,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                      'LS_SHIFT_OVER_SU_MEAN_LT': {'NULLABLE': True,
                                                                   'ORDER': 86,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                      'LS_STRUCTURE_FACTOR_COEF': {'NULLABLE': True,
                                                                   'ORDER': 62,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 10},
                                      'LS_WEIGHTING_DETAILS': {'NULLABLE': True,
                                                               'ORDER': 63,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 200},
                                      'LS_WEIGHTING_SCHEME': {'NULLABLE': True,
                                                              'ORDER': 64,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10},
                                      'LS_WR_FACTOR_ALL': {'NULLABLE': True,
                                                           'ORDER': 65,
                                                           'PRECISION': 6,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'FLOAT',
                                                           'WIDTH': 10},
                                      'LS_WR_FACTOR_OBS': {'NULLABLE': True,
                                                           'ORDER': 66,
                                                           'PRECISION': 6,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'FLOAT',
                                                           'WIDTH': 10},
                                      'LS_WR_FACTOR_R_FREE': {'NULLABLE': True,
                                                              'ORDER': 67,
                                                              'PRECISION': 6,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'FLOAT',
                                                              'WIDTH': 10},
                                      'LS_WR_FACTOR_R_WORK': {'NULLABLE': True,
                                                              'ORDER': 68,
                                                              'PRECISION': 6,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'FLOAT',
                                                              'WIDTH': 10},
                                      'OCCUPANCY_MAX': {'NULLABLE': True,
                                                        'ORDER': 69,
                                                        'PRECISION': 6,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'FLOAT',
                                                        'WIDTH': 10},
                                      'OCCUPANCY_MIN': {'NULLABLE': True,
                                                        'ORDER': 70,
                                                        'PRECISION': 6,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'FLOAT',
                                                        'WIDTH': 10},
                                      'OVERALL_FOM_FREE_R_SET': {'NULLABLE': True,
                                                                 'ORDER': 75,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                      'OVERALL_FOM_WORK_R_SET': {'NULLABLE': True,
                                                                 'ORDER': 76,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                      'OVERALL_SU_B': {'NULLABLE': True,
                                                       'ORDER': 71,
                                                       'PRECISION': 6,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'FLOAT',
                                                       'WIDTH': 10},
                                      'OVERALL_SU_ML': {'NULLABLE': True,
                                                        'ORDER': 72,
                                                        'PRECISION': 6,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'FLOAT',
                                                        'WIDTH': 10},
                                      'OVERALL_SU_R_CRUICKSHANK_DPI': {'NULLABLE': True,
                                                                       'ORDER': 73,
                                                                       'PRECISION': 6,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'FLOAT',
                                                                       'WIDTH': 10},
                                      'OVERALL_SU_R_FREE': {'NULLABLE': True,
                                                            'ORDER': 74,
                                                            'PRECISION': 6,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'FLOAT',
                                                            'WIDTH': 10},
                                      'PDBX_DATA_CUTOFF_HIGH_ABSF': {'NULLABLE': True,
                                                                     'ORDER': 90,
                                                                     'PRECISION': 6,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'FLOAT',
                                                                     'WIDTH': 10},
                                      'PDBX_DATA_CUTOFF_HIGH_RMS_ABSF': {'NULLABLE': True,
                                                                         'ORDER': 91,
                                                                         'PRECISION': 6,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'FLOAT',
                                                                         'WIDTH': 10},
                                      'PDBX_DATA_CUTOFF_LOW_ABSF': {'NULLABLE': True,
                                                                    'ORDER': 92,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                      'PDBX_DENSITY_CORRELATION': {'NULLABLE': True,
                                                                   'ORDER': 106,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                      'PDBX_DIFFRN_ID': {'NULLABLE': True,
                                                         'ORDER': 120,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 10},
                                      'PDBX_ISOTROPIC_THERMAL_MODEL': {'NULLABLE': True,
                                                                       'ORDER': 93,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 200},
                                      'PDBX_LS_CROSS_VALID_METHOD': {'NULLABLE': True,
                                                                     'ORDER': 94,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 511},
                                      'PDBX_LS_SIGMA_F': {'NULLABLE': True,
                                                          'ORDER': 88,
                                                          'PRECISION': 6,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'FLOAT',
                                                          'WIDTH': 10},
                                      'PDBX_LS_SIGMA_FSQD': {'NULLABLE': True,
                                                             'ORDER': 89,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                      'PDBX_LS_SIGMA_I': {'NULLABLE': True,
                                                          'ORDER': 87,
                                                          'PRECISION': 6,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'FLOAT',
                                                          'WIDTH': 10},
                                      'PDBX_METHOD_TO_DETERMINE_STRUCT': {'NULLABLE': True,
                                                                          'ORDER': 95,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 511},
                                      'PDBX_OVERALL_ESU_R': {'NULLABLE': True,
                                                             'ORDER': 100,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                      'PDBX_OVERALL_ESU_R_FREE': {'NULLABLE': True,
                                                                  'ORDER': 101,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10},
                                      'PDBX_OVERALL_PHASE_ERROR': {'NULLABLE': True,
                                                                   'ORDER': 115,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                      'PDBX_OVERALL_SU_R_BLOW_DPI': {'NULLABLE': True,
                                                                     'ORDER': 118,
                                                                     'PRECISION': 6,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'FLOAT',
                                                                     'WIDTH': 10},
                                      'PDBX_OVERALL_SU_R_FREE_BLOW_DPI': {'NULLABLE': True,
                                                                          'ORDER': 117,
                                                                          'PRECISION': 6,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'FLOAT',
                                                                          'WIDTH': 10},
                                      'PDBX_OVERALL_SU_R_FREE_CRUICKSHANK_DPI': {'NULLABLE': True,
                                                                                 'ORDER': 116,
                                                                                 'PRECISION': 6,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'FLOAT',
                                                                                 'WIDTH': 10},
                                      'PDBX_PD_FSQRD_R_FACTOR': {'NULLABLE': True,
                                                                 'ORDER': 113,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                      'PDBX_PD_LS_MATRIX_BAND_WIDTH': {'NULLABLE': True,
                                                                       'ORDER': 114,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'INT',
                                                                       'WIDTH': 10},
                                      'PDBX_PD_MARQUARDT_CORRELATION_COEFF': {'NULLABLE': True,
                                                                              'ORDER': 112,
                                                                              'PRECISION': 6,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'FLOAT',
                                                                              'WIDTH': 10},
                                      'PDBX_PD_MEAS_NUMBER_OF_POINTS': {'NULLABLE': True,
                                                                        'ORDER': 109,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'INT',
                                                                        'WIDTH': 10},
                                      'PDBX_PD_NUMBER_OF_POINTS': {'NULLABLE': True,
                                                                   'ORDER': 108,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'INT',
                                                                   'WIDTH': 10},
                                      'PDBX_PD_NUMBER_OF_POWDER_PATTERNS': {'NULLABLE': True,
                                                                            'ORDER': 107,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'INT',
                                                                            'WIDTH': 10},
                                      'PDBX_PD_PROC_LS_PROF_R_FACTOR': {'NULLABLE': True,
                                                                        'ORDER': 110,
                                                                        'PRECISION': 6,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'FLOAT',
                                                                        'WIDTH': 10},
                                      'PDBX_PD_PROC_LS_PROF_WR_FACTOR': {'NULLABLE': True,
                                                                         'ORDER': 111,
                                                                         'PRECISION': 6,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'FLOAT',
                                                                         'WIDTH': 10},
                                      'PDBX_REAL_SPACE_R': {'NULLABLE': True,
                                                            'ORDER': 105,
                                                            'PRECISION': 6,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'FLOAT',
                                                            'WIDTH': 10},
                                      'PDBX_REFINE_ID': {'NULLABLE': False,
                                                         'ORDER': 21,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': True,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 80},
                                      'PDBX_R_FREE_SELECTION_DETAILS': {'NULLABLE': True,
                                                                        'ORDER': 98,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 511},
                                      'PDBX_SOLVENT_ION_PROBE_RADII': {'NULLABLE': True,
                                                                       'ORDER': 103,
                                                                       'PRECISION': 6,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'FLOAT',
                                                                       'WIDTH': 10},
                                      'PDBX_SOLVENT_SHRINKAGE_RADII': {'NULLABLE': True,
                                                                       'ORDER': 104,
                                                                       'PRECISION': 6,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'FLOAT',
                                                                       'WIDTH': 10},
                                      'PDBX_SOLVENT_VDW_PROBE_RADII': {'NULLABLE': True,
                                                                       'ORDER': 102,
                                                                       'PRECISION': 6,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'FLOAT',
                                                                       'WIDTH': 10},
                                      'PDBX_STARTING_MODEL': {'NULLABLE': True,
                                                              'ORDER': 96,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 511},
                                      'PDBX_STEREOCHEMISTRY_TARGET_VALUES': {'NULLABLE': True,
                                                                             'ORDER': 97,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 511},
                                      'PDBX_STEREOCHEM_TARGET_VAL_SPEC_CASE': {'NULLABLE': True,
                                                                               'ORDER': 99,
                                                                               'PRECISION': 0,
                                                                               'PRIMARY_KEY': False,
                                                                               'SQL_TYPE': 'VARCHAR',
                                                                               'WIDTH': 511},
                                      'PDBX_TLS_RESIDUAL_ADP_FLAG': {'NULLABLE': True,
                                                                     'ORDER': 119,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 80},
                                      'SOLVENT_MODEL_DETAILS': {'NULLABLE': True,
                                                                'ORDER': 77,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 511},
                                      'SOLVENT_MODEL_PARAM_BSOL': {'NULLABLE': True,
                                                                   'ORDER': 78,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                      'SOLVENT_MODEL_PARAM_KSOL': {'NULLABLE': True,
                                                                   'ORDER': 79,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                      'STRUCTURE_ID': {'NULLABLE': False,
                                                       'ORDER': 1,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': True,
                                                       'SQL_TYPE': 'VARCHAR',
                                                       'WIDTH': 10}},
                   'ATTRIBUTE_MAP': {'ANISO_B_1_1': ('refine', 'aniso_B[1][1]', None, None),
                                     'ANISO_B_1_2': ('refine', 'aniso_B[1][2]', None, None),
                                     'ANISO_B_1_3': ('refine', 'aniso_B[1][3]', None, None),
                                     'ANISO_B_2_2': ('refine', 'aniso_B[2][2]', None, None),
                                     'ANISO_B_2_3': ('refine', 'aniso_B[2][3]', None, None),
                                     'ANISO_B_3_3': ('refine', 'aniso_B[3][3]', None, None),
                                     'B_ISO_MAX': ('refine', 'B_iso_max', None, None),
                                     'B_ISO_MEAN': ('refine', 'B_iso_mean', None, None),
                                     'B_ISO_MIN': ('refine', 'B_iso_min', None, None),
                                     'CORRELATION_COEFF_FO_TO_FC': ('refine', 'correlation_coeff_Fo_to_Fc', None, None),
                                     'CORRELATION_COEFF_FO_TO_FC_FREE': ('refine',
                                                                         'correlation_coeff_Fo_to_Fc_free',
                                                                         None,
                                                                         None),
                                     'DETAILS': ('refine', 'details', None, None),
                                     'DIFF_DENSITY_MAX': ('refine', 'diff_density_max', None, None),
                                     'DIFF_DENSITY_MAX_ESD': ('refine', 'diff_density_max_esd', None, None),
                                     'DIFF_DENSITY_MIN': ('refine', 'diff_density_min', None, None),
                                     'DIFF_DENSITY_MIN_ESD': ('refine', 'diff_density_min_esd', None, None),
                                     'DIFF_DENSITY_RMS': ('refine', 'diff_density_rms', None, None),
                                     'DIFF_DENSITY_RMS_ESD': ('refine', 'diff_density_rms_esd', None, None),
                                     'ENTRY_ID': ('refine', 'entry_id', None, None),
                                     'LS_ABS_STRUCTURE_DETAILS': ('refine', 'ls_abs_structure_details', None, None),
                                     'LS_ABS_STRUCTURE_FLACK': ('refine', 'ls_abs_structure_Flack', None, None),
                                     'LS_ABS_STRUCTURE_FLACK_ESD': ('refine', 'ls_abs_structure_Flack_esd', None, None),
                                     'LS_ABS_STRUCTURE_ROGERS': ('refine', 'ls_abs_structure_Rogers', None, None),
                                     'LS_ABS_STRUCTURE_ROGERS_ESD': ('refine', 'ls_abs_structure_Rogers_esd', None, None),
                                     'LS_D_RES_HIGH': ('refine', 'ls_d_res_high', None, None),
                                     'LS_D_RES_LOW': ('refine', 'ls_d_res_low', None, None),
                                     'LS_EXTINCTION_COEF': ('refine', 'ls_extinction_coef', None, None),
                                     'LS_EXTINCTION_COEF_ESD': ('refine', 'ls_extinction_coef_esd', None, None),
                                     'LS_EXTINCTION_EXPRESSION': ('refine', 'ls_extinction_expression', None, None),
                                     'LS_EXTINCTION_METHOD': ('refine', 'ls_extinction_method', None, None),
                                     'LS_GOODNESS_OF_FIT_ALL': ('refine', 'ls_goodness_of_fit_all', None, None),
                                     'LS_GOODNESS_OF_FIT_ALL_ESD': ('refine', 'ls_goodness_of_fit_all_esd', None, None),
                                     'LS_GOODNESS_OF_FIT_GT': ('refine', 'ls_goodness_of_fit_gt', None, None),
                                     'LS_GOODNESS_OF_FIT_OBS': ('refine', 'ls_goodness_of_fit_obs', None, None),
                                     'LS_GOODNESS_OF_FIT_OBS_ESD': ('refine', 'ls_goodness_of_fit_obs_esd', None, None),
                                     'LS_GOODNESS_OF_FIT_REF': ('refine', 'ls_goodness_of_fit_ref', None, None),
                                     'LS_HYDROGEN_TREATMENT': ('refine', 'ls_hydrogen_treatment', None, None),
                                     'LS_MATRIX_TYPE': ('refine', 'ls_matrix_type', None, None),
                                     'LS_NUMBER_CONSTRAINTS': ('refine', 'ls_number_constraints', None, None),
                                     'LS_NUMBER_PARAMETERS': ('refine', 'ls_number_parameters', None, None),
                                     'LS_NUMBER_REFLNS_ALL': ('refine', 'ls_number_reflns_all', None, None),
                                     'LS_NUMBER_REFLNS_OBS': ('refine', 'ls_number_reflns_obs', None, None),
                                     'LS_NUMBER_REFLNS_R_FREE': ('refine', 'ls_number_reflns_R_free', None, None),
                                     'LS_NUMBER_REFLNS_R_WORK': ('refine', 'ls_number_reflns_R_work', None, None),
                                     'LS_NUMBER_RESTRAINTS': ('refine', 'ls_number_restraints', None, None),
                                     'LS_PERCENT_REFLNS_OBS': ('refine', 'ls_percent_reflns_obs', None, None),
                                     'LS_PERCENT_REFLNS_R_FREE': ('refine', 'ls_percent_reflns_R_free', None, None),
                                     'LS_REDUNDANCY_REFLNS_ALL': ('refine', 'ls_redundancy_reflns_all', None, None),
                                     'LS_REDUNDANCY_REFLNS_OBS': ('refine', 'ls_redundancy_reflns_obs', None, None),
                                     'LS_RESTRAINED_S_ALL': ('refine', 'ls_restrained_S_all', None, None),
                                     'LS_RESTRAINED_S_OBS': ('refine', 'ls_restrained_S_obs', None, None),
                                     'LS_R_FACTOR_ALL': ('refine', 'ls_R_factor_all', None, None),
                                     'LS_R_FACTOR_GT': ('refine', 'ls_R_factor_gt', None, None),
                                     'LS_R_FACTOR_OBS': ('refine', 'ls_R_factor_obs', None, None),
                                     'LS_R_FACTOR_R_FREE': ('refine', 'ls_R_factor_R_free', None, None),
                                     'LS_R_FACTOR_R_FREE_ERROR': ('refine', 'ls_R_factor_R_free_error', None, None),
                                     'LS_R_FACTOR_R_FREE_ERROR_DETAILS': ('refine',
                                                                          'ls_R_factor_R_free_error_details',
                                                                          None,
                                                                          None),
                                     'LS_R_FACTOR_R_WORK': ('refine', 'ls_R_factor_R_work', None, None),
                                     'LS_R_FSQD_FACTOR_OBS': ('refine', 'ls_R_Fsqd_factor_obs', None, None),
                                     'LS_R_I_FACTOR_OBS': ('refine', 'ls_R_I_factor_obs', None, None),
                                     'LS_SHIFT_OVER_ESD_MAX': ('refine', 'ls_shift_over_esd_max', None, None),
                                     'LS_SHIFT_OVER_ESD_MEAN': ('refine', 'ls_shift_over_esd_mean', None, None),
                                     'LS_SHIFT_OVER_SU_MAX': ('refine', 'ls_shift_over_su_max', None, None),
                                     'LS_SHIFT_OVER_SU_MAX_LT': ('refine', 'ls_shift_over_su_max_lt', None, None),
                                     'LS_SHIFT_OVER_SU_MEAN': ('refine', 'ls_shift_over_su_mean', None, None),
                                     'LS_SHIFT_OVER_SU_MEAN_LT': ('refine', 'ls_shift_over_su_mean_lt', None, None),
                                     'LS_STRUCTURE_FACTOR_COEF': ('refine', 'ls_structure_factor_coef', None, None),
                                     'LS_WEIGHTING_DETAILS': ('refine', 'ls_weighting_details', None, None),
                                     'LS_WEIGHTING_SCHEME': ('refine', 'ls_weighting_scheme', None, None),
                                     'LS_WR_FACTOR_ALL': ('refine', 'ls_wR_factor_all', None, None),
                                     'LS_WR_FACTOR_OBS': ('refine', 'ls_wR_factor_obs', None, None),
                                     'LS_WR_FACTOR_R_FREE': ('refine', 'ls_wR_factor_R_free', None, None),
                                     'LS_WR_FACTOR_R_WORK': ('refine', 'ls_wR_factor_R_work', None, None),
                                     'OCCUPANCY_MAX': ('refine', 'occupancy_max', None, None),
                                     'OCCUPANCY_MIN': ('refine', 'occupancy_min', None, None),
                                     'OVERALL_FOM_FREE_R_SET': ('refine', 'overall_FOM_free_R_set', None, None),
                                     'OVERALL_FOM_WORK_R_SET': ('refine', 'overall_FOM_work_R_set', None, None),
                                     'OVERALL_SU_B': ('refine', 'overall_SU_B', None, None),
                                     'OVERALL_SU_ML': ('refine', 'overall_SU_ML', None, None),
                                     'OVERALL_SU_R_CRUICKSHANK_DPI': ('refine', 'overall_SU_R_Cruickshank_DPI', None, None),
                                     'OVERALL_SU_R_FREE': ('refine', 'overall_SU_R_free', None, None),
                                     'PDBX_DATA_CUTOFF_HIGH_ABSF': ('refine', 'pdbx_data_cutoff_high_absF', None, None),
                                     'PDBX_DATA_CUTOFF_HIGH_RMS_ABSF': ('refine',
                                                                        'pdbx_data_cutoff_high_rms_absF',
                                                                        None,
                                                                        None),
                                     'PDBX_DATA_CUTOFF_LOW_ABSF': ('refine', 'pdbx_data_cutoff_low_absF', None, None),
                                     'PDBX_DENSITY_CORRELATION': ('refine', 'pdbx_density_correlation', None, None),
                                     'PDBX_DIFFRN_ID': ('refine', 'pdbx_diffrn_id', None, None),
                                     'PDBX_ISOTROPIC_THERMAL_MODEL': ('refine', 'pdbx_isotropic_thermal_model', None, None),
                                     'PDBX_LS_CROSS_VALID_METHOD': ('refine', 'pdbx_ls_cross_valid_method', None, None),
                                     'PDBX_LS_SIGMA_F': ('refine', 'pdbx_ls_sigma_F', None, None),
                                     'PDBX_LS_SIGMA_FSQD': ('refine', 'pdbx_ls_sigma_Fsqd', None, None),
                                     'PDBX_LS_SIGMA_I': ('refine', 'pdbx_ls_sigma_I', None, None),
                                     'PDBX_METHOD_TO_DETERMINE_STRUCT': ('refine',
                                                                         'pdbx_method_to_determine_struct',
                                                                         None,
                                                                         None),
                                     'PDBX_OVERALL_ESU_R': ('refine', 'pdbx_overall_ESU_R', None, None),
                                     'PDBX_OVERALL_ESU_R_FREE': ('refine', 'pdbx_overall_ESU_R_Free', None, None),
                                     'PDBX_OVERALL_PHASE_ERROR': ('refine', 'pdbx_overall_phase_error', None, None),
                                     'PDBX_OVERALL_SU_R_BLOW_DPI': ('refine', 'pdbx_overall_SU_R_Blow_DPI', None, None),
                                     'PDBX_OVERALL_SU_R_FREE_BLOW_DPI': ('refine',
                                                                         'pdbx_overall_SU_R_free_Blow_DPI',
                                                                         None,
                                                                         None),
                                     'PDBX_OVERALL_SU_R_FREE_CRUICKSHANK_DPI': ('refine',
                                                                                'pdbx_overall_SU_R_free_Cruickshank_DPI',
                                                                                None,
                                                                                None),
                                     'PDBX_PD_FSQRD_R_FACTOR': ('refine', 'pdbx_pd_Fsqrd_R_factor', None, None),
                                     'PDBX_PD_LS_MATRIX_BAND_WIDTH': ('refine', 'pdbx_pd_ls_matrix_band_width', None, None),
                                     'PDBX_PD_MARQUARDT_CORRELATION_COEFF': ('refine',
                                                                             'pdbx_pd_Marquardt_correlation_coeff',
                                                                             None,
                                                                             None),
                                     'PDBX_PD_MEAS_NUMBER_OF_POINTS': ('refine', 'pdbx_pd_meas_number_of_points', None, None),
                                     'PDBX_PD_NUMBER_OF_POINTS': ('refine', 'pdbx_pd_number_of_points', None, None),
                                     'PDBX_PD_NUMBER_OF_POWDER_PATTERNS': ('refine',
                                                                           'pdbx_pd_number_of_powder_patterns',
                                                                           None,
                                                                           None),
                                     'PDBX_PD_PROC_LS_PROF_R_FACTOR': ('refine', 'pdbx_pd_proc_ls_prof_R_factor', None, None),
                                     'PDBX_PD_PROC_LS_PROF_WR_FACTOR': ('refine',
                                                                        'pdbx_pd_proc_ls_prof_wR_factor',
                                                                        None,
                                                                        None),
                                     'PDBX_REAL_SPACE_R': ('refine', 'pdbx_real_space_R', None, None),
                                     'PDBX_REFINE_ID': ('refine', 'pdbx_refine_id', None, None),
                                     'PDBX_R_FREE_SELECTION_DETAILS': ('refine', 'pdbx_R_Free_selection_details', None, None),
                                     'PDBX_SOLVENT_ION_PROBE_RADII': ('refine', 'pdbx_solvent_ion_probe_radii', None, None),
                                     'PDBX_SOLVENT_SHRINKAGE_RADII': ('refine', 'pdbx_solvent_shrinkage_radii', None, None),
                                     'PDBX_SOLVENT_VDW_PROBE_RADII': ('refine', 'pdbx_solvent_vdw_probe_radii', None, None),
                                     'PDBX_STARTING_MODEL': ('refine', 'pdbx_starting_model', None, None),
                                     'PDBX_STEREOCHEMISTRY_TARGET_VALUES': ('refine',
                                                                            'pdbx_stereochemistry_target_values',
                                                                            None,
                                                                            None),
                                     'PDBX_STEREOCHEM_TARGET_VAL_SPEC_CASE': ('refine',
                                                                              'pdbx_stereochem_target_val_spec_case',
                                                                              None,
                                                                              None),
                                     'PDBX_TLS_RESIDUAL_ADP_FLAG': ('refine', 'pdbx_TLS_residual_ADP_flag', None, None),
                                     'SOLVENT_MODEL_DETAILS': ('refine', 'solvent_model_details', None, None),
                                     'SOLVENT_MODEL_PARAM_BSOL': ('refine', 'solvent_model_param_bsol', None, None),
                                     'SOLVENT_MODEL_PARAM_KSOL': ('refine', 'solvent_model_param_ksol', None, None),
                                     'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                   'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID', 'PDBX_REFINE_ID'), 'TYPE': 'UNIQUE'},
                               's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                   'MAP_MERGE_INDICES': {'refine': {'ATTRIBUTES': ('entry_id', 'pdbx_refine_id'), 'TYPE': 'EQUI-JOIN'}},
                   'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                   'TABLE_ID': 'REFINE',
                   'TABLE_NAME': 'refine',
                   'TABLE_TYPE': 'transactional'},
        'REFINE_ANALYZE': {'ATTRIBUTES': {'ENTRY_ID': 'entry_id',
                                          'LUZZATI_COORDINATE_ERROR_FREE': 'Luzzati_coordinate_error_free',
                                          'LUZZATI_COORDINATE_ERROR_OBS': 'Luzzati_coordinate_error_obs',
                                          'LUZZATI_D_RES_LOW_FREE': 'Luzzati_d_res_low_free',
                                          'LUZZATI_D_RES_LOW_OBS': 'Luzzati_d_res_low_obs',
                                          'LUZZATI_SIGMA_A_FREE': 'Luzzati_sigma_a_free',
                                          'LUZZATI_SIGMA_A_FREE_DETAILS': 'Luzzati_sigma_a_free_details',
                                          'LUZZATI_SIGMA_A_OBS': 'Luzzati_sigma_a_obs',
                                          'LUZZATI_SIGMA_A_OBS_DETAILS': 'Luzzati_sigma_a_obs_details',
                                          'NUMBER_DISORDERED_RESIDUES': 'number_disordered_residues',
                                          'OCCUPANCY_SUM_HYDROGEN': 'occupancy_sum_hydrogen',
                                          'OCCUPANCY_SUM_NON_HYDROGEN': 'occupancy_sum_non_hydrogen',
                                          'PDBX_LUZZATI_D_RES_HIGH_OBS': 'pdbx_Luzzati_d_res_high_obs',
                                          'PDBX_REFINE_ID': 'pdbx_refine_id',
                                          'RG_D_RES_HIGH': 'RG_d_res_high',
                                          'RG_D_RES_LOW': 'RG_d_res_low',
                                          'RG_FREE': 'RG_free',
                                          'RG_FREE_WORK_RATIO': 'RG_free_work_ratio',
                                          'RG_WORK': 'RG_work',
                                          'STRUCTURE_ID': 'Structure_ID'},
                           'ATTRIBUTE_INFO': {'ENTRY_ID': {'NULLABLE': False,
                                                           'ORDER': 2,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': True,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 10},
                                              'LUZZATI_COORDINATE_ERROR_FREE': {'NULLABLE': True,
                                                                                'ORDER': 4,
                                                                                'PRECISION': 6,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'FLOAT',
                                                                                'WIDTH': 10},
                                              'LUZZATI_COORDINATE_ERROR_OBS': {'NULLABLE': True,
                                                                               'ORDER': 5,
                                                                               'PRECISION': 6,
                                                                               'PRIMARY_KEY': False,
                                                                               'SQL_TYPE': 'FLOAT',
                                                                               'WIDTH': 10},
                                              'LUZZATI_D_RES_LOW_FREE': {'NULLABLE': True,
                                                                         'ORDER': 6,
                                                                         'PRECISION': 6,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'FLOAT',
                                                                         'WIDTH': 10},
                                              'LUZZATI_D_RES_LOW_OBS': {'NULLABLE': True,
                                                                        'ORDER': 7,
                                                                        'PRECISION': 6,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'FLOAT',
                                                                        'WIDTH': 10},
                                              'LUZZATI_SIGMA_A_FREE': {'NULLABLE': True,
                                                                       'ORDER': 8,
                                                                       'PRECISION': 6,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'FLOAT',
                                                                       'WIDTH': 10},
                                              'LUZZATI_SIGMA_A_FREE_DETAILS': {'NULLABLE': True,
                                                                               'ORDER': 9,
                                                                               'PRECISION': 0,
                                                                               'PRIMARY_KEY': False,
                                                                               'SQL_TYPE': 'VARCHAR',
                                                                               'WIDTH': 200},
                                              'LUZZATI_SIGMA_A_OBS': {'NULLABLE': True,
                                                                      'ORDER': 10,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                              'LUZZATI_SIGMA_A_OBS_DETAILS': {'NULLABLE': True,
                                                                              'ORDER': 11,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 200},
                                              'NUMBER_DISORDERED_RESIDUES': {'NULLABLE': True,
                                                                             'ORDER': 12,
                                                                             'PRECISION': 6,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'FLOAT',
                                                                             'WIDTH': 10},
                                              'OCCUPANCY_SUM_HYDROGEN': {'NULLABLE': True,
                                                                         'ORDER': 13,
                                                                         'PRECISION': 6,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'FLOAT',
                                                                         'WIDTH': 10},
                                              'OCCUPANCY_SUM_NON_HYDROGEN': {'NULLABLE': True,
                                                                             'ORDER': 14,
                                                                             'PRECISION': 6,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'FLOAT',
                                                                             'WIDTH': 10},
                                              'PDBX_LUZZATI_D_RES_HIGH_OBS': {'NULLABLE': True,
                                                                              'ORDER': 20,
                                                                              'PRECISION': 6,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'FLOAT',
                                                                              'WIDTH': 10},
                                              'PDBX_REFINE_ID': {'NULLABLE': False,
                                                                 'ORDER': 3,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': True,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 80},
                                              'RG_D_RES_HIGH': {'NULLABLE': True,
                                                                'ORDER': 15,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                              'RG_D_RES_LOW': {'NULLABLE': True,
                                                               'ORDER': 16,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                              'RG_FREE': {'NULLABLE': True,
                                                          'ORDER': 17,
                                                          'PRECISION': 6,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'FLOAT',
                                                          'WIDTH': 10},
                                              'RG_FREE_WORK_RATIO': {'NULLABLE': True,
                                                                     'ORDER': 19,
                                                                     'PRECISION': 6,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'FLOAT',
                                                                     'WIDTH': 10},
                                              'RG_WORK': {'NULLABLE': True,
                                                          'ORDER': 18,
                                                          'PRECISION': 6,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'FLOAT',
                                                          'WIDTH': 10},
                                              'STRUCTURE_ID': {'NULLABLE': False,
                                                               'ORDER': 1,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10}},
                           'ATTRIBUTE_MAP': {'ENTRY_ID': ('refine_analyze', 'entry_id', None, None),
                                             'LUZZATI_COORDINATE_ERROR_FREE': ('refine_analyze',
                                                                               'Luzzati_coordinate_error_free',
                                                                               None,
                                                                               None),
                                             'LUZZATI_COORDINATE_ERROR_OBS': ('refine_analyze',
                                                                              'Luzzati_coordinate_error_obs',
                                                                              None,
                                                                              None),
                                             'LUZZATI_D_RES_LOW_FREE': ('refine_analyze',
                                                                        'Luzzati_d_res_low_free',
                                                                        None,
                                                                        None),
                                             'LUZZATI_D_RES_LOW_OBS': ('refine_analyze', 'Luzzati_d_res_low_obs', None, None),
                                             'LUZZATI_SIGMA_A_FREE': ('refine_analyze', 'Luzzati_sigma_a_free', None, None),
                                             'LUZZATI_SIGMA_A_FREE_DETAILS': ('refine_analyze',
                                                                              'Luzzati_sigma_a_free_details',
                                                                              None,
                                                                              None),
                                             'LUZZATI_SIGMA_A_OBS': ('refine_analyze', 'Luzzati_sigma_a_obs', None, None),
                                             'LUZZATI_SIGMA_A_OBS_DETAILS': ('refine_analyze',
                                                                             'Luzzati_sigma_a_obs_details',
                                                                             None,
                                                                             None),
                                             'NUMBER_DISORDERED_RESIDUES': ('refine_analyze',
                                                                            'number_disordered_residues',
                                                                            None,
                                                                            None),
                                             'OCCUPANCY_SUM_HYDROGEN': ('refine_analyze',
                                                                        'occupancy_sum_hydrogen',
                                                                        None,
                                                                        None),
                                             'OCCUPANCY_SUM_NON_HYDROGEN': ('refine_analyze',
                                                                            'occupancy_sum_non_hydrogen',
                                                                            None,
                                                                            None),
                                             'PDBX_LUZZATI_D_RES_HIGH_OBS': ('refine_analyze',
                                                                             'pdbx_Luzzati_d_res_high_obs',
                                                                             None,
                                                                             None),
                                             'PDBX_REFINE_ID': ('refine_analyze', 'pdbx_refine_id', None, None),
                                             'RG_D_RES_HIGH': ('refine_analyze', 'RG_d_res_high', None, None),
                                             'RG_D_RES_LOW': ('refine_analyze', 'RG_d_res_low', None, None),
                                             'RG_FREE': ('refine_analyze', 'RG_free', None, None),
                                             'RG_FREE_WORK_RATIO': ('refine_analyze', 'RG_free_work_ratio', None, None),
                                             'RG_WORK': ('refine_analyze', 'RG_work', None, None),
                                             'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                           'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID', 'PDBX_REFINE_ID'), 'TYPE': 'UNIQUE'},
                                       's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                           'MAP_MERGE_INDICES': {'refine_analyze': {'ATTRIBUTES': ('entry_id', 'pdbx_refine_id'),
                                                                    'TYPE': 'EQUI-JOIN'}},
                           'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                           'TABLE_ID': 'REFINE_ANALYZE',
                           'TABLE_NAME': 'refine_analyze',
                           'TABLE_TYPE': 'transactional'},
        'REFINE_B_ISO': {'ATTRIBUTES': {'CLASS': 'class',
                                        'DETAILS': 'details',
                                        'PDBX_REFINE_ID': 'pdbx_refine_id',
                                        'STRUCTURE_ID': 'Structure_ID',
                                        'TREATMENT': 'treatment',
                                        'VALUE': 'value'},
                         'ATTRIBUTE_INFO': {'CLASS': {'NULLABLE': False,
                                                      'ORDER': 3,
                                                      'PRECISION': 0,
                                                      'PRIMARY_KEY': True,
                                                      'SQL_TYPE': 'VARCHAR',
                                                      'WIDTH': 200},
                                            'DETAILS': {'NULLABLE': True,
                                                        'ORDER': 4,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 200},
                                            'PDBX_REFINE_ID': {'NULLABLE': False,
                                                               'ORDER': 2,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 80},
                                            'STRUCTURE_ID': {'NULLABLE': False,
                                                             'ORDER': 1,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 10},
                                            'TREATMENT': {'NULLABLE': True,
                                                          'ORDER': 5,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 12},
                                            'VALUE': {'NULLABLE': True,
                                                      'ORDER': 6,
                                                      'PRECISION': 6,
                                                      'PRIMARY_KEY': False,
                                                      'SQL_TYPE': 'FLOAT',
                                                      'WIDTH': 10}},
                         'ATTRIBUTE_MAP': {'CLASS': ('refine_B_iso', 'class', None, None),
                                           'DETAILS': ('refine_B_iso', 'details', None, None),
                                           'PDBX_REFINE_ID': ('refine_B_iso', 'pdbx_refine_id', None, None),
                                           'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                           'TREATMENT': ('refine_B_iso', 'treatment', None, None),
                                           'VALUE': ('refine_B_iso', 'value', None, None)},
                         'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'PDBX_REFINE_ID', 'CLASS'), 'TYPE': 'UNIQUE'},
                                     's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                         'MAP_MERGE_INDICES': {'refine_B_iso': {'ATTRIBUTES': ('pdbx_refine_id', 'class'),
                                                                'TYPE': 'EQUI-JOIN'}},
                         'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                         'TABLE_ID': 'REFINE_B_ISO',
                         'TABLE_NAME': 'refine_B_iso',
                         'TABLE_TYPE': 'transactional'},
        'REFINE_FUNCT_MINIMIZED': {'ATTRIBUTES': {'NUMBER_TERMS': 'number_terms',
                                                  'PDBX_REFINE_ID': 'pdbx_refine_id',
                                                  'RESIDUAL': 'residual',
                                                  'STRUCTURE_ID': 'Structure_ID',
                                                  'TYPE': 'type',
                                                  'WEIGHT': 'weight'},
                                   'ATTRIBUTE_INFO': {'NUMBER_TERMS': {'NULLABLE': True,
                                                                       'ORDER': 3,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'INT',
                                                                       'WIDTH': 10},
                                                      'PDBX_REFINE_ID': {'NULLABLE': False,
                                                                         'ORDER': 2,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': True,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 80},
                                                      'RESIDUAL': {'NULLABLE': True,
                                                                   'ORDER': 4,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                                      'STRUCTURE_ID': {'NULLABLE': False,
                                                                       'ORDER': 1,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': True,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                      'TYPE': {'NULLABLE': False,
                                                               'ORDER': 5,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 80},
                                                      'WEIGHT': {'NULLABLE': True,
                                                                 'ORDER': 6,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10}},
                                   'ATTRIBUTE_MAP': {'NUMBER_TERMS': ('refine_funct_minimized', 'number_terms', None, None),
                                                     'PDBX_REFINE_ID': ('refine_funct_minimized',
                                                                        'pdbx_refine_id',
                                                                        None,
                                                                        None),
                                                     'RESIDUAL': ('refine_funct_minimized', 'residual', None, None),
                                                     'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                     'TYPE': ('refine_funct_minimized', 'type', None, None),
                                                     'WEIGHT': ('refine_funct_minimized', 'weight', None, None)},
                                   'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'PDBX_REFINE_ID', 'TYPE'),
                                                      'TYPE': 'UNIQUE'},
                                               's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                   'MAP_MERGE_INDICES': {'refine_funct_minimized': {'ATTRIBUTES': ('pdbx_refine_id', 'type'),
                                                                                    'TYPE': 'EQUI-JOIN'}},
                                   'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                   'TABLE_ID': 'REFINE_FUNCT_MINIMIZED',
                                   'TABLE_NAME': 'refine_funct_minimized',
                                   'TABLE_TYPE': 'transactional'},
        'REFINE_HIST': {'ATTRIBUTES': {'CYCLE_ID': 'cycle_id',
                                       'DETAILS': 'details',
                                       'D_RES_HIGH': 'd_res_high',
                                       'D_RES_LOW': 'd_res_low',
                                       'NUMBER_ATOMS_SOLVENT': 'number_atoms_solvent',
                                       'NUMBER_ATOMS_TOTAL': 'number_atoms_total',
                                       'NUMBER_REFLNS_ALL': 'number_reflns_all',
                                       'NUMBER_REFLNS_OBS': 'number_reflns_obs',
                                       'NUMBER_REFLNS_R_FREE': 'number_reflns_R_free',
                                       'NUMBER_REFLNS_R_WORK': 'number_reflns_R_work',
                                       'PDBX_NUMBER_ATOMS_CARB': 'pdbx_number_atoms_carb',
                                       'PDBX_NUMBER_ATOMS_LIGAND': 'pdbx_number_atoms_ligand',
                                       'PDBX_NUMBER_ATOMS_LIPID': 'pdbx_number_atoms_lipid',
                                       'PDBX_NUMBER_ATOMS_NUCLEIC_ACID': 'pdbx_number_atoms_nucleic_acid',
                                       'PDBX_NUMBER_ATOMS_PROTEIN': 'pdbx_number_atoms_protein',
                                       'PDBX_PSEUDO_ATOM_DETAILS': 'pdbx_pseudo_atom_details',
                                       'PDBX_REFINE_ID': 'pdbx_refine_id',
                                       'R_FACTOR_ALL': 'R_factor_all',
                                       'R_FACTOR_OBS': 'R_factor_obs',
                                       'R_FACTOR_R_FREE': 'R_factor_R_free',
                                       'R_FACTOR_R_WORK': 'R_factor_R_work',
                                       'STRUCTURE_ID': 'Structure_ID'},
                        'ATTRIBUTE_INFO': {'CYCLE_ID': {'NULLABLE': False,
                                                        'ORDER': 3,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': True,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 10},
                                           'DETAILS': {'NULLABLE': True,
                                                       'ORDER': 4,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'VARCHAR',
                                                       'WIDTH': 200},
                                           'D_RES_HIGH': {'NULLABLE': True,
                                                          'ORDER': 5,
                                                          'PRECISION': 6,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'FLOAT',
                                                          'WIDTH': 10},
                                           'D_RES_LOW': {'NULLABLE': True,
                                                         'ORDER': 6,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                           'NUMBER_ATOMS_SOLVENT': {'NULLABLE': True,
                                                                    'ORDER': 7,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'INT',
                                                                    'WIDTH': 10},
                                           'NUMBER_ATOMS_TOTAL': {'NULLABLE': True,
                                                                  'ORDER': 8,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'INT',
                                                                  'WIDTH': 10},
                                           'NUMBER_REFLNS_ALL': {'NULLABLE': True,
                                                                 'ORDER': 9,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'INT',
                                                                 'WIDTH': 10},
                                           'NUMBER_REFLNS_OBS': {'NULLABLE': True,
                                                                 'ORDER': 10,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'INT',
                                                                 'WIDTH': 10},
                                           'NUMBER_REFLNS_R_FREE': {'NULLABLE': True,
                                                                    'ORDER': 11,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'INT',
                                                                    'WIDTH': 10},
                                           'NUMBER_REFLNS_R_WORK': {'NULLABLE': True,
                                                                    'ORDER': 12,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'INT',
                                                                    'WIDTH': 10},
                                           'PDBX_NUMBER_ATOMS_CARB': {'NULLABLE': True,
                                                                      'ORDER': 21,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'INT',
                                                                      'WIDTH': 10},
                                           'PDBX_NUMBER_ATOMS_LIGAND': {'NULLABLE': True,
                                                                        'ORDER': 19,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'INT',
                                                                        'WIDTH': 10},
                                           'PDBX_NUMBER_ATOMS_LIPID': {'NULLABLE': True,
                                                                       'ORDER': 20,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'INT',
                                                                       'WIDTH': 10},
                                           'PDBX_NUMBER_ATOMS_NUCLEIC_ACID': {'NULLABLE': True,
                                                                              'ORDER': 18,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'INT',
                                                                              'WIDTH': 10},
                                           'PDBX_NUMBER_ATOMS_PROTEIN': {'NULLABLE': True,
                                                                         'ORDER': 17,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'INT',
                                                                         'WIDTH': 10},
                                           'PDBX_PSEUDO_ATOM_DETAILS': {'NULLABLE': True,
                                                                        'ORDER': 22,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 200},
                                           'PDBX_REFINE_ID': {'NULLABLE': False,
                                                              'ORDER': 2,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 80},
                                           'R_FACTOR_ALL': {'NULLABLE': True,
                                                            'ORDER': 13,
                                                            'PRECISION': 6,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'FLOAT',
                                                            'WIDTH': 10},
                                           'R_FACTOR_OBS': {'NULLABLE': True,
                                                            'ORDER': 14,
                                                            'PRECISION': 6,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'FLOAT',
                                                            'WIDTH': 10},
                                           'R_FACTOR_R_FREE': {'NULLABLE': True,
                                                               'ORDER': 15,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                           'R_FACTOR_R_WORK': {'NULLABLE': True,
                                                               'ORDER': 16,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                           'STRUCTURE_ID': {'NULLABLE': False,
                                                            'ORDER': 1,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': True,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 10}},
                        'ATTRIBUTE_MAP': {'CYCLE_ID': ('refine_hist', 'cycle_id', None, None),
                                          'DETAILS': ('refine_hist', 'details', None, None),
                                          'D_RES_HIGH': ('refine_hist', 'd_res_high', None, None),
                                          'D_RES_LOW': ('refine_hist', 'd_res_low', None, None),
                                          'NUMBER_ATOMS_SOLVENT': ('refine_hist', 'number_atoms_solvent', None, None),
                                          'NUMBER_ATOMS_TOTAL': ('refine_hist', 'number_atoms_total', None, None),
                                          'NUMBER_REFLNS_ALL': ('refine_hist', 'number_reflns_all', None, None),
                                          'NUMBER_REFLNS_OBS': ('refine_hist', 'number_reflns_obs', None, None),
                                          'NUMBER_REFLNS_R_FREE': ('refine_hist', 'number_reflns_R_free', None, None),
                                          'NUMBER_REFLNS_R_WORK': ('refine_hist', 'number_reflns_R_work', None, None),
                                          'PDBX_NUMBER_ATOMS_CARB': ('refine_hist', 'pdbx_number_atoms_carb', None, None),
                                          'PDBX_NUMBER_ATOMS_LIGAND': ('refine_hist', 'pdbx_number_atoms_ligand', None, None),
                                          'PDBX_NUMBER_ATOMS_LIPID': ('refine_hist', 'pdbx_number_atoms_lipid', None, None),
                                          'PDBX_NUMBER_ATOMS_NUCLEIC_ACID': ('refine_hist',
                                                                             'pdbx_number_atoms_nucleic_acid',
                                                                             None,
                                                                             None),
                                          'PDBX_NUMBER_ATOMS_PROTEIN': ('refine_hist',
                                                                        'pdbx_number_atoms_protein',
                                                                        None,
                                                                        None),
                                          'PDBX_PSEUDO_ATOM_DETAILS': ('refine_hist', 'pdbx_pseudo_atom_details', None, None),
                                          'PDBX_REFINE_ID': ('refine_hist', 'pdbx_refine_id', None, None),
                                          'R_FACTOR_ALL': ('refine_hist', 'R_factor_all', None, None),
                                          'R_FACTOR_OBS': ('refine_hist', 'R_factor_obs', None, None),
                                          'R_FACTOR_R_FREE': ('refine_hist', 'R_factor_R_free', None, None),
                                          'R_FACTOR_R_WORK': ('refine_hist', 'R_factor_R_work', None, None),
                                          'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                        'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'PDBX_REFINE_ID', 'CYCLE_ID'), 'TYPE': 'UNIQUE'},
                                    's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                        'MAP_MERGE_INDICES': {'refine_hist': {'ATTRIBUTES': ('pdbx_refine_id', 'cycle_id'),
                                                              'TYPE': 'EQUI-JOIN'}},
                        'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                        'TABLE_ID': 'REFINE_HIST',
                        'TABLE_NAME': 'refine_hist',
                        'TABLE_TYPE': 'transactional'},
        'REFINE_LS_CLASS': {'ATTRIBUTES': {'CODE': 'code',
                                           'D_RES_HIGH': 'd_res_high',
                                           'D_RES_LOW': 'd_res_low',
                                           'R_FACTOR_ALL': 'R_factor_all',
                                           'R_FACTOR_GT': 'R_factor_gt',
                                           'R_FSQD_FACTOR': 'R_Fsqd_factor',
                                           'R_I_FACTOR': 'R_I_factor',
                                           'STRUCTURE_ID': 'Structure_ID',
                                           'WR_FACTOR_ALL': 'wR_factor_all'},
                            'ATTRIBUTE_INFO': {'CODE': {'NULLABLE': False,
                                                        'ORDER': 2,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': True,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 10},
                                               'D_RES_HIGH': {'NULLABLE': True,
                                                              'ORDER': 3,
                                                              'PRECISION': 6,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'FLOAT',
                                                              'WIDTH': 10},
                                               'D_RES_LOW': {'NULLABLE': True,
                                                             'ORDER': 4,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                               'R_FACTOR_ALL': {'NULLABLE': True,
                                                                'ORDER': 6,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                               'R_FACTOR_GT': {'NULLABLE': True,
                                                               'ORDER': 5,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                               'R_FSQD_FACTOR': {'NULLABLE': True,
                                                                 'ORDER': 7,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                               'R_I_FACTOR': {'NULLABLE': True,
                                                              'ORDER': 8,
                                                              'PRECISION': 6,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'FLOAT',
                                                              'WIDTH': 10},
                                               'STRUCTURE_ID': {'NULLABLE': False,
                                                                'ORDER': 1,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                               'WR_FACTOR_ALL': {'NULLABLE': True,
                                                                 'ORDER': 9,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10}},
                            'ATTRIBUTE_MAP': {'CODE': ('refine_ls_class', 'code', None, None),
                                              'D_RES_HIGH': ('refine_ls_class', 'd_res_high', None, None),
                                              'D_RES_LOW': ('refine_ls_class', 'd_res_low', None, None),
                                              'R_FACTOR_ALL': ('refine_ls_class', 'R_factor_all', None, None),
                                              'R_FACTOR_GT': ('refine_ls_class', 'R_factor_gt', None, None),
                                              'R_FSQD_FACTOR': ('refine_ls_class', 'R_Fsqd_factor', None, None),
                                              'R_I_FACTOR': ('refine_ls_class', 'R_I_factor', None, None),
                                              'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                              'WR_FACTOR_ALL': ('refine_ls_class', 'wR_factor_all', None, None)},
                            'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'CODE'), 'TYPE': 'UNIQUE'},
                                        's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                            'MAP_MERGE_INDICES': {'refine_ls_class': {'ATTRIBUTES': ('code',), 'TYPE': 'EQUI-JOIN'}},
                            'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                            'TABLE_ID': 'REFINE_LS_CLASS',
                            'TABLE_NAME': 'refine_ls_class',
                            'TABLE_TYPE': 'transactional'},
        'REFINE_LS_RESTR': {'ATTRIBUTES': {'CRITERION': 'criterion',
                                           'DEV_IDEAL': 'dev_ideal',
                                           'DEV_IDEAL_TARGET': 'dev_ideal_target',
                                           'NUMBER': 'number',
                                           'PDBX_REFINE_ID': 'pdbx_refine_id',
                                           'PDBX_RESTRAINT_FUNCTION': 'pdbx_restraint_function',
                                           'REJECTS': 'rejects',
                                           'STRUCTURE_ID': 'Structure_ID',
                                           'TYPE': 'type',
                                           'WEIGHT': 'weight'},
                            'ATTRIBUTE_INFO': {'CRITERION': {'NULLABLE': True,
                                                             'ORDER': 3,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 200},
                                               'DEV_IDEAL': {'NULLABLE': True,
                                                             'ORDER': 4,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                               'DEV_IDEAL_TARGET': {'NULLABLE': True,
                                                                    'ORDER': 5,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                               'NUMBER': {'NULLABLE': True,
                                                          'ORDER': 6,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'INT',
                                                          'WIDTH': 10},
                                               'PDBX_REFINE_ID': {'NULLABLE': False,
                                                                  'ORDER': 2,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': True,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 80},
                                               'PDBX_RESTRAINT_FUNCTION': {'NULLABLE': True,
                                                                           'ORDER': 10,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 200},
                                               'REJECTS': {'NULLABLE': True,
                                                           'ORDER': 7,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'INT',
                                                           'WIDTH': 10},
                                               'STRUCTURE_ID': {'NULLABLE': False,
                                                                'ORDER': 1,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                               'TYPE': {'NULLABLE': False,
                                                        'ORDER': 8,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': True,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 80},
                                               'WEIGHT': {'NULLABLE': True,
                                                          'ORDER': 9,
                                                          'PRECISION': 6,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'FLOAT',
                                                          'WIDTH': 10}},
                            'ATTRIBUTE_MAP': {'CRITERION': ('refine_ls_restr', 'criterion', None, None),
                                              'DEV_IDEAL': ('refine_ls_restr', 'dev_ideal', None, None),
                                              'DEV_IDEAL_TARGET': ('refine_ls_restr', 'dev_ideal_target', None, None),
                                              'NUMBER': ('refine_ls_restr', 'number', None, None),
                                              'PDBX_REFINE_ID': ('refine_ls_restr', 'pdbx_refine_id', None, None),
                                              'PDBX_RESTRAINT_FUNCTION': ('refine_ls_restr',
                                                                          'pdbx_restraint_function',
                                                                          None,
                                                                          None),
                                              'REJECTS': ('refine_ls_restr', 'rejects', None, None),
                                              'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                              'TYPE': ('refine_ls_restr', 'type', None, None),
                                              'WEIGHT': ('refine_ls_restr', 'weight', None, None)},
                            'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'PDBX_REFINE_ID', 'TYPE'), 'TYPE': 'UNIQUE'},
                                        's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                            'MAP_MERGE_INDICES': {'refine_ls_restr': {'ATTRIBUTES': ('pdbx_refine_id', 'type'),
                                                                      'TYPE': 'EQUI-JOIN'}},
                            'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                            'TABLE_ID': 'REFINE_LS_RESTR',
                            'TABLE_NAME': 'refine_ls_restr',
                            'TABLE_TYPE': 'transactional'},
        'REFINE_LS_RESTR_NCS': {'ATTRIBUTES': {'DOM_ID': 'dom_id',
                                               'NCS_MODEL_DETAILS': 'ncs_model_details',
                                               'PDBX_ASYM_ID': 'pdbx_asym_id',
                                               'PDBX_AUTH_ASYM_ID': 'pdbx_auth_asym_id',
                                               'PDBX_ENS_ID': 'pdbx_ens_id',
                                               'PDBX_NUMBER': 'pdbx_number',
                                               'PDBX_ORDINAL': 'pdbx_ordinal',
                                               'PDBX_REFINE_ID': 'pdbx_refine_id',
                                               'PDBX_RMS': 'pdbx_rms',
                                               'PDBX_TYPE': 'pdbx_type',
                                               'PDBX_WEIGHT': 'pdbx_weight',
                                               'RMS_DEV_B_ISO': 'rms_dev_B_iso',
                                               'RMS_DEV_POSITION': 'rms_dev_position',
                                               'STRUCTURE_ID': 'Structure_ID',
                                               'WEIGHT_B_ISO': 'weight_B_iso',
                                               'WEIGHT_POSITION': 'weight_position'},
                                'ATTRIBUTE_INFO': {'DOM_ID': {'NULLABLE': True,
                                                              'ORDER': 3,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10},
                                                   'NCS_MODEL_DETAILS': {'NULLABLE': True,
                                                                         'ORDER': 4,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 1023},
                                                   'PDBX_ASYM_ID': {'NULLABLE': True,
                                                                    'ORDER': 11,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10},
                                                   'PDBX_AUTH_ASYM_ID': {'NULLABLE': True,
                                                                         'ORDER': 12,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                                   'PDBX_ENS_ID': {'NULLABLE': True,
                                                                   'ORDER': 16,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 10},
                                                   'PDBX_NUMBER': {'NULLABLE': True,
                                                                   'ORDER': 13,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'INT',
                                                                   'WIDTH': 10},
                                                   'PDBX_ORDINAL': {'NULLABLE': False,
                                                                    'ORDER': 9,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': True,
                                                                    'SQL_TYPE': 'INT',
                                                                    'WIDTH': 10},
                                                   'PDBX_REFINE_ID': {'NULLABLE': True,
                                                                      'ORDER': 2,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 80},
                                                   'PDBX_RMS': {'NULLABLE': True,
                                                                'ORDER': 14,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                                   'PDBX_TYPE': {'NULLABLE': True,
                                                                 'ORDER': 10,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 200},
                                                   'PDBX_WEIGHT': {'NULLABLE': True,
                                                                   'ORDER': 15,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                                   'RMS_DEV_B_ISO': {'NULLABLE': True,
                                                                     'ORDER': 5,
                                                                     'PRECISION': 6,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'FLOAT',
                                                                     'WIDTH': 10},
                                                   'RMS_DEV_POSITION': {'NULLABLE': True,
                                                                        'ORDER': 6,
                                                                        'PRECISION': 6,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'FLOAT',
                                                                        'WIDTH': 10},
                                                   'STRUCTURE_ID': {'NULLABLE': False,
                                                                    'ORDER': 1,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': True,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10},
                                                   'WEIGHT_B_ISO': {'NULLABLE': True,
                                                                    'ORDER': 7,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                                   'WEIGHT_POSITION': {'NULLABLE': True,
                                                                       'ORDER': 8,
                                                                       'PRECISION': 6,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'FLOAT',
                                                                       'WIDTH': 10}},
                                'ATTRIBUTE_MAP': {'DOM_ID': ('refine_ls_restr_ncs', 'dom_id', None, None),
                                                  'NCS_MODEL_DETAILS': ('refine_ls_restr_ncs',
                                                                        'ncs_model_details',
                                                                        None,
                                                                        None),
                                                  'PDBX_ASYM_ID': ('refine_ls_restr_ncs', 'pdbx_asym_id', None, None),
                                                  'PDBX_AUTH_ASYM_ID': ('refine_ls_restr_ncs',
                                                                        'pdbx_auth_asym_id',
                                                                        None,
                                                                        None),
                                                  'PDBX_ENS_ID': ('refine_ls_restr_ncs', 'pdbx_ens_id', None, None),
                                                  'PDBX_NUMBER': ('refine_ls_restr_ncs', 'pdbx_number', None, None),
                                                  'PDBX_ORDINAL': ('refine_ls_restr_ncs', 'pdbx_ordinal', None, None),
                                                  'PDBX_REFINE_ID': ('refine_ls_restr_ncs', 'pdbx_refine_id', None, None),
                                                  'PDBX_RMS': ('refine_ls_restr_ncs', 'pdbx_rms', None, None),
                                                  'PDBX_TYPE': ('refine_ls_restr_ncs', 'pdbx_type', None, None),
                                                  'PDBX_WEIGHT': ('refine_ls_restr_ncs', 'pdbx_weight', None, None),
                                                  'RMS_DEV_B_ISO': ('refine_ls_restr_ncs', 'rms_dev_B_iso', None, None),
                                                  'RMS_DEV_POSITION': ('refine_ls_restr_ncs', 'rms_dev_position', None, None),
                                                  'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                  'WEIGHT_B_ISO': ('refine_ls_restr_ncs', 'weight_B_iso', None, None),
                                                  'WEIGHT_POSITION': ('refine_ls_restr_ncs', 'weight_position', None, None)},
                                'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'PDBX_ORDINAL'), 'TYPE': 'UNIQUE'},
                                            's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                'MAP_MERGE_INDICES': {'refine_ls_restr_ncs': {'ATTRIBUTES': ('pdbx_ordinal',),
                                                                              'TYPE': 'EQUI-JOIN'}},
                                'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                'TABLE_ID': 'REFINE_LS_RESTR_NCS',
                                'TABLE_NAME': 'refine_ls_restr_ncs',
                                'TABLE_TYPE': 'transactional'},
        'REFINE_LS_RESTR_TYPE': {'ATTRIBUTES': {'DISTANCE_CUTOFF_HIGH': 'distance_cutoff_high',
                                                'DISTANCE_CUTOFF_LOW': 'distance_cutoff_low',
                                                'STRUCTURE_ID': 'Structure_ID',
                                                'TYPE': 'type'},
                                 'ATTRIBUTE_INFO': {'DISTANCE_CUTOFF_HIGH': {'NULLABLE': True,
                                                                             'ORDER': 3,
                                                                             'PRECISION': 6,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'FLOAT',
                                                                             'WIDTH': 10},
                                                    'DISTANCE_CUTOFF_LOW': {'NULLABLE': True,
                                                                            'ORDER': 4,
                                                                            'PRECISION': 6,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'FLOAT',
                                                                            'WIDTH': 10},
                                                    'STRUCTURE_ID': {'NULLABLE': False,
                                                                     'ORDER': 1,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': True,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                                    'TYPE': {'NULLABLE': False,
                                                             'ORDER': 2,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 80}},
                                 'ATTRIBUTE_MAP': {'DISTANCE_CUTOFF_HIGH': ('refine_ls_restr_type',
                                                                            'distance_cutoff_high',
                                                                            None,
                                                                            None),
                                                   'DISTANCE_CUTOFF_LOW': ('refine_ls_restr_type',
                                                                           'distance_cutoff_low',
                                                                           None,
                                                                           None),
                                                   'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                   'TYPE': ('refine_ls_restr_type', 'type', None, None)},
                                 'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'TYPE'), 'TYPE': 'UNIQUE'},
                                             's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                 'MAP_MERGE_INDICES': {'refine_ls_restr_type': {'ATTRIBUTES': ('type',), 'TYPE': 'EQUI-JOIN'}},
                                 'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                 'TABLE_ID': 'REFINE_LS_RESTR_TYPE',
                                 'TABLE_NAME': 'refine_ls_restr_type',
                                 'TABLE_TYPE': 'transactional'},
        'REFINE_LS_SHELL': {'ATTRIBUTES': {'D_RES_HIGH': 'd_res_high',
                                           'D_RES_LOW': 'd_res_low',
                                           'NUMBER_REFLNS_ALL': 'number_reflns_all',
                                           'NUMBER_REFLNS_OBS': 'number_reflns_obs',
                                           'NUMBER_REFLNS_R_FREE': 'number_reflns_R_free',
                                           'NUMBER_REFLNS_R_WORK': 'number_reflns_R_work',
                                           'PDBX_PHASE_ERROR': 'pdbx_phase_error',
                                           'PDBX_REFINE_ID': 'pdbx_refine_id',
                                           'PDBX_TOTAL_NUMBER_OF_BINS_USED': 'pdbx_total_number_of_bins_used',
                                           'PERCENT_REFLNS_OBS': 'percent_reflns_obs',
                                           'PERCENT_REFLNS_R_FREE': 'percent_reflns_R_free',
                                           'REDUNDANCY_REFLNS_ALL': 'redundancy_reflns_all',
                                           'REDUNDANCY_REFLNS_OBS': 'redundancy_reflns_obs',
                                           'R_FACTOR_ALL': 'R_factor_all',
                                           'R_FACTOR_OBS': 'R_factor_obs',
                                           'R_FACTOR_R_FREE': 'R_factor_R_free',
                                           'R_FACTOR_R_FREE_ERROR': 'R_factor_R_free_error',
                                           'R_FACTOR_R_WORK': 'R_factor_R_work',
                                           'STRUCTURE_ID': 'Structure_ID',
                                           'WR_FACTOR_ALL': 'wR_factor_all',
                                           'WR_FACTOR_OBS': 'wR_factor_obs',
                                           'WR_FACTOR_R_FREE': 'wR_factor_R_free',
                                           'WR_FACTOR_R_WORK': 'wR_factor_R_work'},
                            'ATTRIBUTE_INFO': {'D_RES_HIGH': {'NULLABLE': False,
                                                              'ORDER': 3,
                                                              'PRECISION': 6,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'FLOAT',
                                                              'WIDTH': 10},
                                               'D_RES_LOW': {'NULLABLE': True,
                                                             'ORDER': 4,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                               'NUMBER_REFLNS_ALL': {'NULLABLE': True,
                                                                     'ORDER': 5,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'INT',
                                                                     'WIDTH': 10},
                                               'NUMBER_REFLNS_OBS': {'NULLABLE': True,
                                                                     'ORDER': 6,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'INT',
                                                                     'WIDTH': 10},
                                               'NUMBER_REFLNS_R_FREE': {'NULLABLE': True,
                                                                        'ORDER': 7,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'INT',
                                                                        'WIDTH': 10},
                                               'NUMBER_REFLNS_R_WORK': {'NULLABLE': True,
                                                                        'ORDER': 8,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'INT',
                                                                        'WIDTH': 10},
                                               'PDBX_PHASE_ERROR': {'NULLABLE': True,
                                                                    'ORDER': 23,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                               'PDBX_REFINE_ID': {'NULLABLE': False,
                                                                  'ORDER': 2,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': True,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 80},
                                               'PDBX_TOTAL_NUMBER_OF_BINS_USED': {'NULLABLE': True,
                                                                                  'ORDER': 22,
                                                                                  'PRECISION': 0,
                                                                                  'PRIMARY_KEY': False,
                                                                                  'SQL_TYPE': 'INT',
                                                                                  'WIDTH': 10},
                                               'PERCENT_REFLNS_OBS': {'NULLABLE': True,
                                                                      'ORDER': 9,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                               'PERCENT_REFLNS_R_FREE': {'NULLABLE': True,
                                                                         'ORDER': 10,
                                                                         'PRECISION': 6,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'FLOAT',
                                                                         'WIDTH': 10},
                                               'REDUNDANCY_REFLNS_ALL': {'NULLABLE': True,
                                                                         'ORDER': 16,
                                                                         'PRECISION': 6,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'FLOAT',
                                                                         'WIDTH': 10},
                                               'REDUNDANCY_REFLNS_OBS': {'NULLABLE': True,
                                                                         'ORDER': 17,
                                                                         'PRECISION': 6,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'FLOAT',
                                                                         'WIDTH': 10},
                                               'R_FACTOR_ALL': {'NULLABLE': True,
                                                                'ORDER': 11,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                               'R_FACTOR_OBS': {'NULLABLE': True,
                                                                'ORDER': 12,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                               'R_FACTOR_R_FREE': {'NULLABLE': True,
                                                                   'ORDER': 13,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                               'R_FACTOR_R_FREE_ERROR': {'NULLABLE': True,
                                                                         'ORDER': 14,
                                                                         'PRECISION': 6,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'FLOAT',
                                                                         'WIDTH': 10},
                                               'R_FACTOR_R_WORK': {'NULLABLE': True,
                                                                   'ORDER': 15,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                               'STRUCTURE_ID': {'NULLABLE': False,
                                                                'ORDER': 1,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                               'WR_FACTOR_ALL': {'NULLABLE': True,
                                                                 'ORDER': 18,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                               'WR_FACTOR_OBS': {'NULLABLE': True,
                                                                 'ORDER': 19,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                               'WR_FACTOR_R_FREE': {'NULLABLE': True,
                                                                    'ORDER': 20,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                               'WR_FACTOR_R_WORK': {'NULLABLE': True,
                                                                    'ORDER': 21,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10}},
                            'ATTRIBUTE_MAP': {'D_RES_HIGH': ('refine_ls_shell', 'd_res_high', None, None),
                                              'D_RES_LOW': ('refine_ls_shell', 'd_res_low', None, None),
                                              'NUMBER_REFLNS_ALL': ('refine_ls_shell', 'number_reflns_all', None, None),
                                              'NUMBER_REFLNS_OBS': ('refine_ls_shell', 'number_reflns_obs', None, None),
                                              'NUMBER_REFLNS_R_FREE': ('refine_ls_shell', 'number_reflns_R_free', None, None),
                                              'NUMBER_REFLNS_R_WORK': ('refine_ls_shell', 'number_reflns_R_work', None, None),
                                              'PDBX_PHASE_ERROR': ('refine_ls_shell', 'pdbx_phase_error', None, None),
                                              'PDBX_REFINE_ID': ('refine_ls_shell', 'pdbx_refine_id', None, None),
                                              'PDBX_TOTAL_NUMBER_OF_BINS_USED': ('refine_ls_shell',
                                                                                 'pdbx_total_number_of_bins_used',
                                                                                 None,
                                                                                 None),
                                              'PERCENT_REFLNS_OBS': ('refine_ls_shell', 'percent_reflns_obs', None, None),
                                              'PERCENT_REFLNS_R_FREE': ('refine_ls_shell',
                                                                        'percent_reflns_R_free',
                                                                        None,
                                                                        None),
                                              'REDUNDANCY_REFLNS_ALL': ('refine_ls_shell',
                                                                        'redundancy_reflns_all',
                                                                        None,
                                                                        None),
                                              'REDUNDANCY_REFLNS_OBS': ('refine_ls_shell',
                                                                        'redundancy_reflns_obs',
                                                                        None,
                                                                        None),
                                              'R_FACTOR_ALL': ('refine_ls_shell', 'R_factor_all', None, None),
                                              'R_FACTOR_OBS': ('refine_ls_shell', 'R_factor_obs', None, None),
                                              'R_FACTOR_R_FREE': ('refine_ls_shell', 'R_factor_R_free', None, None),
                                              'R_FACTOR_R_FREE_ERROR': ('refine_ls_shell',
                                                                        'R_factor_R_free_error',
                                                                        None,
                                                                        None),
                                              'R_FACTOR_R_WORK': ('refine_ls_shell', 'R_factor_R_work', None, None),
                                              'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                              'WR_FACTOR_ALL': ('refine_ls_shell', 'wR_factor_all', None, None),
                                              'WR_FACTOR_OBS': ('refine_ls_shell', 'wR_factor_obs', None, None),
                                              'WR_FACTOR_R_FREE': ('refine_ls_shell', 'wR_factor_R_free', None, None),
                                              'WR_FACTOR_R_WORK': ('refine_ls_shell', 'wR_factor_R_work', None, None)},
                            'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'PDBX_REFINE_ID', 'D_RES_HIGH'),
                                               'TYPE': 'UNIQUE'},
                                        's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                            'MAP_MERGE_INDICES': {'refine_ls_shell': {'ATTRIBUTES': ('pdbx_refine_id', 'd_res_high'),
                                                                      'TYPE': 'EQUI-JOIN'}},
                            'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                            'TABLE_ID': 'REFINE_LS_SHELL',
                            'TABLE_NAME': 'refine_ls_shell',
                            'TABLE_TYPE': 'transactional'},
        'REFINE_OCCUPANCY': {'ATTRIBUTES': {'CLASS': 'class',
                                            'DETAILS': 'details',
                                            'PDBX_REFINE_ID': 'pdbx_refine_id',
                                            'STRUCTURE_ID': 'Structure_ID',
                                            'TREATMENT': 'treatment',
                                            'VALUE': 'value'},
                             'ATTRIBUTE_INFO': {'CLASS': {'NULLABLE': False,
                                                          'ORDER': 3,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': True,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 200},
                                                'DETAILS': {'NULLABLE': True,
                                                            'ORDER': 4,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 200},
                                                'PDBX_REFINE_ID': {'NULLABLE': False,
                                                                   'ORDER': 2,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': True,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 80},
                                                'STRUCTURE_ID': {'NULLABLE': False,
                                                                 'ORDER': 1,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': True,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                                'TREATMENT': {'NULLABLE': True,
                                                              'ORDER': 5,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10},
                                                'VALUE': {'NULLABLE': True,
                                                          'ORDER': 6,
                                                          'PRECISION': 6,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'FLOAT',
                                                          'WIDTH': 10}},
                             'ATTRIBUTE_MAP': {'CLASS': ('refine_occupancy', 'class', None, None),
                                               'DETAILS': ('refine_occupancy', 'details', None, None),
                                               'PDBX_REFINE_ID': ('refine_occupancy', 'pdbx_refine_id', None, None),
                                               'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                               'TREATMENT': ('refine_occupancy', 'treatment', None, None),
                                               'VALUE': ('refine_occupancy', 'value', None, None)},
                             'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'PDBX_REFINE_ID', 'CLASS'), 'TYPE': 'UNIQUE'},
                                         's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                             'MAP_MERGE_INDICES': {'refine_occupancy': {'ATTRIBUTES': ('pdbx_refine_id', 'class'),
                                                                        'TYPE': 'EQUI-JOIN'}},
                             'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                             'TABLE_ID': 'REFINE_OCCUPANCY',
                             'TABLE_NAME': 'refine_occupancy',
                             'TABLE_TYPE': 'transactional'},
        'REFLN': {'ATTRIBUTES': {'A_CALC': 'A_calc',
                                 'A_CALC_AU': 'A_calc_au',
                                 'A_MEAS': 'A_meas',
                                 'A_MEAS_AU': 'A_meas_au',
                                 'B_CALC': 'B_calc',
                                 'B_CALC_AU': 'B_calc_au',
                                 'B_MEAS': 'B_meas',
                                 'B_MEAS_AU': 'B_meas_au',
                                 'CLASS_CODE': 'class_code',
                                 'CRYSTAL_ID': 'crystal_id',
                                 'D_SPACING': 'd_spacing',
                                 'FOM': 'fom',
                                 'F_CALC': 'F_calc',
                                 'F_CALC_AU': 'F_calc_au',
                                 'F_MEAS': 'F_meas',
                                 'F_MEAS_AU': 'F_meas_au',
                                 'F_MEAS_SIGMA': 'F_meas_sigma',
                                 'F_MEAS_SIGMA_AU': 'F_meas_sigma_au',
                                 'F_SQUARED_CALC': 'F_squared_calc',
                                 'F_SQUARED_MEAS': 'F_squared_meas',
                                 'F_SQUARED_SIGMA': 'F_squared_sigma',
                                 'INCLUDE_STATUS': 'include_status',
                                 'INDEX_H': 'index_h',
                                 'INDEX_K': 'index_k',
                                 'INDEX_L': 'index_l',
                                 'INTENSITY_CALC': 'intensity_calc',
                                 'INTENSITY_MEAS': 'intensity_meas',
                                 'INTENSITY_SIGMA': 'intensity_sigma',
                                 'MEAN_PATH_LENGTH_TBAR': 'mean_path_length_tbar',
                                 'PDBX_ANOM_DIFFERENCE': 'pdbx_anom_difference',
                                 'PDBX_ANOM_DIFFERENCE_SIGMA': 'pdbx_anom_difference_sigma',
                                 'PDBX_DELFWT': 'pdbx_DELFWT',
                                 'PDBX_DELPHWT': 'pdbx_DELPHWT',
                                 'PDBX_DIFFRN_ID': 'pdbx_diffrn_id',
                                 'PDBX_FIBER_COORDINATE': 'pdbx_fiber_coordinate',
                                 'PDBX_FIBER_F_MEAS_AU': 'pdbx_fiber_F_meas_au',
                                 'PDBX_FIBER_LAYER': 'pdbx_fiber_layer',
                                 'PDBX_FWT': 'pdbx_FWT',
                                 'PDBX_F_CALC_PART_SOLVENT': 'pdbx_F_calc_part_solvent',
                                 'PDBX_F_CALC_WITH_SOLVENT': 'pdbx_F_calc_with_solvent',
                                 'PDBX_F_MINUS': 'pdbx_F_minus',
                                 'PDBX_F_MINUS_SIGMA': 'pdbx_F_minus_sigma',
                                 'PDBX_F_PLUS': 'pdbx_F_plus',
                                 'PDBX_F_PLUS_SIGMA': 'pdbx_F_plus_sigma',
                                 'PDBX_HL_A_ISO': 'pdbx_HL_A_iso',
                                 'PDBX_HL_B_ISO': 'pdbx_HL_B_iso',
                                 'PDBX_HL_C_ISO': 'pdbx_HL_C_iso',
                                 'PDBX_HL_D_ISO': 'pdbx_HL_D_iso',
                                 'PDBX_I_MINUS': 'pdbx_I_minus',
                                 'PDBX_I_MINUS_SIGMA': 'pdbx_I_minus_sigma',
                                 'PDBX_I_PLUS': 'pdbx_I_plus',
                                 'PDBX_I_PLUS_SIGMA': 'pdbx_I_plus_sigma',
                                 'PDBX_PHASE_CALC_PART_SOLVENT': 'pdbx_phase_calc_part_solvent',
                                 'PDBX_PHASE_CALC_WITH_SOLVENT': 'pdbx_phase_calc_with_solvent',
                                 'PDBX_PHWT': 'pdbx_PHWT',
                                 'PHASE_CALC': 'phase_calc',
                                 'PHASE_MEAS': 'phase_meas',
                                 'REFINEMENT_STATUS': 'refinement_status',
                                 'SCALE_GROUP_CODE': 'scale_group_code',
                                 'SINT_OVER_LAMBDA': 'sint_over_lambda',
                                 'STATUS': 'status',
                                 'STRUCTURE_ID': 'Structure_ID',
                                 'SYMMETRY_EPSILON': 'symmetry_epsilon',
                                 'SYMMETRY_MULTIPLICITY': 'symmetry_multiplicity',
                                 'WAVELENGTH': 'wavelength',
                                 'WAVELENGTH_ID': 'wavelength_id'},
                  'ATTRIBUTE_INFO': {'A_CALC': {'NULLABLE': True,
                                                'ORDER': 4,
                                                'PRECISION': 6,
                                                'PRIMARY_KEY': False,
                                                'SQL_TYPE': 'FLOAT',
                                                'WIDTH': 10},
                                     'A_CALC_AU': {'NULLABLE': True,
                                                   'ORDER': 5,
                                                   'PRECISION': 6,
                                                   'PRIMARY_KEY': False,
                                                   'SQL_TYPE': 'FLOAT',
                                                   'WIDTH': 10},
                                     'A_MEAS': {'NULLABLE': True,
                                                'ORDER': 6,
                                                'PRECISION': 6,
                                                'PRIMARY_KEY': False,
                                                'SQL_TYPE': 'FLOAT',
                                                'WIDTH': 10},
                                     'A_MEAS_AU': {'NULLABLE': True,
                                                   'ORDER': 7,
                                                   'PRECISION': 6,
                                                   'PRIMARY_KEY': False,
                                                   'SQL_TYPE': 'FLOAT',
                                                   'WIDTH': 10},
                                     'B_CALC': {'NULLABLE': True,
                                                'ORDER': 8,
                                                'PRECISION': 6,
                                                'PRIMARY_KEY': False,
                                                'SQL_TYPE': 'FLOAT',
                                                'WIDTH': 10},
                                     'B_CALC_AU': {'NULLABLE': True,
                                                   'ORDER': 9,
                                                   'PRECISION': 6,
                                                   'PRIMARY_KEY': False,
                                                   'SQL_TYPE': 'FLOAT',
                                                   'WIDTH': 10},
                                     'B_MEAS': {'NULLABLE': True,
                                                'ORDER': 10,
                                                'PRECISION': 6,
                                                'PRIMARY_KEY': False,
                                                'SQL_TYPE': 'FLOAT',
                                                'WIDTH': 10},
                                     'B_MEAS_AU': {'NULLABLE': True,
                                                   'ORDER': 11,
                                                   'PRECISION': 6,
                                                   'PRIMARY_KEY': False,
                                                   'SQL_TYPE': 'FLOAT',
                                                   'WIDTH': 10},
                                     'CLASS_CODE': {'NULLABLE': True,
                                                    'ORDER': 37,
                                                    'PRECISION': 0,
                                                    'PRIMARY_KEY': False,
                                                    'SQL_TYPE': 'VARCHAR',
                                                    'WIDTH': 10},
                                     'CRYSTAL_ID': {'NULLABLE': True,
                                                    'ORDER': 3,
                                                    'PRECISION': 0,
                                                    'PRIMARY_KEY': False,
                                                    'SQL_TYPE': 'VARCHAR',
                                                    'WIDTH': 10},
                                     'D_SPACING': {'NULLABLE': True,
                                                   'ORDER': 38,
                                                   'PRECISION': 6,
                                                   'PRIMARY_KEY': False,
                                                   'SQL_TYPE': 'FLOAT',
                                                   'WIDTH': 10},
                                     'FOM': {'NULLABLE': True,
                                             'ORDER': 21,
                                             'PRECISION': 6,
                                             'PRIMARY_KEY': False,
                                             'SQL_TYPE': 'FLOAT',
                                             'WIDTH': 10},
                                     'F_CALC': {'NULLABLE': True,
                                                'ORDER': 12,
                                                'PRECISION': 6,
                                                'PRIMARY_KEY': False,
                                                'SQL_TYPE': 'FLOAT',
                                                'WIDTH': 10},
                                     'F_CALC_AU': {'NULLABLE': True,
                                                   'ORDER': 13,
                                                   'PRECISION': 6,
                                                   'PRIMARY_KEY': False,
                                                   'SQL_TYPE': 'FLOAT',
                                                   'WIDTH': 10},
                                     'F_MEAS': {'NULLABLE': True,
                                                'ORDER': 14,
                                                'PRECISION': 6,
                                                'PRIMARY_KEY': False,
                                                'SQL_TYPE': 'FLOAT',
                                                'WIDTH': 10},
                                     'F_MEAS_AU': {'NULLABLE': True,
                                                   'ORDER': 15,
                                                   'PRECISION': 6,
                                                   'PRIMARY_KEY': False,
                                                   'SQL_TYPE': 'FLOAT',
                                                   'WIDTH': 10},
                                     'F_MEAS_SIGMA': {'NULLABLE': True,
                                                      'ORDER': 16,
                                                      'PRECISION': 6,
                                                      'PRIMARY_KEY': False,
                                                      'SQL_TYPE': 'FLOAT',
                                                      'WIDTH': 10},
                                     'F_MEAS_SIGMA_AU': {'NULLABLE': True,
                                                         'ORDER': 17,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                     'F_SQUARED_CALC': {'NULLABLE': True,
                                                        'ORDER': 18,
                                                        'PRECISION': 6,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'FLOAT',
                                                        'WIDTH': 10},
                                     'F_SQUARED_MEAS': {'NULLABLE': True,
                                                        'ORDER': 19,
                                                        'PRECISION': 6,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'FLOAT',
                                                        'WIDTH': 10},
                                     'F_SQUARED_SIGMA': {'NULLABLE': True,
                                                         'ORDER': 20,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                     'INCLUDE_STATUS': {'NULLABLE': True,
                                                        'ORDER': 39,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 10},
                                     'INDEX_H': {'NULLABLE': False,
                                                 'ORDER': 22,
                                                 'PRECISION': 0,
                                                 'PRIMARY_KEY': True,
                                                 'SQL_TYPE': 'INT',
                                                 'WIDTH': 10},
                                     'INDEX_K': {'NULLABLE': False,
                                                 'ORDER': 23,
                                                 'PRECISION': 0,
                                                 'PRIMARY_KEY': True,
                                                 'SQL_TYPE': 'INT',
                                                 'WIDTH': 10},
                                     'INDEX_L': {'NULLABLE': False,
                                                 'ORDER': 24,
                                                 'PRECISION': 0,
                                                 'PRIMARY_KEY': True,
                                                 'SQL_TYPE': 'INT',
                                                 'WIDTH': 10},
                                     'INTENSITY_CALC': {'NULLABLE': True,
                                                        'ORDER': 25,
                                                        'PRECISION': 6,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'FLOAT',
                                                        'WIDTH': 10},
                                     'INTENSITY_MEAS': {'NULLABLE': True,
                                                        'ORDER': 26,
                                                        'PRECISION': 6,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'FLOAT',
                                                        'WIDTH': 10},
                                     'INTENSITY_SIGMA': {'NULLABLE': True,
                                                         'ORDER': 27,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                     'MEAN_PATH_LENGTH_TBAR': {'NULLABLE': True,
                                                               'ORDER': 40,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                     'PDBX_ANOM_DIFFERENCE': {'NULLABLE': True,
                                                              'ORDER': 45,
                                                              'PRECISION': 6,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'FLOAT',
                                                              'WIDTH': 10},
                                     'PDBX_ANOM_DIFFERENCE_SIGMA': {'NULLABLE': True,
                                                                    'ORDER': 46,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                     'PDBX_DELFWT': {'NULLABLE': True,
                                                     'ORDER': 64,
                                                     'PRECISION': 6,
                                                     'PRIMARY_KEY': False,
                                                     'SQL_TYPE': 'FLOAT',
                                                     'WIDTH': 10},
                                     'PDBX_DELPHWT': {'NULLABLE': True,
                                                      'ORDER': 65,
                                                      'PRECISION': 6,
                                                      'PRIMARY_KEY': False,
                                                      'SQL_TYPE': 'FLOAT',
                                                      'WIDTH': 10},
                                     'PDBX_DIFFRN_ID': {'NULLABLE': True,
                                                        'ORDER': 66,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 10},
                                     'PDBX_FIBER_COORDINATE': {'NULLABLE': True,
                                                               'ORDER': 60,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                     'PDBX_FIBER_F_MEAS_AU': {'NULLABLE': True,
                                                              'ORDER': 61,
                                                              'PRECISION': 6,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'FLOAT',
                                                              'WIDTH': 10},
                                     'PDBX_FIBER_LAYER': {'NULLABLE': True,
                                                          'ORDER': 59,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'INT',
                                                          'WIDTH': 10},
                                     'PDBX_FWT': {'NULLABLE': True,
                                                  'ORDER': 62,
                                                  'PRECISION': 6,
                                                  'PRIMARY_KEY': False,
                                                  'SQL_TYPE': 'FLOAT',
                                                  'WIDTH': 10},
                                     'PDBX_F_CALC_PART_SOLVENT': {'NULLABLE': True,
                                                                  'ORDER': 41,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10},
                                     'PDBX_F_CALC_WITH_SOLVENT': {'NULLABLE': True,
                                                                  'ORDER': 43,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10},
                                     'PDBX_F_MINUS': {'NULLABLE': True,
                                                      'ORDER': 50,
                                                      'PRECISION': 6,
                                                      'PRIMARY_KEY': False,
                                                      'SQL_TYPE': 'FLOAT',
                                                      'WIDTH': 10},
                                     'PDBX_F_MINUS_SIGMA': {'NULLABLE': True,
                                                            'ORDER': 53,
                                                            'PRECISION': 6,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'FLOAT',
                                                            'WIDTH': 10},
                                     'PDBX_F_PLUS': {'NULLABLE': True,
                                                     'ORDER': 49,
                                                     'PRECISION': 6,
                                                     'PRIMARY_KEY': False,
                                                     'SQL_TYPE': 'FLOAT',
                                                     'WIDTH': 10},
                                     'PDBX_F_PLUS_SIGMA': {'NULLABLE': True,
                                                           'ORDER': 54,
                                                           'PRECISION': 6,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'FLOAT',
                                                           'WIDTH': 10},
                                     'PDBX_HL_A_ISO': {'NULLABLE': True,
                                                       'ORDER': 55,
                                                       'PRECISION': 6,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'FLOAT',
                                                       'WIDTH': 10},
                                     'PDBX_HL_B_ISO': {'NULLABLE': True,
                                                       'ORDER': 56,
                                                       'PRECISION': 6,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'FLOAT',
                                                       'WIDTH': 10},
                                     'PDBX_HL_C_ISO': {'NULLABLE': True,
                                                       'ORDER': 57,
                                                       'PRECISION': 6,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'FLOAT',
                                                       'WIDTH': 10},
                                     'PDBX_HL_D_ISO': {'NULLABLE': True,
                                                       'ORDER': 58,
                                                       'PRECISION': 6,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'FLOAT',
                                                       'WIDTH': 10},
                                     'PDBX_I_MINUS': {'NULLABLE': True,
                                                      'ORDER': 48,
                                                      'PRECISION': 6,
                                                      'PRIMARY_KEY': False,
                                                      'SQL_TYPE': 'FLOAT',
                                                      'WIDTH': 10},
                                     'PDBX_I_MINUS_SIGMA': {'NULLABLE': True,
                                                            'ORDER': 52,
                                                            'PRECISION': 6,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'FLOAT',
                                                            'WIDTH': 10},
                                     'PDBX_I_PLUS': {'NULLABLE': True,
                                                     'ORDER': 47,
                                                     'PRECISION': 6,
                                                     'PRIMARY_KEY': False,
                                                     'SQL_TYPE': 'FLOAT',
                                                     'WIDTH': 10},
                                     'PDBX_I_PLUS_SIGMA': {'NULLABLE': True,
                                                           'ORDER': 51,
                                                           'PRECISION': 6,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'FLOAT',
                                                           'WIDTH': 10},
                                     'PDBX_PHASE_CALC_PART_SOLVENT': {'NULLABLE': True,
                                                                      'ORDER': 42,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                     'PDBX_PHASE_CALC_WITH_SOLVENT': {'NULLABLE': True,
                                                                      'ORDER': 44,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                     'PDBX_PHWT': {'NULLABLE': True,
                                                   'ORDER': 63,
                                                   'PRECISION': 6,
                                                   'PRIMARY_KEY': False,
                                                   'SQL_TYPE': 'FLOAT',
                                                   'WIDTH': 10},
                                     'PHASE_CALC': {'NULLABLE': True,
                                                    'ORDER': 29,
                                                    'PRECISION': 6,
                                                    'PRIMARY_KEY': False,
                                                    'SQL_TYPE': 'FLOAT',
                                                    'WIDTH': 10},
                                     'PHASE_MEAS': {'NULLABLE': True,
                                                    'ORDER': 30,
                                                    'PRECISION': 6,
                                                    'PRIMARY_KEY': False,
                                                    'SQL_TYPE': 'FLOAT',
                                                    'WIDTH': 10},
                                     'REFINEMENT_STATUS': {'NULLABLE': True,
                                                           'ORDER': 31,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 10},
                                     'SCALE_GROUP_CODE': {'NULLABLE': True,
                                                          'ORDER': 32,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 80},
                                     'SINT_OVER_LAMBDA': {'NULLABLE': True,
                                                          'ORDER': 33,
                                                          'PRECISION': 6,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'FLOAT',
                                                          'WIDTH': 10},
                                     'STATUS': {'NULLABLE': True,
                                                'ORDER': 28,
                                                'PRECISION': 0,
                                                'PRIMARY_KEY': False,
                                                'SQL_TYPE': 'VARCHAR',
                                                'WIDTH': 10},
                                     'STRUCTURE_ID': {'NULLABLE': False,
                                                      'ORDER': 1,
                                                      'PRECISION': 0,
                                                      'PRIMARY_KEY': True,
                                                      'SQL_TYPE': 'VARCHAR',
                                                      'WIDTH': 10},
                                     'SYMMETRY_EPSILON': {'NULLABLE': True,
                                                          'ORDER': 34,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'INT',
                                                          'WIDTH': 10},
                                     'SYMMETRY_MULTIPLICITY': {'NULLABLE': True,
                                                               'ORDER': 35,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'INT',
                                                               'WIDTH': 10},
                                     'WAVELENGTH': {'NULLABLE': True,
                                                    'ORDER': 36,
                                                    'PRECISION': 6,
                                                    'PRIMARY_KEY': False,
                                                    'SQL_TYPE': 'FLOAT',
                                                    'WIDTH': 10},
                                     'WAVELENGTH_ID': {'NULLABLE': True,
                                                       'ORDER': 2,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'VARCHAR',
                                                       'WIDTH': 10}},
                  'ATTRIBUTE_MAP': {'A_CALC': ('refln', 'A_calc', None, None),
                                    'A_CALC_AU': ('refln', 'A_calc_au', None, None),
                                    'A_MEAS': ('refln', 'A_meas', None, None),
                                    'A_MEAS_AU': ('refln', 'A_meas_au', None, None),
                                    'B_CALC': ('refln', 'B_calc', None, None),
                                    'B_CALC_AU': ('refln', 'B_calc_au', None, None),
                                    'B_MEAS': ('refln', 'B_meas', None, None),
                                    'B_MEAS_AU': ('refln', 'B_meas_au', None, None),
                                    'CLASS_CODE': ('refln', 'class_code', None, None),
                                    'CRYSTAL_ID': ('refln', 'crystal_id', None, None),
                                    'D_SPACING': ('refln', 'd_spacing', None, None),
                                    'FOM': ('refln', 'fom', None, None),
                                    'F_CALC': ('refln', 'F_calc', None, None),
                                    'F_CALC_AU': ('refln', 'F_calc_au', None, None),
                                    'F_MEAS': ('refln', 'F_meas', None, None),
                                    'F_MEAS_AU': ('refln', 'F_meas_au', None, None),
                                    'F_MEAS_SIGMA': ('refln', 'F_meas_sigma', None, None),
                                    'F_MEAS_SIGMA_AU': ('refln', 'F_meas_sigma_au', None, None),
                                    'F_SQUARED_CALC': ('refln', 'F_squared_calc', None, None),
                                    'F_SQUARED_MEAS': ('refln', 'F_squared_meas', None, None),
                                    'F_SQUARED_SIGMA': ('refln', 'F_squared_sigma', None, None),
                                    'INCLUDE_STATUS': ('refln', 'include_status', None, None),
                                    'INDEX_H': ('refln', 'index_h', None, None),
                                    'INDEX_K': ('refln', 'index_k', None, None),
                                    'INDEX_L': ('refln', 'index_l', None, None),
                                    'INTENSITY_CALC': ('refln', 'intensity_calc', None, None),
                                    'INTENSITY_MEAS': ('refln', 'intensity_meas', None, None),
                                    'INTENSITY_SIGMA': ('refln', 'intensity_sigma', None, None),
                                    'MEAN_PATH_LENGTH_TBAR': ('refln', 'mean_path_length_tbar', None, None),
                                    'PDBX_ANOM_DIFFERENCE': ('refln', 'pdbx_anom_difference', None, None),
                                    'PDBX_ANOM_DIFFERENCE_SIGMA': ('refln', 'pdbx_anom_difference_sigma', None, None),
                                    'PDBX_DELFWT': ('refln', 'pdbx_DELFWT', None, None),
                                    'PDBX_DELPHWT': ('refln', 'pdbx_DELPHWT', None, None),
                                    'PDBX_DIFFRN_ID': ('refln', 'pdbx_diffrn_id', None, None),
                                    'PDBX_FIBER_COORDINATE': ('refln', 'pdbx_fiber_coordinate', None, None),
                                    'PDBX_FIBER_F_MEAS_AU': ('refln', 'pdbx_fiber_F_meas_au', None, None),
                                    'PDBX_FIBER_LAYER': ('refln', 'pdbx_fiber_layer', None, None),
                                    'PDBX_FWT': ('refln', 'pdbx_FWT', None, None),
                                    'PDBX_F_CALC_PART_SOLVENT': ('refln', 'pdbx_F_calc_part_solvent', None, None),
                                    'PDBX_F_CALC_WITH_SOLVENT': ('refln', 'pdbx_F_calc_with_solvent', None, None),
                                    'PDBX_F_MINUS': ('refln', 'pdbx_F_minus', None, None),
                                    'PDBX_F_MINUS_SIGMA': ('refln', 'pdbx_F_minus_sigma', None, None),
                                    'PDBX_F_PLUS': ('refln', 'pdbx_F_plus', None, None),
                                    'PDBX_F_PLUS_SIGMA': ('refln', 'pdbx_F_plus_sigma', None, None),
                                    'PDBX_HL_A_ISO': ('refln', 'pdbx_HL_A_iso', None, None),
                                    'PDBX_HL_B_ISO': ('refln', 'pdbx_HL_B_iso', None, None),
                                    'PDBX_HL_C_ISO': ('refln', 'pdbx_HL_C_iso', None, None),
                                    'PDBX_HL_D_ISO': ('refln', 'pdbx_HL_D_iso', None, None),
                                    'PDBX_I_MINUS': ('refln', 'pdbx_I_minus', None, None),
                                    'PDBX_I_MINUS_SIGMA': ('refln', 'pdbx_I_minus_sigma', None, None),
                                    'PDBX_I_PLUS': ('refln', 'pdbx_I_plus', None, None),
                                    'PDBX_I_PLUS_SIGMA': ('refln', 'pdbx_I_plus_sigma', None, None),
                                    'PDBX_PHASE_CALC_PART_SOLVENT': ('refln', 'pdbx_phase_calc_part_solvent', None, None),
                                    'PDBX_PHASE_CALC_WITH_SOLVENT': ('refln', 'pdbx_phase_calc_with_solvent', None, None),
                                    'PDBX_PHWT': ('refln', 'pdbx_PHWT', None, None),
                                    'PHASE_CALC': ('refln', 'phase_calc', None, None),
                                    'PHASE_MEAS': ('refln', 'phase_meas', None, None),
                                    'REFINEMENT_STATUS': ('refln', 'refinement_status', None, None),
                                    'SCALE_GROUP_CODE': ('refln', 'scale_group_code', None, None),
                                    'SINT_OVER_LAMBDA': ('refln', 'sint_over_lambda', None, None),
                                    'STATUS': ('refln', 'status', None, None),
                                    'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                    'SYMMETRY_EPSILON': ('refln', 'symmetry_epsilon', None, None),
                                    'SYMMETRY_MULTIPLICITY': ('refln', 'symmetry_multiplicity', None, None),
                                    'WAVELENGTH': ('refln', 'wavelength', None, None),
                                    'WAVELENGTH_ID': ('refln', 'wavelength_id', None, None)},
                  'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'INDEX_H', 'INDEX_K', 'INDEX_L'), 'TYPE': 'UNIQUE'},
                              's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                  'MAP_MERGE_INDICES': {'refln': {'ATTRIBUTES': ('index_h', 'index_k', 'index_l'), 'TYPE': 'EQUI-JOIN'}},
                  'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                  'TABLE_ID': 'REFLN',
                  'TABLE_NAME': 'refln',
                  'TABLE_TYPE': 'transactional'},
        'REFLNS': {'ATTRIBUTES': {'B_ISO_WILSON_ESTIMATE': 'B_iso_Wilson_estimate',
                                  'DATA_REDUCTION_DETAILS': 'data_reduction_details',
                                  'DATA_REDUCTION_METHOD': 'data_reduction_method',
                                  'DETAILS': 'details',
                                  'D_RESOLUTION_HIGH': 'd_resolution_high',
                                  'D_RESOLUTION_LOW': 'd_resolution_low',
                                  'ENTRY_ID': 'entry_id',
                                  'FRIEDEL_COVERAGE': 'Friedel_coverage',
                                  'LIMIT_H_MAX': 'limit_h_max',
                                  'LIMIT_H_MIN': 'limit_h_min',
                                  'LIMIT_K_MAX': 'limit_k_max',
                                  'LIMIT_K_MIN': 'limit_k_min',
                                  'LIMIT_L_MAX': 'limit_l_max',
                                  'LIMIT_L_MIN': 'limit_l_min',
                                  'NUMBER_ALL': 'number_all',
                                  'NUMBER_GT': 'number_gt',
                                  'NUMBER_OBS': 'number_obs',
                                  'OBSERVED_CRITERION': 'observed_criterion',
                                  'OBSERVED_CRITERION_F_MAX': 'observed_criterion_F_max',
                                  'OBSERVED_CRITERION_F_MIN': 'observed_criterion_F_min',
                                  'OBSERVED_CRITERION_I_MAX': 'observed_criterion_I_max',
                                  'OBSERVED_CRITERION_I_MIN': 'observed_criterion_I_min',
                                  'OBSERVED_CRITERION_SIGMA_F': 'observed_criterion_sigma_F',
                                  'OBSERVED_CRITERION_SIGMA_I': 'observed_criterion_sigma_I',
                                  'PDBX_CHI_SQUARED': 'pdbx_chi_squared',
                                  'PDBX_DIFFRN_ID': 'pdbx_diffrn_id',
                                  'PDBX_D_OPT': 'pdbx_d_opt',
                                  'PDBX_D_RES_HIGH_OPT': 'pdbx_d_res_high_opt',
                                  'PDBX_D_RES_LOW_OPT': 'pdbx_d_res_low_opt',
                                  'PDBX_D_RES_OPT_METHOD': 'pdbx_d_res_opt_method',
                                  'PDBX_NETI_OVER_AV_SIGMAI': 'pdbx_netI_over_av_sigmaI',
                                  'PDBX_NETI_OVER_SIGMAI': 'pdbx_netI_over_sigmaI',
                                  'PDBX_NUMBER_MEASURED_ALL': 'pdbx_number_measured_all',
                                  'PDBX_ORDINAL': 'pdbx_ordinal',
                                  'PDBX_REDUNDANCY': 'pdbx_redundancy',
                                  'PDBX_RES_NETI_OVER_AV_SIGMAI_2': 'pdbx_res_netI_over_av_sigmaI_2',
                                  'PDBX_RES_NETI_OVER_SIGMAI_2': 'pdbx_res_netI_over_sigmaI_2',
                                  'PDBX_RMERGE_I_ALL': 'pdbx_Rmerge_I_all',
                                  'PDBX_RMERGE_I_OBS': 'pdbx_Rmerge_I_obs',
                                  'PDBX_RPIM_I_ALL': 'pdbx_Rpim_I_all',
                                  'PDBX_RRIM_I_ALL': 'pdbx_Rrim_I_all',
                                  'PDBX_RSYM_VALUE': 'pdbx_Rsym_value',
                                  'PDBX_SCALING_REJECTS': 'pdbx_scaling_rejects',
                                  'PERCENT_POSSIBLE_OBS': 'percent_possible_obs',
                                  'PHASE_CALCULATION_DETAILS': 'phase_calculation_details',
                                  'RMERGE_F_ALL': 'Rmerge_F_all',
                                  'RMERGE_F_OBS': 'Rmerge_F_obs',
                                  'R_FREE_DETAILS': 'R_free_details',
                                  'STRUCTURE_ID': 'Structure_ID',
                                  'THRESHOLD_EXPRESSION': 'threshold_expression'},
                   'ATTRIBUTE_INFO': {'B_ISO_WILSON_ESTIMATE': {'NULLABLE': True,
                                                                'ORDER': 3,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                      'DATA_REDUCTION_DETAILS': {'NULLABLE': True,
                                                                 'ORDER': 4,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 200},
                                      'DATA_REDUCTION_METHOD': {'NULLABLE': True,
                                                                'ORDER': 5,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 200},
                                      'DETAILS': {'NULLABLE': True,
                                                  'ORDER': 8,
                                                  'PRECISION': 0,
                                                  'PRIMARY_KEY': False,
                                                  'SQL_TYPE': 'VARCHAR',
                                                  'WIDTH': 200},
                                      'D_RESOLUTION_HIGH': {'NULLABLE': True,
                                                            'ORDER': 6,
                                                            'PRECISION': 6,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'FLOAT',
                                                            'WIDTH': 10},
                                      'D_RESOLUTION_LOW': {'NULLABLE': True,
                                                           'ORDER': 7,
                                                           'PRECISION': 6,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'FLOAT',
                                                           'WIDTH': 10},
                                      'ENTRY_ID': {'NULLABLE': True,
                                                   'ORDER': 2,
                                                   'PRECISION': 0,
                                                   'PRIMARY_KEY': False,
                                                   'SQL_TYPE': 'VARCHAR',
                                                   'WIDTH': 10},
                                      'FRIEDEL_COVERAGE': {'NULLABLE': True,
                                                           'ORDER': 28,
                                                           'PRECISION': 6,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'FLOAT',
                                                           'WIDTH': 10},
                                      'LIMIT_H_MAX': {'NULLABLE': True,
                                                      'ORDER': 9,
                                                      'PRECISION': 0,
                                                      'PRIMARY_KEY': False,
                                                      'SQL_TYPE': 'INT',
                                                      'WIDTH': 10},
                                      'LIMIT_H_MIN': {'NULLABLE': True,
                                                      'ORDER': 10,
                                                      'PRECISION': 0,
                                                      'PRIMARY_KEY': False,
                                                      'SQL_TYPE': 'INT',
                                                      'WIDTH': 10},
                                      'LIMIT_K_MAX': {'NULLABLE': True,
                                                      'ORDER': 11,
                                                      'PRECISION': 0,
                                                      'PRIMARY_KEY': False,
                                                      'SQL_TYPE': 'INT',
                                                      'WIDTH': 10},
                                      'LIMIT_K_MIN': {'NULLABLE': True,
                                                      'ORDER': 12,
                                                      'PRECISION': 0,
                                                      'PRIMARY_KEY': False,
                                                      'SQL_TYPE': 'INT',
                                                      'WIDTH': 10},
                                      'LIMIT_L_MAX': {'NULLABLE': True,
                                                      'ORDER': 13,
                                                      'PRECISION': 0,
                                                      'PRIMARY_KEY': False,
                                                      'SQL_TYPE': 'INT',
                                                      'WIDTH': 10},
                                      'LIMIT_L_MIN': {'NULLABLE': True,
                                                      'ORDER': 14,
                                                      'PRECISION': 0,
                                                      'PRIMARY_KEY': False,
                                                      'SQL_TYPE': 'INT',
                                                      'WIDTH': 10},
                                      'NUMBER_ALL': {'NULLABLE': True,
                                                     'ORDER': 15,
                                                     'PRECISION': 0,
                                                     'PRIMARY_KEY': False,
                                                     'SQL_TYPE': 'INT',
                                                     'WIDTH': 10},
                                      'NUMBER_GT': {'NULLABLE': True,
                                                    'ORDER': 29,
                                                    'PRECISION': 0,
                                                    'PRIMARY_KEY': False,
                                                    'SQL_TYPE': 'INT',
                                                    'WIDTH': 10},
                                      'NUMBER_OBS': {'NULLABLE': True,
                                                     'ORDER': 16,
                                                     'PRECISION': 0,
                                                     'PRIMARY_KEY': False,
                                                     'SQL_TYPE': 'INT',
                                                     'WIDTH': 10},
                                      'OBSERVED_CRITERION': {'NULLABLE': True,
                                                             'ORDER': 17,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 200},
                                      'OBSERVED_CRITERION_F_MAX': {'NULLABLE': True,
                                                                   'ORDER': 18,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                      'OBSERVED_CRITERION_F_MIN': {'NULLABLE': True,
                                                                   'ORDER': 19,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                      'OBSERVED_CRITERION_I_MAX': {'NULLABLE': True,
                                                                   'ORDER': 20,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                      'OBSERVED_CRITERION_I_MIN': {'NULLABLE': True,
                                                                   'ORDER': 21,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                      'OBSERVED_CRITERION_SIGMA_F': {'NULLABLE': True,
                                                                     'ORDER': 22,
                                                                     'PRECISION': 6,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'FLOAT',
                                                                     'WIDTH': 10},
                                      'OBSERVED_CRITERION_SIGMA_I': {'NULLABLE': True,
                                                                     'ORDER': 23,
                                                                     'PRECISION': 6,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'FLOAT',
                                                                     'WIDTH': 10},
                                      'PDBX_CHI_SQUARED': {'NULLABLE': True,
                                                           'ORDER': 39,
                                                           'PRECISION': 6,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'FLOAT',
                                                           'WIDTH': 10},
                                      'PDBX_DIFFRN_ID': {'NULLABLE': True,
                                                         'ORDER': 49,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 10},
                                      'PDBX_D_OPT': {'NULLABLE': True,
                                                     'ORDER': 47,
                                                     'PRECISION': 6,
                                                     'PRIMARY_KEY': False,
                                                     'SQL_TYPE': 'FLOAT',
                                                     'WIDTH': 10},
                                      'PDBX_D_RES_HIGH_OPT': {'NULLABLE': True,
                                                              'ORDER': 41,
                                                              'PRECISION': 6,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'FLOAT',
                                                              'WIDTH': 10},
                                      'PDBX_D_RES_LOW_OPT': {'NULLABLE': True,
                                                             'ORDER': 42,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                      'PDBX_D_RES_OPT_METHOD': {'NULLABLE': True,
                                                                'ORDER': 43,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 200},
                                      'PDBX_NETI_OVER_AV_SIGMAI': {'NULLABLE': True,
                                                                   'ORDER': 35,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                      'PDBX_NETI_OVER_SIGMAI': {'NULLABLE': True,
                                                                'ORDER': 36,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                      'PDBX_NUMBER_MEASURED_ALL': {'NULLABLE': True,
                                                                   'ORDER': 48,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'INT',
                                                                   'WIDTH': 10},
                                      'PDBX_ORDINAL': {'NULLABLE': False,
                                                       'ORDER': 50,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': True,
                                                       'SQL_TYPE': 'INT',
                                                       'WIDTH': 10},
                                      'PDBX_REDUNDANCY': {'NULLABLE': True,
                                                          'ORDER': 31,
                                                          'PRECISION': 6,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'FLOAT',
                                                          'WIDTH': 10},
                                      'PDBX_RES_NETI_OVER_AV_SIGMAI_2': {'NULLABLE': True,
                                                                         'ORDER': 37,
                                                                         'PRECISION': 6,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'FLOAT',
                                                                         'WIDTH': 10},
                                      'PDBX_RES_NETI_OVER_SIGMAI_2': {'NULLABLE': True,
                                                                      'ORDER': 38,
                                                                      'PRECISION': 6,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'FLOAT',
                                                                      'WIDTH': 10},
                                      'PDBX_RMERGE_I_ALL': {'NULLABLE': True,
                                                            'ORDER': 33,
                                                            'PRECISION': 6,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'FLOAT',
                                                            'WIDTH': 10},
                                      'PDBX_RMERGE_I_OBS': {'NULLABLE': True,
                                                            'ORDER': 32,
                                                            'PRECISION': 6,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'FLOAT',
                                                            'WIDTH': 10},
                                      'PDBX_RPIM_I_ALL': {'NULLABLE': True,
                                                          'ORDER': 46,
                                                          'PRECISION': 6,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'FLOAT',
                                                          'WIDTH': 10},
                                      'PDBX_RRIM_I_ALL': {'NULLABLE': True,
                                                          'ORDER': 45,
                                                          'PRECISION': 6,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'FLOAT',
                                                          'WIDTH': 10},
                                      'PDBX_RSYM_VALUE': {'NULLABLE': True,
                                                          'ORDER': 34,
                                                          'PRECISION': 6,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'FLOAT',
                                                          'WIDTH': 10},
                                      'PDBX_SCALING_REJECTS': {'NULLABLE': True,
                                                               'ORDER': 40,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'INT',
                                                               'WIDTH': 10},
                                      'PERCENT_POSSIBLE_OBS': {'NULLABLE': True,
                                                               'ORDER': 24,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                      'PHASE_CALCULATION_DETAILS': {'NULLABLE': True,
                                                                    'ORDER': 44,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 200},
                                      'RMERGE_F_ALL': {'NULLABLE': True,
                                                       'ORDER': 26,
                                                       'PRECISION': 6,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'FLOAT',
                                                       'WIDTH': 10},
                                      'RMERGE_F_OBS': {'NULLABLE': True,
                                                       'ORDER': 27,
                                                       'PRECISION': 6,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'FLOAT',
                                                       'WIDTH': 10},
                                      'R_FREE_DETAILS': {'NULLABLE': True,
                                                         'ORDER': 25,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 200},
                                      'STRUCTURE_ID': {'NULLABLE': False,
                                                       'ORDER': 1,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': True,
                                                       'SQL_TYPE': 'VARCHAR',
                                                       'WIDTH': 10},
                                      'THRESHOLD_EXPRESSION': {'NULLABLE': True,
                                                               'ORDER': 30,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 200}},
                   'ATTRIBUTE_MAP': {'B_ISO_WILSON_ESTIMATE': ('reflns', 'B_iso_Wilson_estimate', None, None),
                                     'DATA_REDUCTION_DETAILS': ('reflns', 'data_reduction_details', None, None),
                                     'DATA_REDUCTION_METHOD': ('reflns', 'data_reduction_method', None, None),
                                     'DETAILS': ('reflns', 'details', None, None),
                                     'D_RESOLUTION_HIGH': ('reflns', 'd_resolution_high', None, None),
                                     'D_RESOLUTION_LOW': ('reflns', 'd_resolution_low', None, None),
                                     'ENTRY_ID': ('reflns', 'entry_id', None, None),
                                     'FRIEDEL_COVERAGE': ('reflns', 'Friedel_coverage', None, None),
                                     'LIMIT_H_MAX': ('reflns', 'limit_h_max', None, None),
                                     'LIMIT_H_MIN': ('reflns', 'limit_h_min', None, None),
                                     'LIMIT_K_MAX': ('reflns', 'limit_k_max', None, None),
                                     'LIMIT_K_MIN': ('reflns', 'limit_k_min', None, None),
                                     'LIMIT_L_MAX': ('reflns', 'limit_l_max', None, None),
                                     'LIMIT_L_MIN': ('reflns', 'limit_l_min', None, None),
                                     'NUMBER_ALL': ('reflns', 'number_all', None, None),
                                     'NUMBER_GT': ('reflns', 'number_gt', None, None),
                                     'NUMBER_OBS': ('reflns', 'number_obs', None, None),
                                     'OBSERVED_CRITERION': ('reflns', 'observed_criterion', None, None),
                                     'OBSERVED_CRITERION_F_MAX': ('reflns', 'observed_criterion_F_max', None, None),
                                     'OBSERVED_CRITERION_F_MIN': ('reflns', 'observed_criterion_F_min', None, None),
                                     'OBSERVED_CRITERION_I_MAX': ('reflns', 'observed_criterion_I_max', None, None),
                                     'OBSERVED_CRITERION_I_MIN': ('reflns', 'observed_criterion_I_min', None, None),
                                     'OBSERVED_CRITERION_SIGMA_F': ('reflns', 'observed_criterion_sigma_F', None, None),
                                     'OBSERVED_CRITERION_SIGMA_I': ('reflns', 'observed_criterion_sigma_I', None, None),
                                     'PDBX_CHI_SQUARED': ('reflns', 'pdbx_chi_squared', None, None),
                                     'PDBX_DIFFRN_ID': ('reflns', 'pdbx_diffrn_id', None, None),
                                     'PDBX_D_OPT': ('reflns', 'pdbx_d_opt', None, None),
                                     'PDBX_D_RES_HIGH_OPT': ('reflns', 'pdbx_d_res_high_opt', None, None),
                                     'PDBX_D_RES_LOW_OPT': ('reflns', 'pdbx_d_res_low_opt', None, None),
                                     'PDBX_D_RES_OPT_METHOD': ('reflns', 'pdbx_d_res_opt_method', None, None),
                                     'PDBX_NETI_OVER_AV_SIGMAI': ('reflns', 'pdbx_netI_over_av_sigmaI', None, None),
                                     'PDBX_NETI_OVER_SIGMAI': ('reflns', 'pdbx_netI_over_sigmaI', None, None),
                                     'PDBX_NUMBER_MEASURED_ALL': ('reflns', 'pdbx_number_measured_all', None, None),
                                     'PDBX_ORDINAL': ('reflns', 'pdbx_ordinal', None, None),
                                     'PDBX_REDUNDANCY': ('reflns', 'pdbx_redundancy', None, None),
                                     'PDBX_RES_NETI_OVER_AV_SIGMAI_2': ('reflns',
                                                                        'pdbx_res_netI_over_av_sigmaI_2',
                                                                        None,
                                                                        None),
                                     'PDBX_RES_NETI_OVER_SIGMAI_2': ('reflns', 'pdbx_res_netI_over_sigmaI_2', None, None),
                                     'PDBX_RMERGE_I_ALL': ('reflns', 'pdbx_Rmerge_I_all', None, None),
                                     'PDBX_RMERGE_I_OBS': ('reflns', 'pdbx_Rmerge_I_obs', None, None),
                                     'PDBX_RPIM_I_ALL': ('reflns', 'pdbx_Rpim_I_all', None, None),
                                     'PDBX_RRIM_I_ALL': ('reflns', 'pdbx_Rrim_I_all', None, None),
                                     'PDBX_RSYM_VALUE': ('reflns', 'pdbx_Rsym_value', None, None),
                                     'PDBX_SCALING_REJECTS': ('reflns', 'pdbx_scaling_rejects', None, None),
                                     'PERCENT_POSSIBLE_OBS': ('reflns', 'percent_possible_obs', None, None),
                                     'PHASE_CALCULATION_DETAILS': ('reflns', 'phase_calculation_details', None, None),
                                     'RMERGE_F_ALL': ('reflns', 'Rmerge_F_all', None, None),
                                     'RMERGE_F_OBS': ('reflns', 'Rmerge_F_obs', None, None),
                                     'R_FREE_DETAILS': ('reflns', 'R_free_details', None, None),
                                     'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                     'THRESHOLD_EXPRESSION': ('reflns', 'threshold_expression', None, None)},
                   'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'PDBX_ORDINAL'), 'TYPE': 'UNIQUE'},
                               's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                   'MAP_MERGE_INDICES': {'reflns': {'ATTRIBUTES': ('pdbx_ordinal',), 'TYPE': 'EQUI-JOIN'}},
                   'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                   'TABLE_ID': 'REFLNS',
                   'TABLE_NAME': 'reflns',
                   'TABLE_TYPE': 'transactional'},
        'REFLNS_CLASS': {'ATTRIBUTES': {'CODE': 'code',
                                        'DESCRIPTION': 'description',
                                        'D_RES_HIGH': 'd_res_high',
                                        'D_RES_LOW': 'd_res_low',
                                        'NUMBER_GT': 'number_gt',
                                        'NUMBER_TOTAL': 'number_total',
                                        'R_FACTOR_ALL': 'R_factor_all',
                                        'R_FACTOR_GT': 'R_factor_gt',
                                        'R_FSQD_FACTOR': 'R_Fsqd_factor',
                                        'R_I_FACTOR': 'R_I_factor',
                                        'STRUCTURE_ID': 'Structure_ID',
                                        'WR_FACTOR_ALL': 'wR_factor_all'},
                         'ATTRIBUTE_INFO': {'CODE': {'NULLABLE': False,
                                                     'ORDER': 2,
                                                     'PRECISION': 0,
                                                     'PRIMARY_KEY': True,
                                                     'SQL_TYPE': 'VARCHAR',
                                                     'WIDTH': 10},
                                            'DESCRIPTION': {'NULLABLE': True,
                                                            'ORDER': 3,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 200},
                                            'D_RES_HIGH': {'NULLABLE': True,
                                                           'ORDER': 4,
                                                           'PRECISION': 6,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'FLOAT',
                                                           'WIDTH': 10},
                                            'D_RES_LOW': {'NULLABLE': True,
                                                          'ORDER': 5,
                                                          'PRECISION': 6,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'FLOAT',
                                                          'WIDTH': 10},
                                            'NUMBER_GT': {'NULLABLE': True,
                                                          'ORDER': 6,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'INT',
                                                          'WIDTH': 10},
                                            'NUMBER_TOTAL': {'NULLABLE': True,
                                                             'ORDER': 7,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'INT',
                                                             'WIDTH': 10},
                                            'R_FACTOR_ALL': {'NULLABLE': True,
                                                             'ORDER': 8,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                            'R_FACTOR_GT': {'NULLABLE': True,
                                                            'ORDER': 9,
                                                            'PRECISION': 6,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'FLOAT',
                                                            'WIDTH': 10},
                                            'R_FSQD_FACTOR': {'NULLABLE': True,
                                                              'ORDER': 10,
                                                              'PRECISION': 6,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'FLOAT',
                                                              'WIDTH': 10},
                                            'R_I_FACTOR': {'NULLABLE': True,
                                                           'ORDER': 11,
                                                           'PRECISION': 6,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'FLOAT',
                                                           'WIDTH': 10},
                                            'STRUCTURE_ID': {'NULLABLE': False,
                                                             'ORDER': 1,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 10},
                                            'WR_FACTOR_ALL': {'NULLABLE': True,
                                                              'ORDER': 12,
                                                              'PRECISION': 6,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'FLOAT',
                                                              'WIDTH': 10}},
                         'ATTRIBUTE_MAP': {'CODE': ('reflns_class', 'code', None, None),
                                           'DESCRIPTION': ('reflns_class', 'description', None, None),
                                           'D_RES_HIGH': ('reflns_class', 'd_res_high', None, None),
                                           'D_RES_LOW': ('reflns_class', 'd_res_low', None, None),
                                           'NUMBER_GT': ('reflns_class', 'number_gt', None, None),
                                           'NUMBER_TOTAL': ('reflns_class', 'number_total', None, None),
                                           'R_FACTOR_ALL': ('reflns_class', 'R_factor_all', None, None),
                                           'R_FACTOR_GT': ('reflns_class', 'R_factor_gt', None, None),
                                           'R_FSQD_FACTOR': ('reflns_class', 'R_Fsqd_factor', None, None),
                                           'R_I_FACTOR': ('reflns_class', 'R_I_factor', None, None),
                                           'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                           'WR_FACTOR_ALL': ('reflns_class', 'wR_factor_all', None, None)},
                         'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'CODE'), 'TYPE': 'UNIQUE'},
                                     's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                         'MAP_MERGE_INDICES': {'reflns_class': {'ATTRIBUTES': ('code',), 'TYPE': 'EQUI-JOIN'}},
                         'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                         'TABLE_ID': 'REFLNS_CLASS',
                         'TABLE_NAME': 'reflns_class',
                         'TABLE_TYPE': 'transactional'},
        'REFLNS_SCALE': {'ATTRIBUTES': {'GROUP_CODE': 'group_code',
                                        'MEAS_F': 'meas_F',
                                        'MEAS_F_SQUARED': 'meas_F_squared',
                                        'MEAS_INTENSITY': 'meas_intensity',
                                        'STRUCTURE_ID': 'Structure_ID'},
                         'ATTRIBUTE_INFO': {'GROUP_CODE': {'NULLABLE': False,
                                                           'ORDER': 2,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': True,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 80},
                                            'MEAS_F': {'NULLABLE': True,
                                                       'ORDER': 3,
                                                       'PRECISION': 6,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'FLOAT',
                                                       'WIDTH': 10},
                                            'MEAS_F_SQUARED': {'NULLABLE': True,
                                                               'ORDER': 4,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                            'MEAS_INTENSITY': {'NULLABLE': True,
                                                               'ORDER': 5,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                            'STRUCTURE_ID': {'NULLABLE': False,
                                                             'ORDER': 1,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 10}},
                         'ATTRIBUTE_MAP': {'GROUP_CODE': ('reflns_scale', 'group_code', None, None),
                                           'MEAS_F': ('reflns_scale', 'meas_F', None, None),
                                           'MEAS_F_SQUARED': ('reflns_scale', 'meas_F_squared', None, None),
                                           'MEAS_INTENSITY': ('reflns_scale', 'meas_intensity', None, None),
                                           'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                         'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'GROUP_CODE'), 'TYPE': 'UNIQUE'},
                                     's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                         'MAP_MERGE_INDICES': {'reflns_scale': {'ATTRIBUTES': ('group_code',), 'TYPE': 'EQUI-JOIN'}},
                         'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                         'TABLE_ID': 'REFLNS_SCALE',
                         'TABLE_NAME': 'reflns_scale',
                         'TABLE_TYPE': 'transactional'},
        'REFLNS_SHELL': {'ATTRIBUTES': {'D_RES_HIGH': 'd_res_high',
                                        'D_RES_LOW': 'd_res_low',
                                        'MEANI_OVER_SIGI_ALL': 'meanI_over_sigI_all',
                                        'MEANI_OVER_SIGI_GT': 'meanI_over_sigI_gt',
                                        'MEANI_OVER_SIGI_OBS': 'meanI_over_sigI_obs',
                                        'MEANI_OVER_UI_ALL': 'meanI_over_uI_all',
                                        'MEANI_OVER_UI_GT': 'meanI_over_uI_gt',
                                        'NUMBER_MEASURED_ALL': 'number_measured_all',
                                        'NUMBER_MEASURED_GT': 'number_measured_gt',
                                        'NUMBER_MEASURED_OBS': 'number_measured_obs',
                                        'NUMBER_POSSIBLE': 'number_possible',
                                        'NUMBER_UNIQUE_ALL': 'number_unique_all',
                                        'NUMBER_UNIQUE_GT': 'number_unique_gt',
                                        'NUMBER_UNIQUE_OBS': 'number_unique_obs',
                                        'PDBX_CHI_SQUARED': 'pdbx_chi_squared',
                                        'PDBX_DIFFRN_ID': 'pdbx_diffrn_id',
                                        'PDBX_NETI_OVER_SIGMAI_ALL': 'pdbx_netI_over_sigmaI_all',
                                        'PDBX_NETI_OVER_SIGMAI_OBS': 'pdbx_netI_over_sigmaI_obs',
                                        'PDBX_ORDINAL': 'pdbx_ordinal',
                                        'PDBX_REDUNDANCY': 'pdbx_redundancy',
                                        'PDBX_REJECTS': 'pdbx_rejects',
                                        'PDBX_RPIM_I_ALL': 'pdbx_Rpim_I_all',
                                        'PDBX_RRIM_I_ALL': 'pdbx_Rrim_I_all',
                                        'PDBX_RSYM_VALUE': 'pdbx_Rsym_value',
                                        'PERCENT_POSSIBLE_ALL': 'percent_possible_all',
                                        'PERCENT_POSSIBLE_GT': 'percent_possible_gt',
                                        'PERCENT_POSSIBLE_OBS': 'percent_possible_obs',
                                        'RMERGE_F_ALL': 'Rmerge_F_all',
                                        'RMERGE_F_GT': 'Rmerge_F_gt',
                                        'RMERGE_F_OBS': 'Rmerge_F_obs',
                                        'RMERGE_I_ALL': 'Rmerge_I_all',
                                        'RMERGE_I_GT': 'Rmerge_I_gt',
                                        'RMERGE_I_OBS': 'Rmerge_I_obs',
                                        'STRUCTURE_ID': 'Structure_ID'},
                         'ATTRIBUTE_INFO': {'D_RES_HIGH': {'NULLABLE': True,
                                                           'ORDER': 2,
                                                           'PRECISION': 6,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'FLOAT',
                                                           'WIDTH': 10},
                                            'D_RES_LOW': {'NULLABLE': True,
                                                          'ORDER': 3,
                                                          'PRECISION': 6,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'FLOAT',
                                                          'WIDTH': 10},
                                            'MEANI_OVER_SIGI_ALL': {'NULLABLE': True,
                                                                    'ORDER': 4,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                            'MEANI_OVER_SIGI_GT': {'NULLABLE': True,
                                                                   'ORDER': 17,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                            'MEANI_OVER_SIGI_OBS': {'NULLABLE': True,
                                                                    'ORDER': 5,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                            'MEANI_OVER_UI_ALL': {'NULLABLE': True,
                                                                  'ORDER': 18,
                                                                  'PRECISION': 6,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'FLOAT',
                                                                  'WIDTH': 10},
                                            'MEANI_OVER_UI_GT': {'NULLABLE': True,
                                                                 'ORDER': 19,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                            'NUMBER_MEASURED_ALL': {'NULLABLE': True,
                                                                    'ORDER': 6,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'INT',
                                                                    'WIDTH': 10},
                                            'NUMBER_MEASURED_GT': {'NULLABLE': True,
                                                                   'ORDER': 20,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'INT',
                                                                   'WIDTH': 10},
                                            'NUMBER_MEASURED_OBS': {'NULLABLE': True,
                                                                    'ORDER': 7,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'INT',
                                                                    'WIDTH': 10},
                                            'NUMBER_POSSIBLE': {'NULLABLE': True,
                                                                'ORDER': 8,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'INT',
                                                                'WIDTH': 10},
                                            'NUMBER_UNIQUE_ALL': {'NULLABLE': True,
                                                                  'ORDER': 9,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'INT',
                                                                  'WIDTH': 10},
                                            'NUMBER_UNIQUE_GT': {'NULLABLE': True,
                                                                 'ORDER': 21,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'INT',
                                                                 'WIDTH': 10},
                                            'NUMBER_UNIQUE_OBS': {'NULLABLE': True,
                                                                  'ORDER': 10,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'INT',
                                                                  'WIDTH': 10},
                                            'PDBX_CHI_SQUARED': {'NULLABLE': True,
                                                                 'ORDER': 27,
                                                                 'PRECISION': 6,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'FLOAT',
                                                                 'WIDTH': 10},
                                            'PDBX_DIFFRN_ID': {'NULLABLE': True,
                                                               'ORDER': 34,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                            'PDBX_NETI_OVER_SIGMAI_ALL': {'NULLABLE': True,
                                                                          'ORDER': 28,
                                                                          'PRECISION': 6,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'FLOAT',
                                                                          'WIDTH': 10},
                                            'PDBX_NETI_OVER_SIGMAI_OBS': {'NULLABLE': True,
                                                                          'ORDER': 29,
                                                                          'PRECISION': 6,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'FLOAT',
                                                                          'WIDTH': 10},
                                            'PDBX_ORDINAL': {'NULLABLE': False,
                                                             'ORDER': 33,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'INT',
                                                             'WIDTH': 10},
                                            'PDBX_REDUNDANCY': {'NULLABLE': True,
                                                                'ORDER': 25,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                            'PDBX_REJECTS': {'NULLABLE': True,
                                                             'ORDER': 32,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'INT',
                                                             'WIDTH': 10},
                                            'PDBX_RPIM_I_ALL': {'NULLABLE': True,
                                                                'ORDER': 31,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                            'PDBX_RRIM_I_ALL': {'NULLABLE': True,
                                                                'ORDER': 30,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                            'PDBX_RSYM_VALUE': {'NULLABLE': True,
                                                                'ORDER': 26,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                            'PERCENT_POSSIBLE_ALL': {'NULLABLE': True,
                                                                     'ORDER': 11,
                                                                     'PRECISION': 6,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'FLOAT',
                                                                     'WIDTH': 10},
                                            'PERCENT_POSSIBLE_GT': {'NULLABLE': True,
                                                                    'ORDER': 22,
                                                                    'PRECISION': 6,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'FLOAT',
                                                                    'WIDTH': 10},
                                            'PERCENT_POSSIBLE_OBS': {'NULLABLE': True,
                                                                     'ORDER': 12,
                                                                     'PRECISION': 6,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'FLOAT',
                                                                     'WIDTH': 10},
                                            'RMERGE_F_ALL': {'NULLABLE': True,
                                                             'ORDER': 13,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                            'RMERGE_F_GT': {'NULLABLE': True,
                                                            'ORDER': 23,
                                                            'PRECISION': 6,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'FLOAT',
                                                            'WIDTH': 10},
                                            'RMERGE_F_OBS': {'NULLABLE': True,
                                                             'ORDER': 14,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                            'RMERGE_I_ALL': {'NULLABLE': True,
                                                             'ORDER': 15,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                            'RMERGE_I_GT': {'NULLABLE': True,
                                                            'ORDER': 24,
                                                            'PRECISION': 6,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'FLOAT',
                                                            'WIDTH': 10},
                                            'RMERGE_I_OBS': {'NULLABLE': True,
                                                             'ORDER': 16,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                            'STRUCTURE_ID': {'NULLABLE': False,
                                                             'ORDER': 1,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 10}},
                         'ATTRIBUTE_MAP': {'D_RES_HIGH': ('reflns_shell', 'd_res_high', None, None),
                                           'D_RES_LOW': ('reflns_shell', 'd_res_low', None, None),
                                           'MEANI_OVER_SIGI_ALL': ('reflns_shell', 'meanI_over_sigI_all', None, None),
                                           'MEANI_OVER_SIGI_GT': ('reflns_shell', 'meanI_over_sigI_gt', None, None),
                                           'MEANI_OVER_SIGI_OBS': ('reflns_shell', 'meanI_over_sigI_obs', None, None),
                                           'MEANI_OVER_UI_ALL': ('reflns_shell', 'meanI_over_uI_all', None, None),
                                           'MEANI_OVER_UI_GT': ('reflns_shell', 'meanI_over_uI_gt', None, None),
                                           'NUMBER_MEASURED_ALL': ('reflns_shell', 'number_measured_all', None, None),
                                           'NUMBER_MEASURED_GT': ('reflns_shell', 'number_measured_gt', None, None),
                                           'NUMBER_MEASURED_OBS': ('reflns_shell', 'number_measured_obs', None, None),
                                           'NUMBER_POSSIBLE': ('reflns_shell', 'number_possible', None, None),
                                           'NUMBER_UNIQUE_ALL': ('reflns_shell', 'number_unique_all', None, None),
                                           'NUMBER_UNIQUE_GT': ('reflns_shell', 'number_unique_gt', None, None),
                                           'NUMBER_UNIQUE_OBS': ('reflns_shell', 'number_unique_obs', None, None),
                                           'PDBX_CHI_SQUARED': ('reflns_shell', 'pdbx_chi_squared', None, None),
                                           'PDBX_DIFFRN_ID': ('reflns_shell', 'pdbx_diffrn_id', None, None),
                                           'PDBX_NETI_OVER_SIGMAI_ALL': ('reflns_shell',
                                                                         'pdbx_netI_over_sigmaI_all',
                                                                         None,
                                                                         None),
                                           'PDBX_NETI_OVER_SIGMAI_OBS': ('reflns_shell',
                                                                         'pdbx_netI_over_sigmaI_obs',
                                                                         None,
                                                                         None),
                                           'PDBX_ORDINAL': ('reflns_shell', 'pdbx_ordinal', None, None),
                                           'PDBX_REDUNDANCY': ('reflns_shell', 'pdbx_redundancy', None, None),
                                           'PDBX_REJECTS': ('reflns_shell', 'pdbx_rejects', None, None),
                                           'PDBX_RPIM_I_ALL': ('reflns_shell', 'pdbx_Rpim_I_all', None, None),
                                           'PDBX_RRIM_I_ALL': ('reflns_shell', 'pdbx_Rrim_I_all', None, None),
                                           'PDBX_RSYM_VALUE': ('reflns_shell', 'pdbx_Rsym_value', None, None),
                                           'PERCENT_POSSIBLE_ALL': ('reflns_shell', 'percent_possible_all', None, None),
                                           'PERCENT_POSSIBLE_GT': ('reflns_shell', 'percent_possible_gt', None, None),
                                           'PERCENT_POSSIBLE_OBS': ('reflns_shell', 'percent_possible_obs', None, None),
                                           'RMERGE_F_ALL': ('reflns_shell', 'Rmerge_F_all', None, None),
                                           'RMERGE_F_GT': ('reflns_shell', 'Rmerge_F_gt', None, None),
                                           'RMERGE_F_OBS': ('reflns_shell', 'Rmerge_F_obs', None, None),
                                           'RMERGE_I_ALL': ('reflns_shell', 'Rmerge_I_all', None, None),
                                           'RMERGE_I_GT': ('reflns_shell', 'Rmerge_I_gt', None, None),
                                           'RMERGE_I_OBS': ('reflns_shell', 'Rmerge_I_obs', None, None),
                                           'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                         'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'PDBX_ORDINAL'), 'TYPE': 'UNIQUE'},
                                     's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                         'MAP_MERGE_INDICES': {'reflns_shell': {'ATTRIBUTES': ('pdbx_ordinal',), 'TYPE': 'EQUI-JOIN'}},
                         'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                         'TABLE_ID': 'REFLNS_SHELL',
                         'TABLE_NAME': 'reflns_shell',
                         'TABLE_TYPE': 'transactional'},
        'REFLN_SYS_ABS': {'ATTRIBUTES': {'I': 'I',
                                         'INDEX_H': 'index_h',
                                         'INDEX_K': 'index_k',
                                         'INDEX_L': 'index_l',
                                         'I_OVER_SIGMAI': 'I_over_sigmaI',
                                         'SIGMAI': 'sigmaI',
                                         'STRUCTURE_ID': 'Structure_ID'},
                          'ATTRIBUTE_INFO': {'I': {'NULLABLE': True,
                                                   'ORDER': 2,
                                                   'PRECISION': 6,
                                                   'PRIMARY_KEY': False,
                                                   'SQL_TYPE': 'FLOAT',
                                                   'WIDTH': 10},
                                             'INDEX_H': {'NULLABLE': False,
                                                         'ORDER': 4,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': True,
                                                         'SQL_TYPE': 'INT',
                                                         'WIDTH': 10},
                                             'INDEX_K': {'NULLABLE': False,
                                                         'ORDER': 5,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': True,
                                                         'SQL_TYPE': 'INT',
                                                         'WIDTH': 10},
                                             'INDEX_L': {'NULLABLE': False,
                                                         'ORDER': 6,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': True,
                                                         'SQL_TYPE': 'INT',
                                                         'WIDTH': 10},
                                             'I_OVER_SIGMAI': {'NULLABLE': True,
                                                               'ORDER': 3,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                             'SIGMAI': {'NULLABLE': True,
                                                        'ORDER': 7,
                                                        'PRECISION': 6,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'FLOAT',
                                                        'WIDTH': 10},
                                             'STRUCTURE_ID': {'NULLABLE': False,
                                                              'ORDER': 1,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10}},
                          'ATTRIBUTE_MAP': {'I': ('refln_sys_abs', 'I', None, None),
                                            'INDEX_H': ('refln_sys_abs', 'index_h', None, None),
                                            'INDEX_K': ('refln_sys_abs', 'index_k', None, None),
                                            'INDEX_L': ('refln_sys_abs', 'index_l', None, None),
                                            'I_OVER_SIGMAI': ('refln_sys_abs', 'I_over_sigmaI', None, None),
                                            'SIGMAI': ('refln_sys_abs', 'sigmaI', None, None),
                                            'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                          'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'INDEX_H', 'INDEX_K', 'INDEX_L'),
                                             'TYPE': 'UNIQUE'},
                                      's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                          'MAP_MERGE_INDICES': {'refln_sys_abs': {'ATTRIBUTES': ('index_h', 'index_k', 'index_l'),
                                                                  'TYPE': 'EQUI-JOIN'}},
                          'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                          'TABLE_ID': 'REFLN_SYS_ABS',
                          'TABLE_NAME': 'refln_sys_abs',
                          'TABLE_TYPE': 'transactional'},
        'SOFTWARE': {'ATTRIBUTES': {'CITATION_ID': 'citation_id',
                                    'CLASSIFICATION': 'classification',
                                    'COMPILER_NAME': 'compiler_name',
                                    'COMPILER_VERSION': 'compiler_version',
                                    'CONTACT_AUTHOR': 'contact_author',
                                    'CONTACT_AUTHOR_EMAIL': 'contact_author_email',
                                    'DATE': 'date',
                                    'DEPENDENCIES': 'dependencies',
                                    'DESCRIPTION': 'description',
                                    'HARDWARE': 'hardware',
                                    'LANGUAGE': 'language',
                                    'LOCATION': 'location',
                                    'MODS': 'mods',
                                    'NAME': 'name',
                                    'OS': 'os',
                                    'OS_VERSION': 'os_version',
                                    'PDBX_ORDINAL': 'pdbx_ordinal',
                                    'STRUCTURE_ID': 'Structure_ID',
                                    'TYPE': 'type',
                                    'VERSION': 'version'},
                     'ATTRIBUTE_INFO': {'CITATION_ID': {'NULLABLE': True,
                                                        'ORDER': 2,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 10},
                                        'CLASSIFICATION': {'NULLABLE': True,
                                                           'ORDER': 3,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 80},
                                        'COMPILER_NAME': {'NULLABLE': True,
                                                          'ORDER': 4,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 80},
                                        'COMPILER_VERSION': {'NULLABLE': True,
                                                             'ORDER': 5,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 80},
                                        'CONTACT_AUTHOR': {'NULLABLE': True,
                                                           'ORDER': 6,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 255},
                                        'CONTACT_AUTHOR_EMAIL': {'NULLABLE': True,
                                                                 'ORDER': 7,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 80},
                                        'DATE': {'NULLABLE': True,
                                                 'ORDER': 8,
                                                 'PRECISION': 0,
                                                 'PRIMARY_KEY': False,
                                                 'SQL_TYPE': 'VARCHAR',
                                                 'WIDTH': 80},
                                        'DEPENDENCIES': {'NULLABLE': True,
                                                         'ORDER': 10,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 80},
                                        'DESCRIPTION': {'NULLABLE': True,
                                                        'ORDER': 9,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 80},
                                        'HARDWARE': {'NULLABLE': True,
                                                     'ORDER': 11,
                                                     'PRECISION': 0,
                                                     'PRIMARY_KEY': False,
                                                     'SQL_TYPE': 'VARCHAR',
                                                     'WIDTH': 80},
                                        'LANGUAGE': {'NULLABLE': True,
                                                     'ORDER': 12,
                                                     'PRECISION': 0,
                                                     'PRIMARY_KEY': False,
                                                     'SQL_TYPE': 'VARCHAR',
                                                     'WIDTH': 80},
                                        'LOCATION': {'NULLABLE': True,
                                                     'ORDER': 13,
                                                     'PRECISION': 0,
                                                     'PRIMARY_KEY': False,
                                                     'SQL_TYPE': 'VARCHAR',
                                                     'WIDTH': 255},
                                        'MODS': {'NULLABLE': True,
                                                 'ORDER': 14,
                                                 'PRECISION': 0,
                                                 'PRIMARY_KEY': False,
                                                 'SQL_TYPE': 'VARCHAR',
                                                 'WIDTH': 80},
                                        'NAME': {'NULLABLE': True,
                                                 'ORDER': 15,
                                                 'PRECISION': 0,
                                                 'PRIMARY_KEY': False,
                                                 'SQL_TYPE': 'VARCHAR',
                                                 'WIDTH': 200},
                                        'OS': {'NULLABLE': True,
                                               'ORDER': 16,
                                               'PRECISION': 0,
                                               'PRIMARY_KEY': False,
                                               'SQL_TYPE': 'VARCHAR',
                                               'WIDTH': 200},
                                        'OS_VERSION': {'NULLABLE': True,
                                                       'ORDER': 17,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'VARCHAR',
                                                       'WIDTH': 200},
                                        'PDBX_ORDINAL': {'NULLABLE': False,
                                                         'ORDER': 20,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': True,
                                                         'SQL_TYPE': 'INT',
                                                         'WIDTH': 10},
                                        'STRUCTURE_ID': {'NULLABLE': False,
                                                         'ORDER': 1,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': True,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 10},
                                        'TYPE': {'NULLABLE': True,
                                                 'ORDER': 18,
                                                 'PRECISION': 0,
                                                 'PRIMARY_KEY': False,
                                                 'SQL_TYPE': 'VARCHAR',
                                                 'WIDTH': 80},
                                        'VERSION': {'NULLABLE': True,
                                                    'ORDER': 19,
                                                    'PRECISION': 0,
                                                    'PRIMARY_KEY': False,
                                                    'SQL_TYPE': 'VARCHAR',
                                                    'WIDTH': 128}},
                     'ATTRIBUTE_MAP': {'CITATION_ID': ('software', 'citation_id', None, None),
                                       'CLASSIFICATION': ('software', 'classification', None, None),
                                       'COMPILER_NAME': ('software', 'compiler_name', None, None),
                                       'COMPILER_VERSION': ('software', 'compiler_version', None, None),
                                       'CONTACT_AUTHOR': ('software', 'contact_author', None, None),
                                       'CONTACT_AUTHOR_EMAIL': ('software', 'contact_author_email', None, None),
                                       'DATE': ('software', 'date', None, None),
                                       'DEPENDENCIES': ('software', 'dependencies', None, None),
                                       'DESCRIPTION': ('software', 'description', None, None),
                                       'HARDWARE': ('software', 'hardware', None, None),
                                       'LANGUAGE': ('software', 'language', None, None),
                                       'LOCATION': ('software', 'location', None, None),
                                       'MODS': ('software', 'mods', None, None),
                                       'NAME': ('software', 'name', None, None),
                                       'OS': ('software', 'os', None, None),
                                       'OS_VERSION': ('software', 'os_version', None, None),
                                       'PDBX_ORDINAL': ('software', 'pdbx_ordinal', None, None),
                                       'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                       'TYPE': ('software', 'type', None, None),
                                       'VERSION': ('software', 'version', None, None)},
                     'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'PDBX_ORDINAL'), 'TYPE': 'UNIQUE'},
                                 's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                     'MAP_MERGE_INDICES': {'software': {'ATTRIBUTES': ('pdbx_ordinal',), 'TYPE': 'EQUI-JOIN'}},
                     'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                     'TABLE_ID': 'SOFTWARE',
                     'TABLE_NAME': 'software',
                     'TABLE_TYPE': 'transactional'},
        'SPACE_GROUP': {'ATTRIBUTES': {'CRYSTAL_SYSTEM': 'crystal_system',
                                       'ID': 'id',
                                       'IT_NUMBER': 'IT_number',
                                       'NAME_HALL': 'name_Hall',
                                       'NAME_H_M_ALT': 'name_H_M_alt',
                                       'STRUCTURE_ID': 'Structure_ID'},
                        'ATTRIBUTE_INFO': {'CRYSTAL_SYSTEM': {'NULLABLE': True,
                                                              'ORDER': 2,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10},
                                           'ID': {'NULLABLE': False,
                                                  'ORDER': 3,
                                                  'PRECISION': 0,
                                                  'PRIMARY_KEY': True,
                                                  'SQL_TYPE': 'VARCHAR',
                                                  'WIDTH': 10},
                                           'IT_NUMBER': {'NULLABLE': True,
                                                         'ORDER': 4,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'INT',
                                                         'WIDTH': 10},
                                           'NAME_HALL': {'NULLABLE': True,
                                                         'ORDER': 5,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 80},
                                           'NAME_H_M_ALT': {'NULLABLE': True,
                                                            'ORDER': 6,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 80},
                                           'STRUCTURE_ID': {'NULLABLE': False,
                                                            'ORDER': 1,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': True,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 10}},
                        'ATTRIBUTE_MAP': {'CRYSTAL_SYSTEM': ('space_group', 'crystal_system', None, None),
                                          'ID': ('space_group', 'id', None, None),
                                          'IT_NUMBER': ('space_group', 'IT_number', None, None),
                                          'NAME_HALL': ('space_group', 'name_Hall', None, None),
                                          'NAME_H_M_ALT': ('space_group', 'name_H-M_alt', None, None),
                                          'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                        'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                    's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                        'MAP_MERGE_INDICES': {'space_group': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                        'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                        'TABLE_ID': 'SPACE_GROUP',
                        'TABLE_NAME': 'space_group',
                        'TABLE_TYPE': 'transactional'},
        'SPACE_GROUP_SYMOP': {'ATTRIBUTES': {'ID': 'id',
                                             'OPERATION_XYZ': 'operation_xyz',
                                             'SG_ID': 'sg_id',
                                             'STRUCTURE_ID': 'Structure_ID'},
                              'ATTRIBUTE_INFO': {'ID': {'NULLABLE': False,
                                                        'ORDER': 2,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': True,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 10},
                                                 'OPERATION_XYZ': {'NULLABLE': True,
                                                                   'ORDER': 3,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 80},
                                                 'SG_ID': {'NULLABLE': True,
                                                           'ORDER': 4,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 10},
                                                 'STRUCTURE_ID': {'NULLABLE': False,
                                                                  'ORDER': 1,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': True,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10}},
                              'ATTRIBUTE_MAP': {'ID': ('space_group_symop', 'id', None, None),
                                                'OPERATION_XYZ': ('space_group_symop', 'operation_xyz', None, None),
                                                'SG_ID': ('space_group_symop', 'sg_id', None, None),
                                                'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                              'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                          's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                              'MAP_MERGE_INDICES': {'space_group_symop': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                              'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                              'TABLE_ID': 'SPACE_GROUP_SYMOP',
                              'TABLE_NAME': 'space_group_symop',
                              'TABLE_TYPE': 'transactional'},
        'STRUCT': {'ATTRIBUTES': {'ENTRY_ID': 'entry_id',
                                  'PDBX_CASP_FLAG': 'pdbx_CASP_flag',
                                  'PDBX_DESCRIPTOR': 'pdbx_descriptor',
                                  'PDBX_FORMULA_WEIGHT': 'pdbx_formula_weight',
                                  'PDBX_FORMULA_WEIGHT_METHOD': 'pdbx_formula_weight_method',
                                  'PDBX_MODEL_DETAILS': 'pdbx_model_details',
                                  'PDBX_MODEL_TYPE_DETAILS': 'pdbx_model_type_details',
                                  'STRUCTURE_ID': 'Structure_ID',
                                  'TITLE': 'title'},
                   'ATTRIBUTE_INFO': {'ENTRY_ID': {'NULLABLE': False,
                                                   'ORDER': 2,
                                                   'PRECISION': 0,
                                                   'PRIMARY_KEY': True,
                                                   'SQL_TYPE': 'VARCHAR',
                                                   'WIDTH': 10},
                                      'PDBX_CASP_FLAG': {'NULLABLE': True,
                                                         'ORDER': 9,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 2},
                                      'PDBX_DESCRIPTOR': {'NULLABLE': True,
                                                          'ORDER': 4,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 4095},
                                      'PDBX_FORMULA_WEIGHT': {'NULLABLE': True,
                                                              'ORDER': 6,
                                                              'PRECISION': 6,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'FLOAT',
                                                              'WIDTH': 10},
                                      'PDBX_FORMULA_WEIGHT_METHOD': {'NULLABLE': True,
                                                                     'ORDER': 7,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 80},
                                      'PDBX_MODEL_DETAILS': {'NULLABLE': True,
                                                             'ORDER': 5,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 16383},
                                      'PDBX_MODEL_TYPE_DETAILS': {'NULLABLE': True,
                                                                  'ORDER': 8,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 255},
                                      'STRUCTURE_ID': {'NULLABLE': False,
                                                       'ORDER': 1,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': True,
                                                       'SQL_TYPE': 'VARCHAR',
                                                       'WIDTH': 10},
                                      'TITLE': {'NULLABLE': True,
                                                'ORDER': 3,
                                                'PRECISION': 0,
                                                'PRIMARY_KEY': False,
                                                'SQL_TYPE': 'VARCHAR',
                                                'WIDTH': 511}},
                   'ATTRIBUTE_MAP': {'ENTRY_ID': ('struct', 'entry_id', None, None),
                                     'PDBX_CASP_FLAG': ('struct', 'pdbx_CASP_flag', None, None),
                                     'PDBX_DESCRIPTOR': ('struct', 'pdbx_descriptor', None, None),
                                     'PDBX_FORMULA_WEIGHT': ('struct', 'pdbx_formula_weight', None, None),
                                     'PDBX_FORMULA_WEIGHT_METHOD': ('struct', 'pdbx_formula_weight_method', None, None),
                                     'PDBX_MODEL_DETAILS': ('struct', 'pdbx_model_details', None, None),
                                     'PDBX_MODEL_TYPE_DETAILS': ('struct', 'pdbx_model_type_details', None, None),
                                     'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                     'TITLE': ('struct', 'title', None, None)},
                   'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID'), 'TYPE': 'UNIQUE'},
                               's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                   'MAP_MERGE_INDICES': {'struct': {'ATTRIBUTES': ('entry_id',), 'TYPE': 'EQUI-JOIN'}},
                   'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                   'TABLE_ID': 'STRUCT',
                   'TABLE_NAME': 'struct',
                   'TABLE_TYPE': 'transactional'},
        'STRUCT_ASYM': {'ATTRIBUTES': {'DETAILS': 'details',
                                       'ENTITY_ID': 'entity_id',
                                       'ID': 'id',
                                       'PDBX_BLANK_PDB_CHAINID_FLAG': 'pdbx_blank_PDB_chainid_flag',
                                       'PDBX_MODIFIED': 'pdbx_modified',
                                       'STRUCTURE_ID': 'Structure_ID'},
                        'ATTRIBUTE_INFO': {'DETAILS': {'NULLABLE': True,
                                                       'ORDER': 3,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'VARCHAR',
                                                       'WIDTH': 200},
                                           'ENTITY_ID': {'NULLABLE': True,
                                                         'ORDER': 2,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 10},
                                           'ID': {'NULLABLE': False,
                                                  'ORDER': 4,
                                                  'PRECISION': 0,
                                                  'PRIMARY_KEY': True,
                                                  'SQL_TYPE': 'VARCHAR',
                                                  'WIDTH': 10},
                                           'PDBX_BLANK_PDB_CHAINID_FLAG': {'NULLABLE': True,
                                                                           'ORDER': 6,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10},
                                           'PDBX_MODIFIED': {'NULLABLE': True,
                                                             'ORDER': 5,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 200},
                                           'STRUCTURE_ID': {'NULLABLE': False,
                                                            'ORDER': 1,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': True,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 10}},
                        'ATTRIBUTE_MAP': {'DETAILS': ('struct_asym', 'details', None, None),
                                          'ENTITY_ID': ('struct_asym', 'entity_id', None, None),
                                          'ID': ('struct_asym', 'id', None, None),
                                          'PDBX_BLANK_PDB_CHAINID_FLAG': ('struct_asym',
                                                                          'pdbx_blank_PDB_chainid_flag',
                                                                          None,
                                                                          None),
                                          'PDBX_MODIFIED': ('struct_asym', 'pdbx_modified', None, None),
                                          'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                        'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                    's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                        'MAP_MERGE_INDICES': {'struct_asym': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                        'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                        'TABLE_ID': 'STRUCT_ASYM',
                        'TABLE_NAME': 'struct_asym',
                        'TABLE_TYPE': 'transactional'},
        'STRUCT_BIOL': {'ATTRIBUTES': {'DETAILS': 'details',
                                       'ID': 'id',
                                       'PDBX_AGGREGATION_STATE': 'pdbx_aggregation_state',
                                       'PDBX_ASSEMBLY_METHOD': 'pdbx_assembly_method',
                                       'PDBX_FORMULA_WEIGHT': 'pdbx_formula_weight',
                                       'PDBX_FORMULA_WEIGHT_METHOD': 'pdbx_formula_weight_method',
                                       'PDBX_PARENT_BIOL_ID': 'pdbx_parent_biol_id',
                                       'STRUCTURE_ID': 'Structure_ID'},
                        'ATTRIBUTE_INFO': {'DETAILS': {'NULLABLE': True,
                                                       'ORDER': 2,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'VARCHAR',
                                                       'WIDTH': 32000},
                                           'ID': {'NULLABLE': False,
                                                  'ORDER': 3,
                                                  'PRECISION': 0,
                                                  'PRIMARY_KEY': True,
                                                  'SQL_TYPE': 'VARCHAR',
                                                  'WIDTH': 80},
                                           'PDBX_AGGREGATION_STATE': {'NULLABLE': True,
                                                                      'ORDER': 7,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 80},
                                           'PDBX_ASSEMBLY_METHOD': {'NULLABLE': True,
                                                                    'ORDER': 8,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 200},
                                           'PDBX_FORMULA_WEIGHT': {'NULLABLE': True,
                                                                   'ORDER': 5,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                           'PDBX_FORMULA_WEIGHT_METHOD': {'NULLABLE': True,
                                                                          'ORDER': 6,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 80},
                                           'PDBX_PARENT_BIOL_ID': {'NULLABLE': True,
                                                                   'ORDER': 4,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 80},
                                           'STRUCTURE_ID': {'NULLABLE': False,
                                                            'ORDER': 1,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': True,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 10}},
                        'ATTRIBUTE_MAP': {'DETAILS': ('struct_biol', 'details', None, None),
                                          'ID': ('struct_biol', 'id', None, None),
                                          'PDBX_AGGREGATION_STATE': ('struct_biol', 'pdbx_aggregation_state', None, None),
                                          'PDBX_ASSEMBLY_METHOD': ('struct_biol', 'pdbx_assembly_method', None, None),
                                          'PDBX_FORMULA_WEIGHT': ('struct_biol', 'pdbx_formula_weight', None, None),
                                          'PDBX_FORMULA_WEIGHT_METHOD': ('struct_biol',
                                                                         'pdbx_formula_weight_method',
                                                                         None,
                                                                         None),
                                          'PDBX_PARENT_BIOL_ID': ('struct_biol', 'pdbx_parent_biol_id', None, None),
                                          'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                        'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                    's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                        'MAP_MERGE_INDICES': {'struct_biol': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                        'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                        'TABLE_ID': 'STRUCT_BIOL',
                        'TABLE_NAME': 'struct_biol',
                        'TABLE_TYPE': 'transactional'},
        'STRUCT_BIOL_GEN': {'ATTRIBUTES': {'ASYM_ID': 'asym_id',
                                           'BIOL_ID': 'biol_id',
                                           'DETAILS': 'details',
                                           'PDBX_FULL_SYMMETRY_OPERATION': 'pdbx_full_symmetry_operation',
                                           'PDBX_PDB_ORDER': 'pdbx_PDB_order',
                                           'STRUCTURE_ID': 'Structure_ID',
                                           'SYMMETRY': 'symmetry'},
                            'ATTRIBUTE_INFO': {'ASYM_ID': {'NULLABLE': False,
                                                           'ORDER': 2,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': True,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 10},
                                               'BIOL_ID': {'NULLABLE': False,
                                                           'ORDER': 3,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': True,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 80},
                                               'DETAILS': {'NULLABLE': True,
                                                           'ORDER': 4,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 200},
                                               'PDBX_FULL_SYMMETRY_OPERATION': {'NULLABLE': True,
                                                                                'ORDER': 6,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 20},
                                               'PDBX_PDB_ORDER': {'NULLABLE': True,
                                                                  'ORDER': 7,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'INT',
                                                                  'WIDTH': 10},
                                               'STRUCTURE_ID': {'NULLABLE': False,
                                                                'ORDER': 1,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                               'SYMMETRY': {'NULLABLE': False,
                                                            'ORDER': 5,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': True,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 10}},
                            'ATTRIBUTE_MAP': {'ASYM_ID': ('struct_biol_gen', 'asym_id', None, None),
                                              'BIOL_ID': ('struct_biol_gen', 'biol_id', None, None),
                                              'DETAILS': ('struct_biol_gen', 'details', None, None),
                                              'PDBX_FULL_SYMMETRY_OPERATION': ('struct_biol_gen',
                                                                               'pdbx_full_symmetry_operation',
                                                                               None,
                                                                               None),
                                              'PDBX_PDB_ORDER': ('struct_biol_gen', 'pdbx_PDB_order', None, None),
                                              'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                              'SYMMETRY': ('struct_biol_gen', 'symmetry', None, None)},
                            'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ASYM_ID', 'BIOL_ID', 'SYMMETRY'),
                                               'TYPE': 'UNIQUE'},
                                        's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                            'MAP_MERGE_INDICES': {'struct_biol_gen': {'ATTRIBUTES': ('asym_id', 'biol_id', 'symmetry'),
                                                                      'TYPE': 'EQUI-JOIN'}},
                            'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                            'TABLE_ID': 'STRUCT_BIOL_GEN',
                            'TABLE_NAME': 'struct_biol_gen',
                            'TABLE_TYPE': 'transactional'},
        'STRUCT_BIOL_KEYWORDS': {'ATTRIBUTES': {'BIOL_ID': 'biol_id', 'STRUCTURE_ID': 'Structure_ID', 'TEXT': 'text'},
                                 'ATTRIBUTE_INFO': {'BIOL_ID': {'NULLABLE': False,
                                                                'ORDER': 2,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 80},
                                                    'STRUCTURE_ID': {'NULLABLE': False,
                                                                     'ORDER': 1,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': True,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                                    'TEXT': {'NULLABLE': False,
                                                             'ORDER': 3,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 200}},
                                 'ATTRIBUTE_MAP': {'BIOL_ID': ('struct_biol_keywords', 'biol_id', None, None),
                                                   'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                   'TEXT': ('struct_biol_keywords', 'text', None, None)},
                                 'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'BIOL_ID', 'TEXT'), 'TYPE': 'UNIQUE'},
                                             's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                 'MAP_MERGE_INDICES': {'struct_biol_keywords': {'ATTRIBUTES': ('biol_id', 'text'),
                                                                                'TYPE': 'EQUI-JOIN'}},
                                 'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                 'TABLE_ID': 'STRUCT_BIOL_KEYWORDS',
                                 'TABLE_NAME': 'struct_biol_keywords',
                                 'TABLE_TYPE': 'transactional'},
        'STRUCT_BIOL_VIEW': {'ATTRIBUTES': {'BIOL_ID': 'biol_id',
                                            'DETAILS': 'details',
                                            'ID': 'id',
                                            'ROT_MATRIX_1_1': 'rot_matrix_1_1',
                                            'ROT_MATRIX_1_2': 'rot_matrix_1_2',
                                            'ROT_MATRIX_1_3': 'rot_matrix_1_3',
                                            'ROT_MATRIX_2_1': 'rot_matrix_2_1',
                                            'ROT_MATRIX_2_2': 'rot_matrix_2_2',
                                            'ROT_MATRIX_2_3': 'rot_matrix_2_3',
                                            'ROT_MATRIX_3_1': 'rot_matrix_3_1',
                                            'ROT_MATRIX_3_2': 'rot_matrix_3_2',
                                            'ROT_MATRIX_3_3': 'rot_matrix_3_3',
                                            'STRUCTURE_ID': 'Structure_ID'},
                             'ATTRIBUTE_INFO': {'BIOL_ID': {'NULLABLE': False,
                                                            'ORDER': 2,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': True,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 80},
                                                'DETAILS': {'NULLABLE': True,
                                                            'ORDER': 3,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 200},
                                                'ID': {'NULLABLE': False,
                                                       'ORDER': 4,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': True,
                                                       'SQL_TYPE': 'VARCHAR',
                                                       'WIDTH': 80},
                                                'ROT_MATRIX_1_1': {'NULLABLE': True,
                                                                   'ORDER': 5,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                                'ROT_MATRIX_1_2': {'NULLABLE': True,
                                                                   'ORDER': 6,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                                'ROT_MATRIX_1_3': {'NULLABLE': True,
                                                                   'ORDER': 7,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                                'ROT_MATRIX_2_1': {'NULLABLE': True,
                                                                   'ORDER': 8,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                                'ROT_MATRIX_2_2': {'NULLABLE': True,
                                                                   'ORDER': 9,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                                'ROT_MATRIX_2_3': {'NULLABLE': True,
                                                                   'ORDER': 10,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                                'ROT_MATRIX_3_1': {'NULLABLE': True,
                                                                   'ORDER': 11,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                                'ROT_MATRIX_3_2': {'NULLABLE': True,
                                                                   'ORDER': 12,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                                'ROT_MATRIX_3_3': {'NULLABLE': True,
                                                                   'ORDER': 13,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                                'STRUCTURE_ID': {'NULLABLE': False,
                                                                 'ORDER': 1,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': True,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10}},
                             'ATTRIBUTE_MAP': {'BIOL_ID': ('struct_biol_view', 'biol_id', None, None),
                                               'DETAILS': ('struct_biol_view', 'details', None, None),
                                               'ID': ('struct_biol_view', 'id', None, None),
                                               'ROT_MATRIX_1_1': ('struct_biol_view', 'rot_matrix[1][1]', None, None),
                                               'ROT_MATRIX_1_2': ('struct_biol_view', 'rot_matrix[1][2]', None, None),
                                               'ROT_MATRIX_1_3': ('struct_biol_view', 'rot_matrix[1][3]', None, None),
                                               'ROT_MATRIX_2_1': ('struct_biol_view', 'rot_matrix[2][1]', None, None),
                                               'ROT_MATRIX_2_2': ('struct_biol_view', 'rot_matrix[2][2]', None, None),
                                               'ROT_MATRIX_2_3': ('struct_biol_view', 'rot_matrix[2][3]', None, None),
                                               'ROT_MATRIX_3_1': ('struct_biol_view', 'rot_matrix[3][1]', None, None),
                                               'ROT_MATRIX_3_2': ('struct_biol_view', 'rot_matrix[3][2]', None, None),
                                               'ROT_MATRIX_3_3': ('struct_biol_view', 'rot_matrix[3][3]', None, None),
                                               'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                             'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'BIOL_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                         's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                             'MAP_MERGE_INDICES': {'struct_biol_view': {'ATTRIBUTES': ('biol_id', 'id'), 'TYPE': 'EQUI-JOIN'}},
                             'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                             'TABLE_ID': 'STRUCT_BIOL_VIEW',
                             'TABLE_NAME': 'struct_biol_view',
                             'TABLE_TYPE': 'transactional'},
        'STRUCT_CONF': {'ATTRIBUTES': {'BEG_AUTH_ASYM_ID': 'beg_auth_asym_id',
                                       'BEG_AUTH_COMP_ID': 'beg_auth_comp_id',
                                       'BEG_AUTH_SEQ_ID': 'beg_auth_seq_id',
                                       'BEG_LABEL_ASYM_ID': 'beg_label_asym_id',
                                       'BEG_LABEL_COMP_ID': 'beg_label_comp_id',
                                       'BEG_LABEL_SEQ_ID': 'beg_label_seq_id',
                                       'CONF_TYPE_ID': 'conf_type_id',
                                       'DETAILS': 'details',
                                       'END_AUTH_ASYM_ID': 'end_auth_asym_id',
                                       'END_AUTH_COMP_ID': 'end_auth_comp_id',
                                       'END_AUTH_SEQ_ID': 'end_auth_seq_id',
                                       'END_LABEL_ASYM_ID': 'end_label_asym_id',
                                       'END_LABEL_COMP_ID': 'end_label_comp_id',
                                       'END_LABEL_SEQ_ID': 'end_label_seq_id',
                                       'ID': 'id',
                                       'PDBX_BEG_PDB_INS_CODE': 'pdbx_beg_PDB_ins_code',
                                       'PDBX_END_PDB_INS_CODE': 'pdbx_end_PDB_ins_code',
                                       'PDBX_PDB_HELIX_CLASS': 'pdbx_PDB_helix_class',
                                       'PDBX_PDB_HELIX_ID': 'pdbx_PDB_helix_id',
                                       'PDBX_PDB_HELIX_LENGTH': 'pdbx_PDB_helix_length',
                                       'STRUCTURE_ID': 'Structure_ID'},
                        'ATTRIBUTE_INFO': {'BEG_AUTH_ASYM_ID': {'NULLABLE': True,
                                                                'ORDER': 2,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                           'BEG_AUTH_COMP_ID': {'NULLABLE': True,
                                                                'ORDER': 4,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                           'BEG_AUTH_SEQ_ID': {'NULLABLE': True,
                                                               'ORDER': 6,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                           'BEG_LABEL_ASYM_ID': {'NULLABLE': True,
                                                                 'ORDER': 12,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                           'BEG_LABEL_COMP_ID': {'NULLABLE': True,
                                                                 'ORDER': 8,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                           'BEG_LABEL_SEQ_ID': {'NULLABLE': True,
                                                                'ORDER': 10,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'INT',
                                                                'WIDTH': 10},
                                           'CONF_TYPE_ID': {'NULLABLE': True,
                                                            'ORDER': 14,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 10},
                                           'DETAILS': {'NULLABLE': True,
                                                       'ORDER': 15,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'VARCHAR',
                                                       'WIDTH': 200},
                                           'END_AUTH_ASYM_ID': {'NULLABLE': True,
                                                                'ORDER': 3,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                           'END_AUTH_COMP_ID': {'NULLABLE': True,
                                                                'ORDER': 5,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                           'END_AUTH_SEQ_ID': {'NULLABLE': True,
                                                               'ORDER': 7,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                           'END_LABEL_ASYM_ID': {'NULLABLE': True,
                                                                 'ORDER': 13,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                           'END_LABEL_COMP_ID': {'NULLABLE': True,
                                                                 'ORDER': 9,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                           'END_LABEL_SEQ_ID': {'NULLABLE': True,
                                                                'ORDER': 11,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'INT',
                                                                'WIDTH': 10},
                                           'ID': {'NULLABLE': False,
                                                  'ORDER': 16,
                                                  'PRECISION': 0,
                                                  'PRIMARY_KEY': True,
                                                  'SQL_TYPE': 'VARCHAR',
                                                  'WIDTH': 10},
                                           'PDBX_BEG_PDB_INS_CODE': {'NULLABLE': True,
                                                                     'ORDER': 17,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                           'PDBX_END_PDB_INS_CODE': {'NULLABLE': True,
                                                                     'ORDER': 18,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                           'PDBX_PDB_HELIX_CLASS': {'NULLABLE': True,
                                                                    'ORDER': 19,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 80},
                                           'PDBX_PDB_HELIX_ID': {'NULLABLE': True,
                                                                 'ORDER': 21,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                           'PDBX_PDB_HELIX_LENGTH': {'NULLABLE': True,
                                                                     'ORDER': 20,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'INT',
                                                                     'WIDTH': 10},
                                           'STRUCTURE_ID': {'NULLABLE': False,
                                                            'ORDER': 1,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': True,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 10}},
                        'ATTRIBUTE_MAP': {'BEG_AUTH_ASYM_ID': ('struct_conf', 'beg_auth_asym_id', None, None),
                                          'BEG_AUTH_COMP_ID': ('struct_conf', 'beg_auth_comp_id', None, None),
                                          'BEG_AUTH_SEQ_ID': ('struct_conf', 'beg_auth_seq_id', None, None),
                                          'BEG_LABEL_ASYM_ID': ('struct_conf', 'beg_label_asym_id', None, None),
                                          'BEG_LABEL_COMP_ID': ('struct_conf', 'beg_label_comp_id', None, None),
                                          'BEG_LABEL_SEQ_ID': ('struct_conf', 'beg_label_seq_id', None, None),
                                          'CONF_TYPE_ID': ('struct_conf', 'conf_type_id', None, None),
                                          'DETAILS': ('struct_conf', 'details', None, None),
                                          'END_AUTH_ASYM_ID': ('struct_conf', 'end_auth_asym_id', None, None),
                                          'END_AUTH_COMP_ID': ('struct_conf', 'end_auth_comp_id', None, None),
                                          'END_AUTH_SEQ_ID': ('struct_conf', 'end_auth_seq_id', None, None),
                                          'END_LABEL_ASYM_ID': ('struct_conf', 'end_label_asym_id', None, None),
                                          'END_LABEL_COMP_ID': ('struct_conf', 'end_label_comp_id', None, None),
                                          'END_LABEL_SEQ_ID': ('struct_conf', 'end_label_seq_id', None, None),
                                          'ID': ('struct_conf', 'id', None, None),
                                          'PDBX_BEG_PDB_INS_CODE': ('struct_conf', 'pdbx_beg_PDB_ins_code', None, None),
                                          'PDBX_END_PDB_INS_CODE': ('struct_conf', 'pdbx_end_PDB_ins_code', None, None),
                                          'PDBX_PDB_HELIX_CLASS': ('struct_conf', 'pdbx_PDB_helix_class', None, None),
                                          'PDBX_PDB_HELIX_ID': ('struct_conf', 'pdbx_PDB_helix_id', None, None),
                                          'PDBX_PDB_HELIX_LENGTH': ('struct_conf', 'pdbx_PDB_helix_length', None, None),
                                          'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                        'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                    's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                        'MAP_MERGE_INDICES': {'struct_conf': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                        'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                        'TABLE_ID': 'STRUCT_CONF',
                        'TABLE_NAME': 'struct_conf',
                        'TABLE_TYPE': 'transactional'},
        'STRUCT_CONF_TYPE': {'ATTRIBUTES': {'CRITERIA': 'criteria',
                                            'ID': 'id',
                                            'REFERENCE': 'reference',
                                            'STRUCTURE_ID': 'Structure_ID'},
                             'ATTRIBUTE_INFO': {'CRITERIA': {'NULLABLE': True,
                                                             'ORDER': 2,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 200},
                                                'ID': {'NULLABLE': False,
                                                       'ORDER': 3,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': True,
                                                       'SQL_TYPE': 'VARCHAR',
                                                       'WIDTH': 10},
                                                'REFERENCE': {'NULLABLE': True,
                                                              'ORDER': 4,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 200},
                                                'STRUCTURE_ID': {'NULLABLE': False,
                                                                 'ORDER': 1,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': True,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10}},
                             'ATTRIBUTE_MAP': {'CRITERIA': ('struct_conf_type', 'criteria', None, None),
                                               'ID': ('struct_conf_type', 'id', None, None),
                                               'REFERENCE': ('struct_conf_type', 'reference', None, None),
                                               'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                             'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                         's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                             'MAP_MERGE_INDICES': {'struct_conf_type': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                             'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                             'TABLE_ID': 'STRUCT_CONF_TYPE',
                             'TABLE_NAME': 'struct_conf_type',
                             'TABLE_TYPE': 'transactional'},
        'STRUCT_CONN': {'ATTRIBUTES': {'CONN_TYPE_ID': 'conn_type_id',
                                       'DETAILS': 'details',
                                       'ID': 'id',
                                       'PDBX_DIST_VALUE': 'pdbx_dist_value',
                                       'PDBX_PDB_ID': 'pdbx_PDB_id',
                                       'PDBX_PTNR1_AUTH_ALT_ID': 'pdbx_ptnr1_auth_alt_id',
                                       'PDBX_PTNR1_LABEL_ALT_ID': 'pdbx_ptnr1_label_alt_id',
                                       'PDBX_PTNR1_PDB_INS_CODE': 'pdbx_ptnr1_PDB_ins_code',
                                       'PDBX_PTNR1_STANDARD_COMP_ID': 'pdbx_ptnr1_standard_comp_id',
                                       'PDBX_PTNR2_AUTH_ALT_ID': 'pdbx_ptnr2_auth_alt_id',
                                       'PDBX_PTNR2_LABEL_ALT_ID': 'pdbx_ptnr2_label_alt_id',
                                       'PDBX_PTNR2_PDB_INS_CODE': 'pdbx_ptnr2_PDB_ins_code',
                                       'PDBX_PTNR3_AUTH_ALT_ID': 'pdbx_ptnr3_auth_alt_id',
                                       'PDBX_PTNR3_AUTH_ASYM_ID': 'pdbx_ptnr3_auth_asym_id',
                                       'PDBX_PTNR3_AUTH_ATOM_ID': 'pdbx_ptnr3_auth_atom_id',
                                       'PDBX_PTNR3_AUTH_COMP_ID': 'pdbx_ptnr3_auth_comp_id',
                                       'PDBX_PTNR3_AUTH_SEQ_ID': 'pdbx_ptnr3_auth_seq_id',
                                       'PDBX_PTNR3_LABEL_ALT_ID': 'pdbx_ptnr3_label_alt_id',
                                       'PDBX_PTNR3_LABEL_ASYM_ID': 'pdbx_ptnr3_label_asym_id',
                                       'PDBX_PTNR3_LABEL_ATOM_ID': 'pdbx_ptnr3_label_atom_id',
                                       'PDBX_PTNR3_LABEL_COMP_ID': 'pdbx_ptnr3_label_comp_id',
                                       'PDBX_PTNR3_LABEL_SEQ_ID': 'pdbx_ptnr3_label_seq_id',
                                       'PDBX_PTNR3_PDB_INS_CODE': 'pdbx_ptnr3_PDB_ins_code',
                                       'PDBX_VALUE_ORDER': 'pdbx_value_order',
                                       'PTNR1_AUTH_ASYM_ID': 'ptnr1_auth_asym_id',
                                       'PTNR1_AUTH_ATOM_ID': 'ptnr1_auth_atom_id',
                                       'PTNR1_AUTH_COMP_ID': 'ptnr1_auth_comp_id',
                                       'PTNR1_AUTH_SEQ_ID': 'ptnr1_auth_seq_id',
                                       'PTNR1_LABEL_ALT_ID': 'ptnr1_label_alt_id',
                                       'PTNR1_LABEL_ASYM_ID': 'ptnr1_label_asym_id',
                                       'PTNR1_LABEL_ATOM_ID': 'ptnr1_label_atom_id',
                                       'PTNR1_LABEL_COMP_ID': 'ptnr1_label_comp_id',
                                       'PTNR1_LABEL_SEQ_ID': 'ptnr1_label_seq_id',
                                       'PTNR1_ROLE': 'ptnr1_role',
                                       'PTNR1_SYMMETRY': 'ptnr1_symmetry',
                                       'PTNR2_AUTH_ASYM_ID': 'ptnr2_auth_asym_id',
                                       'PTNR2_AUTH_ATOM_ID': 'ptnr2_auth_atom_id',
                                       'PTNR2_AUTH_COMP_ID': 'ptnr2_auth_comp_id',
                                       'PTNR2_AUTH_SEQ_ID': 'ptnr2_auth_seq_id',
                                       'PTNR2_LABEL_ALT_ID': 'ptnr2_label_alt_id',
                                       'PTNR2_LABEL_ASYM_ID': 'ptnr2_label_asym_id',
                                       'PTNR2_LABEL_ATOM_ID': 'ptnr2_label_atom_id',
                                       'PTNR2_LABEL_COMP_ID': 'ptnr2_label_comp_id',
                                       'PTNR2_LABEL_SEQ_ID': 'ptnr2_label_seq_id',
                                       'PTNR2_ROLE': 'ptnr2_role',
                                       'PTNR2_SYMMETRY': 'ptnr2_symmetry',
                                       'STRUCTURE_ID': 'Structure_ID'},
                        'ATTRIBUTE_INFO': {'CONN_TYPE_ID': {'NULLABLE': True,
                                                            'ORDER': 20,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 17},
                                           'DETAILS': {'NULLABLE': True,
                                                       'ORDER': 21,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'VARCHAR',
                                                       'WIDTH': 200},
                                           'ID': {'NULLABLE': False,
                                                  'ORDER': 22,
                                                  'PRECISION': 0,
                                                  'PRIMARY_KEY': True,
                                                  'SQL_TYPE': 'VARCHAR',
                                                  'WIDTH': 18},
                                           'PDBX_DIST_VALUE': {'NULLABLE': True,
                                                               'ORDER': 46,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                           'PDBX_PDB_ID': {'NULLABLE': True,
                                                           'ORDER': 45,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 10},
                                           'PDBX_PTNR1_AUTH_ALT_ID': {'NULLABLE': True,
                                                                      'ORDER': 28,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                           'PDBX_PTNR1_LABEL_ALT_ID': {'NULLABLE': True,
                                                                       'ORDER': 29,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                           'PDBX_PTNR1_PDB_INS_CODE': {'NULLABLE': True,
                                                                       'ORDER': 27,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                           'PDBX_PTNR1_STANDARD_COMP_ID': {'NULLABLE': True,
                                                                           'ORDER': 30,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10},
                                           'PDBX_PTNR2_AUTH_ALT_ID': {'NULLABLE': True,
                                                                      'ORDER': 32,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                           'PDBX_PTNR2_LABEL_ALT_ID': {'NULLABLE': True,
                                                                       'ORDER': 33,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                           'PDBX_PTNR2_PDB_INS_CODE': {'NULLABLE': True,
                                                                       'ORDER': 31,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                           'PDBX_PTNR3_AUTH_ALT_ID': {'NULLABLE': True,
                                                                      'ORDER': 34,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                           'PDBX_PTNR3_AUTH_ASYM_ID': {'NULLABLE': True,
                                                                       'ORDER': 35,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                           'PDBX_PTNR3_AUTH_ATOM_ID': {'NULLABLE': True,
                                                                       'ORDER': 36,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 6},
                                           'PDBX_PTNR3_AUTH_COMP_ID': {'NULLABLE': True,
                                                                       'ORDER': 37,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                           'PDBX_PTNR3_AUTH_SEQ_ID': {'NULLABLE': True,
                                                                      'ORDER': 39,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                           'PDBX_PTNR3_LABEL_ALT_ID': {'NULLABLE': True,
                                                                       'ORDER': 40,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                           'PDBX_PTNR3_LABEL_ASYM_ID': {'NULLABLE': True,
                                                                        'ORDER': 41,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                           'PDBX_PTNR3_LABEL_ATOM_ID': {'NULLABLE': True,
                                                                        'ORDER': 42,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 6},
                                           'PDBX_PTNR3_LABEL_COMP_ID': {'NULLABLE': True,
                                                                        'ORDER': 43,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                           'PDBX_PTNR3_LABEL_SEQ_ID': {'NULLABLE': True,
                                                                       'ORDER': 44,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'INT',
                                                                       'WIDTH': 10},
                                           'PDBX_PTNR3_PDB_INS_CODE': {'NULLABLE': True,
                                                                       'ORDER': 38,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                           'PDBX_VALUE_ORDER': {'NULLABLE': True,
                                                                'ORDER': 47,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                           'PTNR1_AUTH_ASYM_ID': {'NULLABLE': True,
                                                                  'ORDER': 2,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10},
                                           'PTNR1_AUTH_ATOM_ID': {'NULLABLE': True,
                                                                  'ORDER': 4,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 6},
                                           'PTNR1_AUTH_COMP_ID': {'NULLABLE': True,
                                                                  'ORDER': 6,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10},
                                           'PTNR1_AUTH_SEQ_ID': {'NULLABLE': True,
                                                                 'ORDER': 8,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                           'PTNR1_LABEL_ALT_ID': {'NULLABLE': True,
                                                                  'ORDER': 10,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10},
                                           'PTNR1_LABEL_ASYM_ID': {'NULLABLE': True,
                                                                   'ORDER': 18,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 10},
                                           'PTNR1_LABEL_ATOM_ID': {'NULLABLE': True,
                                                                   'ORDER': 14,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 6},
                                           'PTNR1_LABEL_COMP_ID': {'NULLABLE': True,
                                                                   'ORDER': 12,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 10},
                                           'PTNR1_LABEL_SEQ_ID': {'NULLABLE': True,
                                                                  'ORDER': 16,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'INT',
                                                                  'WIDTH': 10},
                                           'PTNR1_ROLE': {'NULLABLE': True,
                                                          'ORDER': 23,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 80},
                                           'PTNR1_SYMMETRY': {'NULLABLE': True,
                                                              'ORDER': 24,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10},
                                           'PTNR2_AUTH_ASYM_ID': {'NULLABLE': True,
                                                                  'ORDER': 3,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10},
                                           'PTNR2_AUTH_ATOM_ID': {'NULLABLE': True,
                                                                  'ORDER': 5,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 6},
                                           'PTNR2_AUTH_COMP_ID': {'NULLABLE': True,
                                                                  'ORDER': 7,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10},
                                           'PTNR2_AUTH_SEQ_ID': {'NULLABLE': True,
                                                                 'ORDER': 9,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                           'PTNR2_LABEL_ALT_ID': {'NULLABLE': True,
                                                                  'ORDER': 11,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10},
                                           'PTNR2_LABEL_ASYM_ID': {'NULLABLE': True,
                                                                   'ORDER': 19,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 10},
                                           'PTNR2_LABEL_ATOM_ID': {'NULLABLE': True,
                                                                   'ORDER': 15,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 6},
                                           'PTNR2_LABEL_COMP_ID': {'NULLABLE': True,
                                                                   'ORDER': 13,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 10},
                                           'PTNR2_LABEL_SEQ_ID': {'NULLABLE': True,
                                                                  'ORDER': 17,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'INT',
                                                                  'WIDTH': 10},
                                           'PTNR2_ROLE': {'NULLABLE': True,
                                                          'ORDER': 25,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 80},
                                           'PTNR2_SYMMETRY': {'NULLABLE': True,
                                                              'ORDER': 26,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10},
                                           'STRUCTURE_ID': {'NULLABLE': False,
                                                            'ORDER': 1,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': True,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 10}},
                        'ATTRIBUTE_MAP': {'CONN_TYPE_ID': ('struct_conn', 'conn_type_id', None, None),
                                          'DETAILS': ('struct_conn', 'details', None, None),
                                          'ID': ('struct_conn', 'id', None, None),
                                          'PDBX_DIST_VALUE': ('struct_conn', 'pdbx_dist_value', None, None),
                                          'PDBX_PDB_ID': ('struct_conn', 'pdbx_PDB_id', None, None),
                                          'PDBX_PTNR1_AUTH_ALT_ID': ('struct_conn', 'pdbx_ptnr1_auth_alt_id', None, None),
                                          'PDBX_PTNR1_LABEL_ALT_ID': ('struct_conn', 'pdbx_ptnr1_label_alt_id', None, None),
                                          'PDBX_PTNR1_PDB_INS_CODE': ('struct_conn', 'pdbx_ptnr1_PDB_ins_code', None, None),
                                          'PDBX_PTNR1_STANDARD_COMP_ID': ('struct_conn',
                                                                          'pdbx_ptnr1_standard_comp_id',
                                                                          None,
                                                                          None),
                                          'PDBX_PTNR2_AUTH_ALT_ID': ('struct_conn', 'pdbx_ptnr2_auth_alt_id', None, None),
                                          'PDBX_PTNR2_LABEL_ALT_ID': ('struct_conn', 'pdbx_ptnr2_label_alt_id', None, None),
                                          'PDBX_PTNR2_PDB_INS_CODE': ('struct_conn', 'pdbx_ptnr2_PDB_ins_code', None, None),
                                          'PDBX_PTNR3_AUTH_ALT_ID': ('struct_conn', 'pdbx_ptnr3_auth_alt_id', None, None),
                                          'PDBX_PTNR3_AUTH_ASYM_ID': ('struct_conn', 'pdbx_ptnr3_auth_asym_id', None, None),
                                          'PDBX_PTNR3_AUTH_ATOM_ID': ('struct_conn', 'pdbx_ptnr3_auth_atom_id', None, None),
                                          'PDBX_PTNR3_AUTH_COMP_ID': ('struct_conn', 'pdbx_ptnr3_auth_comp_id', None, None),
                                          'PDBX_PTNR3_AUTH_SEQ_ID': ('struct_conn', 'pdbx_ptnr3_auth_seq_id', None, None),
                                          'PDBX_PTNR3_LABEL_ALT_ID': ('struct_conn', 'pdbx_ptnr3_label_alt_id', None, None),
                                          'PDBX_PTNR3_LABEL_ASYM_ID': ('struct_conn', 'pdbx_ptnr3_label_asym_id', None, None),
                                          'PDBX_PTNR3_LABEL_ATOM_ID': ('struct_conn', 'pdbx_ptnr3_label_atom_id', None, None),
                                          'PDBX_PTNR3_LABEL_COMP_ID': ('struct_conn', 'pdbx_ptnr3_label_comp_id', None, None),
                                          'PDBX_PTNR3_LABEL_SEQ_ID': ('struct_conn', 'pdbx_ptnr3_label_seq_id', None, None),
                                          'PDBX_PTNR3_PDB_INS_CODE': ('struct_conn', 'pdbx_ptnr3_PDB_ins_code', None, None),
                                          'PDBX_VALUE_ORDER': ('struct_conn', 'pdbx_value_order', None, None),
                                          'PTNR1_AUTH_ASYM_ID': ('struct_conn', 'ptnr1_auth_asym_id', None, None),
                                          'PTNR1_AUTH_ATOM_ID': ('struct_conn', 'ptnr1_auth_atom_id', None, None),
                                          'PTNR1_AUTH_COMP_ID': ('struct_conn', 'ptnr1_auth_comp_id', None, None),
                                          'PTNR1_AUTH_SEQ_ID': ('struct_conn', 'ptnr1_auth_seq_id', None, None),
                                          'PTNR1_LABEL_ALT_ID': ('struct_conn', 'ptnr1_label_alt_id', None, None),
                                          'PTNR1_LABEL_ASYM_ID': ('struct_conn', 'ptnr1_label_asym_id', None, None),
                                          'PTNR1_LABEL_ATOM_ID': ('struct_conn', 'ptnr1_label_atom_id', None, None),
                                          'PTNR1_LABEL_COMP_ID': ('struct_conn', 'ptnr1_label_comp_id', None, None),
                                          'PTNR1_LABEL_SEQ_ID': ('struct_conn', 'ptnr1_label_seq_id', None, None),
                                          'PTNR1_ROLE': ('struct_conn', 'ptnr1_role', None, None),
                                          'PTNR1_SYMMETRY': ('struct_conn', 'ptnr1_symmetry', None, None),
                                          'PTNR2_AUTH_ASYM_ID': ('struct_conn', 'ptnr2_auth_asym_id', None, None),
                                          'PTNR2_AUTH_ATOM_ID': ('struct_conn', 'ptnr2_auth_atom_id', None, None),
                                          'PTNR2_AUTH_COMP_ID': ('struct_conn', 'ptnr2_auth_comp_id', None, None),
                                          'PTNR2_AUTH_SEQ_ID': ('struct_conn', 'ptnr2_auth_seq_id', None, None),
                                          'PTNR2_LABEL_ALT_ID': ('struct_conn', 'ptnr2_label_alt_id', None, None),
                                          'PTNR2_LABEL_ASYM_ID': ('struct_conn', 'ptnr2_label_asym_id', None, None),
                                          'PTNR2_LABEL_ATOM_ID': ('struct_conn', 'ptnr2_label_atom_id', None, None),
                                          'PTNR2_LABEL_COMP_ID': ('struct_conn', 'ptnr2_label_comp_id', None, None),
                                          'PTNR2_LABEL_SEQ_ID': ('struct_conn', 'ptnr2_label_seq_id', None, None),
                                          'PTNR2_ROLE': ('struct_conn', 'ptnr2_role', None, None),
                                          'PTNR2_SYMMETRY': ('struct_conn', 'ptnr2_symmetry', None, None),
                                          'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                        'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                    's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                        'MAP_MERGE_INDICES': {'struct_conn': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                        'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                        'TABLE_ID': 'STRUCT_CONN',
                        'TABLE_NAME': 'struct_conn',
                        'TABLE_TYPE': 'transactional'},
        'STRUCT_CONN_TYPE': {'ATTRIBUTES': {'CRITERIA': 'criteria',
                                            'ID': 'id',
                                            'REFERENCE': 'reference',
                                            'STRUCTURE_ID': 'Structure_ID'},
                             'ATTRIBUTE_INFO': {'CRITERIA': {'NULLABLE': True,
                                                             'ORDER': 2,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 200},
                                                'ID': {'NULLABLE': False,
                                                       'ORDER': 3,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': True,
                                                       'SQL_TYPE': 'VARCHAR',
                                                       'WIDTH': 17},
                                                'REFERENCE': {'NULLABLE': True,
                                                              'ORDER': 4,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 200},
                                                'STRUCTURE_ID': {'NULLABLE': False,
                                                                 'ORDER': 1,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': True,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10}},
                             'ATTRIBUTE_MAP': {'CRITERIA': ('struct_conn_type', 'criteria', None, None),
                                               'ID': ('struct_conn_type', 'id', None, None),
                                               'REFERENCE': ('struct_conn_type', 'reference', None, None),
                                               'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                             'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                         's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                             'MAP_MERGE_INDICES': {'struct_conn_type': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                             'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                             'TABLE_ID': 'STRUCT_CONN_TYPE',
                             'TABLE_NAME': 'struct_conn_type',
                             'TABLE_TYPE': 'transactional'},
        'STRUCT_KEYWORDS': {'ATTRIBUTES': {'ENTRY_ID': 'entry_id',
                                           'PDBX_KEYWORDS': 'pdbx_keywords',
                                           'STRUCTURE_ID': 'Structure_ID',
                                           'TEXT': 'text'},
                            'ATTRIBUTE_INFO': {'ENTRY_ID': {'NULLABLE': False,
                                                            'ORDER': 2,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': True,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 10},
                                               'PDBX_KEYWORDS': {'NULLABLE': True,
                                                                 'ORDER': 4,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 80},
                                               'STRUCTURE_ID': {'NULLABLE': False,
                                                                'ORDER': 1,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                               'TEXT': {'NULLABLE': True,
                                                        'ORDER': 3,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 1023}},
                            'ATTRIBUTE_MAP': {'ENTRY_ID': ('struct_keywords', 'entry_id', None, None),
                                              'PDBX_KEYWORDS': ('struct_keywords', 'pdbx_keywords', None, None),
                                              'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                              'TEXT': ('struct_keywords', 'text', None, None)},
                            'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID'), 'TYPE': 'UNIQUE'},
                                        's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                            'MAP_MERGE_INDICES': {'struct_keywords': {'ATTRIBUTES': ('entry_id',), 'TYPE': 'EQUI-JOIN'}},
                            'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                            'TABLE_ID': 'STRUCT_KEYWORDS',
                            'TABLE_NAME': 'struct_keywords',
                            'TABLE_TYPE': 'transactional'},
        'STRUCT_MON_DETAILS': {'ATTRIBUTES': {'ENTRY_ID': 'entry_id',
                                              'PROT_CIS': 'prot_cis',
                                              'RSCC': 'RSCC',
                                              'RSR': 'RSR',
                                              'STRUCTURE_ID': 'Structure_ID'},
                               'ATTRIBUTE_INFO': {'ENTRY_ID': {'NULLABLE': False,
                                                               'ORDER': 2,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                                  'PROT_CIS': {'NULLABLE': True,
                                                               'ORDER': 3,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                                  'RSCC': {'NULLABLE': True,
                                                           'ORDER': 4,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 200},
                                                  'RSR': {'NULLABLE': True,
                                                          'ORDER': 5,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 200},
                                                  'STRUCTURE_ID': {'NULLABLE': False,
                                                                   'ORDER': 1,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': True,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 10}},
                               'ATTRIBUTE_MAP': {'ENTRY_ID': ('struct_mon_details', 'entry_id', None, None),
                                                 'PROT_CIS': ('struct_mon_details', 'prot_cis', None, None),
                                                 'RSCC': ('struct_mon_details', 'RSCC', None, None),
                                                 'RSR': ('struct_mon_details', 'RSR', None, None),
                                                 'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                               'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID'), 'TYPE': 'UNIQUE'},
                                           's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                               'MAP_MERGE_INDICES': {'struct_mon_details': {'ATTRIBUTES': ('entry_id',), 'TYPE': 'EQUI-JOIN'}},
                               'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                               'TABLE_ID': 'STRUCT_MON_DETAILS',
                               'TABLE_NAME': 'struct_mon_details',
                               'TABLE_TYPE': 'transactional'},
        'STRUCT_MON_NUCL': {'ATTRIBUTES': {'ALPHA': 'alpha',
                                           'AUTH_ASYM_ID': 'auth_asym_id',
                                           'AUTH_COMP_ID': 'auth_comp_id',
                                           'AUTH_SEQ_ID': 'auth_seq_id',
                                           'BETA': 'beta',
                                           'CHI1': 'chi1',
                                           'CHI2': 'chi2',
                                           'DELTA': 'delta',
                                           'DETAILS': 'details',
                                           'EPSILON': 'epsilon',
                                           'GAMMA': 'gamma',
                                           'LABEL_ALT_ID': 'label_alt_id',
                                           'LABEL_ASYM_ID': 'label_asym_id',
                                           'LABEL_COMP_ID': 'label_comp_id',
                                           'LABEL_SEQ_ID': 'label_seq_id',
                                           'MEAN_B_ALL': 'mean_B_all',
                                           'MEAN_B_BASE': 'mean_B_base',
                                           'MEAN_B_PHOS': 'mean_B_phos',
                                           'MEAN_B_SUGAR': 'mean_B_sugar',
                                           'NU0': 'nu0',
                                           'NU1': 'nu1',
                                           'NU2': 'nu2',
                                           'NU3': 'nu3',
                                           'NU4': 'nu4',
                                           'P': 'P',
                                           'RSCC_ALL': 'RSCC_all',
                                           'RSCC_BASE': 'RSCC_base',
                                           'RSCC_PHOS': 'RSCC_phos',
                                           'RSCC_SUGAR': 'RSCC_sugar',
                                           'RSR_ALL': 'RSR_all',
                                           'RSR_BASE': 'RSR_base',
                                           'RSR_PHOS': 'RSR_phos',
                                           'RSR_SUGAR': 'RSR_sugar',
                                           'STRUCTURE_ID': 'Structure_ID',
                                           'TAU0': 'tau0',
                                           'TAU1': 'tau1',
                                           'TAU2': 'tau2',
                                           'TAU3': 'tau3',
                                           'TAU4': 'tau4',
                                           'TAUM': 'taum',
                                           'ZETA': 'zeta'},
                            'ATTRIBUTE_INFO': {'ALPHA': {'NULLABLE': True,
                                                         'ORDER': 9,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                               'AUTH_ASYM_ID': {'NULLABLE': True,
                                                                'ORDER': 2,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                               'AUTH_COMP_ID': {'NULLABLE': True,
                                                                'ORDER': 3,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                               'AUTH_SEQ_ID': {'NULLABLE': True,
                                                               'ORDER': 4,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                               'BETA': {'NULLABLE': True,
                                                        'ORDER': 10,
                                                        'PRECISION': 6,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'FLOAT',
                                                        'WIDTH': 10},
                                               'CHI1': {'NULLABLE': True,
                                                        'ORDER': 11,
                                                        'PRECISION': 6,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'FLOAT',
                                                        'WIDTH': 10},
                                               'CHI2': {'NULLABLE': True,
                                                        'ORDER': 12,
                                                        'PRECISION': 6,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'FLOAT',
                                                        'WIDTH': 10},
                                               'DELTA': {'NULLABLE': True,
                                                         'ORDER': 13,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                               'DETAILS': {'NULLABLE': True,
                                                           'ORDER': 14,
                                                           'PRECISION': 6,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'FLOAT',
                                                           'WIDTH': 10},
                                               'EPSILON': {'NULLABLE': True,
                                                           'ORDER': 15,
                                                           'PRECISION': 6,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'FLOAT',
                                                           'WIDTH': 10},
                                               'GAMMA': {'NULLABLE': True,
                                                         'ORDER': 16,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                               'LABEL_ALT_ID': {'NULLABLE': False,
                                                                'ORDER': 5,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                               'LABEL_ASYM_ID': {'NULLABLE': False,
                                                                 'ORDER': 8,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': True,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                               'LABEL_COMP_ID': {'NULLABLE': False,
                                                                 'ORDER': 6,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': True,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                               'LABEL_SEQ_ID': {'NULLABLE': False,
                                                                'ORDER': 7,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'INT',
                                                                'WIDTH': 10},
                                               'MEAN_B_ALL': {'NULLABLE': True,
                                                              'ORDER': 17,
                                                              'PRECISION': 6,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'FLOAT',
                                                              'WIDTH': 10},
                                               'MEAN_B_BASE': {'NULLABLE': True,
                                                               'ORDER': 18,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                               'MEAN_B_PHOS': {'NULLABLE': True,
                                                               'ORDER': 19,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                               'MEAN_B_SUGAR': {'NULLABLE': True,
                                                                'ORDER': 20,
                                                                'PRECISION': 6,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'FLOAT',
                                                                'WIDTH': 10},
                                               'NU0': {'NULLABLE': True,
                                                       'ORDER': 21,
                                                       'PRECISION': 6,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'FLOAT',
                                                       'WIDTH': 10},
                                               'NU1': {'NULLABLE': True,
                                                       'ORDER': 22,
                                                       'PRECISION': 6,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'FLOAT',
                                                       'WIDTH': 10},
                                               'NU2': {'NULLABLE': True,
                                                       'ORDER': 23,
                                                       'PRECISION': 6,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'FLOAT',
                                                       'WIDTH': 10},
                                               'NU3': {'NULLABLE': True,
                                                       'ORDER': 24,
                                                       'PRECISION': 6,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'FLOAT',
                                                       'WIDTH': 10},
                                               'NU4': {'NULLABLE': True,
                                                       'ORDER': 25,
                                                       'PRECISION': 6,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'FLOAT',
                                                       'WIDTH': 10},
                                               'P': {'NULLABLE': True,
                                                     'ORDER': 26,
                                                     'PRECISION': 6,
                                                     'PRIMARY_KEY': False,
                                                     'SQL_TYPE': 'FLOAT',
                                                     'WIDTH': 10},
                                               'RSCC_ALL': {'NULLABLE': True,
                                                            'ORDER': 27,
                                                            'PRECISION': 6,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'FLOAT',
                                                            'WIDTH': 10},
                                               'RSCC_BASE': {'NULLABLE': True,
                                                             'ORDER': 28,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                               'RSCC_PHOS': {'NULLABLE': True,
                                                             'ORDER': 29,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                               'RSCC_SUGAR': {'NULLABLE': True,
                                                              'ORDER': 30,
                                                              'PRECISION': 6,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'FLOAT',
                                                              'WIDTH': 10},
                                               'RSR_ALL': {'NULLABLE': True,
                                                           'ORDER': 31,
                                                           'PRECISION': 6,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'FLOAT',
                                                           'WIDTH': 10},
                                               'RSR_BASE': {'NULLABLE': True,
                                                            'ORDER': 32,
                                                            'PRECISION': 6,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'FLOAT',
                                                            'WIDTH': 10},
                                               'RSR_PHOS': {'NULLABLE': True,
                                                            'ORDER': 33,
                                                            'PRECISION': 6,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'FLOAT',
                                                            'WIDTH': 10},
                                               'RSR_SUGAR': {'NULLABLE': True,
                                                             'ORDER': 34,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                               'STRUCTURE_ID': {'NULLABLE': False,
                                                                'ORDER': 1,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                               'TAU0': {'NULLABLE': True,
                                                        'ORDER': 35,
                                                        'PRECISION': 6,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'FLOAT',
                                                        'WIDTH': 10},
                                               'TAU1': {'NULLABLE': True,
                                                        'ORDER': 36,
                                                        'PRECISION': 6,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'FLOAT',
                                                        'WIDTH': 10},
                                               'TAU2': {'NULLABLE': True,
                                                        'ORDER': 37,
                                                        'PRECISION': 6,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'FLOAT',
                                                        'WIDTH': 10},
                                               'TAU3': {'NULLABLE': True,
                                                        'ORDER': 38,
                                                        'PRECISION': 6,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'FLOAT',
                                                        'WIDTH': 10},
                                               'TAU4': {'NULLABLE': True,
                                                        'ORDER': 39,
                                                        'PRECISION': 6,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'FLOAT',
                                                        'WIDTH': 10},
                                               'TAUM': {'NULLABLE': True,
                                                        'ORDER': 40,
                                                        'PRECISION': 6,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'FLOAT',
                                                        'WIDTH': 10},
                                               'ZETA': {'NULLABLE': True,
                                                        'ORDER': 41,
                                                        'PRECISION': 6,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'FLOAT',
                                                        'WIDTH': 10}},
                            'ATTRIBUTE_MAP': {'ALPHA': ('struct_mon_nucl', 'alpha', None, None),
                                              'AUTH_ASYM_ID': ('struct_mon_nucl', 'auth_asym_id', None, None),
                                              'AUTH_COMP_ID': ('struct_mon_nucl', 'auth_comp_id', None, None),
                                              'AUTH_SEQ_ID': ('struct_mon_nucl', 'auth_seq_id', None, None),
                                              'BETA': ('struct_mon_nucl', 'beta', None, None),
                                              'CHI1': ('struct_mon_nucl', 'chi1', None, None),
                                              'CHI2': ('struct_mon_nucl', 'chi2', None, None),
                                              'DELTA': ('struct_mon_nucl', 'delta', None, None),
                                              'DETAILS': ('struct_mon_nucl', 'details', None, None),
                                              'EPSILON': ('struct_mon_nucl', 'epsilon', None, None),
                                              'GAMMA': ('struct_mon_nucl', 'gamma', None, None),
                                              'LABEL_ALT_ID': ('struct_mon_nucl', 'label_alt_id', None, None),
                                              'LABEL_ASYM_ID': ('struct_mon_nucl', 'label_asym_id', None, None),
                                              'LABEL_COMP_ID': ('struct_mon_nucl', 'label_comp_id', None, None),
                                              'LABEL_SEQ_ID': ('struct_mon_nucl', 'label_seq_id', None, None),
                                              'MEAN_B_ALL': ('struct_mon_nucl', 'mean_B_all', None, None),
                                              'MEAN_B_BASE': ('struct_mon_nucl', 'mean_B_base', None, None),
                                              'MEAN_B_PHOS': ('struct_mon_nucl', 'mean_B_phos', None, None),
                                              'MEAN_B_SUGAR': ('struct_mon_nucl', 'mean_B_sugar', None, None),
                                              'NU0': ('struct_mon_nucl', 'nu0', None, None),
                                              'NU1': ('struct_mon_nucl', 'nu1', None, None),
                                              'NU2': ('struct_mon_nucl', 'nu2', None, None),
                                              'NU3': ('struct_mon_nucl', 'nu3', None, None),
                                              'NU4': ('struct_mon_nucl', 'nu4', None, None),
                                              'P': ('struct_mon_nucl', 'P', None, None),
                                              'RSCC_ALL': ('struct_mon_nucl', 'RSCC_all', None, None),
                                              'RSCC_BASE': ('struct_mon_nucl', 'RSCC_base', None, None),
                                              'RSCC_PHOS': ('struct_mon_nucl', 'RSCC_phos', None, None),
                                              'RSCC_SUGAR': ('struct_mon_nucl', 'RSCC_sugar', None, None),
                                              'RSR_ALL': ('struct_mon_nucl', 'RSR_all', None, None),
                                              'RSR_BASE': ('struct_mon_nucl', 'RSR_base', None, None),
                                              'RSR_PHOS': ('struct_mon_nucl', 'RSR_phos', None, None),
                                              'RSR_SUGAR': ('struct_mon_nucl', 'RSR_sugar', None, None),
                                              'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                              'TAU0': ('struct_mon_nucl', 'tau0', None, None),
                                              'TAU1': ('struct_mon_nucl', 'tau1', None, None),
                                              'TAU2': ('struct_mon_nucl', 'tau2', None, None),
                                              'TAU3': ('struct_mon_nucl', 'tau3', None, None),
                                              'TAU4': ('struct_mon_nucl', 'tau4', None, None),
                                              'TAUM': ('struct_mon_nucl', 'taum', None, None),
                                              'ZETA': ('struct_mon_nucl', 'zeta', None, None)},
                            'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID',
                                                              'LABEL_ALT_ID',
                                                              'LABEL_COMP_ID',
                                                              'LABEL_SEQ_ID',
                                                              'LABEL_ASYM_ID'),
                                               'TYPE': 'UNIQUE'},
                                        's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                            'MAP_MERGE_INDICES': {'struct_mon_nucl': {'ATTRIBUTES': ('label_alt_id',
                                                                                     'label_comp_id',
                                                                                     'label_seq_id',
                                                                                     'label_asym_id'),
                                                                      'TYPE': 'EQUI-JOIN'}},
                            'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                            'TABLE_ID': 'STRUCT_MON_NUCL',
                            'TABLE_NAME': 'struct_mon_nucl',
                            'TABLE_TYPE': 'transactional'},
        'STRUCT_MON_PROT': {'ATTRIBUTES': {'AUTH_ASYM_ID': 'auth_asym_id',
                                           'AUTH_COMP_ID': 'auth_comp_id',
                                           'AUTH_SEQ_ID': 'auth_seq_id',
                                           'CHI1': 'chi1',
                                           'CHI2': 'chi2',
                                           'CHI3': 'chi3',
                                           'CHI4': 'chi4',
                                           'CHI5': 'chi5',
                                           'DETAILS': 'details',
                                           'LABEL_ALT_ID': 'label_alt_id',
                                           'LABEL_ASYM_ID': 'label_asym_id',
                                           'LABEL_COMP_ID': 'label_comp_id',
                                           'LABEL_SEQ_ID': 'label_seq_id',
                                           'MEAN_B_ALL': 'mean_B_all',
                                           'MEAN_B_MAIN': 'mean_B_main',
                                           'MEAN_B_SIDE': 'mean_B_side',
                                           'OMEGA': 'omega',
                                           'PHI': 'phi',
                                           'PSI': 'psi',
                                           'RSCC_ALL': 'RSCC_all',
                                           'RSCC_MAIN': 'RSCC_main',
                                           'RSCC_SIDE': 'RSCC_side',
                                           'RSR_ALL': 'RSR_all',
                                           'RSR_MAIN': 'RSR_main',
                                           'RSR_SIDE': 'RSR_side',
                                           'STRUCTURE_ID': 'Structure_ID'},
                            'ATTRIBUTE_INFO': {'AUTH_ASYM_ID': {'NULLABLE': True,
                                                                'ORDER': 2,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                               'AUTH_COMP_ID': {'NULLABLE': True,
                                                                'ORDER': 3,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                               'AUTH_SEQ_ID': {'NULLABLE': True,
                                                               'ORDER': 4,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                               'CHI1': {'NULLABLE': True,
                                                        'ORDER': 9,
                                                        'PRECISION': 6,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'FLOAT',
                                                        'WIDTH': 10},
                                               'CHI2': {'NULLABLE': True,
                                                        'ORDER': 10,
                                                        'PRECISION': 6,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'FLOAT',
                                                        'WIDTH': 10},
                                               'CHI3': {'NULLABLE': True,
                                                        'ORDER': 11,
                                                        'PRECISION': 6,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'FLOAT',
                                                        'WIDTH': 10},
                                               'CHI4': {'NULLABLE': True,
                                                        'ORDER': 12,
                                                        'PRECISION': 6,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'FLOAT',
                                                        'WIDTH': 10},
                                               'CHI5': {'NULLABLE': True,
                                                        'ORDER': 13,
                                                        'PRECISION': 6,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'FLOAT',
                                                        'WIDTH': 10},
                                               'DETAILS': {'NULLABLE': True,
                                                           'ORDER': 14,
                                                           'PRECISION': 6,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'FLOAT',
                                                           'WIDTH': 10},
                                               'LABEL_ALT_ID': {'NULLABLE': False,
                                                                'ORDER': 5,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                               'LABEL_ASYM_ID': {'NULLABLE': False,
                                                                 'ORDER': 8,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': True,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                               'LABEL_COMP_ID': {'NULLABLE': False,
                                                                 'ORDER': 6,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': True,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                               'LABEL_SEQ_ID': {'NULLABLE': False,
                                                                'ORDER': 7,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'INT',
                                                                'WIDTH': 10},
                                               'MEAN_B_ALL': {'NULLABLE': True,
                                                              'ORDER': 21,
                                                              'PRECISION': 6,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'FLOAT',
                                                              'WIDTH': 10},
                                               'MEAN_B_MAIN': {'NULLABLE': True,
                                                               'ORDER': 22,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                               'MEAN_B_SIDE': {'NULLABLE': True,
                                                               'ORDER': 23,
                                                               'PRECISION': 6,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'FLOAT',
                                                               'WIDTH': 10},
                                               'OMEGA': {'NULLABLE': True,
                                                         'ORDER': 24,
                                                         'PRECISION': 6,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'FLOAT',
                                                         'WIDTH': 10},
                                               'PHI': {'NULLABLE': True,
                                                       'ORDER': 25,
                                                       'PRECISION': 6,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'FLOAT',
                                                       'WIDTH': 10},
                                               'PSI': {'NULLABLE': True,
                                                       'ORDER': 26,
                                                       'PRECISION': 6,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'FLOAT',
                                                       'WIDTH': 10},
                                               'RSCC_ALL': {'NULLABLE': True,
                                                            'ORDER': 15,
                                                            'PRECISION': 6,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'FLOAT',
                                                            'WIDTH': 10},
                                               'RSCC_MAIN': {'NULLABLE': True,
                                                             'ORDER': 16,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                               'RSCC_SIDE': {'NULLABLE': True,
                                                             'ORDER': 17,
                                                             'PRECISION': 6,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'FLOAT',
                                                             'WIDTH': 10},
                                               'RSR_ALL': {'NULLABLE': True,
                                                           'ORDER': 18,
                                                           'PRECISION': 6,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'FLOAT',
                                                           'WIDTH': 10},
                                               'RSR_MAIN': {'NULLABLE': True,
                                                            'ORDER': 19,
                                                            'PRECISION': 6,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'FLOAT',
                                                            'WIDTH': 10},
                                               'RSR_SIDE': {'NULLABLE': True,
                                                            'ORDER': 20,
                                                            'PRECISION': 6,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'FLOAT',
                                                            'WIDTH': 10},
                                               'STRUCTURE_ID': {'NULLABLE': False,
                                                                'ORDER': 1,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10}},
                            'ATTRIBUTE_MAP': {'AUTH_ASYM_ID': ('struct_mon_prot', 'auth_asym_id', None, None),
                                              'AUTH_COMP_ID': ('struct_mon_prot', 'auth_comp_id', None, None),
                                              'AUTH_SEQ_ID': ('struct_mon_prot', 'auth_seq_id', None, None),
                                              'CHI1': ('struct_mon_prot', 'chi1', None, None),
                                              'CHI2': ('struct_mon_prot', 'chi2', None, None),
                                              'CHI3': ('struct_mon_prot', 'chi3', None, None),
                                              'CHI4': ('struct_mon_prot', 'chi4', None, None),
                                              'CHI5': ('struct_mon_prot', 'chi5', None, None),
                                              'DETAILS': ('struct_mon_prot', 'details', None, None),
                                              'LABEL_ALT_ID': ('struct_mon_prot', 'label_alt_id', None, None),
                                              'LABEL_ASYM_ID': ('struct_mon_prot', 'label_asym_id', None, None),
                                              'LABEL_COMP_ID': ('struct_mon_prot', 'label_comp_id', None, None),
                                              'LABEL_SEQ_ID': ('struct_mon_prot', 'label_seq_id', None, None),
                                              'MEAN_B_ALL': ('struct_mon_prot', 'mean_B_all', None, None),
                                              'MEAN_B_MAIN': ('struct_mon_prot', 'mean_B_main', None, None),
                                              'MEAN_B_SIDE': ('struct_mon_prot', 'mean_B_side', None, None),
                                              'OMEGA': ('struct_mon_prot', 'omega', None, None),
                                              'PHI': ('struct_mon_prot', 'phi', None, None),
                                              'PSI': ('struct_mon_prot', 'psi', None, None),
                                              'RSCC_ALL': ('struct_mon_prot', 'RSCC_all', None, None),
                                              'RSCC_MAIN': ('struct_mon_prot', 'RSCC_main', None, None),
                                              'RSCC_SIDE': ('struct_mon_prot', 'RSCC_side', None, None),
                                              'RSR_ALL': ('struct_mon_prot', 'RSR_all', None, None),
                                              'RSR_MAIN': ('struct_mon_prot', 'RSR_main', None, None),
                                              'RSR_SIDE': ('struct_mon_prot', 'RSR_side', None, None),
                                              'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                            'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID',
                                                              'LABEL_ALT_ID',
                                                              'LABEL_COMP_ID',
                                                              'LABEL_SEQ_ID',
                                                              'LABEL_ASYM_ID'),
                                               'TYPE': 'UNIQUE'},
                                        's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                            'MAP_MERGE_INDICES': {'struct_mon_prot': {'ATTRIBUTES': ('label_alt_id',
                                                                                     'label_comp_id',
                                                                                     'label_seq_id',
                                                                                     'label_asym_id'),
                                                                      'TYPE': 'EQUI-JOIN'}},
                            'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                            'TABLE_ID': 'STRUCT_MON_PROT',
                            'TABLE_NAME': 'struct_mon_prot',
                            'TABLE_TYPE': 'transactional'},
        'STRUCT_MON_PROT_CIS': {'ATTRIBUTES': {'AUTH_ASYM_ID': 'auth_asym_id',
                                               'AUTH_COMP_ID': 'auth_comp_id',
                                               'AUTH_SEQ_ID': 'auth_seq_id',
                                               'LABEL_ALT_ID': 'label_alt_id',
                                               'LABEL_ASYM_ID': 'label_asym_id',
                                               'LABEL_COMP_ID': 'label_comp_id',
                                               'LABEL_SEQ_ID': 'label_seq_id',
                                               'PDBX_AUTH_ASYM_ID_2': 'pdbx_auth_asym_id_2',
                                               'PDBX_AUTH_COMP_ID_2': 'pdbx_auth_comp_id_2',
                                               'PDBX_AUTH_SEQ_ID_2': 'pdbx_auth_seq_id_2',
                                               'PDBX_ID': 'pdbx_id',
                                               'PDBX_LABEL_ASYM_ID_2': 'pdbx_label_asym_id_2',
                                               'PDBX_LABEL_COMP_ID_2': 'pdbx_label_comp_id_2',
                                               'PDBX_LABEL_SEQ_ID_2': 'pdbx_label_seq_id_2',
                                               'PDBX_OMEGA_ANGLE': 'pdbx_omega_angle',
                                               'PDBX_PDB_INS_CODE': 'pdbx_PDB_ins_code',
                                               'PDBX_PDB_INS_CODE_2': 'pdbx_PDB_ins_code_2',
                                               'PDBX_PDB_MODEL_NUM': 'pdbx_PDB_model_num',
                                               'STRUCTURE_ID': 'Structure_ID'},
                                'ATTRIBUTE_INFO': {'AUTH_ASYM_ID': {'NULLABLE': True,
                                                                    'ORDER': 2,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10},
                                                   'AUTH_COMP_ID': {'NULLABLE': True,
                                                                    'ORDER': 3,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10},
                                                   'AUTH_SEQ_ID': {'NULLABLE': True,
                                                                   'ORDER': 4,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 10},
                                                   'LABEL_ALT_ID': {'NULLABLE': True,
                                                                    'ORDER': 5,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10},
                                                   'LABEL_ASYM_ID': {'NULLABLE': True,
                                                                     'ORDER': 8,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                                   'LABEL_COMP_ID': {'NULLABLE': True,
                                                                     'ORDER': 6,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': False,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                                   'LABEL_SEQ_ID': {'NULLABLE': True,
                                                                    'ORDER': 7,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'INT',
                                                                    'WIDTH': 10},
                                                   'PDBX_AUTH_ASYM_ID_2': {'NULLABLE': True,
                                                                           'ORDER': 9,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10},
                                                   'PDBX_AUTH_COMP_ID_2': {'NULLABLE': True,
                                                                           'ORDER': 10,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10},
                                                   'PDBX_AUTH_SEQ_ID_2': {'NULLABLE': True,
                                                                          'ORDER': 11,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                   'PDBX_ID': {'NULLABLE': False,
                                                               'ORDER': 19,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                                   'PDBX_LABEL_ASYM_ID_2': {'NULLABLE': True,
                                                                            'ORDER': 12,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 10},
                                                   'PDBX_LABEL_COMP_ID_2': {'NULLABLE': True,
                                                                            'ORDER': 13,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 10},
                                                   'PDBX_LABEL_SEQ_ID_2': {'NULLABLE': True,
                                                                           'ORDER': 14,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'INT',
                                                                           'WIDTH': 10},
                                                   'PDBX_OMEGA_ANGLE': {'NULLABLE': True,
                                                                        'ORDER': 18,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                                   'PDBX_PDB_INS_CODE': {'NULLABLE': True,
                                                                         'ORDER': 15,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                                   'PDBX_PDB_INS_CODE_2': {'NULLABLE': True,
                                                                           'ORDER': 16,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 10},
                                                   'PDBX_PDB_MODEL_NUM': {'NULLABLE': True,
                                                                          'ORDER': 17,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'INT',
                                                                          'WIDTH': 10},
                                                   'STRUCTURE_ID': {'NULLABLE': False,
                                                                    'ORDER': 1,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': True,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10}},
                                'ATTRIBUTE_MAP': {'AUTH_ASYM_ID': ('struct_mon_prot_cis', 'auth_asym_id', None, None),
                                                  'AUTH_COMP_ID': ('struct_mon_prot_cis', 'auth_comp_id', None, None),
                                                  'AUTH_SEQ_ID': ('struct_mon_prot_cis', 'auth_seq_id', None, None),
                                                  'LABEL_ALT_ID': ('struct_mon_prot_cis', 'label_alt_id', None, None),
                                                  'LABEL_ASYM_ID': ('struct_mon_prot_cis', 'label_asym_id', None, None),
                                                  'LABEL_COMP_ID': ('struct_mon_prot_cis', 'label_comp_id', None, None),
                                                  'LABEL_SEQ_ID': ('struct_mon_prot_cis', 'label_seq_id', None, None),
                                                  'PDBX_AUTH_ASYM_ID_2': ('struct_mon_prot_cis',
                                                                          'pdbx_auth_asym_id_2',
                                                                          None,
                                                                          None),
                                                  'PDBX_AUTH_COMP_ID_2': ('struct_mon_prot_cis',
                                                                          'pdbx_auth_comp_id_2',
                                                                          None,
                                                                          None),
                                                  'PDBX_AUTH_SEQ_ID_2': ('struct_mon_prot_cis',
                                                                         'pdbx_auth_seq_id_2',
                                                                         None,
                                                                         None),
                                                  'PDBX_ID': ('struct_mon_prot_cis', 'pdbx_id', None, None),
                                                  'PDBX_LABEL_ASYM_ID_2': ('struct_mon_prot_cis',
                                                                           'pdbx_label_asym_id_2',
                                                                           None,
                                                                           None),
                                                  'PDBX_LABEL_COMP_ID_2': ('struct_mon_prot_cis',
                                                                           'pdbx_label_comp_id_2',
                                                                           None,
                                                                           None),
                                                  'PDBX_LABEL_SEQ_ID_2': ('struct_mon_prot_cis',
                                                                          'pdbx_label_seq_id_2',
                                                                          None,
                                                                          None),
                                                  'PDBX_OMEGA_ANGLE': ('struct_mon_prot_cis', 'pdbx_omega_angle', None, None),
                                                  'PDBX_PDB_INS_CODE': ('struct_mon_prot_cis',
                                                                        'pdbx_PDB_ins_code',
                                                                        None,
                                                                        None),
                                                  'PDBX_PDB_INS_CODE_2': ('struct_mon_prot_cis',
                                                                          'pdbx_PDB_ins_code_2',
                                                                          None,
                                                                          None),
                                                  'PDBX_PDB_MODEL_NUM': ('struct_mon_prot_cis',
                                                                         'pdbx_PDB_model_num',
                                                                         None,
                                                                         None),
                                                  'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'PDBX_ID'), 'TYPE': 'UNIQUE'},
                                            's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                'MAP_MERGE_INDICES': {'struct_mon_prot_cis': {'ATTRIBUTES': ('pdbx_id',),
                                                                              'TYPE': 'EQUI-JOIN'}},
                                'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                'TABLE_ID': 'STRUCT_MON_PROT_CIS',
                                'TABLE_NAME': 'struct_mon_prot_cis',
                                'TABLE_TYPE': 'transactional'},
        'STRUCT_NCS_DOM': {'ATTRIBUTES': {'DETAILS': 'details',
                                          'ID': 'id',
                                          'PDBX_ENS_ID': 'pdbx_ens_id',
                                          'STRUCTURE_ID': 'Structure_ID'},
                           'ATTRIBUTE_INFO': {'DETAILS': {'NULLABLE': True,
                                                          'ORDER': 2,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 511},
                                              'ID': {'NULLABLE': False,
                                                     'ORDER': 3,
                                                     'PRECISION': 0,
                                                     'PRIMARY_KEY': True,
                                                     'SQL_TYPE': 'VARCHAR',
                                                     'WIDTH': 10},
                                              'PDBX_ENS_ID': {'NULLABLE': False,
                                                              'ORDER': 4,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10},
                                              'STRUCTURE_ID': {'NULLABLE': False,
                                                               'ORDER': 1,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10}},
                           'ATTRIBUTE_MAP': {'DETAILS': ('struct_ncs_dom', 'details', None, None),
                                             'ID': ('struct_ncs_dom', 'id', None, None),
                                             'PDBX_ENS_ID': ('struct_ncs_dom', 'pdbx_ens_id', None, None),
                                             'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                           'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID', 'PDBX_ENS_ID'), 'TYPE': 'UNIQUE'},
                                       's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                           'MAP_MERGE_INDICES': {'struct_ncs_dom': {'ATTRIBUTES': ('id', 'pdbx_ens_id'), 'TYPE': 'EQUI-JOIN'}},
                           'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                           'TABLE_ID': 'STRUCT_NCS_DOM',
                           'TABLE_NAME': 'struct_ncs_dom',
                           'TABLE_TYPE': 'transactional'},
        'STRUCT_NCS_DOM_LIM': {'ATTRIBUTES': {'BEG_AUTH_ASYM_ID': 'beg_auth_asym_id',
                                              'BEG_AUTH_COMP_ID': 'beg_auth_comp_id',
                                              'BEG_AUTH_SEQ_ID': 'beg_auth_seq_id',
                                              'BEG_LABEL_ALT_ID': 'beg_label_alt_id',
                                              'BEG_LABEL_ASYM_ID': 'beg_label_asym_id',
                                              'BEG_LABEL_COMP_ID': 'beg_label_comp_id',
                                              'BEG_LABEL_SEQ_ID': 'beg_label_seq_id',
                                              'DOM_ID': 'dom_id',
                                              'END_AUTH_ASYM_ID': 'end_auth_asym_id',
                                              'END_AUTH_COMP_ID': 'end_auth_comp_id',
                                              'END_AUTH_SEQ_ID': 'end_auth_seq_id',
                                              'END_LABEL_ALT_ID': 'end_label_alt_id',
                                              'END_LABEL_ASYM_ID': 'end_label_asym_id',
                                              'END_LABEL_COMP_ID': 'end_label_comp_id',
                                              'END_LABEL_SEQ_ID': 'end_label_seq_id',
                                              'PDBX_COMPONENT_ID': 'pdbx_component_id',
                                              'PDBX_ENS_ID': 'pdbx_ens_id',
                                              'PDBX_REFINE_CODE': 'pdbx_refine_code',
                                              'SELECTION_DETAILS': 'selection_details',
                                              'STRUCTURE_ID': 'Structure_ID'},
                               'ATTRIBUTE_INFO': {'BEG_AUTH_ASYM_ID': {'NULLABLE': True,
                                                                       'ORDER': 7,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                  'BEG_AUTH_COMP_ID': {'NULLABLE': True,
                                                                       'ORDER': 8,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                  'BEG_AUTH_SEQ_ID': {'NULLABLE': True,
                                                                      'ORDER': 9,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                                  'BEG_LABEL_ALT_ID': {'NULLABLE': True,
                                                                       'ORDER': 3,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                  'BEG_LABEL_ASYM_ID': {'NULLABLE': True,
                                                                        'ORDER': 4,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                                  'BEG_LABEL_COMP_ID': {'NULLABLE': True,
                                                                        'ORDER': 5,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                                  'BEG_LABEL_SEQ_ID': {'NULLABLE': True,
                                                                       'ORDER': 6,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'INT',
                                                                       'WIDTH': 10},
                                                  'DOM_ID': {'NULLABLE': False,
                                                             'ORDER': 2,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 10},
                                                  'END_AUTH_ASYM_ID': {'NULLABLE': True,
                                                                       'ORDER': 14,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                  'END_AUTH_COMP_ID': {'NULLABLE': True,
                                                                       'ORDER': 15,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                  'END_AUTH_SEQ_ID': {'NULLABLE': True,
                                                                      'ORDER': 16,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                                  'END_LABEL_ALT_ID': {'NULLABLE': True,
                                                                       'ORDER': 10,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                  'END_LABEL_ASYM_ID': {'NULLABLE': True,
                                                                        'ORDER': 11,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                                  'END_LABEL_COMP_ID': {'NULLABLE': True,
                                                                        'ORDER': 12,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                                  'END_LABEL_SEQ_ID': {'NULLABLE': True,
                                                                       'ORDER': 13,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'INT',
                                                                       'WIDTH': 10},
                                                  'PDBX_COMPONENT_ID': {'NULLABLE': False,
                                                                        'ORDER': 18,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': True,
                                                                        'SQL_TYPE': 'INT',
                                                                        'WIDTH': 10},
                                                  'PDBX_ENS_ID': {'NULLABLE': False,
                                                                  'ORDER': 20,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': True,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10},
                                                  'PDBX_REFINE_CODE': {'NULLABLE': True,
                                                                       'ORDER': 19,
                                                                       'PRECISION': 6,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'FLOAT',
                                                                       'WIDTH': 10},
                                                  'SELECTION_DETAILS': {'NULLABLE': True,
                                                                        'ORDER': 17,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 1023},
                                                  'STRUCTURE_ID': {'NULLABLE': False,
                                                                   'ORDER': 1,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': True,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 10}},
                               'ATTRIBUTE_MAP': {'BEG_AUTH_ASYM_ID': ('struct_ncs_dom_lim', 'beg_auth_asym_id', None, None),
                                                 'BEG_AUTH_COMP_ID': ('struct_ncs_dom_lim', 'beg_auth_comp_id', None, None),
                                                 'BEG_AUTH_SEQ_ID': ('struct_ncs_dom_lim', 'beg_auth_seq_id', None, None),
                                                 'BEG_LABEL_ALT_ID': ('struct_ncs_dom_lim', 'beg_label_alt_id', None, None),
                                                 'BEG_LABEL_ASYM_ID': ('struct_ncs_dom_lim', 'beg_label_asym_id', None, None),
                                                 'BEG_LABEL_COMP_ID': ('struct_ncs_dom_lim', 'beg_label_comp_id', None, None),
                                                 'BEG_LABEL_SEQ_ID': ('struct_ncs_dom_lim', 'beg_label_seq_id', None, None),
                                                 'DOM_ID': ('struct_ncs_dom_lim', 'dom_id', None, None),
                                                 'END_AUTH_ASYM_ID': ('struct_ncs_dom_lim', 'end_auth_asym_id', None, None),
                                                 'END_AUTH_COMP_ID': ('struct_ncs_dom_lim', 'end_auth_comp_id', None, None),
                                                 'END_AUTH_SEQ_ID': ('struct_ncs_dom_lim', 'end_auth_seq_id', None, None),
                                                 'END_LABEL_ALT_ID': ('struct_ncs_dom_lim', 'end_label_alt_id', None, None),
                                                 'END_LABEL_ASYM_ID': ('struct_ncs_dom_lim', 'end_label_asym_id', None, None),
                                                 'END_LABEL_COMP_ID': ('struct_ncs_dom_lim', 'end_label_comp_id', None, None),
                                                 'END_LABEL_SEQ_ID': ('struct_ncs_dom_lim', 'end_label_seq_id', None, None),
                                                 'PDBX_COMPONENT_ID': ('struct_ncs_dom_lim', 'pdbx_component_id', None, None),
                                                 'PDBX_ENS_ID': ('struct_ncs_dom_lim', 'pdbx_ens_id', None, None),
                                                 'PDBX_REFINE_CODE': ('struct_ncs_dom_lim', 'pdbx_refine_code', None, None),
                                                 'SELECTION_DETAILS': ('struct_ncs_dom_lim', 'selection_details', None, None),
                                                 'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                               'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'DOM_ID', 'PDBX_COMPONENT_ID', 'PDBX_ENS_ID'),
                                                  'TYPE': 'UNIQUE'},
                                           's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                               'MAP_MERGE_INDICES': {'struct_ncs_dom_lim': {'ATTRIBUTES': ('dom_id',
                                                                                           'pdbx_component_id',
                                                                                           'pdbx_ens_id'),
                                                                            'TYPE': 'EQUI-JOIN'}},
                               'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                               'TABLE_ID': 'STRUCT_NCS_DOM_LIM',
                               'TABLE_NAME': 'struct_ncs_dom_lim',
                               'TABLE_TYPE': 'transactional'},
        'STRUCT_NCS_ENS': {'ATTRIBUTES': {'DETAILS': 'details',
                                          'ID': 'id',
                                          'POINT_GROUP': 'point_group',
                                          'STRUCTURE_ID': 'Structure_ID'},
                           'ATTRIBUTE_INFO': {'DETAILS': {'NULLABLE': True,
                                                          'ORDER': 2,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 200},
                                              'ID': {'NULLABLE': False,
                                                     'ORDER': 3,
                                                     'PRECISION': 0,
                                                     'PRIMARY_KEY': True,
                                                     'SQL_TYPE': 'VARCHAR',
                                                     'WIDTH': 10},
                                              'POINT_GROUP': {'NULLABLE': True,
                                                              'ORDER': 4,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 80},
                                              'STRUCTURE_ID': {'NULLABLE': False,
                                                               'ORDER': 1,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10}},
                           'ATTRIBUTE_MAP': {'DETAILS': ('struct_ncs_ens', 'details', None, None),
                                             'ID': ('struct_ncs_ens', 'id', None, None),
                                             'POINT_GROUP': ('struct_ncs_ens', 'point_group', None, None),
                                             'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                           'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                       's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                           'MAP_MERGE_INDICES': {'struct_ncs_ens': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                           'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                           'TABLE_ID': 'STRUCT_NCS_ENS',
                           'TABLE_NAME': 'struct_ncs_ens',
                           'TABLE_TYPE': 'transactional'},
        'STRUCT_NCS_ENS_GEN': {'ATTRIBUTES': {'DOM_ID_1': 'dom_id_1',
                                              'DOM_ID_2': 'dom_id_2',
                                              'ENS_ID': 'ens_id',
                                              'OPER_ID': 'oper_id',
                                              'STRUCTURE_ID': 'Structure_ID'},
                               'ATTRIBUTE_INFO': {'DOM_ID_1': {'NULLABLE': False,
                                                               'ORDER': 2,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                                  'DOM_ID_2': {'NULLABLE': False,
                                                               'ORDER': 3,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                                  'ENS_ID': {'NULLABLE': False,
                                                             'ORDER': 4,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 10},
                                                  'OPER_ID': {'NULLABLE': False,
                                                              'ORDER': 5,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10},
                                                  'STRUCTURE_ID': {'NULLABLE': False,
                                                                   'ORDER': 1,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': True,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 10}},
                               'ATTRIBUTE_MAP': {'DOM_ID_1': ('struct_ncs_ens_gen', 'dom_id_1', None, None),
                                                 'DOM_ID_2': ('struct_ncs_ens_gen', 'dom_id_2', None, None),
                                                 'ENS_ID': ('struct_ncs_ens_gen', 'ens_id', None, None),
                                                 'OPER_ID': ('struct_ncs_ens_gen', 'oper_id', None, None),
                                                 'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                               'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'DOM_ID_1', 'DOM_ID_2', 'ENS_ID', 'OPER_ID'),
                                                  'TYPE': 'UNIQUE'},
                                           's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                               'MAP_MERGE_INDICES': {'struct_ncs_ens_gen': {'ATTRIBUTES': ('dom_id_1',
                                                                                           'dom_id_2',
                                                                                           'ens_id',
                                                                                           'oper_id'),
                                                                            'TYPE': 'EQUI-JOIN'}},
                               'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                               'TABLE_ID': 'STRUCT_NCS_ENS_GEN',
                               'TABLE_NAME': 'struct_ncs_ens_gen',
                               'TABLE_TYPE': 'transactional'},
        'STRUCT_NCS_OPER': {'ATTRIBUTES': {'CODE': 'code',
                                           'DETAILS': 'details',
                                           'ID': 'id',
                                           'MATRIX_1_1': 'matrix_1_1',
                                           'MATRIX_1_2': 'matrix_1_2',
                                           'MATRIX_1_3': 'matrix_1_3',
                                           'MATRIX_2_1': 'matrix_2_1',
                                           'MATRIX_2_2': 'matrix_2_2',
                                           'MATRIX_2_3': 'matrix_2_3',
                                           'MATRIX_3_1': 'matrix_3_1',
                                           'MATRIX_3_2': 'matrix_3_2',
                                           'MATRIX_3_3': 'matrix_3_3',
                                           'STRUCTURE_ID': 'Structure_ID',
                                           'VECTOR_1': 'vector_1',
                                           'VECTOR_2': 'vector_2',
                                           'VECTOR_3': 'vector_3'},
                            'ATTRIBUTE_INFO': {'CODE': {'NULLABLE': True,
                                                        'ORDER': 2,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 10},
                                               'DETAILS': {'NULLABLE': True,
                                                           'ORDER': 3,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 200},
                                               'ID': {'NULLABLE': False,
                                                      'ORDER': 4,
                                                      'PRECISION': 0,
                                                      'PRIMARY_KEY': True,
                                                      'SQL_TYPE': 'VARCHAR',
                                                      'WIDTH': 10},
                                               'MATRIX_1_1': {'NULLABLE': True,
                                                              'ORDER': 5,
                                                              'PRECISION': 6,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'FLOAT',
                                                              'WIDTH': 10},
                                               'MATRIX_1_2': {'NULLABLE': True,
                                                              'ORDER': 6,
                                                              'PRECISION': 6,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'FLOAT',
                                                              'WIDTH': 10},
                                               'MATRIX_1_3': {'NULLABLE': True,
                                                              'ORDER': 7,
                                                              'PRECISION': 6,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'FLOAT',
                                                              'WIDTH': 10},
                                               'MATRIX_2_1': {'NULLABLE': True,
                                                              'ORDER': 8,
                                                              'PRECISION': 6,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'FLOAT',
                                                              'WIDTH': 10},
                                               'MATRIX_2_2': {'NULLABLE': True,
                                                              'ORDER': 9,
                                                              'PRECISION': 6,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'FLOAT',
                                                              'WIDTH': 10},
                                               'MATRIX_2_3': {'NULLABLE': True,
                                                              'ORDER': 10,
                                                              'PRECISION': 6,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'FLOAT',
                                                              'WIDTH': 10},
                                               'MATRIX_3_1': {'NULLABLE': True,
                                                              'ORDER': 11,
                                                              'PRECISION': 6,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'FLOAT',
                                                              'WIDTH': 10},
                                               'MATRIX_3_2': {'NULLABLE': True,
                                                              'ORDER': 12,
                                                              'PRECISION': 6,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'FLOAT',
                                                              'WIDTH': 10},
                                               'MATRIX_3_3': {'NULLABLE': True,
                                                              'ORDER': 13,
                                                              'PRECISION': 6,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'FLOAT',
                                                              'WIDTH': 10},
                                               'STRUCTURE_ID': {'NULLABLE': False,
                                                                'ORDER': 1,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                               'VECTOR_1': {'NULLABLE': True,
                                                            'ORDER': 14,
                                                            'PRECISION': 6,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'FLOAT',
                                                            'WIDTH': 10},
                                               'VECTOR_2': {'NULLABLE': True,
                                                            'ORDER': 15,
                                                            'PRECISION': 6,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'FLOAT',
                                                            'WIDTH': 10},
                                               'VECTOR_3': {'NULLABLE': True,
                                                            'ORDER': 16,
                                                            'PRECISION': 6,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'FLOAT',
                                                            'WIDTH': 10}},
                            'ATTRIBUTE_MAP': {'CODE': ('struct_ncs_oper', 'code', None, None),
                                              'DETAILS': ('struct_ncs_oper', 'details', None, None),
                                              'ID': ('struct_ncs_oper', 'id', None, None),
                                              'MATRIX_1_1': ('struct_ncs_oper', 'matrix[1][1]', None, None),
                                              'MATRIX_1_2': ('struct_ncs_oper', 'matrix[1][2]', None, None),
                                              'MATRIX_1_3': ('struct_ncs_oper', 'matrix[1][3]', None, None),
                                              'MATRIX_2_1': ('struct_ncs_oper', 'matrix[2][1]', None, None),
                                              'MATRIX_2_2': ('struct_ncs_oper', 'matrix[2][2]', None, None),
                                              'MATRIX_2_3': ('struct_ncs_oper', 'matrix[2][3]', None, None),
                                              'MATRIX_3_1': ('struct_ncs_oper', 'matrix[3][1]', None, None),
                                              'MATRIX_3_2': ('struct_ncs_oper', 'matrix[3][2]', None, None),
                                              'MATRIX_3_3': ('struct_ncs_oper', 'matrix[3][3]', None, None),
                                              'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                              'VECTOR_1': ('struct_ncs_oper', 'vector[1]', None, None),
                                              'VECTOR_2': ('struct_ncs_oper', 'vector[2]', None, None),
                                              'VECTOR_3': ('struct_ncs_oper', 'vector[3]', None, None)},
                            'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                        's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                            'MAP_MERGE_INDICES': {'struct_ncs_oper': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                            'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                            'TABLE_ID': 'STRUCT_NCS_OPER',
                            'TABLE_NAME': 'struct_ncs_oper',
                            'TABLE_TYPE': 'transactional'},
        'STRUCT_REF': {'ATTRIBUTES': {'BIOL_ID': 'biol_id',
                                      'DB_CODE': 'db_code',
                                      'DB_NAME': 'db_name',
                                      'DETAILS': 'details',
                                      'ENTITY_ID': 'entity_id',
                                      'ID': 'id',
                                      'PDBX_ALIGN_BEGIN': 'pdbx_align_begin',
                                      'PDBX_DB_ACCESSION': 'pdbx_db_accession',
                                      'PDBX_SEQ_ONE_LETTER_CODE': 'pdbx_seq_one_letter_code',
                                      'SEQ_ALIGN': 'seq_align',
                                      'SEQ_DIF': 'seq_dif',
                                      'STRUCTURE_ID': 'Structure_ID'},
                       'ATTRIBUTE_INFO': {'BIOL_ID': {'NULLABLE': True,
                                                      'ORDER': 3,
                                                      'PRECISION': 0,
                                                      'PRIMARY_KEY': False,
                                                      'SQL_TYPE': 'VARCHAR',
                                                      'WIDTH': 80},
                                          'DB_CODE': {'NULLABLE': True,
                                                      'ORDER': 4,
                                                      'PRECISION': 0,
                                                      'PRIMARY_KEY': False,
                                                      'SQL_TYPE': 'VARCHAR',
                                                      'WIDTH': 80},
                                          'DB_NAME': {'NULLABLE': True,
                                                      'ORDER': 5,
                                                      'PRECISION': 0,
                                                      'PRIMARY_KEY': False,
                                                      'SQL_TYPE': 'VARCHAR',
                                                      'WIDTH': 80},
                                          'DETAILS': {'NULLABLE': True,
                                                      'ORDER': 6,
                                                      'PRECISION': 0,
                                                      'PRIMARY_KEY': False,
                                                      'SQL_TYPE': 'VARCHAR',
                                                      'WIDTH': 200},
                                          'ENTITY_ID': {'NULLABLE': True,
                                                        'ORDER': 2,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 10},
                                          'ID': {'NULLABLE': False,
                                                 'ORDER': 7,
                                                 'PRECISION': 0,
                                                 'PRIMARY_KEY': True,
                                                 'SQL_TYPE': 'VARCHAR',
                                                 'WIDTH': 10},
                                          'PDBX_ALIGN_BEGIN': {'NULLABLE': True,
                                                               'ORDER': 12,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 13},
                                          'PDBX_DB_ACCESSION': {'NULLABLE': True,
                                                                'ORDER': 10,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 13},
                                          'PDBX_SEQ_ONE_LETTER_CODE': {'NULLABLE': True,
                                                                       'ORDER': 11,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 32000},
                                          'SEQ_ALIGN': {'NULLABLE': True,
                                                        'ORDER': 8,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 10},
                                          'SEQ_DIF': {'NULLABLE': True,
                                                      'ORDER': 9,
                                                      'PRECISION': 0,
                                                      'PRIMARY_KEY': False,
                                                      'SQL_TYPE': 'VARCHAR',
                                                      'WIDTH': 10},
                                          'STRUCTURE_ID': {'NULLABLE': False,
                                                           'ORDER': 1,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': True,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 10}},
                       'ATTRIBUTE_MAP': {'BIOL_ID': ('struct_ref', 'biol_id', None, None),
                                         'DB_CODE': ('struct_ref', 'db_code', None, None),
                                         'DB_NAME': ('struct_ref', 'db_name', None, None),
                                         'DETAILS': ('struct_ref', 'details', None, None),
                                         'ENTITY_ID': ('struct_ref', 'entity_id', None, None),
                                         'ID': ('struct_ref', 'id', None, None),
                                         'PDBX_ALIGN_BEGIN': ('struct_ref', 'pdbx_align_begin', None, None),
                                         'PDBX_DB_ACCESSION': ('struct_ref', 'pdbx_db_accession', None, None),
                                         'PDBX_SEQ_ONE_LETTER_CODE': ('struct_ref', 'pdbx_seq_one_letter_code', None, None),
                                         'SEQ_ALIGN': ('struct_ref', 'seq_align', None, None),
                                         'SEQ_DIF': ('struct_ref', 'seq_dif', None, None),
                                         'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                       'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                   's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                       'MAP_MERGE_INDICES': {'struct_ref': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                       'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                       'TABLE_ID': 'STRUCT_REF',
                       'TABLE_NAME': 'struct_ref',
                       'TABLE_TYPE': 'transactional'},
        'STRUCT_REF_SEQ': {'ATTRIBUTES': {'ALIGN_ID': 'align_id',
                                          'DB_ALIGN_BEG': 'db_align_beg',
                                          'DB_ALIGN_END': 'db_align_end',
                                          'DETAILS': 'details',
                                          'PDBX_AUTH_SEQ_ALIGN_BEG': 'pdbx_auth_seq_align_beg',
                                          'PDBX_AUTH_SEQ_ALIGN_END': 'pdbx_auth_seq_align_end',
                                          'PDBX_DB_ACCESSION': 'pdbx_db_accession',
                                          'PDBX_DB_ALIGN_BEG_INS_CODE': 'pdbx_db_align_beg_ins_code',
                                          'PDBX_DB_ALIGN_END_INS_CODE': 'pdbx_db_align_end_ins_code',
                                          'PDBX_PDB_ID_CODE': 'pdbx_PDB_id_code',
                                          'PDBX_SEQ_ALIGN_BEG_INS_CODE': 'pdbx_seq_align_beg_ins_code',
                                          'PDBX_SEQ_ALIGN_END_INS_CODE': 'pdbx_seq_align_end_ins_code',
                                          'PDBX_STRAND_ID': 'pdbx_strand_id',
                                          'REF_ID': 'ref_id',
                                          'SEQ_ALIGN_BEG': 'seq_align_beg',
                                          'SEQ_ALIGN_END': 'seq_align_end',
                                          'STRUCTURE_ID': 'Structure_ID'},
                           'ATTRIBUTE_INFO': {'ALIGN_ID': {'NULLABLE': False,
                                                           'ORDER': 5,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': True,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 10},
                                              'DB_ALIGN_BEG': {'NULLABLE': True,
                                                               'ORDER': 6,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'INT',
                                                               'WIDTH': 10},
                                              'DB_ALIGN_END': {'NULLABLE': True,
                                                               'ORDER': 7,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'INT',
                                                               'WIDTH': 10},
                                              'DETAILS': {'NULLABLE': True,
                                                          'ORDER': 8,
                                                          'PRECISION': 0,
                                                          'PRIMARY_KEY': False,
                                                          'SQL_TYPE': 'VARCHAR',
                                                          'WIDTH': 200},
                                              'PDBX_AUTH_SEQ_ALIGN_BEG': {'NULLABLE': True,
                                                                          'ORDER': 14,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                              'PDBX_AUTH_SEQ_ALIGN_END': {'NULLABLE': True,
                                                                          'ORDER': 15,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                              'PDBX_DB_ACCESSION': {'NULLABLE': True,
                                                                    'ORDER': 10,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': False,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 13},
                                              'PDBX_DB_ALIGN_BEG_INS_CODE': {'NULLABLE': True,
                                                                             'ORDER': 11,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                              'PDBX_DB_ALIGN_END_INS_CODE': {'NULLABLE': True,
                                                                             'ORDER': 12,
                                                                             'PRECISION': 0,
                                                                             'PRIMARY_KEY': False,
                                                                             'SQL_TYPE': 'VARCHAR',
                                                                             'WIDTH': 10},
                                              'PDBX_PDB_ID_CODE': {'NULLABLE': True,
                                                                   'ORDER': 13,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 10},
                                              'PDBX_SEQ_ALIGN_BEG_INS_CODE': {'NULLABLE': True,
                                                                              'ORDER': 16,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                              'PDBX_SEQ_ALIGN_END_INS_CODE': {'NULLABLE': True,
                                                                              'ORDER': 17,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                              'PDBX_STRAND_ID': {'NULLABLE': True,
                                                                 'ORDER': 9,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                              'REF_ID': {'NULLABLE': True,
                                                         'ORDER': 4,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 10},
                                              'SEQ_ALIGN_BEG': {'NULLABLE': True,
                                                                'ORDER': 2,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'INT',
                                                                'WIDTH': 10},
                                              'SEQ_ALIGN_END': {'NULLABLE': True,
                                                                'ORDER': 3,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'INT',
                                                                'WIDTH': 10},
                                              'STRUCTURE_ID': {'NULLABLE': False,
                                                               'ORDER': 1,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10}},
                           'ATTRIBUTE_MAP': {'ALIGN_ID': ('struct_ref_seq', 'align_id', None, None),
                                             'DB_ALIGN_BEG': ('struct_ref_seq', 'db_align_beg', None, None),
                                             'DB_ALIGN_END': ('struct_ref_seq', 'db_align_end', None, None),
                                             'DETAILS': ('struct_ref_seq', 'details', None, None),
                                             'PDBX_AUTH_SEQ_ALIGN_BEG': ('struct_ref_seq',
                                                                         'pdbx_auth_seq_align_beg',
                                                                         None,
                                                                         None),
                                             'PDBX_AUTH_SEQ_ALIGN_END': ('struct_ref_seq',
                                                                         'pdbx_auth_seq_align_end',
                                                                         None,
                                                                         None),
                                             'PDBX_DB_ACCESSION': ('struct_ref_seq', 'pdbx_db_accession', None, None),
                                             'PDBX_DB_ALIGN_BEG_INS_CODE': ('struct_ref_seq',
                                                                            'pdbx_db_align_beg_ins_code',
                                                                            None,
                                                                            None),
                                             'PDBX_DB_ALIGN_END_INS_CODE': ('struct_ref_seq',
                                                                            'pdbx_db_align_end_ins_code',
                                                                            None,
                                                                            None),
                                             'PDBX_PDB_ID_CODE': ('struct_ref_seq', 'pdbx_PDB_id_code', None, None),
                                             'PDBX_SEQ_ALIGN_BEG_INS_CODE': ('struct_ref_seq',
                                                                             'pdbx_seq_align_beg_ins_code',
                                                                             None,
                                                                             None),
                                             'PDBX_SEQ_ALIGN_END_INS_CODE': ('struct_ref_seq',
                                                                             'pdbx_seq_align_end_ins_code',
                                                                             None,
                                                                             None),
                                             'PDBX_STRAND_ID': ('struct_ref_seq', 'pdbx_strand_id', None, None),
                                             'REF_ID': ('struct_ref_seq', 'ref_id', None, None),
                                             'SEQ_ALIGN_BEG': ('struct_ref_seq', 'seq_align_beg', None, None),
                                             'SEQ_ALIGN_END': ('struct_ref_seq', 'seq_align_end', None, None),
                                             'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                           'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ALIGN_ID'), 'TYPE': 'UNIQUE'},
                                       's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                           'MAP_MERGE_INDICES': {'struct_ref_seq': {'ATTRIBUTES': ('align_id',), 'TYPE': 'EQUI-JOIN'}},
                           'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                           'TABLE_ID': 'STRUCT_REF_SEQ',
                           'TABLE_NAME': 'struct_ref_seq',
                           'TABLE_TYPE': 'transactional'},
        'STRUCT_REF_SEQ_DIF': {'ATTRIBUTES': {'ALIGN_ID': 'align_id',
                                              'DB_MON_ID': 'db_mon_id',
                                              'DETAILS': 'details',
                                              'MON_ID': 'mon_id',
                                              'PDBX_AUTH_SEQ_NUM': 'pdbx_auth_seq_num',
                                              'PDBX_ORDINAL': 'pdbx_ordinal',
                                              'PDBX_PDB_ID_CODE': 'pdbx_pdb_id_code',
                                              'PDBX_PDB_INS_CODE': 'pdbx_pdb_ins_code',
                                              'PDBX_PDB_STRAND_ID': 'pdbx_pdb_strand_id',
                                              'PDBX_SEQ_DB_ACCESSION_CODE': 'pdbx_seq_db_accession_code',
                                              'PDBX_SEQ_DB_NAME': 'pdbx_seq_db_name',
                                              'PDBX_SEQ_DB_SEQ_NUM': 'pdbx_seq_db_seq_num',
                                              'SEQ_NUM': 'seq_num',
                                              'STRUCTURE_ID': 'Structure_ID'},
                               'ATTRIBUTE_INFO': {'ALIGN_ID': {'NULLABLE': True,
                                                               'ORDER': 5,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                                  'DB_MON_ID': {'NULLABLE': True,
                                                                'ORDER': 2,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                                  'DETAILS': {'NULLABLE': True,
                                                              'ORDER': 6,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 200},
                                                  'MON_ID': {'NULLABLE': True,
                                                             'ORDER': 3,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 10},
                                                  'PDBX_AUTH_SEQ_NUM': {'NULLABLE': True,
                                                                        'ORDER': 10,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                                  'PDBX_ORDINAL': {'NULLABLE': False,
                                                                   'ORDER': 14,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': True,
                                                                   'SQL_TYPE': 'INT',
                                                                   'WIDTH': 10},
                                                  'PDBX_PDB_ID_CODE': {'NULLABLE': True,
                                                                       'ORDER': 7,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                  'PDBX_PDB_INS_CODE': {'NULLABLE': True,
                                                                        'ORDER': 9,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                                  'PDBX_PDB_STRAND_ID': {'NULLABLE': True,
                                                                         'ORDER': 8,
                                                                         'PRECISION': 0,
                                                                         'PRIMARY_KEY': False,
                                                                         'SQL_TYPE': 'VARCHAR',
                                                                         'WIDTH': 10},
                                                  'PDBX_SEQ_DB_ACCESSION_CODE': {'NULLABLE': True,
                                                                                 'ORDER': 12,
                                                                                 'PRECISION': 0,
                                                                                 'PRIMARY_KEY': False,
                                                                                 'SQL_TYPE': 'VARCHAR',
                                                                                 'WIDTH': 12},
                                                  'PDBX_SEQ_DB_NAME': {'NULLABLE': True,
                                                                       'ORDER': 11,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                  'PDBX_SEQ_DB_SEQ_NUM': {'NULLABLE': True,
                                                                          'ORDER': 13,
                                                                          'PRECISION': 0,
                                                                          'PRIMARY_KEY': False,
                                                                          'SQL_TYPE': 'VARCHAR',
                                                                          'WIDTH': 10},
                                                  'SEQ_NUM': {'NULLABLE': True,
                                                              'ORDER': 4,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'INT',
                                                              'WIDTH': 10},
                                                  'STRUCTURE_ID': {'NULLABLE': False,
                                                                   'ORDER': 1,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': True,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 10}},
                               'ATTRIBUTE_MAP': {'ALIGN_ID': ('struct_ref_seq_dif', 'align_id', None, None),
                                                 'DB_MON_ID': ('struct_ref_seq_dif', 'db_mon_id', None, None),
                                                 'DETAILS': ('struct_ref_seq_dif', 'details', None, None),
                                                 'MON_ID': ('struct_ref_seq_dif', 'mon_id', None, None),
                                                 'PDBX_AUTH_SEQ_NUM': ('struct_ref_seq_dif', 'pdbx_auth_seq_num', None, None),
                                                 'PDBX_ORDINAL': ('struct_ref_seq_dif', 'pdbx_ordinal', None, None),
                                                 'PDBX_PDB_ID_CODE': ('struct_ref_seq_dif', 'pdbx_pdb_id_code', None, None),
                                                 'PDBX_PDB_INS_CODE': ('struct_ref_seq_dif', 'pdbx_pdb_ins_code', None, None),
                                                 'PDBX_PDB_STRAND_ID': ('struct_ref_seq_dif',
                                                                        'pdbx_pdb_strand_id',
                                                                        None,
                                                                        None),
                                                 'PDBX_SEQ_DB_ACCESSION_CODE': ('struct_ref_seq_dif',
                                                                                'pdbx_seq_db_accession_code',
                                                                                None,
                                                                                None),
                                                 'PDBX_SEQ_DB_NAME': ('struct_ref_seq_dif', 'pdbx_seq_db_name', None, None),
                                                 'PDBX_SEQ_DB_SEQ_NUM': ('struct_ref_seq_dif',
                                                                         'pdbx_seq_db_seq_num',
                                                                         None,
                                                                         None),
                                                 'SEQ_NUM': ('struct_ref_seq_dif', 'seq_num', None, None),
                                                 'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                               'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'PDBX_ORDINAL'), 'TYPE': 'UNIQUE'},
                                           's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                               'MAP_MERGE_INDICES': {'struct_ref_seq_dif': {'ATTRIBUTES': ('pdbx_ordinal',),
                                                                            'TYPE': 'EQUI-JOIN'}},
                               'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                               'TABLE_ID': 'STRUCT_REF_SEQ_DIF',
                               'TABLE_NAME': 'struct_ref_seq_dif',
                               'TABLE_TYPE': 'transactional'},
        'STRUCT_SHEET': {'ATTRIBUTES': {'DETAILS': 'details',
                                        'ID': 'id',
                                        'NUMBER_STRANDS': 'number_strands',
                                        'STRUCTURE_ID': 'Structure_ID',
                                        'TYPE': 'type'},
                         'ATTRIBUTE_INFO': {'DETAILS': {'NULLABLE': True,
                                                        'ORDER': 2,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 200},
                                            'ID': {'NULLABLE': False,
                                                   'ORDER': 3,
                                                   'PRECISION': 0,
                                                   'PRIMARY_KEY': True,
                                                   'SQL_TYPE': 'VARCHAR',
                                                   'WIDTH': 10},
                                            'NUMBER_STRANDS': {'NULLABLE': True,
                                                               'ORDER': 4,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'INT',
                                                               'WIDTH': 10},
                                            'STRUCTURE_ID': {'NULLABLE': False,
                                                             'ORDER': 1,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 10},
                                            'TYPE': {'NULLABLE': True,
                                                     'ORDER': 5,
                                                     'PRECISION': 0,
                                                     'PRIMARY_KEY': False,
                                                     'SQL_TYPE': 'VARCHAR',
                                                     'WIDTH': 200}},
                         'ATTRIBUTE_MAP': {'DETAILS': ('struct_sheet', 'details', None, None),
                                           'ID': ('struct_sheet', 'id', None, None),
                                           'NUMBER_STRANDS': ('struct_sheet', 'number_strands', None, None),
                                           'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                           'TYPE': ('struct_sheet', 'type', None, None)},
                         'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                     's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                         'MAP_MERGE_INDICES': {'struct_sheet': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                         'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                         'TABLE_ID': 'STRUCT_SHEET',
                         'TABLE_NAME': 'struct_sheet',
                         'TABLE_TYPE': 'transactional'},
        'STRUCT_SHEET_HBOND': {'ATTRIBUTES': {'PDBX_RANGE_1_BEG_AUTH_ASYM_ID': 'pdbx_range_1_beg_auth_asym_id',
                                              'PDBX_RANGE_1_BEG_AUTH_COMP_ID': 'pdbx_range_1_beg_auth_comp_id',
                                              'PDBX_RANGE_1_BEG_LABEL_ASYM_ID': 'pdbx_range_1_beg_label_asym_id',
                                              'PDBX_RANGE_1_BEG_LABEL_COMP_ID': 'pdbx_range_1_beg_label_comp_id',
                                              'PDBX_RANGE_1_BEG_PDB_INS_CODE': 'pdbx_range_1_beg_PDB_ins_code',
                                              'PDBX_RANGE_1_END_AUTH_ASYM_ID': 'pdbx_range_1_end_auth_asym_id',
                                              'PDBX_RANGE_1_END_AUTH_COMP_ID': 'pdbx_range_1_end_auth_comp_id',
                                              'PDBX_RANGE_1_END_LABEL_ASYM_ID': 'pdbx_range_1_end_label_asym_id',
                                              'PDBX_RANGE_1_END_LABEL_COMP_ID': 'pdbx_range_1_end_label_comp_id',
                                              'PDBX_RANGE_1_END_PDB_INS_CODE': 'pdbx_range_1_end_PDB_ins_code',
                                              'PDBX_RANGE_2_BEG_LABEL_ASYM_ID': 'pdbx_range_2_beg_label_asym_id',
                                              'PDBX_RANGE_2_BEG_LABEL_COMP_ID': 'pdbx_range_2_beg_label_comp_id',
                                              'PDBX_RANGE_2_BEG_PDB_INS_CODE': 'pdbx_range_2_beg_PDB_ins_code',
                                              'PDBX_RANGE_2_END_LABEL_ASYM_ID': 'pdbx_range_2_end_label_asym_id',
                                              'PDBX_RANGE_2_END_LABEL_COMP_ID': 'pdbx_range_2_end_label_comp_id',
                                              'PDBX_RANGE_2_END_LABEL_INS_CODE': 'pdbx_range_2_end_label_ins_code',
                                              'RANGE_1_BEG_AUTH_ATOM_ID': 'range_1_beg_auth_atom_id',
                                              'RANGE_1_BEG_AUTH_SEQ_ID': 'range_1_beg_auth_seq_id',
                                              'RANGE_1_BEG_LABEL_ATOM_ID': 'range_1_beg_label_atom_id',
                                              'RANGE_1_BEG_LABEL_SEQ_ID': 'range_1_beg_label_seq_id',
                                              'RANGE_1_END_AUTH_ATOM_ID': 'range_1_end_auth_atom_id',
                                              'RANGE_1_END_AUTH_SEQ_ID': 'range_1_end_auth_seq_id',
                                              'RANGE_1_END_LABEL_ATOM_ID': 'range_1_end_label_atom_id',
                                              'RANGE_1_END_LABEL_SEQ_ID': 'range_1_end_label_seq_id',
                                              'RANGE_2_BEG_AUTH_ATOM_ID': 'range_2_beg_auth_atom_id',
                                              'RANGE_2_BEG_AUTH_SEQ_ID': 'range_2_beg_auth_seq_id',
                                              'RANGE_2_BEG_LABEL_ATOM_ID': 'range_2_beg_label_atom_id',
                                              'RANGE_2_BEG_LABEL_SEQ_ID': 'range_2_beg_label_seq_id',
                                              'RANGE_2_END_AUTH_ATOM_ID': 'range_2_end_auth_atom_id',
                                              'RANGE_2_END_AUTH_SEQ_ID': 'range_2_end_auth_seq_id',
                                              'RANGE_2_END_LABEL_ATOM_ID': 'range_2_end_label_atom_id',
                                              'RANGE_2_END_LABEL_SEQ_ID': 'range_2_end_label_seq_id',
                                              'RANGE_ID_1': 'range_id_1',
                                              'RANGE_ID_2': 'range_id_2',
                                              'SHEET_ID': 'sheet_id',
                                              'STRUCTURE_ID': 'Structure_ID'},
                               'ATTRIBUTE_INFO': {'PDBX_RANGE_1_BEG_AUTH_ASYM_ID': {'NULLABLE': True,
                                                                                    'ORDER': 22,
                                                                                    'PRECISION': 0,
                                                                                    'PRIMARY_KEY': False,
                                                                                    'SQL_TYPE': 'VARCHAR',
                                                                                    'WIDTH': 10},
                                                  'PDBX_RANGE_1_BEG_AUTH_COMP_ID': {'NULLABLE': True,
                                                                                    'ORDER': 21,
                                                                                    'PRECISION': 0,
                                                                                    'PRIMARY_KEY': False,
                                                                                    'SQL_TYPE': 'VARCHAR',
                                                                                    'WIDTH': 10},
                                                  'PDBX_RANGE_1_BEG_LABEL_ASYM_ID': {'NULLABLE': True,
                                                                                     'ORDER': 26,
                                                                                     'PRECISION': 0,
                                                                                     'PRIMARY_KEY': False,
                                                                                     'SQL_TYPE': 'VARCHAR',
                                                                                     'WIDTH': 10},
                                                  'PDBX_RANGE_1_BEG_LABEL_COMP_ID': {'NULLABLE': True,
                                                                                     'ORDER': 25,
                                                                                     'PRECISION': 0,
                                                                                     'PRIMARY_KEY': False,
                                                                                     'SQL_TYPE': 'VARCHAR',
                                                                                     'WIDTH': 10},
                                                  'PDBX_RANGE_1_BEG_PDB_INS_CODE': {'NULLABLE': True,
                                                                                    'ORDER': 27,
                                                                                    'PRECISION': 0,
                                                                                    'PRIMARY_KEY': False,
                                                                                    'SQL_TYPE': 'VARCHAR',
                                                                                    'WIDTH': 10},
                                                  'PDBX_RANGE_1_END_AUTH_ASYM_ID': {'NULLABLE': True,
                                                                                    'ORDER': 24,
                                                                                    'PRECISION': 0,
                                                                                    'PRIMARY_KEY': False,
                                                                                    'SQL_TYPE': 'VARCHAR',
                                                                                    'WIDTH': 10},
                                                  'PDBX_RANGE_1_END_AUTH_COMP_ID': {'NULLABLE': True,
                                                                                    'ORDER': 23,
                                                                                    'PRECISION': 0,
                                                                                    'PRIMARY_KEY': False,
                                                                                    'SQL_TYPE': 'VARCHAR',
                                                                                    'WIDTH': 10},
                                                  'PDBX_RANGE_1_END_LABEL_ASYM_ID': {'NULLABLE': True,
                                                                                     'ORDER': 29,
                                                                                     'PRECISION': 0,
                                                                                     'PRIMARY_KEY': False,
                                                                                     'SQL_TYPE': 'VARCHAR',
                                                                                     'WIDTH': 10},
                                                  'PDBX_RANGE_1_END_LABEL_COMP_ID': {'NULLABLE': True,
                                                                                     'ORDER': 28,
                                                                                     'PRECISION': 0,
                                                                                     'PRIMARY_KEY': False,
                                                                                     'SQL_TYPE': 'VARCHAR',
                                                                                     'WIDTH': 10},
                                                  'PDBX_RANGE_1_END_PDB_INS_CODE': {'NULLABLE': True,
                                                                                    'ORDER': 30,
                                                                                    'PRECISION': 0,
                                                                                    'PRIMARY_KEY': False,
                                                                                    'SQL_TYPE': 'VARCHAR',
                                                                                    'WIDTH': 10},
                                                  'PDBX_RANGE_2_BEG_LABEL_ASYM_ID': {'NULLABLE': True,
                                                                                     'ORDER': 32,
                                                                                     'PRECISION': 0,
                                                                                     'PRIMARY_KEY': False,
                                                                                     'SQL_TYPE': 'VARCHAR',
                                                                                     'WIDTH': 10},
                                                  'PDBX_RANGE_2_BEG_LABEL_COMP_ID': {'NULLABLE': True,
                                                                                     'ORDER': 31,
                                                                                     'PRECISION': 0,
                                                                                     'PRIMARY_KEY': False,
                                                                                     'SQL_TYPE': 'VARCHAR',
                                                                                     'WIDTH': 10},
                                                  'PDBX_RANGE_2_BEG_PDB_INS_CODE': {'NULLABLE': True,
                                                                                    'ORDER': 33,
                                                                                    'PRECISION': 0,
                                                                                    'PRIMARY_KEY': False,
                                                                                    'SQL_TYPE': 'VARCHAR',
                                                                                    'WIDTH': 10},
                                                  'PDBX_RANGE_2_END_LABEL_ASYM_ID': {'NULLABLE': True,
                                                                                     'ORDER': 35,
                                                                                     'PRECISION': 0,
                                                                                     'PRIMARY_KEY': False,
                                                                                     'SQL_TYPE': 'VARCHAR',
                                                                                     'WIDTH': 10},
                                                  'PDBX_RANGE_2_END_LABEL_COMP_ID': {'NULLABLE': True,
                                                                                     'ORDER': 34,
                                                                                     'PRECISION': 0,
                                                                                     'PRIMARY_KEY': False,
                                                                                     'SQL_TYPE': 'VARCHAR',
                                                                                     'WIDTH': 10},
                                                  'PDBX_RANGE_2_END_LABEL_INS_CODE': {'NULLABLE': True,
                                                                                      'ORDER': 36,
                                                                                      'PRECISION': 0,
                                                                                      'PRIMARY_KEY': False,
                                                                                      'SQL_TYPE': 'VARCHAR',
                                                                                      'WIDTH': 10},
                                                  'RANGE_1_BEG_AUTH_ATOM_ID': {'NULLABLE': True,
                                                                               'ORDER': 2,
                                                                               'PRECISION': 0,
                                                                               'PRIMARY_KEY': False,
                                                                               'SQL_TYPE': 'VARCHAR',
                                                                               'WIDTH': 6},
                                                  'RANGE_1_BEG_AUTH_SEQ_ID': {'NULLABLE': True,
                                                                              'ORDER': 6,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                                  'RANGE_1_BEG_LABEL_ATOM_ID': {'NULLABLE': True,
                                                                                'ORDER': 10,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 6},
                                                  'RANGE_1_BEG_LABEL_SEQ_ID': {'NULLABLE': True,
                                                                               'ORDER': 14,
                                                                               'PRECISION': 0,
                                                                               'PRIMARY_KEY': False,
                                                                               'SQL_TYPE': 'INT',
                                                                               'WIDTH': 10},
                                                  'RANGE_1_END_AUTH_ATOM_ID': {'NULLABLE': True,
                                                                               'ORDER': 3,
                                                                               'PRECISION': 0,
                                                                               'PRIMARY_KEY': False,
                                                                               'SQL_TYPE': 'VARCHAR',
                                                                               'WIDTH': 6},
                                                  'RANGE_1_END_AUTH_SEQ_ID': {'NULLABLE': True,
                                                                              'ORDER': 7,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                                  'RANGE_1_END_LABEL_ATOM_ID': {'NULLABLE': True,
                                                                                'ORDER': 11,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 6},
                                                  'RANGE_1_END_LABEL_SEQ_ID': {'NULLABLE': True,
                                                                               'ORDER': 15,
                                                                               'PRECISION': 0,
                                                                               'PRIMARY_KEY': False,
                                                                               'SQL_TYPE': 'INT',
                                                                               'WIDTH': 10},
                                                  'RANGE_2_BEG_AUTH_ATOM_ID': {'NULLABLE': True,
                                                                               'ORDER': 4,
                                                                               'PRECISION': 0,
                                                                               'PRIMARY_KEY': False,
                                                                               'SQL_TYPE': 'VARCHAR',
                                                                               'WIDTH': 6},
                                                  'RANGE_2_BEG_AUTH_SEQ_ID': {'NULLABLE': True,
                                                                              'ORDER': 8,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                                  'RANGE_2_BEG_LABEL_ATOM_ID': {'NULLABLE': True,
                                                                                'ORDER': 12,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 6},
                                                  'RANGE_2_BEG_LABEL_SEQ_ID': {'NULLABLE': True,
                                                                               'ORDER': 16,
                                                                               'PRECISION': 0,
                                                                               'PRIMARY_KEY': False,
                                                                               'SQL_TYPE': 'INT',
                                                                               'WIDTH': 10},
                                                  'RANGE_2_END_AUTH_ATOM_ID': {'NULLABLE': True,
                                                                               'ORDER': 5,
                                                                               'PRECISION': 0,
                                                                               'PRIMARY_KEY': False,
                                                                               'SQL_TYPE': 'VARCHAR',
                                                                               'WIDTH': 6},
                                                  'RANGE_2_END_AUTH_SEQ_ID': {'NULLABLE': True,
                                                                              'ORDER': 9,
                                                                              'PRECISION': 0,
                                                                              'PRIMARY_KEY': False,
                                                                              'SQL_TYPE': 'VARCHAR',
                                                                              'WIDTH': 10},
                                                  'RANGE_2_END_LABEL_ATOM_ID': {'NULLABLE': True,
                                                                                'ORDER': 13,
                                                                                'PRECISION': 0,
                                                                                'PRIMARY_KEY': False,
                                                                                'SQL_TYPE': 'VARCHAR',
                                                                                'WIDTH': 6},
                                                  'RANGE_2_END_LABEL_SEQ_ID': {'NULLABLE': True,
                                                                               'ORDER': 17,
                                                                               'PRECISION': 0,
                                                                               'PRIMARY_KEY': False,
                                                                               'SQL_TYPE': 'INT',
                                                                               'WIDTH': 10},
                                                  'RANGE_ID_1': {'NULLABLE': False,
                                                                 'ORDER': 19,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': True,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                                  'RANGE_ID_2': {'NULLABLE': False,
                                                                 'ORDER': 20,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': True,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                                  'SHEET_ID': {'NULLABLE': False,
                                                               'ORDER': 18,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                                  'STRUCTURE_ID': {'NULLABLE': False,
                                                                   'ORDER': 1,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': True,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 10}},
                               'ATTRIBUTE_MAP': {'PDBX_RANGE_1_BEG_AUTH_ASYM_ID': ('struct_sheet_hbond',
                                                                                   'pdbx_range_1_beg_auth_asym_id',
                                                                                   None,
                                                                                   None),
                                                 'PDBX_RANGE_1_BEG_AUTH_COMP_ID': ('struct_sheet_hbond',
                                                                                   'pdbx_range_1_beg_auth_comp_id',
                                                                                   None,
                                                                                   None),
                                                 'PDBX_RANGE_1_BEG_LABEL_ASYM_ID': ('struct_sheet_hbond',
                                                                                    'pdbx_range_1_beg_label_asym_id',
                                                                                    None,
                                                                                    None),
                                                 'PDBX_RANGE_1_BEG_LABEL_COMP_ID': ('struct_sheet_hbond',
                                                                                    'pdbx_range_1_beg_label_comp_id',
                                                                                    None,
                                                                                    None),
                                                 'PDBX_RANGE_1_BEG_PDB_INS_CODE': ('struct_sheet_hbond',
                                                                                   'pdbx_range_1_beg_PDB_ins_code',
                                                                                   None,
                                                                                   None),
                                                 'PDBX_RANGE_1_END_AUTH_ASYM_ID': ('struct_sheet_hbond',
                                                                                   'pdbx_range_1_end_auth_asym_id',
                                                                                   None,
                                                                                   None),
                                                 'PDBX_RANGE_1_END_AUTH_COMP_ID': ('struct_sheet_hbond',
                                                                                   'pdbx_range_1_end_auth_comp_id',
                                                                                   None,
                                                                                   None),
                                                 'PDBX_RANGE_1_END_LABEL_ASYM_ID': ('struct_sheet_hbond',
                                                                                    'pdbx_range_1_end_label_asym_id',
                                                                                    None,
                                                                                    None),
                                                 'PDBX_RANGE_1_END_LABEL_COMP_ID': ('struct_sheet_hbond',
                                                                                    'pdbx_range_1_end_label_comp_id',
                                                                                    None,
                                                                                    None),
                                                 'PDBX_RANGE_1_END_PDB_INS_CODE': ('struct_sheet_hbond',
                                                                                   'pdbx_range_1_end_PDB_ins_code',
                                                                                   None,
                                                                                   None),
                                                 'PDBX_RANGE_2_BEG_LABEL_ASYM_ID': ('struct_sheet_hbond',
                                                                                    'pdbx_range_2_beg_label_asym_id',
                                                                                    None,
                                                                                    None),
                                                 'PDBX_RANGE_2_BEG_LABEL_COMP_ID': ('struct_sheet_hbond',
                                                                                    'pdbx_range_2_beg_label_comp_id',
                                                                                    None,
                                                                                    None),
                                                 'PDBX_RANGE_2_BEG_PDB_INS_CODE': ('struct_sheet_hbond',
                                                                                   'pdbx_range_2_beg_PDB_ins_code',
                                                                                   None,
                                                                                   None),
                                                 'PDBX_RANGE_2_END_LABEL_ASYM_ID': ('struct_sheet_hbond',
                                                                                    'pdbx_range_2_end_label_asym_id',
                                                                                    None,
                                                                                    None),
                                                 'PDBX_RANGE_2_END_LABEL_COMP_ID': ('struct_sheet_hbond',
                                                                                    'pdbx_range_2_end_label_comp_id',
                                                                                    None,
                                                                                    None),
                                                 'PDBX_RANGE_2_END_LABEL_INS_CODE': ('struct_sheet_hbond',
                                                                                     'pdbx_range_2_end_label_ins_code',
                                                                                     None,
                                                                                     None),
                                                 'RANGE_1_BEG_AUTH_ATOM_ID': ('struct_sheet_hbond',
                                                                              'range_1_beg_auth_atom_id',
                                                                              None,
                                                                              None),
                                                 'RANGE_1_BEG_AUTH_SEQ_ID': ('struct_sheet_hbond',
                                                                             'range_1_beg_auth_seq_id',
                                                                             None,
                                                                             None),
                                                 'RANGE_1_BEG_LABEL_ATOM_ID': ('struct_sheet_hbond',
                                                                               'range_1_beg_label_atom_id',
                                                                               None,
                                                                               None),
                                                 'RANGE_1_BEG_LABEL_SEQ_ID': ('struct_sheet_hbond',
                                                                              'range_1_beg_label_seq_id',
                                                                              None,
                                                                              None),
                                                 'RANGE_1_END_AUTH_ATOM_ID': ('struct_sheet_hbond',
                                                                              'range_1_end_auth_atom_id',
                                                                              None,
                                                                              None),
                                                 'RANGE_1_END_AUTH_SEQ_ID': ('struct_sheet_hbond',
                                                                             'range_1_end_auth_seq_id',
                                                                             None,
                                                                             None),
                                                 'RANGE_1_END_LABEL_ATOM_ID': ('struct_sheet_hbond',
                                                                               'range_1_end_label_atom_id',
                                                                               None,
                                                                               None),
                                                 'RANGE_1_END_LABEL_SEQ_ID': ('struct_sheet_hbond',
                                                                              'range_1_end_label_seq_id',
                                                                              None,
                                                                              None),
                                                 'RANGE_2_BEG_AUTH_ATOM_ID': ('struct_sheet_hbond',
                                                                              'range_2_beg_auth_atom_id',
                                                                              None,
                                                                              None),
                                                 'RANGE_2_BEG_AUTH_SEQ_ID': ('struct_sheet_hbond',
                                                                             'range_2_beg_auth_seq_id',
                                                                             None,
                                                                             None),
                                                 'RANGE_2_BEG_LABEL_ATOM_ID': ('struct_sheet_hbond',
                                                                               'range_2_beg_label_atom_id',
                                                                               None,
                                                                               None),
                                                 'RANGE_2_BEG_LABEL_SEQ_ID': ('struct_sheet_hbond',
                                                                              'range_2_beg_label_seq_id',
                                                                              None,
                                                                              None),
                                                 'RANGE_2_END_AUTH_ATOM_ID': ('struct_sheet_hbond',
                                                                              'range_2_end_auth_atom_id',
                                                                              None,
                                                                              None),
                                                 'RANGE_2_END_AUTH_SEQ_ID': ('struct_sheet_hbond',
                                                                             'range_2_end_auth_seq_id',
                                                                             None,
                                                                             None),
                                                 'RANGE_2_END_LABEL_ATOM_ID': ('struct_sheet_hbond',
                                                                               'range_2_end_label_atom_id',
                                                                               None,
                                                                               None),
                                                 'RANGE_2_END_LABEL_SEQ_ID': ('struct_sheet_hbond',
                                                                              'range_2_end_label_seq_id',
                                                                              None,
                                                                              None),
                                                 'RANGE_ID_1': ('struct_sheet_hbond', 'range_id_1', None, None),
                                                 'RANGE_ID_2': ('struct_sheet_hbond', 'range_id_2', None, None),
                                                 'SHEET_ID': ('struct_sheet_hbond', 'sheet_id', None, None),
                                                 'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                               'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'SHEET_ID', 'RANGE_ID_1', 'RANGE_ID_2'),
                                                  'TYPE': 'UNIQUE'},
                                           's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                               'MAP_MERGE_INDICES': {'struct_sheet_hbond': {'ATTRIBUTES': ('sheet_id',
                                                                                           'range_id_1',
                                                                                           'range_id_2'),
                                                                            'TYPE': 'EQUI-JOIN'}},
                               'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                               'TABLE_ID': 'STRUCT_SHEET_HBOND',
                               'TABLE_NAME': 'struct_sheet_hbond',
                               'TABLE_TYPE': 'transactional'},
        'STRUCT_SHEET_ORDER': {'ATTRIBUTES': {'OFFSET': 'offset',
                                              'RANGE_ID_1': 'range_id_1',
                                              'RANGE_ID_2': 'range_id_2',
                                              'SENSE': 'sense',
                                              'SHEET_ID': 'sheet_id',
                                              'STRUCTURE_ID': 'Structure_ID'},
                               'ATTRIBUTE_INFO': {'OFFSET': {'NULLABLE': True,
                                                             'ORDER': 3,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'INT',
                                                             'WIDTH': 10},
                                                  'RANGE_ID_1': {'NULLABLE': False,
                                                                 'ORDER': 4,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': True,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                                  'RANGE_ID_2': {'NULLABLE': False,
                                                                 'ORDER': 5,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': True,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                                  'SENSE': {'NULLABLE': True,
                                                            'ORDER': 6,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 14},
                                                  'SHEET_ID': {'NULLABLE': False,
                                                               'ORDER': 2,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                                  'STRUCTURE_ID': {'NULLABLE': False,
                                                                   'ORDER': 1,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': True,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 10}},
                               'ATTRIBUTE_MAP': {'OFFSET': ('struct_sheet_order', 'offset', None, None),
                                                 'RANGE_ID_1': ('struct_sheet_order', 'range_id_1', None, None),
                                                 'RANGE_ID_2': ('struct_sheet_order', 'range_id_2', None, None),
                                                 'SENSE': ('struct_sheet_order', 'sense', None, None),
                                                 'SHEET_ID': ('struct_sheet_order', 'sheet_id', None, None),
                                                 'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                               'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'SHEET_ID', 'RANGE_ID_1', 'RANGE_ID_2'),
                                                  'TYPE': 'UNIQUE'},
                                           's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                               'MAP_MERGE_INDICES': {'struct_sheet_order': {'ATTRIBUTES': ('sheet_id',
                                                                                           'range_id_1',
                                                                                           'range_id_2'),
                                                                            'TYPE': 'EQUI-JOIN'}},
                               'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                               'TABLE_ID': 'STRUCT_SHEET_ORDER',
                               'TABLE_NAME': 'struct_sheet_order',
                               'TABLE_TYPE': 'transactional'},
        'STRUCT_SHEET_RANGE': {'ATTRIBUTES': {'BEG_AUTH_ASYM_ID': 'beg_auth_asym_id',
                                              'BEG_AUTH_COMP_ID': 'beg_auth_comp_id',
                                              'BEG_AUTH_SEQ_ID': 'beg_auth_seq_id',
                                              'BEG_LABEL_ASYM_ID': 'beg_label_asym_id',
                                              'BEG_LABEL_COMP_ID': 'beg_label_comp_id',
                                              'BEG_LABEL_SEQ_ID': 'beg_label_seq_id',
                                              'END_AUTH_ASYM_ID': 'end_auth_asym_id',
                                              'END_AUTH_COMP_ID': 'end_auth_comp_id',
                                              'END_AUTH_SEQ_ID': 'end_auth_seq_id',
                                              'END_LABEL_ASYM_ID': 'end_label_asym_id',
                                              'END_LABEL_COMP_ID': 'end_label_comp_id',
                                              'END_LABEL_SEQ_ID': 'end_label_seq_id',
                                              'ID': 'id',
                                              'PDBX_BEG_PDB_INS_CODE': 'pdbx_beg_PDB_ins_code',
                                              'PDBX_END_PDB_INS_CODE': 'pdbx_end_PDB_ins_code',
                                              'SHEET_ID': 'sheet_id',
                                              'STRUCTURE_ID': 'Structure_ID',
                                              'SYMMETRY': 'symmetry'},
                               'ATTRIBUTE_INFO': {'BEG_AUTH_ASYM_ID': {'NULLABLE': True,
                                                                       'ORDER': 2,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                  'BEG_AUTH_COMP_ID': {'NULLABLE': True,
                                                                       'ORDER': 4,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                  'BEG_AUTH_SEQ_ID': {'NULLABLE': True,
                                                                      'ORDER': 6,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                                  'BEG_LABEL_ASYM_ID': {'NULLABLE': True,
                                                                        'ORDER': 12,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                                  'BEG_LABEL_COMP_ID': {'NULLABLE': True,
                                                                        'ORDER': 8,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                                  'BEG_LABEL_SEQ_ID': {'NULLABLE': True,
                                                                       'ORDER': 10,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'INT',
                                                                       'WIDTH': 10},
                                                  'END_AUTH_ASYM_ID': {'NULLABLE': True,
                                                                       'ORDER': 3,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                  'END_AUTH_COMP_ID': {'NULLABLE': True,
                                                                       'ORDER': 5,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'VARCHAR',
                                                                       'WIDTH': 10},
                                                  'END_AUTH_SEQ_ID': {'NULLABLE': True,
                                                                      'ORDER': 7,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                                  'END_LABEL_ASYM_ID': {'NULLABLE': True,
                                                                        'ORDER': 13,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                                  'END_LABEL_COMP_ID': {'NULLABLE': True,
                                                                        'ORDER': 9,
                                                                        'PRECISION': 0,
                                                                        'PRIMARY_KEY': False,
                                                                        'SQL_TYPE': 'VARCHAR',
                                                                        'WIDTH': 10},
                                                  'END_LABEL_SEQ_ID': {'NULLABLE': True,
                                                                       'ORDER': 11,
                                                                       'PRECISION': 0,
                                                                       'PRIMARY_KEY': False,
                                                                       'SQL_TYPE': 'INT',
                                                                       'WIDTH': 10},
                                                  'ID': {'NULLABLE': False,
                                                         'ORDER': 15,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': True,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 10},
                                                  'PDBX_BEG_PDB_INS_CODE': {'NULLABLE': True,
                                                                            'ORDER': 17,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 10},
                                                  'PDBX_END_PDB_INS_CODE': {'NULLABLE': True,
                                                                            'ORDER': 18,
                                                                            'PRECISION': 0,
                                                                            'PRIMARY_KEY': False,
                                                                            'SQL_TYPE': 'VARCHAR',
                                                                            'WIDTH': 10},
                                                  'SHEET_ID': {'NULLABLE': False,
                                                               'ORDER': 14,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                                  'STRUCTURE_ID': {'NULLABLE': False,
                                                                   'ORDER': 1,
                                                                   'PRECISION': 0,
                                                                   'PRIMARY_KEY': True,
                                                                   'SQL_TYPE': 'VARCHAR',
                                                                   'WIDTH': 10},
                                                  'SYMMETRY': {'NULLABLE': True,
                                                               'ORDER': 16,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10}},
                               'ATTRIBUTE_MAP': {'BEG_AUTH_ASYM_ID': ('struct_sheet_range', 'beg_auth_asym_id', None, None),
                                                 'BEG_AUTH_COMP_ID': ('struct_sheet_range', 'beg_auth_comp_id', None, None),
                                                 'BEG_AUTH_SEQ_ID': ('struct_sheet_range', 'beg_auth_seq_id', None, None),
                                                 'BEG_LABEL_ASYM_ID': ('struct_sheet_range', 'beg_label_asym_id', None, None),
                                                 'BEG_LABEL_COMP_ID': ('struct_sheet_range', 'beg_label_comp_id', None, None),
                                                 'BEG_LABEL_SEQ_ID': ('struct_sheet_range', 'beg_label_seq_id', None, None),
                                                 'END_AUTH_ASYM_ID': ('struct_sheet_range', 'end_auth_asym_id', None, None),
                                                 'END_AUTH_COMP_ID': ('struct_sheet_range', 'end_auth_comp_id', None, None),
                                                 'END_AUTH_SEQ_ID': ('struct_sheet_range', 'end_auth_seq_id', None, None),
                                                 'END_LABEL_ASYM_ID': ('struct_sheet_range', 'end_label_asym_id', None, None),
                                                 'END_LABEL_COMP_ID': ('struct_sheet_range', 'end_label_comp_id', None, None),
                                                 'END_LABEL_SEQ_ID': ('struct_sheet_range', 'end_label_seq_id', None, None),
                                                 'ID': ('struct_sheet_range', 'id', None, None),
                                                 'PDBX_BEG_PDB_INS_CODE': ('struct_sheet_range',
                                                                           'pdbx_beg_PDB_ins_code',
                                                                           None,
                                                                           None),
                                                 'PDBX_END_PDB_INS_CODE': ('struct_sheet_range',
                                                                           'pdbx_end_PDB_ins_code',
                                                                           None,
                                                                           None),
                                                 'SHEET_ID': ('struct_sheet_range', 'sheet_id', None, None),
                                                 'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                 'SYMMETRY': ('struct_sheet_range', 'symmetry', None, None)},
                               'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'SHEET_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                           's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                               'MAP_MERGE_INDICES': {'struct_sheet_range': {'ATTRIBUTES': ('sheet_id', 'id'),
                                                                            'TYPE': 'EQUI-JOIN'}},
                               'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                               'TABLE_ID': 'STRUCT_SHEET_RANGE',
                               'TABLE_NAME': 'struct_sheet_range',
                               'TABLE_TYPE': 'transactional'},
        'STRUCT_SHEET_TOPOLOGY': {'ATTRIBUTES': {'OFFSET': 'offset',
                                                 'RANGE_ID_1': 'range_id_1',
                                                 'RANGE_ID_2': 'range_id_2',
                                                 'SENSE': 'sense',
                                                 'SHEET_ID': 'sheet_id',
                                                 'STRUCTURE_ID': 'Structure_ID'},
                                  'ATTRIBUTE_INFO': {'OFFSET': {'NULLABLE': True,
                                                                'ORDER': 5,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'INT',
                                                                'WIDTH': 10},
                                                     'RANGE_ID_1': {'NULLABLE': False,
                                                                    'ORDER': 3,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': True,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10},
                                                     'RANGE_ID_2': {'NULLABLE': False,
                                                                    'ORDER': 4,
                                                                    'PRECISION': 0,
                                                                    'PRIMARY_KEY': True,
                                                                    'SQL_TYPE': 'VARCHAR',
                                                                    'WIDTH': 10},
                                                     'SENSE': {'NULLABLE': True,
                                                               'ORDER': 6,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                                     'SHEET_ID': {'NULLABLE': False,
                                                                  'ORDER': 2,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': True,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 10},
                                                     'STRUCTURE_ID': {'NULLABLE': False,
                                                                      'ORDER': 1,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': True,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10}},
                                  'ATTRIBUTE_MAP': {'OFFSET': ('struct_sheet_topology', 'offset', None, None),
                                                    'RANGE_ID_1': ('struct_sheet_topology', 'range_id_1', None, None),
                                                    'RANGE_ID_2': ('struct_sheet_topology', 'range_id_2', None, None),
                                                    'SENSE': ('struct_sheet_topology', 'sense', None, None),
                                                    'SHEET_ID': ('struct_sheet_topology', 'sheet_id', None, None),
                                                    'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                                  'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'SHEET_ID', 'RANGE_ID_1', 'RANGE_ID_2'),
                                                     'TYPE': 'UNIQUE'},
                                              's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                  'MAP_MERGE_INDICES': {'struct_sheet_topology': {'ATTRIBUTES': ('sheet_id',
                                                                                                 'range_id_1',
                                                                                                 'range_id_2'),
                                                                                  'TYPE': 'EQUI-JOIN'}},
                                  'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                  'TABLE_ID': 'STRUCT_SHEET_TOPOLOGY',
                                  'TABLE_NAME': 'struct_sheet_topology',
                                  'TABLE_TYPE': 'transactional'},
        'STRUCT_SITE': {'ATTRIBUTES': {'DETAILS': 'details',
                                       'ID': 'id',
                                       'PDBX_EVIDENCE_CODE': 'pdbx_evidence_code',
                                       'PDBX_NUM_RESIDUES': 'pdbx_num_residues',
                                       'STRUCTURE_ID': 'Structure_ID'},
                        'ATTRIBUTE_INFO': {'DETAILS': {'NULLABLE': True,
                                                       'ORDER': 2,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': False,
                                                       'SQL_TYPE': 'VARCHAR',
                                                       'WIDTH': 1023},
                                           'ID': {'NULLABLE': False,
                                                  'ORDER': 3,
                                                  'PRECISION': 0,
                                                  'PRIMARY_KEY': True,
                                                  'SQL_TYPE': 'VARCHAR',
                                                  'WIDTH': 80},
                                           'PDBX_EVIDENCE_CODE': {'NULLABLE': True,
                                                                  'ORDER': 5,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 200},
                                           'PDBX_NUM_RESIDUES': {'NULLABLE': True,
                                                                 'ORDER': 4,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'INT',
                                                                 'WIDTH': 10},
                                           'STRUCTURE_ID': {'NULLABLE': False,
                                                            'ORDER': 1,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': True,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 10}},
                        'ATTRIBUTE_MAP': {'DETAILS': ('struct_site', 'details', None, None),
                                          'ID': ('struct_site', 'id', None, None),
                                          'PDBX_EVIDENCE_CODE': ('struct_site', 'pdbx_evidence_code', None, None),
                                          'PDBX_NUM_RESIDUES': ('struct_site', 'pdbx_num_residues', None, None),
                                          'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                        'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                    's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                        'MAP_MERGE_INDICES': {'struct_site': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                        'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                        'TABLE_ID': 'STRUCT_SITE',
                        'TABLE_NAME': 'struct_site',
                        'TABLE_TYPE': 'transactional'},
        'STRUCT_SITE_GEN': {'ATTRIBUTES': {'AUTH_ASYM_ID': 'auth_asym_id',
                                           'AUTH_ATOM_ID': 'auth_atom_id',
                                           'AUTH_COMP_ID': 'auth_comp_id',
                                           'AUTH_SEQ_ID': 'auth_seq_id',
                                           'DETAILS': 'details',
                                           'ID': 'id',
                                           'LABEL_ALT_ID': 'label_alt_id',
                                           'LABEL_ASYM_ID': 'label_asym_id',
                                           'LABEL_ATOM_ID': 'label_atom_id',
                                           'LABEL_COMP_ID': 'label_comp_id',
                                           'LABEL_SEQ_ID': 'label_seq_id',
                                           'PDBX_AUTH_INS_CODE': 'pdbx_auth_ins_code',
                                           'PDBX_NUM_RES': 'pdbx_num_res',
                                           'SITE_ID': 'site_id',
                                           'STRUCTURE_ID': 'Structure_ID',
                                           'SYMMETRY': 'symmetry'},
                            'ATTRIBUTE_INFO': {'AUTH_ASYM_ID': {'NULLABLE': True,
                                                                'ORDER': 2,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                               'AUTH_ATOM_ID': {'NULLABLE': True,
                                                                'ORDER': 3,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 6},
                                               'AUTH_COMP_ID': {'NULLABLE': True,
                                                                'ORDER': 4,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                               'AUTH_SEQ_ID': {'NULLABLE': True,
                                                               'ORDER': 5,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': False,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10},
                                               'DETAILS': {'NULLABLE': True,
                                                           'ORDER': 12,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': False,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 200},
                                               'ID': {'NULLABLE': False,
                                                      'ORDER': 13,
                                                      'PRECISION': 0,
                                                      'PRIMARY_KEY': True,
                                                      'SQL_TYPE': 'VARCHAR',
                                                      'WIDTH': 80},
                                               'LABEL_ALT_ID': {'NULLABLE': True,
                                                                'ORDER': 6,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                               'LABEL_ASYM_ID': {'NULLABLE': True,
                                                                 'ORDER': 10,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                               'LABEL_ATOM_ID': {'NULLABLE': True,
                                                                 'ORDER': 8,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 6},
                                               'LABEL_COMP_ID': {'NULLABLE': True,
                                                                 'ORDER': 7,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10},
                                               'LABEL_SEQ_ID': {'NULLABLE': True,
                                                                'ORDER': 9,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'INT',
                                                                'WIDTH': 10},
                                               'PDBX_AUTH_INS_CODE': {'NULLABLE': True,
                                                                      'ORDER': 15,
                                                                      'PRECISION': 0,
                                                                      'PRIMARY_KEY': False,
                                                                      'SQL_TYPE': 'VARCHAR',
                                                                      'WIDTH': 10},
                                               'PDBX_NUM_RES': {'NULLABLE': True,
                                                                'ORDER': 16,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': False,
                                                                'SQL_TYPE': 'INT',
                                                                'WIDTH': 10},
                                               'SITE_ID': {'NULLABLE': False,
                                                           'ORDER': 11,
                                                           'PRECISION': 0,
                                                           'PRIMARY_KEY': True,
                                                           'SQL_TYPE': 'VARCHAR',
                                                           'WIDTH': 80},
                                               'STRUCTURE_ID': {'NULLABLE': False,
                                                                'ORDER': 1,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 10},
                                               'SYMMETRY': {'NULLABLE': True,
                                                            'ORDER': 14,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 10}},
                            'ATTRIBUTE_MAP': {'AUTH_ASYM_ID': ('struct_site_gen', 'auth_asym_id', None, None),
                                              'AUTH_ATOM_ID': ('struct_site_gen', 'auth_atom_id', None, None),
                                              'AUTH_COMP_ID': ('struct_site_gen', 'auth_comp_id', None, None),
                                              'AUTH_SEQ_ID': ('struct_site_gen', 'auth_seq_id', None, None),
                                              'DETAILS': ('struct_site_gen', 'details', None, None),
                                              'ID': ('struct_site_gen', 'id', None, None),
                                              'LABEL_ALT_ID': ('struct_site_gen', 'label_alt_id', None, None),
                                              'LABEL_ASYM_ID': ('struct_site_gen', 'label_asym_id', None, None),
                                              'LABEL_ATOM_ID': ('struct_site_gen', 'label_atom_id', None, None),
                                              'LABEL_COMP_ID': ('struct_site_gen', 'label_comp_id', None, None),
                                              'LABEL_SEQ_ID': ('struct_site_gen', 'label_seq_id', None, None),
                                              'PDBX_AUTH_INS_CODE': ('struct_site_gen', 'pdbx_auth_ins_code', None, None),
                                              'PDBX_NUM_RES': ('struct_site_gen', 'pdbx_num_res', None, None),
                                              'SITE_ID': ('struct_site_gen', 'site_id', None, None),
                                              'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                              'SYMMETRY': ('struct_site_gen', 'symmetry', None, None)},
                            'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'SITE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                        's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                            'MAP_MERGE_INDICES': {'struct_site_gen': {'ATTRIBUTES': ('site_id', 'id'), 'TYPE': 'EQUI-JOIN'}},
                            'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                            'TABLE_ID': 'STRUCT_SITE_GEN',
                            'TABLE_NAME': 'struct_site_gen',
                            'TABLE_TYPE': 'transactional'},
        'STRUCT_SITE_KEYWORDS': {'ATTRIBUTES': {'SITE_ID': 'site_id', 'STRUCTURE_ID': 'Structure_ID', 'TEXT': 'text'},
                                 'ATTRIBUTE_INFO': {'SITE_ID': {'NULLABLE': False,
                                                                'ORDER': 2,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'VARCHAR',
                                                                'WIDTH': 80},
                                                    'STRUCTURE_ID': {'NULLABLE': False,
                                                                     'ORDER': 1,
                                                                     'PRECISION': 0,
                                                                     'PRIMARY_KEY': True,
                                                                     'SQL_TYPE': 'VARCHAR',
                                                                     'WIDTH': 10},
                                                    'TEXT': {'NULLABLE': False,
                                                             'ORDER': 3,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': True,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 200}},
                                 'ATTRIBUTE_MAP': {'SITE_ID': ('struct_site_keywords', 'site_id', None, None),
                                                   'STRUCTURE_ID': (None, None, 'datablockid()', None),
                                                   'TEXT': ('struct_site_keywords', 'text', None, None)},
                                 'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'SITE_ID', 'TEXT'), 'TYPE': 'UNIQUE'},
                                             's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                                 'MAP_MERGE_INDICES': {'struct_site_keywords': {'ATTRIBUTES': ('site_id', 'text'),
                                                                                'TYPE': 'EQUI-JOIN'}},
                                 'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                                 'TABLE_ID': 'STRUCT_SITE_KEYWORDS',
                                 'TABLE_NAME': 'struct_site_keywords',
                                 'TABLE_TYPE': 'transactional'},
        'STRUCT_SITE_VIEW': {'ATTRIBUTES': {'DETAILS': 'details',
                                            'ID': 'id',
                                            'ROT_MATRIX_1_1': 'rot_matrix_1_1',
                                            'ROT_MATRIX_1_2': 'rot_matrix_1_2',
                                            'ROT_MATRIX_1_3': 'rot_matrix_1_3',
                                            'ROT_MATRIX_2_1': 'rot_matrix_2_1',
                                            'ROT_MATRIX_2_2': 'rot_matrix_2_2',
                                            'ROT_MATRIX_2_3': 'rot_matrix_2_3',
                                            'ROT_MATRIX_3_1': 'rot_matrix_3_1',
                                            'ROT_MATRIX_3_2': 'rot_matrix_3_2',
                                            'ROT_MATRIX_3_3': 'rot_matrix_3_3',
                                            'SITE_ID': 'site_id',
                                            'STRUCTURE_ID': 'Structure_ID'},
                             'ATTRIBUTE_INFO': {'DETAILS': {'NULLABLE': True,
                                                            'ORDER': 3,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 200},
                                                'ID': {'NULLABLE': False,
                                                       'ORDER': 4,
                                                       'PRECISION': 0,
                                                       'PRIMARY_KEY': True,
                                                       'SQL_TYPE': 'VARCHAR',
                                                       'WIDTH': 80},
                                                'ROT_MATRIX_1_1': {'NULLABLE': True,
                                                                   'ORDER': 5,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                                'ROT_MATRIX_1_2': {'NULLABLE': True,
                                                                   'ORDER': 6,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                                'ROT_MATRIX_1_3': {'NULLABLE': True,
                                                                   'ORDER': 7,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                                'ROT_MATRIX_2_1': {'NULLABLE': True,
                                                                   'ORDER': 8,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                                'ROT_MATRIX_2_2': {'NULLABLE': True,
                                                                   'ORDER': 9,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                                'ROT_MATRIX_2_3': {'NULLABLE': True,
                                                                   'ORDER': 10,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                                'ROT_MATRIX_3_1': {'NULLABLE': True,
                                                                   'ORDER': 11,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                                'ROT_MATRIX_3_2': {'NULLABLE': True,
                                                                   'ORDER': 12,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                                'ROT_MATRIX_3_3': {'NULLABLE': True,
                                                                   'ORDER': 13,
                                                                   'PRECISION': 6,
                                                                   'PRIMARY_KEY': False,
                                                                   'SQL_TYPE': 'FLOAT',
                                                                   'WIDTH': 10},
                                                'SITE_ID': {'NULLABLE': True,
                                                            'ORDER': 2,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': False,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 80},
                                                'STRUCTURE_ID': {'NULLABLE': False,
                                                                 'ORDER': 1,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': True,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 10}},
                             'ATTRIBUTE_MAP': {'DETAILS': ('struct_site_view', 'details', None, None),
                                               'ID': ('struct_site_view', 'id', None, None),
                                               'ROT_MATRIX_1_1': ('struct_site_view', 'rot_matrix[1][1]', None, None),
                                               'ROT_MATRIX_1_2': ('struct_site_view', 'rot_matrix[1][2]', None, None),
                                               'ROT_MATRIX_1_3': ('struct_site_view', 'rot_matrix[1][3]', None, None),
                                               'ROT_MATRIX_2_1': ('struct_site_view', 'rot_matrix[2][1]', None, None),
                                               'ROT_MATRIX_2_2': ('struct_site_view', 'rot_matrix[2][2]', None, None),
                                               'ROT_MATRIX_2_3': ('struct_site_view', 'rot_matrix[2][3]', None, None),
                                               'ROT_MATRIX_3_1': ('struct_site_view', 'rot_matrix[3][1]', None, None),
                                               'ROT_MATRIX_3_2': ('struct_site_view', 'rot_matrix[3][2]', None, None),
                                               'ROT_MATRIX_3_3': ('struct_site_view', 'rot_matrix[3][3]', None, None),
                                               'SITE_ID': ('struct_site_view', 'site_id', None, None),
                                               'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                             'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                         's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                             'MAP_MERGE_INDICES': {'struct_site_view': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                             'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                             'TABLE_ID': 'STRUCT_SITE_VIEW',
                             'TABLE_NAME': 'struct_site_view',
                             'TABLE_TYPE': 'transactional'},
        'SYMMETRY': {'ATTRIBUTES': {'CELL_SETTING': 'cell_setting',
                                    'ENTRY_ID': 'entry_id',
                                    'INT_TABLES_NUMBER': 'Int_Tables_number',
                                    'PDBX_FULL_SPACE_GROUP_NAME_H_M': 'pdbx_full_space_group_name_H_M',
                                    'SPACE_GROUP_NAME_HALL': 'space_group_name_Hall',
                                    'SPACE_GROUP_NAME_H_M': 'space_group_name_H_M',
                                    'STRUCTURE_ID': 'Structure_ID'},
                     'ATTRIBUTE_INFO': {'CELL_SETTING': {'NULLABLE': True,
                                                         'ORDER': 3,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 13},
                                        'ENTRY_ID': {'NULLABLE': False,
                                                     'ORDER': 2,
                                                     'PRECISION': 0,
                                                     'PRIMARY_KEY': True,
                                                     'SQL_TYPE': 'VARCHAR',
                                                     'WIDTH': 10},
                                        'INT_TABLES_NUMBER': {'NULLABLE': True,
                                                              'ORDER': 4,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': False,
                                                              'SQL_TYPE': 'INT',
                                                              'WIDTH': 10},
                                        'PDBX_FULL_SPACE_GROUP_NAME_H_M': {'NULLABLE': True,
                                                                           'ORDER': 7,
                                                                           'PRECISION': 0,
                                                                           'PRIMARY_KEY': False,
                                                                           'SQL_TYPE': 'VARCHAR',
                                                                           'WIDTH': 80},
                                        'SPACE_GROUP_NAME_HALL': {'NULLABLE': True,
                                                                  'ORDER': 5,
                                                                  'PRECISION': 0,
                                                                  'PRIMARY_KEY': False,
                                                                  'SQL_TYPE': 'VARCHAR',
                                                                  'WIDTH': 80},
                                        'SPACE_GROUP_NAME_H_M': {'NULLABLE': True,
                                                                 'ORDER': 6,
                                                                 'PRECISION': 0,
                                                                 'PRIMARY_KEY': False,
                                                                 'SQL_TYPE': 'VARCHAR',
                                                                 'WIDTH': 80},
                                        'STRUCTURE_ID': {'NULLABLE': False,
                                                         'ORDER': 1,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': True,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 10}},
                     'ATTRIBUTE_MAP': {'CELL_SETTING': ('symmetry', 'cell_setting', None, None),
                                       'ENTRY_ID': ('symmetry', 'entry_id', None, None),
                                       'INT_TABLES_NUMBER': ('symmetry', 'Int_Tables_number', None, None),
                                       'PDBX_FULL_SPACE_GROUP_NAME_H_M': ('symmetry',
                                                                          'pdbx_full_space_group_name_H-M',
                                                                          None,
                                                                          None),
                                       'SPACE_GROUP_NAME_HALL': ('symmetry', 'space_group_name_Hall', None, None),
                                       'SPACE_GROUP_NAME_H_M': ('symmetry', 'space_group_name_H-M', None, None),
                                       'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                     'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ENTRY_ID'), 'TYPE': 'UNIQUE'},
                                 's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                     'MAP_MERGE_INDICES': {'symmetry': {'ATTRIBUTES': ('entry_id',), 'TYPE': 'EQUI-JOIN'}},
                     'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                     'TABLE_ID': 'SYMMETRY',
                     'TABLE_NAME': 'symmetry',
                     'TABLE_TYPE': 'transactional'},
        'SYMMETRY_EQUIV': {'ATTRIBUTES': {'ID': 'id', 'POS_AS_XYZ': 'pos_as_xyz', 'STRUCTURE_ID': 'Structure_ID'},
                           'ATTRIBUTE_INFO': {'ID': {'NULLABLE': False,
                                                     'ORDER': 2,
                                                     'PRECISION': 0,
                                                     'PRIMARY_KEY': True,
                                                     'SQL_TYPE': 'VARCHAR',
                                                     'WIDTH': 10},
                                              'POS_AS_XYZ': {'NULLABLE': True,
                                                             'ORDER': 3,
                                                             'PRECISION': 0,
                                                             'PRIMARY_KEY': False,
                                                             'SQL_TYPE': 'VARCHAR',
                                                             'WIDTH': 80},
                                              'STRUCTURE_ID': {'NULLABLE': False,
                                                               'ORDER': 1,
                                                               'PRECISION': 0,
                                                               'PRIMARY_KEY': True,
                                                               'SQL_TYPE': 'VARCHAR',
                                                               'WIDTH': 10}},
                           'ATTRIBUTE_MAP': {'ID': ('symmetry_equiv', 'id', None, None),
                                             'POS_AS_XYZ': ('symmetry_equiv', 'pos_as_xyz', None, None),
                                             'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                           'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                       's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                           'MAP_MERGE_INDICES': {'symmetry_equiv': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                           'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                           'TABLE_ID': 'SYMMETRY_EQUIV',
                           'TABLE_NAME': 'symmetry_equiv',
                           'TABLE_TYPE': 'transactional'},
        'VALENCE_PARAM': {'ATTRIBUTES': {'ATOM_1': 'atom_1',
                                         'ATOM_1_VALENCE': 'atom_1_valence',
                                         'ATOM_2': 'atom_2',
                                         'ATOM_2_VALENCE': 'atom_2_valence',
                                         'B': 'B',
                                         'DETAILS': 'details',
                                         'ID': 'id',
                                         'REF_ID': 'ref_id',
                                         'RO': 'Ro',
                                         'STRUCTURE_ID': 'Structure_ID'},
                          'ATTRIBUTE_INFO': {'ATOM_1': {'NULLABLE': False,
                                                        'ORDER': 2,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': True,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 10},
                                             'ATOM_1_VALENCE': {'NULLABLE': False,
                                                                'ORDER': 3,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'INT',
                                                                'WIDTH': 10},
                                             'ATOM_2': {'NULLABLE': False,
                                                        'ORDER': 4,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': True,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 10},
                                             'ATOM_2_VALENCE': {'NULLABLE': False,
                                                                'ORDER': 5,
                                                                'PRECISION': 0,
                                                                'PRIMARY_KEY': True,
                                                                'SQL_TYPE': 'INT',
                                                                'WIDTH': 10},
                                             'B': {'NULLABLE': True,
                                                   'ORDER': 6,
                                                   'PRECISION': 6,
                                                   'PRIMARY_KEY': False,
                                                   'SQL_TYPE': 'FLOAT',
                                                   'WIDTH': 10},
                                             'DETAILS': {'NULLABLE': True,
                                                         'ORDER': 7,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 200},
                                             'ID': {'NULLABLE': True,
                                                    'ORDER': 8,
                                                    'PRECISION': 0,
                                                    'PRIMARY_KEY': False,
                                                    'SQL_TYPE': 'VARCHAR',
                                                    'WIDTH': 10},
                                             'REF_ID': {'NULLABLE': True,
                                                        'ORDER': 9,
                                                        'PRECISION': 0,
                                                        'PRIMARY_KEY': False,
                                                        'SQL_TYPE': 'VARCHAR',
                                                        'WIDTH': 10},
                                             'RO': {'NULLABLE': True,
                                                    'ORDER': 10,
                                                    'PRECISION': 6,
                                                    'PRIMARY_KEY': False,
                                                    'SQL_TYPE': 'FLOAT',
                                                    'WIDTH': 10},
                                             'STRUCTURE_ID': {'NULLABLE': False,
                                                              'ORDER': 1,
                                                              'PRECISION': 0,
                                                              'PRIMARY_KEY': True,
                                                              'SQL_TYPE': 'VARCHAR',
                                                              'WIDTH': 10}},
                          'ATTRIBUTE_MAP': {'ATOM_1': ('valence_param', 'atom_1', None, None),
                                            'ATOM_1_VALENCE': ('valence_param', 'atom_1_valence', None, None),
                                            'ATOM_2': ('valence_param', 'atom_2', None, None),
                                            'ATOM_2_VALENCE': ('valence_param', 'atom_2_valence', None, None),
                                            'B': ('valence_param', 'B', None, None),
                                            'DETAILS': ('valence_param', 'details', None, None),
                                            'ID': ('valence_param', 'id', None, None),
                                            'REF_ID': ('valence_param', 'ref_id', None, None),
                                            'RO': ('valence_param', 'Ro', None, None),
                                            'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                          'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID',
                                                            'ATOM_1',
                                                            'ATOM_1_VALENCE',
                                                            'ATOM_2',
                                                            'ATOM_2_VALENCE'),
                                             'TYPE': 'UNIQUE'},
                                      's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                          'MAP_MERGE_INDICES': {'valence_param': {'ATTRIBUTES': ('atom_1',
                                                                                 'atom_1_valence',
                                                                                 'atom_2',
                                                                                 'atom_2_valence'),
                                                                  'TYPE': 'EQUI-JOIN'}},
                          'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                          'TABLE_ID': 'VALENCE_PARAM',
                          'TABLE_NAME': 'valence_param',
                          'TABLE_TYPE': 'transactional'},
        'VALENCE_REF': {'ATTRIBUTES': {'ID': 'id', 'REFERENCE': 'reference', 'STRUCTURE_ID': 'Structure_ID'},
                        'ATTRIBUTE_INFO': {'ID': {'NULLABLE': False,
                                                  'ORDER': 2,
                                                  'PRECISION': 0,
                                                  'PRIMARY_KEY': True,
                                                  'SQL_TYPE': 'VARCHAR',
                                                  'WIDTH': 10},
                                           'REFERENCE': {'NULLABLE': True,
                                                         'ORDER': 3,
                                                         'PRECISION': 0,
                                                         'PRIMARY_KEY': False,
                                                         'SQL_TYPE': 'VARCHAR',
                                                         'WIDTH': 200},
                                           'STRUCTURE_ID': {'NULLABLE': False,
                                                            'ORDER': 1,
                                                            'PRECISION': 0,
                                                            'PRIMARY_KEY': True,
                                                            'SQL_TYPE': 'VARCHAR',
                                                            'WIDTH': 10}},
                        'ATTRIBUTE_MAP': {'ID': ('valence_ref', 'id', None, None),
                                          'REFERENCE': ('valence_ref', 'reference', None, None),
                                          'STRUCTURE_ID': (None, None, 'datablockid()', None)},
                        'INDICES': {'p1': {'ATTRIBUTES': ('STRUCTURE_ID', 'ID'), 'TYPE': 'UNIQUE'},
                                    's1': {'ATTRIBUTES': ('STRUCTURE_ID',), 'TYPE': 'SEARCH'}},
                        'MAP_MERGE_INDICES': {'valence_ref': {'ATTRIBUTES': ('id',), 'TYPE': 'EQUI-JOIN'}},
                        'TABLE_DELETE_ATTRIBUTE': 'STRUCTURE_ID',
                        'TABLE_ID': 'VALENCE_REF',
                        'TABLE_NAME': 'valence_ref',
                        'TABLE_TYPE': 'transactional'}
    }

    def __init__(self, verbose=True, log=sys.stderr):
        super(PdbxSchemaDef, self).__init__(databaseName=PdbxSchemaDef._databaseName, schemaDefDict=PdbxSchemaDef._schemaDefDict,
                                            verbose=verbose, log=log)


if __name__ == "__main__":
    sd = PdbxSchemaDef()
    tableIdList = sd.getTableIdList()

    for tableId in tableIdList:
        aIdL = sd.getAttributeIdList(tableId)
        tObj = sd.getTable(tableId)
        attributeIdList = tObj.getAttributeIdList()
        attributeNameList = tObj.getAttributeNameList()
        sys.stdout.write("Ordered attribute Id   list %s\n" % (str(attributeIdList)))
        sys.stdout.write("Ordered attribute name list %s\n" % (str(attributeNameList)))
        #
        mAL = tObj.getMapAttributeNameList()
        sys.stdout.write("Ordered mapped attribute name list %s\n" % (str(mAL)))

        mAL = tObj.getMapAttributeIdList()
        sys.stdout.write("Ordered mapped attribute id   list %s\n" % (str(mAL)))

        cL = tObj.getMapInstanceCategoryList()
        sys.stdout.write("Mapped category list %s\n" % (str(cL)))
        for c in cL:
            aL = tObj.getMapInstanceAttributeList(c)
            sys.stdout.write("Mapped attribute list in %s :  %s\n" % (c, str(aL)))
